/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client;

import javax.swing.JDialog;
import javax.swing.JFrame;
import javax.swing.SwingUtilities;
import javax.swing.UIManager;

import mot.client.swing.window.etc.LoadProgressWindow;
import mot.client.swing.window.etc.StartupWindow;
import mot.client.swing.window.main.MainWindow;
import mot.common.util.Logger;
import mot.common.util.PropertyManager;

/**
 * Main class that will start the program
 */
public class Main  {
	
    public Main() {
        Logger.clearContents();
        try {
        	//
        	// We run the show() methods for the windows from the dispatcher thread because
        	// show() does not to be as thread safe as it should be - when opening multiple
        	// windows it can fail!
        	//
            Runnable runner = new Runnable() {
                public void run() {
                	try {
                        UIManager.setLookAndFeel(PropertyManager.getMandatory("look.and.feel"));
                        JFrame.setDefaultLookAndFeelDecorated(true);	// to decorate frames
                        JDialog.setDefaultLookAndFeelDecorated(true);	// to decorate dialogs
                        if (!MotCommandLineOptions.getSkipLoadProgressWindow()) {
                        	new LoadProgressWindow(null);
                        }
                        MainWindow.getInstance();
                        new StartupWindow();
                	} catch (Exception ex) {
                		Logger.logError("Main.Main() Failed due to error", ex);
                	}
                }
            };
            try {
                SwingUtilities.invokeLater(runner);
            } catch (Exception ex) { 
            	Logger.logError("", ex);
            }
        } catch (Exception e) {
            Logger.logError("Main.Main() Failed due to error ",e);
        }
    }

    /**
     * The Main Class for running a single user local client game.
     */
    public static void main(String[] args) {
    	MotCommandLineOptions.setOptions(args);
		Main main = new Main();
    }
}