/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 * 
 */
package mot.client.actions;

import java.util.List;

/**
 * This represents an action that is to be taken when a user 
 * clicks or double clicks on an object. 
 */
public class IndexedSelectionPolicy implements MultipleMatchSelectionPolicy {

	private int nextIndex = 0;
	
	public IndexedSelectionPolicy() {
	}
	
	/**
	 * Each time selectFrom is called it returns the next object in the list items.
	 */
	public Object selectFrom(List items) {
		if (nextIndex >= items.size()) {
			nextIndex = 0;
		}
		if (items.size() == 0) {
			return null;
		}
		return items.get(nextIndex++);
	}
	
	public void moveToStart() {
		nextIndex = 0;
	}
}
