/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 * 
 */
package mot.client.actions;

import java.util.List;

/**
 * When an ActiveRectangleList contains multiple objects located at the point
 * on the map which the user clicks, which one shoudl be selected for execution?
 * use this interface to define mechanisms for selecting the correct object from
 * the list of matching objects. 
 */
public interface MultipleMatchSelectionPolicy {
	/**
	 * Select the next object from the list of objects passed in that the user is
	 * is selecting.
	 * @param items The list of items to select from.
	 * @return The next item selected
	 */
	public Object selectFrom(List items);
	
	/**
	 * Tells the selection policy that the next item to be selected should be the 
	 * first from the list. 
	 */
	public void moveToStart();
}
