/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */package mot.client.alarms;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.net.URL;

import javax.swing.SwingUtilities;

import mot.common.bean.Settings;
import mot.common.util.Comp;
import mot.common.util.Logger;
import mot.common.util.PropertyManager;

public class LatestVersionFetcher extends Thread {

	private String latestVersion;

	public void run() {
		try {
			Settings settings = Settings.getInstance();
			if (settings.isAppletMode()) {
				return;
			}
			long timeNow = System.currentTimeMillis();
			settings.setTimeVersionChecked(timeNow);
			Settings.getInstance().save();
			latestVersion = fetchLatestVersion();
			if (Logger.isDebug()) {
				Logger.logDebug("LatestVersionFetcher.run() version="+latestVersion);
			}
			if (latestVersion != null) {
				if (isNewerVersion(latestVersion)) {
					settings.setLatestVersion(latestVersion);
					Settings.getInstance().save();
				}
				SwingUtilities.invokeLater(new Runnable() {
					public void run() {
						try {
							AlarmSystem.getInstance().checkLatestVersion(latestVersion);
						} catch (Exception e) {
							Logger.logError("", e);
						}
					}
				});
			}
		} catch (Exception e) {
			Logger.logError("", e);
		}
	}

	private String fetchLatestVersion() throws IOException {
		URL url = new URL("http://www.masteroftactics.org/latestversion.txt");
	    InputStream is = url.openConnection().getInputStream();
	    BufferedReader reader = new BufferedReader( new InputStreamReader( is )  );
	    StringBuffer sb = new StringBuffer();
	    String line = null;
	    int qty = 0;
	    while( ( line = reader.readLine() ) != null )  {
	    	if (qty > 0) sb.append('\n');
	       sb.append(line);
	       qty++;
	    }
	    reader.close();
	    return sb.toString();
	}

	private static final String DEVELOPMENT_VERSION = "@@@_Development_@@@";
	
	public static boolean isNewerVersion(String latestVersion) {
        double latest = new Double(latestVersion);
        String version = PropertyManager.getVersion();
        if (Comp.same(version, DEVELOPMENT_VERSION)) version = "Version 1.09 - 2014-01-23";
        int i1 = version.indexOf(' ');
        int i2 = version.indexOf(' ', i1+1);
		String versionStr = version.substring(i1,i2);
		double current = new Double(versionStr);
		return (latest > current);
	}

	
}
