/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.animation;

import mot.client.sounds.Sound;
import mot.common.util.ApplicationError;

public class BattleAnimationSound {
	
    /**
     * This is a sound to be played while this animation is active.
     */
    private Sound sound;
    
    /**
     * This is the stage of the animation that this sound should be 
     * played at. Not all animation sounds start at the beginning of
     * the animation, some start half way through etc.
     * This should should only be stared when the owning animation
     * reaches this stage!
     */
    private int stage;

    public BattleAnimationSound(Sound sound, int stage) {
		this.sound = sound;
		this.stage = stage;
	}

	public void playSound() throws ApplicationError {
		sound.play();
	}

	public void stopSound() {
		sound.stop();
	}

	public Sound getSound() { return sound; }
	public int getStage() { return stage; }

}
