/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.animation;

import java.util.ArrayList;

import mot.client.actions.ActiveRectangle;
import mot.client.swing.window.galaxy.TrailAnimation;
import mot.client.swing.window.galaxy.TrailAnimationRange;

/**
 * This is a list of animations being displayed.
 */
public class GalaxyAnimationList  {

    /**
     * The list of animations being displayed on the screen.
     */
    private ArrayList list = new ArrayList();
    
    /**
     * This is a temporary animation used to display the range a craft can travel
     */
    private TrailAnimationRange rangeAnimation;

    public GalaxyAnimationList() {
    }

    public ArrayList getList() {
        return list;
    }

    public GalaxyAnimation [] getAll() {
    	if (list == null || list.size() == 0) {
    		return null;
    	} else {
    		return (GalaxyAnimation[]) list.toArray(new GalaxyAnimation[list.size()]);
    	}
    }

    public void setList(ArrayList list) {
        this.list = list;
    }
    
    public void add(GalaxyAnimation a) {
        list.add(a);
    }
    
    public void add(GalaxyAnimation [] a) {
        if (a == null) return;
        for (int i=0; i<a.length; i++) {
        	add(a[i]);
        }
    }
    
    public void remove(GalaxyAnimation a) {
        if (a == rangeAnimation) {
        	removeRangeAnimation();
        } else {        	
        	list.remove(a);
        }
    }
    
    public void remove(BattleAnimation a) {
        list.remove(a);
    }
    
    public void removeAll() {
        list.clear();
        rangeAnimation = null;
    }
    
    public void setRangeAnimation(TrailAnimationRange a) {
    	removeRangeAnimation();
    	if (a != null) {
	        list.add(a);
	        rangeAnimation = a;
    	}
    }
    
    public boolean containsTrailAnimation(ActiveRectangle from, ActiveRectangle to) {
    	GalaxyAnimation[] all = getAll();
    	if (all == null) return false;
    	for (int i = 0; i < all.length; i++) {
			if (all[i] instanceof TrailAnimation) {
				TrailAnimation ta = (TrailAnimation) all[i];
				if (ta.getSource().equals(from) && ta.getDestination().equals(to)) {
					return true;
				}
			}
		}
    	return false;
    }
    
    public void removeRangeAnimation() {
    	if (rangeAnimation != null) {    		
    		list.remove(rangeAnimation);
    		rangeAnimation = null;
    	}
    }
    
    public int getQuantity() {
        return list.size();
    }
   
}