/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.animation;

import java.util.ArrayList;

/**
 * Contains all orbits around a given star.
 * 
 * A star has an orbit description for every planet in orbit around it.
 * 
 * This is purely a UI concern - The engine is not aware about the 
 * details of a planets orbit around a star.
 * @see GalaxyAnimationRegister for more details
 */
public class GalaxyOrbitCollection {
	
	/**
	 * This is a list of OrbitDescription objects. Each object describes 
	 * an object in orbit around a star
	 */
	private ArrayList orbits = new ArrayList();
	
	public GalaxyOrbitCollection() {
	}
	
	public void add(GalaxyOrbitDescription od) {
		orbits.add(od);
	}
	
	public int getQtyOrbits() {
		return orbits.size();
	}
	 
	public GalaxyOrbitDescription getOrbitWithIndex(int index) {
		return (GalaxyOrbitDescription) orbits.get(index);
	}

}
