/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.animation;

import java.awt.Container;

import mot.client.deligates.ImageObjectDelegate;
import mot.client.deligates.PlayerDelegate;
import mot.client.deligates.UserPlayerDelegate;
import mot.common.util.ApplicationError;

/**
 * A window that contains animations must implement this interface. 
 * This interface is used to the animation package to query the container about
 * the status of the animated objects and the.
 * This is required for a window to display weapon fire animations, craft destroyed
 * animations etc.
 */
public interface GraphicalAnimationContainer {
	
	/**
	 * @return The object the Image that is currently selected by the user (or null) 
	 */
	ImageObjectDelegate getImageSelection();

	/**
	 * @return The player that owes this window (container)
	 */
	UserPlayerDelegate getWindowOwner();

	/**
	 * @return The window that will be used to display objects in this container.
	 */
	Container getContainer();

	/**
	 * @return True if and only if the image object passed in is visible in the container 
	 * returned by the getContainer() method on this interface. 
	 */
	boolean isVisible(ImageObjectDelegate imageObject) throws ApplicationError;

	/**
	 * @return The owner (player who owned the object being animated) of the active animation in the window.
	 * Returns null if there are is nothing being animated;
	 * @throws ApplicationError 
	 */
	PlayerDelegate getOwnerOfActiveAnimation() throws ApplicationError;

	/**
	 * @return The numbers of animations in progress and queued to be displayed at this point of time;
	 * @throws ApplicationError 
	 */
	int getQtyAnimations() throws ApplicationError;
}
