/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.bean;

import java.util.ArrayList;

import mot.client.deligates.CraftDelegate;
import mot.common.designs.CraftDesign;
import mot.common.util.ApplicationError;

/**
 * 
 */
public class CraftDelegateBundle {

    private ArrayList<CraftDelegate> content;

    public CraftDelegateBundle() {
    }
    
	public CraftDelegateBundle(CraftDelegate v) {
		add(v);
	}

	public void add(CraftDelegate v) {
		if (content == null) content = new ArrayList<CraftDelegate>();
		content.add(v);
	}
	
	public int getQuantity() {
		if (content == null) {
			return 0;
		} else {
			return content.size();
		}
	}
	
	public CraftDelegate getCraft(int index) {
		if (content == null || content.size() <= index ) {
			return null;
		} else {
			return content.get(index);
		}
	}
	
	public boolean firstCraftIsSameDesign(CraftDelegate other) throws ApplicationError {
		if (content == null || other == null) {
			return false;
		} else {
			CraftDelegate c = content.get(0);
			CraftDesign cd1 = c.getCraftDesign();
			CraftDesign cd2 = other.getCraftDesign();
			return cd1.same(cd2);
		}
	}
}
