/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.bean;

import java.io.File;
import java.net.URL;

import mot.common.bean.CraftGraphics;
import mot.common.bean.PlayerColor;
import mot.common.bean.Size;
import mot.common.factory.GraphicsFactory;
import mot.common.util.ApplicationError;
import mot.common.util.Logger;

public class CraftGraphicsWrapper {

    public static String getDefaultImageNoError(String hullName) {
    	try {
           	CraftGraphics craftGraphics = GraphicsFactory.getRaceGraphicsList().getHullGraphics("Monster", hullName);
           	return getImage(craftGraphics, null);
		} catch (ApplicationError e) {
			Logger.logError("Unable to get Thumb Image", e);
			return null;
		}
    }
    
    public static String getImageThumbNoError(String hullName) {
    	try {
    		CraftGraphics craftGraphics = GraphicsFactory.getRaceGraphicsList().getHullGraphics("Monster", hullName);
            String image = CraftGraphics.CRAFT_IMAGE_FOLDER+craftGraphics.getPictureNormal() + "_thumb" + craftGraphics.getFileExtension();
        	URL fileUrl = ClassLoader.getSystemResource(image);
            if (fileUrl != null) {
            	return image;
            } else {
            	return getImage(craftGraphics, null);
            }
		} catch (ApplicationError e) {
			Logger.logError("Unable to get Thumb Image", e);
			return null;
		}
    }
    
    public static String getImage(String ownerName, String hullName, PlayerColor pc) throws ApplicationError {
	    CraftGraphics craftGraphics = GraphicsFactory.getRaceGraphicsList().getHullGraphics(ownerName, hullName);
       	return getImage(craftGraphics, pc);
    }
    
    public static String getImage(CraftGraphics craftGraphics, PlayerColor pc) throws ApplicationError {
        String colorName  = "";
        if (pc != null) colorName = pc.getName();
        String image = CraftGraphics.CRAFT_IMAGE_FOLDER+craftGraphics.getPictureNormal() + "_" + colorName + craftGraphics.getFileExtension();
    	URL fileUrl = ClassLoader.getSystemResource(image);
        if (fileUrl == null) {
            image = CraftGraphics.CRAFT_IMAGE_FOLDER+craftGraphics.getPictureNormal() + craftGraphics.getFileExtension();
        }
       	return image;
    }

    public static String getCloakedImage(CraftGraphics craftGraphics, PlayerColor pc) throws ApplicationError {
        String colorName  = "";
        if (pc != null) colorName = pc.getName();
        String image = CraftGraphics.CRAFT_IMAGE_FOLDER+craftGraphics.getPictureCloaked() + "_" + colorName + craftGraphics.getFileExtension();
    	URL fileUrl = ClassLoader.getSystemResource(image);
        if (fileUrl == null) {
            image = CraftGraphics.CRAFT_IMAGE_FOLDER+craftGraphics.getPictureCloaked() + craftGraphics.getFileExtension();
        }
    	fileUrl = ClassLoader.getSystemResource(image);
        if (fileUrl == null) {
        	return getImage(craftGraphics, pc);
        }
       	return image;
    }

    public static String getSmallImage(String ownerName, String hullName, PlayerColor pc) throws ApplicationError {
	    CraftGraphics craftGraphics = GraphicsFactory.getRaceGraphicsList().getHullGraphics(ownerName, hullName);
        String colorName  = "";
        if (pc != null) colorName = pc.getName();
        String image = CraftGraphics.CRAFT_IMAGE_FOLDER+craftGraphics.getPictureSmall() + "_" + colorName + craftGraphics.getFileExtension();
    	URL fileUrl = ClassLoader.getSystemResource(image);
        if (fileUrl == null) {
            image = CraftGraphics.CRAFT_IMAGE_FOLDER+craftGraphics.getPictureSmall() + craftGraphics.getFileExtension();
            if ( !(new File(image).exists()) ) {
            	image = getImage(craftGraphics, pc);
            }
        }
       	return image;
    }

    public static Size getBiggestImage() throws ApplicationError {
	    CraftGraphics biggestCraft = GraphicsFactory.getRaceGraphicsList().getBiggestCraft();
    	if (biggestCraft == null) {
    		return new Size(80,80);
    	} else {
    		return biggestCraft.getSize();
    	}
    }
}
