/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.bean;

import mot.client.deligates.UserPlayerDelegate;
import mot.client.swing.window.main.MainWindowConfig;
import mot.common.util.Logger;

public class GameEditor {
	
	private static final String MOT_EDITOR_SWING_WINDOW_EDITOR_WINDOW_CONFIG = "mot.editor.swing.window.EditorWindowConfig";
	private static Boolean hasEditor = null; 
	
	public static boolean hasEditor() {
		if (hasEditor != null) {
			return hasEditor;
		}
		try {
			hasEditor = (Class.forName(MOT_EDITOR_SWING_WINDOW_EDITOR_WINDOW_CONFIG) != null);
		} catch (ClassNotFoundException e) {
			hasEditor = false;
		}
		return hasEditor;
	}
	
	public static MainWindowConfig getEditorConfig(UserPlayerDelegate owner) {
		if (hasEditor != null && hasEditor) {
			return _getEditorConfig(owner);
		} else {
			return null;
		}
	}

	private static MainWindowConfig _getEditorConfig(UserPlayerDelegate owner) {
		try {
			Class configClass = Class.forName(MOT_EDITOR_SWING_WINDOW_EDITOR_WINDOW_CONFIG);
			MainWindowConfig editorConfig = (MainWindowConfig) configClass.newInstance();
			((GameEditorConfig)editorConfig).setOwner(owner.getName());
			return editorConfig;
		} catch (ClassNotFoundException e) {
			return null; 
		} catch (InstantiationException e) {
			Logger.logError("", e);
			return null;
		} catch (IllegalAccessException e) {
			Logger.logError("", e);
			return null;
		}
	}
}
