/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.bean;

import mot.common.bean.GalaxyDefinitions;
import mot.common.technology.Technology;
import mot.common.util.ApplicationError;

public class PotentialResearchProject implements ResearchProject {

	private Technology technology;
	private Double fromSalvageProbability;
	
	public PotentialResearchProject(Technology technology) {
		this.technology = technology;
		this.fromSalvageProbability = null;
	}

	public PotentialResearchProject(Technology technology, Double fromSalvageProbability) {
		this.technology = technology;
		this.fromSalvageProbability = fromSalvageProbability;
	}

	public int getWork() {
		return 0;
	}

	public Technology getTechnology() throws ApplicationError {
		return technology;
	}

	public double getFromSalvageProbability() {
		if (fromSalvageProbability == null) {
			return 0.0;
		} else {
			return fromSalvageProbability;
		}
	}

	public int getCostToResearch() throws ApplicationError {
    	Technology technology = getTechnology();
    	if (technology != null) {
    		if (fromSalvageProbability != null) {
    			int cost = technology.getCostToResearch()*GalaxyDefinitions.FROM_SALVAGE_COST_FACTOR;
    			return cost;
    		} else {
    			int cost = technology.getCostToResearch();
    			return cost;
    		}
    	} else {
    		return 0;
    	}
	}

	public String getProjectDescription() throws ApplicationError {
		return "Start researching "+technology.getName();
	}

	public boolean isResearchingSalvage() {
		return fromSalvageProbability != null && fromSalvageProbability > 0.0;
	}

}
