/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.coms;

import javax.swing.SwingUtilities;

import mot.client.proxy.CommandResponseProcessor;
import mot.client.swing.window.main.MainWindow;
import mot.common.command_results.CommandResult;
import mot.common.util.Logger;
import mot.common.util.ValidationError;

public class SendResponseToGuiThread implements Runnable {

	private CommandResponseProcessor responseProcessor;
	private CommandResult cr;
	
	public SendResponseToGuiThread(CommandResponseProcessor responseProcessor, CommandResult cr) {
		this.responseProcessor = responseProcessor;
		this.cr = cr;
	}
	
	public void run() {
		// now in GUI thread
		try {
			responseProcessor.processCommandResponse(cr);
		} catch (ValidationError e) {
			MainWindow.getExestingInstance().showTemporaryMessage(e.getMessage(), true, null, 0);
		} catch (Throwable e) {
			Logger.logError("Process Response Failed", e);
		}
	}
	
	public static void send(CommandResponseProcessor responseProcessor, CommandResult commandResponse) {
		SwingUtilities.invokeLater(new SendResponseToGuiThread(responseProcessor, commandResponse));	
	}
	
}
