/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.deligates;

import mot.common.bean.CraftGraphics;
import mot.common.bean.CraftState;
import mot.common.bean.PlayerColor;
import mot.common.util.ApplicationError;
import mot.client.deligates.CraftDelegate;
import mot.client.deligates.BattleObjectDelegate;

public interface BattleCraftDelegate extends BattleObjectDelegate {
	
    /**
     * NOTE - The next craft in a battle is only selected if there is no movement
     * remaining AND all weapons have been fired. @see getWeapons() for details
     * of weapons fired.
     * @return The remaining movement this craft has available (this turn).
     * The value is between 0 and 1 where 0 implies the objects turn has finished.
     */
    public double getMoveRemainingAsPercent();

    /**
     * @return The craft that this battle craft represents.
     */
    public CraftDelegate getCraft() throws ApplicationError;

    /**
     * If a craft in a battlefield is cloaked - It may not be visible.
     * @return true if and only if this player's scanners are strong enough to see this craft through
     * its shields at the distance from this player's crafts / planets.
     */
    public boolean isVisible() throws ApplicationError;

    /**
     * @return True iff this craft is an attacker in this battle.
     */
	public boolean isAggressor();

	/**
	 * @return True iff this craft is a hologram.
	 */
	public boolean isHologram();

	/**
	 * @return True iff this craft is an orbital.
	 */
	public boolean isOrbital();

	/**
	 * @return The state of this craft.
	 * @throws ApplicationError 
	 */
	public CraftState getState() throws ApplicationError;

	public CraftGraphics getCraftGraphics() throws ApplicationError;

	public String getImage(PlayerColor pc, Boolean isVisible) throws ApplicationError;

    public int getSpeed();
    
    public int getTurningSpeed();

}