/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.deligates;

import mot.client.deligates.cache.BattleDelegateCache;
import mot.common.bean.AnimatedBattleAreaDetails;
import mot.common.bean.NameList;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;
import mot.common.vo.OrbitVO;

public interface BattleDelegate extends Delegate {

	/**
	 * All battles have a unique name
	 */
	public String getName();
	
	/**
	 * @return The orbit this battle is taking place at.
	 */
    public OrbitVO getOrbit();
    
    /**
     * @return If a player has attacked a planet then this will not be null and is the planet's representative in battle.
     * @throws ApplicationError
     */
    public BattlePlanetDelegate getPlanet() throws ApplicationError;

    /**
     * @return All the crafts in the battle (includes real crafts, battle stations, holo crafts)
     * @throws ApplicationError
     */
    public BattleCraftDelegate[] getCrafts() throws ApplicationError;
    
    /**
     * @return All automatons in the battle (includes missiles, mines, droid mines) .
     * @throws ApplicationError
     */
    public BattleAutomatonDelegate[]  getAutomatons() throws ApplicationError;
    
    public int getTurn() throws ApplicationError;
    
    public boolean hasEnded() throws ApplicationError;
    public boolean isWinner(PlayerDelegate player) throws ApplicationError;
    
    /**
     * Examples of these types of animations are special distortions, asteroid fields and wreckage.
     * These should not be confused with event animations that are more temporary and only the 
     * client side is aware of.
     * @return A list of areas on the battle map that contains an animations to be displayed. 
     */
	public AnimatedBattleAreaDetails[] getAnnimatedBattleAreas() throws ApplicationError;
    
    /**
     * @return TRUE iff this play was in the battle at any point in time.
     */
	public boolean containsStartingPlayer(PlayerDelegate owner);
	
    public boolean equals(BattleDelegate other) throws ApplicationError;
    
    /**
     * @return A long battle name (not just the name of the battle).
     */
    public String getBattleName();

    /**
	 * @return List of player names that were attacked in this battle.
     * @throws ApplicationError
     */
    public NameList getVictims() throws ApplicationError;
    
    /**
	 * @return List of player names that are the attackers in this battle.
     */
    public NameList getAggressors() throws ApplicationError;

    /**
     * @return The next battle object to move in the battle owned by a user. 
     * @throws ApplicationError
     * @throws ValidationError 
     */
    public BattleObjectDelegate getNextObjectToMove() throws ApplicationError;


    /**
     * @return The cache of all accumulated delegates in this battle.
     */
	public BattleDelegateCache getDelegateCache();

	public boolean inNebula();

}