/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.deligates;

import mot.common.bean.CraftState;
import mot.common.technology.Weapon;
import mot.common.util.ApplicationError;
import mot.common.vo.WeaponInstanceVO;

public interface BattleObjectDelegate extends ImageObjectDelegate {
	
	/**
	 * @return The name of the battle this object is in.
	 */
    public String getBattleName();
    
    /**
     * NOTE - Than can be much faster than getOwner() - so if you only need the name
     * use this method! It does not have to fetch or update all the player information
     * from the server.
     * @return The name of the player that owns this object on the battle field.
     */
    public String getOwner() throws ApplicationError;
    
    /**
     * @param p A player in this game
     * @return True if this craft is owned by the player p
     */
    public boolean isOwnedBy(PlayerDelegate p) throws ApplicationError;

    /**
     * An object is controlled by a player is the player owns that object OR
     * has used some Mine Control weapon to take temporary possession of it.
     * @param p A player in this game
     * @return True if this craft is controlled by the player p
     */
    public boolean isControlledBy(PlayerDelegate p) throws ApplicationError;

    /**
     * This may be used to fetch all weapons and find out how many of those weapons 
     * have been fired already.
     * @return The details and status of all weapons on this object. 
     */
    public WeaponInstanceVO [] getWeapons() throws ApplicationError;
	public WeaponInstanceVO getWeapon(Weapon w) throws ApplicationError;

    /**
     * @return The state of this object at this point in time.
     * @throws ApplicationError 
     */
    public CraftState getState() throws ApplicationError;

	/**
	 * return True iff this craft has fighters than can be launched now in this battle.
	 */
	public boolean hasFightersToLaunch();

	/**
	 * Uses cached state that must be flushed using flushCache() when owner changes.
	 * @return The delegate for the owner of this object.
	 */
	public PlayerDelegate getOwnerDelegate();

    public int getAnimationRotation() throws ApplicationError;

	public void flushCache();

	public BattleObjectDelegate getBattleObjectDelegate() throws ApplicationError;

}
