/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.deligates;

import mot.client.deligates.debug.DeligateDebugState;
import mot.common.bean.CraftGraphics;
import mot.common.designs.CraftDesign;
import mot.common.util.ApplicationError;
import mot.common.vo.CraftVO;

public interface CraftDelegate extends MoveableOwnedObjectDelegate {

    /**
     * @return A value between 0 and 1 representing the health of this craft (0 is not damage).
     */
    public double getDamageAsPercent() throws ApplicationError;
    
    /**
     * @return A value between 0 and 1 representing the build quality of this craft (1.0 is perfect build quality).
     */
    public double getBuildQualityAsPercent() throws ApplicationError;
    
    /**
     * The owner may be different than the origin race after a craft has been invaded.
     * ALSO - The origin species of a craft is the species of the planet that created the craft which can also be different to the owner!
     * @return The name of the race that created an operate this craft
     * @throws ApplicationError
     */
    public String getOrigin() throws ApplicationError;
	PlayerDelegate getOriginDelegate() throws ApplicationError;
    
    /**
     * @return The name of the fleet this craft is part of OR null if this craft is not in a fleet.
     * @throws ApplicationError
     */
	public String getFleet() throws ApplicationError;
	public FleetDelegate getFleetDelegate() throws ApplicationError;

	/**
	 * @return The design of this craft.
	 * @throws ApplicationError
	 */
    public CraftDesign getCraftDesign() throws ApplicationError;
    
	public CraftGraphics getCraftGraphics() throws ApplicationError;
	
    public int getMaintenanceCost();

	boolean canColonise(PlanetDelegate pd) throws ApplicationError;

	public PlanetDelegate[] getColonisablePlanets(PlanetDelegate[] planets, boolean includeColonies) throws ApplicationError;

	public CraftVO getCraftValue();

	// For debugging only (stores trace information during a battle so animation anomalies can be detected).
	public void setDebugState(DeligateDebugState debugState);
	public DeligateDebugState getDebugState();


}