/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.deligates;

import mot.common.bean.Area;
import mot.common.bean.LocatedObject;
import mot.common.bean.Location;
import mot.common.bean.PlayerColor;
import mot.common.bean.Size;
import mot.common.util.ApplicationError;

public interface ImageObjectDelegate extends NamedObjectDelegate, LocatedObject {
	
    /**
     * The location can be anywhere in the galaxy map / battle map. However, if this 
     * object is in orbit around a stellar object then this location should be the 
     * same location as the stellar object's and getOrbit() will not return null.
     * @return The location of this object.
     * @throws ApplicationError
     */
	public Location getLocation();
	
    public int getDirection() throws ApplicationError;
    
    public int getDirection(Location loc) throws ApplicationError;
    
    /**
     * @return The area on the screen that this object occupies. This is NOT the size of the image. 
     * It is the size of the image plus space (INTER_CRAFT_GAP) around the image. 
     * @throws ApplicationError
     */
	public Area getArea() throws ApplicationError;

	/**
	 * @return The size of the image.
	 * @throws ApplicationError
	 */
    public Size getImageSize() throws ApplicationError;

    /**
     * This is usually the craft image, but if a craft is cloaked it will be the cloaked
     * craft image. Note that the image may change depending on the player viewing
     * the craft - even a cloaked craft is visible to the owner and may be visible to some
     * players but not other in the battle.
     * Everything other than a craft is ALWAYS visible. If a mine is NOT visible to a player then
     * it is the server's responsibility not to send its image information!
     * @return The name of the image to use.
     * @throws mot.common.util.ApplicationError
     */
    public String getImage() throws ApplicationError;
    
    /**
     * Same as getImage() but returns the image that would be used if it was owned by a different player
     * of the name ownerName. 
     */
    public String getImage(PlayerColor pc, Boolean isVisible) throws ApplicationError;

    public boolean isSelectableBy(PlayerDelegate player) throws ApplicationError;
    
    public boolean equals(ImageObjectDelegate other);

	public boolean isDestroyed();
}