/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.deligates;
import java.util.ArrayList;
import java.util.Iterator;

import mot.common.util.ApplicationError;

public class PlanetListDelegate implements Delegate {

    interface PlanetListDeligateComparator {
        /**
         * @return True if a is less than b 
         * @throws ApplicationError 
         */
    public boolean isBigger(PlanetDelegate a, PlanetDelegate b) throws ApplicationError;
    }

    private PlanetDelegate [] planets;

    public PlanetListDelegate(PlanetDelegate [] planets) {
        this.planets = planets;
    }


    public void setPlanets(PlanetDelegate[] planets) {
        this.planets = planets;
    }


    public PlanetDelegate[] getPlanets() {
        return planets;
    }
    
    public PlanetDelegate [] orderByName() throws ApplicationError {
        _order( new PlanetListDeligateComparator() {
            public boolean isBigger(PlanetDelegate a, PlanetDelegate b) { return a.getName().toLowerCase().compareTo(b.getName().toLowerCase()) < 0; }
        } );
        return planets;
    }
    
    public PlanetDelegate [] orderByPopulation() throws ApplicationError {
        _order( new PlanetListDeligateComparator() {
            public boolean isBigger(PlanetDelegate a, PlanetDelegate b) { return a.getPopulation() > b.getPopulation(); }
        } );
        return planets;
    }
    
    public PlanetDelegate [] orderByTerraform() throws ApplicationError {
        _order( new PlanetListDeligateComparator() {
            public boolean isBigger(PlanetDelegate a, PlanetDelegate b) { return a.getTeraforming() > b.getTeraforming(); }
        } );
        return planets;
    }
    
    public PlanetDelegate [] orderByProductionOutput() throws ApplicationError {
        _order( new PlanetListDeligateComparator() {
            public boolean isBigger(PlanetDelegate a, PlanetDelegate b) throws ApplicationError { return a.getProductionOutput() > b.getProductionOutput(); }
        } );
        return planets;
    }
    
    private void _order(PlanetListDeligateComparator comp) throws ApplicationError {
        ArrayList list = getAsList();
        if (list == null) return;
        PlanetDelegate [] t = new PlanetDelegate [list.size()];
        for (int i=0; i<planets.length; i++) {
            PlanetDelegate next = null;
            Iterator j = list.iterator();
            while (j.hasNext()) {
                PlanetDelegate p = (PlanetDelegate) j.next();
                if (next == null || comp.isBigger(p, next)) {
                    next = p;
                }
            }
            list.remove(next);
            t[i] = next;
        }
        planets = t;
    }
    
    public ArrayList getAsList() {
        if (planets == null) return null;
        ArrayList l = new ArrayList(planets.length);
        for (int i=0; i<planets.length; i++) {
            l.add(planets[i]);
        }
        return l;
    }
}

