/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.deligates;

import mot.client.bean.ResearchProject;
import mot.common.bean.GalaxyDefinitions;
import mot.common.technology.Technologies;
import mot.common.technology.Technology;
import mot.common.util.ApplicationError;
import mot.common.vo.ResearchProjectVO;

public class ResearchProjectDelegate implements ResearchProject,Delegate {
	
	private ResearchProjectVO researchProject;

	public ResearchProjectDelegate(ResearchProjectVO researchProject) {
		this.researchProject = researchProject;
	}

	public int getWork() {
		if (researchProject == null) {
			return 0;
		} else {
			return researchProject.getWork();
		}
	}
	
	public Technology getTechnology() throws ApplicationError {
		if (researchProject == null) {
			return null;
		} else {
			return Technologies.getTechnology(researchProject.getTechnology());
		}
	}
	
	public double getFromSalvageProbability() {
		if (researchProject == null) {
			return 0;
		} else {
			return researchProject.getFromSalvageProbability();
		}
	}
	
	public boolean isResearchingSalvage() {
		return researchProject != null && researchProject.getFromSalvageProbability() > 0.0;
	}

	public int getCostToResearch() throws ApplicationError {
    	Technology technology = getTechnology();
    	if (technology != null) {
    		double fromSalvageProbability = getFromSalvageProbability();
    		if (fromSalvageProbability > 0.0) {
    			int cost = technology.getCostToResearch()*GalaxyDefinitions.FROM_SALVAGE_COST_FACTOR;
    			return cost;
    		} else {
    			int cost = technology.getCostToResearch();
    			return cost;
    		}
    	} else {
    		return 0;
    	}
	}
	
    public String getProjectDescription() throws ApplicationError {
    	Technology technology = getTechnology();
    	if (technology != null) {
    		int cost = getCostToResearch();
    		double fromSalvageProbability = getFromSalvageProbability();
    		int work = getWork();
    		if (fromSalvageProbability > 0.0) {
    			return "Researching a "+technology.getTechType()+" called "+technology.getName()+" from salvage [ "+work+" of "+cost+" ]";
    		} else {
    			return "Researching a "+technology.getTechType()+" called "+technology.getName()+" [ "+work+" of "+cost+" ]";
    		}
    	} else {
    		return "Researching nothing";
    	}
    }


}