/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.deligates;

import mot.common.util.NameValuePairList;

/**
 * A Trade route is a link between two planets that is visible on the galaxy map 
 * that increases economic activity on each planet.
 * 
 * This representation of a TradeRoute object found in the engine code.
 *
 */
public interface TradeRouteDelegate extends NamedObjectDelegate {

	public SolarSystemDelegate getSolarSystem1();
	public String getSolarSystem1Name();

	public SolarSystemDelegate getSolarSystem2();
	public String getSolarSystem2Name();

	public int getStartDate();
	
	/**
	 * DOES NOT contain details of bonuses to planets NOT owned by you OR mining colonies
	 * @return A list of planet names and the output bonuses provided to that planet
	 */
	public NameValuePairList getIndustryOutput();
	
	/**
	 * @return The bonuses provided to planet by this trade route
	 */
	public int getIndustryOutput(String planetName);

	/**
	 * @return Total Industry output for all planets in this trade route
	 */
	public int getTotalIndustryOutput();
	
	/**
	 * DOES NOT contain details of bonuses to planets NOT owned by you OR mining colonies
	 * @return A list of planet names and the output bonuses provided to that planet
	 */
	public NameValuePairList getResearchOutput();
	
	/**
	 * @return The bonuses provided to planet by this trade route
	 */
	public int getResearchOutput(String planetName);

	/**
	 * @return Total Industry output for all planets in this trade route
	 */
	public int getTotalResearchOutput();
	
	public boolean contains(String solarSystemName);
	
	public boolean equals(String solarSystem1, String solarSystem2);

}