/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.deligates;

import mot.common.bean.NameList;
import mot.common.bean.PlayerResources;
import mot.common.designs.CraftDesign;
import mot.common.designs.CraftDesigns;
import mot.common.designs.CraftDesignsSupplier;
import mot.common.leaders.GeneralLeader;
import mot.common.leaders.GovenorLeader;
import mot.common.technology.Biotechnologies;
import mot.common.technology.Computers;
import mot.common.technology.Engines;
import mot.common.technology.Factories;
import mot.common.technology.Hulls;
import mot.common.technology.Laboratories;
import mot.common.technology.MiscTechnologies;
import mot.common.technology.Modules;
import mot.common.technology.Scanners;
import mot.common.technology.Shields;
import mot.common.technology.Specials;
import mot.common.technology.TechnologyList;
import mot.common.technology.TechnologyOwner;
import mot.common.technology.Theories;
import mot.common.technology.Weapons;
import mot.common.util.ApplicationError;
import mot.common.vo.OrbitVO;

public interface UserPlayerDelegate extends PlayerDelegate, TechnologyOwner, CraftDesignsSupplier {
    public String getTransportName() throws ApplicationError;

    public GeneralLeader getGeneralLeader() throws ApplicationError;
    public GovenorLeader getGovenorLeader() throws ApplicationError;

    /**
     * @return TRUE if this player (you) has assigned spies on player pd.
     */
	public boolean canViewDetails(PlayerDelegate pd) throws ApplicationError;

	public OrbitVO getFleetWayPoint() throws ApplicationError;

	public NameList getWeaponsToExcludeFromFireAll() throws ApplicationError;
	
    public ResearchProjectDelegate getResearchProject() throws ApplicationError;

    public CraftDesigns getCraftDesigns() throws ApplicationError;
	public CraftDesign getLastCraftDesigned() throws ApplicationError;

	public double getBuildQuality(String name);

	public TechnologyList getTechnologies() throws ApplicationError;
	public Biotechnologies getBiotechnologies() throws ApplicationError;
	public Computers getComputers() throws ApplicationError;
	public Engines getEngines() throws ApplicationError;
	public Factories getFactories() throws ApplicationError;
	public Hulls getHulls() throws ApplicationError;
	public Laboratories getLaboratories() throws ApplicationError;
	public Scanners getScanners() throws ApplicationError;
	public Shields getShields() throws ApplicationError;
	public Specials getSpecials() throws ApplicationError;
	public Weapons getWeapons() throws ApplicationError;
	public Modules getModules() throws ApplicationError;
	public Theories getTheories() throws ApplicationError;
	public MiscTechnologies getMiscTechnologies() throws ApplicationError;

    /**
     * The home solar system is usually defined as the original planet / solar system from which
     * the player started. However, if the player lost this planet then it is the oldest colony 
     * owned by this player.
     * @return The Home Solar System for this player.
     */
    public PlanetDelegate getHomePlanet() throws ApplicationError;
        
	/**
	 * @return A list of all resource bonuses this player receives each turn.
	 * @throws ApplicationError 
	 */
	public PlayerResources getPlayerResources() throws ApplicationError;
	
    /**
     * Not all technologies are available for all players - a random proportion of technologies
     * will never be available to a player. These are called missed technologies. This method 
     * will only return technologies in that list. 
     * @return All the technologies that this player could research now (dependencies have been
     * satisfied - see technology tree for details) but they are on the missed list.
     * @throws ApplicationError
     */
	public TechnologyList getMissedTechnologies() throws ApplicationError;

	public SolarSystemDelegate [] getSolarSystemsOwnedBy() throws ApplicationError;

    public int getNetIncome() throws ApplicationError;

    public int getQtyFreeTransport();
	public int getQtySpiesDefending() throws ApplicationError;

    public double getChanceToDiscoverSalvage();

    /**
     * @return List of treaty names between this player and the other
     * @throws ApplicationError 
     */
	public String[] getTreatyNames(PlayerDelegate craftOwner) throws ApplicationError;
    

}