/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.deligates.cache;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collection;
import java.util.Comparator;
import java.util.HashMap;
import java.util.Iterator;

import mot.client.deligates.BattleAutomatonDelegate;
import mot.client.deligates.BattleCraftDelegate;
import mot.client.deligates.BattleDelegate;
import mot.client.deligates.BattleObjectDelegate;
import mot.client.deligates.CraftDelegate;
import mot.client.deligates.FleetDelegate;
import mot.client.deligates.MoveableOwnedObjectDelegate;
import mot.client.deligates.PlanetDelegate;
import mot.client.deligates.PlayerDelegate;
import mot.client.deligates.RelationDelegate;
import mot.client.deligates.SolarSystemDelegate;
import mot.client.deligates.StellarObjectDelegate;
import mot.client.deligates.TradeRouteDelegate;
import mot.client.deligates.TransportDelegate;
import mot.client.deligates.UserPlayerDelegate;
import mot.client.deligates.mot.MotBlackHoleDelegate;
import mot.client.deligates.mot.MotComputerPlayerDelegate;
import mot.client.deligates.mot.MotCraftDelegate;
import mot.client.deligates.mot.MotFleetDelegate;
import mot.client.deligates.mot.MotMoveableOwnedObjectDelegate;
import mot.client.deligates.mot.MotPlanetDelegate;
import mot.client.deligates.mot.MotPlayerDelegate;
import mot.client.deligates.mot.MotRelationDelegate;
import mot.client.deligates.mot.MotSolarSystemDelegate;
import mot.client.deligates.mot.MotStellarObjectDelegate;
import mot.client.deligates.mot.MotTradeRouteDelegate;
import mot.client.deligates.mot.MotTransportDelegate;
import mot.client.deligates.mot.MotUserPlayerDelegate;
import mot.client.proxy.ProxyStore;
import mot.client.proxy.ServerProxy;
import mot.client.swing.window.main.MainWindow;
import mot.client.tutorials.TutorialSystem;
import mot.common.bean.Area;
import mot.common.bean.GalaxyDetails;
import mot.common.bean.Location;
import mot.common.bean.NameList;
import mot.common.bean.Rectangle;
import mot.common.bean.SectorOwnerGrid;
import mot.common.event.BattleEvent;
import mot.common.event.BattleStateUpdateEventAdapter;
import mot.common.event.MotEvent;
import mot.common.event.NewBattleEvent;
import mot.common.event.PlayerLoseEvent;
import mot.common.event.PlayerSurrenderEvent;
import mot.common.event.StateContainer;
import mot.common.event.StateUpdateEvent;
import mot.common.event.TradeRouteInvalidEvent;
import mot.common.technology.Technology;
import mot.common.technology.TechnologyList;
import mot.common.util.ApplicationError;
import mot.common.util.Comp;
import mot.common.util.Logger;
import mot.common.util.ValidationError;
import mot.common.vo.BattleObjectVO;
import mot.common.vo.BattleValueObject;
import mot.common.vo.BlackHoleVO;
import mot.common.vo.ComputerPlayerVO;
import mot.common.vo.CraftDesignUpdateVO;
import mot.common.vo.CraftDesignVO;
import mot.common.vo.CraftDesignsVO;
import mot.common.vo.CraftVO;
import mot.common.vo.DateVO;
import mot.common.vo.DeadPlayerVO;
import mot.common.vo.FleetVO;
import mot.common.vo.FlushCraftCacheVO;
import mot.common.vo.FlushDelegateCacheVO;
import mot.common.vo.MoveableOwnedObjectVO;
import mot.common.vo.NavigatorVO;
import mot.common.vo.OrbitVO;
import mot.common.vo.PlanetVO;
import mot.common.vo.PlayerConstantsVO;
import mot.common.vo.PlayerDetailsVO;
import mot.common.vo.PlayerTechnologiesVO;
import mot.common.vo.PlayerTechnologyVO;
import mot.common.vo.PlayerVO;
import mot.common.vo.RelationVO;
import mot.common.vo.RemoveMooVO;
import mot.common.vo.RenameListVO;
import mot.common.vo.RenameVO;
import mot.common.vo.ResearchProjectUpdateVO;
import mot.common.vo.SolarSystemVO;
import mot.common.vo.StellarObjectVO;
import mot.common.vo.TechnologyAvailableForResearchVO;
import mot.common.vo.TradeRouteInvalidVO;
import mot.common.vo.TradeRouteListVO;
import mot.common.vo.TradeRouteVO;
import mot.common.vo.TransportVO;
import mot.common.vo.UserPlayerVO;
import mot.common.vo.ValueObject;

/**
 * Delegates are cached on the client to prevent them from being re-created continuously.
 * This is purely an efficiency thing. For remote clients less information needs to be fetched
 * from the server while for local clients less objects are created. 
 * Locals Clients - Local delegates are write through so there should not by any 
 * synchronisation issues.
 * Remote Clients - Remote delegates must be refreshed frequently because they are working on
 * copies of the server's data that may get out of date!
 * 
 * NOTE - This cache must be flushed when a new game is started or loaded!
 *
 */




//
//		REMOVE THIS WHOLE PACKAGE
//		MAKE DELEGATES PROPER DELEGATES, MANAGE CACHING AND THEN CREATE A PROXY FOR ALL
//		DELEGATES TO COMMUNICAATE WITH SERVER.
//
public class DeligateCacheManager {
	
    private static SectorOwnerGrid sog = null;
    private static GalaxyDetails galaxyDetails = null;
    private static MotPlayerDelegate monsterPlayer = null;
	private static HashMap<String, PlayerDelegate> players = new HashMap();
	private static HashMap<String, PlayerDelegate> deadPlayers = new HashMap();
	private static HashMap<String, MoveableOwnedObjectDelegate> moos = new HashMap();
	private static HashMap sos = new HashMap();	
	private static HashMap planets = new HashMap();	
	private static HashMap<String, BattleDelegateCache> battles = new HashMap<String, BattleDelegateCache>();	
	private static Technology [] techsAvailableForResearch;
	private static TradeRouteDelegate[] tradeRoutes;
	private static RelationDelegate[] relations;
	private static int date;
	

    public static SectorOwnerGrid getSectorOwnerGrid() throws ApplicationError {
		return sog;
    }
    
	private static void flushSectorOwnerGrid() {
    	sog = null;
    }
    
    public static GalaxyDetails getGalaxyDetails() throws ApplicationError {
    	return galaxyDetails;
    }

    private static void flushGalaxyDetails() {
    	galaxyDetails = null;
    }
    
    private static void updatePlanetImages() throws ApplicationError {
    	if (planets != null) {
    		Collection keys = planets.values();
    		if (keys != null) {    			
    			for (Iterator i = keys.iterator(); i.hasNext();) {
    				PlanetDelegate planet = (PlanetDelegate) i.next();
    				planet.updateImages();
    			}
    		}
    	}
    }

    private static void updateCraftImages() throws ApplicationError {
    	if (moos != null) {
    		Collection keys = moos.values();
    		if (keys != null) {    			
    			for (Iterator i = keys.iterator(); i.hasNext();) {
    				MoveableOwnedObjectDelegate moo = (MoveableOwnedObjectDelegate) i.next();
    				moo.flushImageCache();
    			}
    		}
    	}
    }

	
	public static PlayerDelegate getPlayer(String name) {
		if (name == null) return null;
		if (Comp.same(name, monsterPlayer)) return monsterPlayer;
		PlayerDelegate player = (PlayerDelegate) players.get(name);
		if (player == null) {
			player = (PlayerDelegate) deadPlayers.get(name);
		}
		return player;
	}

	public static UserPlayerDelegate getUserPlayer(String name) {
		if (name == null) return null;
		UserPlayerDelegate player = (UserPlayerDelegate) players.get(name);
		if (player == null) {
			player = (UserPlayerDelegate) deadPlayers.get(name);
		}
		return player;
	}
	

	public static PlayerDelegate [] getPlayers() {
		Collection values = players.values();
		if (values != null && values.size() > 0) {
			return (PlayerDelegate[]) values.toArray(new PlayerDelegate[values.size()]);
		} else {
			return null;
		}
	}

	public static UserPlayerDelegate [] getUserPlayers() {
		Collection<PlayerDelegate> values = players.values();
		ArrayList r = null;
		if (values != null && values.size() > 0) {
			for (PlayerDelegate pd : values) {
				if (pd instanceof UserPlayerDelegate) {
					if (r == null) r = new ArrayList();
					r.add(pd);
				}
			}
			if (r != null) {
				return (UserPlayerDelegate[]) r.toArray(new UserPlayerDelegate[r.size()]);
			} else {
				return null;
			}
		} else {
			return null;
		}
	}

	public static void addPlayer(PlayerDelegate player) {
		if (player != null) {
			if (player.isMonsterPlayer()) {
				monsterPlayer = (MotComputerPlayerDelegate) player;
			} else {
				players.put(player.getName(), player);
			}
		}
	}

	public static void removePlayer(PlayerDelegate player) {
		if (player != null) {
			players.remove(player.getName());
			deadPlayers.put(player.getName(), player);
		}
	}

	public static void removeTradeRoute(String solarSystem1, String solarSystem2) {
		ArrayList<TradeRouteDelegate> l = null;
		if (tradeRoutes != null) {			
			for (int i = 0; i < tradeRoutes.length; i++) {
				if (!tradeRoutes[i].equals(solarSystem1, solarSystem2)) {
					if (l == null) l = new ArrayList<TradeRouteDelegate>();
					l.add(tradeRoutes[i]);
				}
			}
		}
		if (l == null) {
			tradeRoutes = null;
		} else {
			tradeRoutes = l.toArray(new TradeRouteDelegate[l.size()]);
		}
	}
	
	public static MoveableOwnedObjectDelegate getMoo(String name) {
		MoveableOwnedObjectDelegate moo = (MoveableOwnedObjectDelegate) moos.get(name);
		return moo;
	}
	
	public static CraftDelegate getCraft(String name) {
		CraftDelegate craft = (CraftDelegate) moos.get(name);
		return craft;
	}
	
	public static MoveableOwnedObjectDelegate [] getMoos() throws ApplicationError {
		Collection<MoveableOwnedObjectDelegate> mooList = moos.values();
		if (mooList != null && mooList.size() > 0) {
			ArrayList<MoveableOwnedObjectDelegate> r = new ArrayList();
			for (MoveableOwnedObjectDelegate moo : mooList) {
				if (moo instanceof CraftDelegate) {
					if (((CraftDelegate) moo).getFleet() == null) {
						r.add(moo);
					}
				} else {
					r.add(moo);
				}
			}
			MoveableOwnedObjectDelegate[] ra = (MoveableOwnedObjectDelegate[]) r.toArray(new MoveableOwnedObjectDelegate[r.size()]);
			if (TutorialSystem.isActive()) {
				Arrays.sort(ra, new Comparator<MoveableOwnedObjectDelegate>() {
					public int compare(MoveableOwnedObjectDelegate o1, MoveableOwnedObjectDelegate o2) {
						if (o1 != null && o2 != null) {
							return o1.getName().compareTo(o2.getName());
						} else {
							return 0;
						}
					}
				});
			}
			return ra;
		} else {
			return null;
		}
	}

	private static MoveableOwnedObjectDelegate [] getAllMoos() {
		Collection entrySet = moos.values();
		if (entrySet != null && entrySet.size() > 0) {
			return (MoveableOwnedObjectDelegate[]) entrySet.toArray(new MoveableOwnedObjectDelegate[entrySet.size()]);
		} else {
			return null;
		}
	}

	public static CraftDelegate[] getCrafts(PlayerDelegate owner) throws ApplicationError {
		Collection<MoveableOwnedObjectDelegate> entrySet = moos.values();
		ArrayList r = null;
		if (entrySet != null && entrySet.size() > 0) {
			for (MoveableOwnedObjectDelegate moo : entrySet) {
				if (moo.isOwnedBy(owner)) {
					if (r == null) r = new ArrayList();
					if (moo instanceof CraftDelegate) {
						r.add(moo);
					}
				}
			}
			if (r != null) {
				return (CraftDelegate[]) r.toArray(new CraftDelegate[r.size()]);
			} else {
				return null;
			}
		} else {
			return null;
		}
	}

	public static CraftDelegate[] getCrafts() throws ApplicationError {
		Collection<MoveableOwnedObjectDelegate> entrySet = moos.values();
		ArrayList r = null;
		if (entrySet != null && entrySet.size() > 0) {
			for (MoveableOwnedObjectDelegate moo : entrySet) {
				if (r == null) r = new ArrayList();
				if (moo instanceof CraftDelegate) {
					r.add(moo);
				}
			}
			if (r != null) {
				return (CraftDelegate[]) r.toArray(new CraftDelegate[r.size()]);
			} else {
				return null;
			}
		} else {
			return null;
		}
	}

	public static CraftDelegate[] getCrafts(PlayerDelegate owner, NameList excluding) throws ApplicationError {
		Collection<MoveableOwnedObjectDelegate> entrySet = moos.values();
		ArrayList r = null;
		if (entrySet != null && entrySet.size() > 0) {
			for (MoveableOwnedObjectDelegate moo : entrySet) {
				if (moo.isOwnedBy(owner) && (excluding == null || !excluding.contains(moo.getName())) ) {
					if (r == null) r = new ArrayList();
					if (moo instanceof CraftDelegate) {
						r.add(moo);
					}
				}
			}
			if (r != null) {
				return (CraftDelegate[]) r.toArray(new CraftDelegate[r.size()]);
			} else {
				return null;
			}
		} else {
			return null;
		}
	}


	public static CraftDelegate[] getCraftsInFleet(String fleetName) throws ApplicationError {
		Collection<MoveableOwnedObjectDelegate> entrySet = moos.values();
		ArrayList r = null;
		if (entrySet != null && entrySet.size() > 0) {
			for (MoveableOwnedObjectDelegate moo : entrySet) {
				if (moo instanceof CraftDelegate && Comp.same(((CraftDelegate) moo).getFleet(), fleetName)) {
					if (r == null) r = new ArrayList();
					r.add(moo);
				}
			}
			if (r != null) {
				return (CraftDelegate[]) r.toArray(new CraftDelegate[r.size()]);
			} else {
				return null;
			}
		} else {
			return null;
		}
	}

	public static FleetDelegate[] getFleets() throws ApplicationError {
		Collection<MoveableOwnedObjectDelegate> entrySet = moos.values();
		ArrayList r = null;
		if (entrySet != null && entrySet.size() > 0) {
			for (MoveableOwnedObjectDelegate moo : entrySet) {
				if (moo instanceof FleetDelegate) {
					if (r == null) r = new ArrayList();
					r.add(moo);
				}
			}
			if (r != null) {
				return (FleetDelegate[]) r.toArray(new FleetDelegate[r.size()]);
			} else {
				return null;
			}
		} else {
			return null;
		}
	}

	public static CraftDelegate[] getCraftsAt(PlayerDelegate owner, StellarObjectDelegate sod) throws ApplicationError {
		Collection<MoveableOwnedObjectDelegate> entrySet = moos.values();
		ArrayList r = null;
		if (entrySet != null && entrySet.size() > 0) {
			for (MoveableOwnedObjectDelegate moo : entrySet) {
				if (moo.isOwnedBy(owner) && moo instanceof CraftDelegate) {
					if (moo.getOrbit() != null && Comp.same(moo.getOrbit().getStellarObject(), sod.getName())) {
						if (r == null) r = new ArrayList();
						r.add(moo);
					}
				}
			}
			if (r != null) {
				return (CraftDelegate[]) r.toArray(new CraftDelegate[r.size()]);
			} else {
				return null;
			}
		} else {
			return null;
		}
	}

	public static MoveableOwnedObjectDelegate[] getMoos(PlayerDelegate owner) throws ApplicationError {
		Collection<MoveableOwnedObjectDelegate> entrySet = moos.values();
		ArrayList r = null;
		if (entrySet != null && entrySet.size() > 0) {
			for (MoveableOwnedObjectDelegate moo : entrySet) {
				if (moo.isOwnedBy(owner)) {
					if (r == null) r = new ArrayList();
					r.add(moo);
				}
			}
			if (r != null) {
				return (MoveableOwnedObjectDelegate[]) r.toArray(new MoveableOwnedObjectDelegate[r.size()]);
			} else {
				return null;
			}
		} else {
			return null;
		}
	}

	public static MoveableOwnedObjectDelegate addMoo(MoveableOwnedObjectDelegate moo) {
		if (moo != null) {
			moos.put(moo.getName(), moo);
		}
		return moo;
	}
	
	/**
	 * Only crafts visible by Player player or null if there are none.
	 * @return An array of crafts on the map over location location if the size that occupy is size. 
	 * @throws ApplicationError 
	 */
	public static MoveableOwnedObjectDelegate[] getMOOsAt(Rectangle rect, boolean hasNavigator, OrbitVO orbit) throws ApplicationError {
        ArrayList r = null;
        MoveableOwnedObjectDelegate[] crafts = getMoos();
        Area area = rect.getArea();
        if (crafts != null) {
            for (int i=0; i<crafts.length; i++) {
                Location loc = crafts[i].getLocation();
                if ( area.contains(loc) ) {
                	if (r  == null) r = new ArrayList();
                	if (crafts[i] instanceof CraftDelegate) {
                		CraftDelegate craft = (CraftDelegate) crafts[i];
                        FleetDelegate fleet = craft.getFleetDelegate();
                        if (fleet == null) {
                            addToList(r, crafts[i], hasNavigator, orbit);
                        }
                	} else {
                        addToList(r, crafts[i], hasNavigator, orbit);
                	}
                }
            }
        }
        if (r == null || r.size() == 0) {
            return null;
        } else {
            return (MoveableOwnedObjectDelegate []) r.toArray(new MoveableOwnedObjectDelegate[r.size()]);
        }
	}

    private static void addToList(ArrayList r, MoveableOwnedObjectDelegate moo, boolean hasNavigator, OrbitVO orbit) throws ApplicationError {
        if (hasNavigator) {
            if (moo.getNavigator() != null) {
                if (orbit != null) {
                    if (orbit.equals(moo.getOrbit())) {
                        r.add(moo);
                    }
                } else {
                    r.add(moo);
                }
            }
        } else {
            if (moo.getNavigator() == null) {
                if (orbit != null) {
                    if (orbit.equals(moo.getOrbit())) {
                        r.add(moo);
                    }
                } else {
                    r.add(moo);
                }
            }
        }
    }

	public static MoveableOwnedObjectDelegate [] getMoosEnroute(PlanetDelegate p) throws ApplicationError {
		if (p == null) return null;
		MoveableOwnedObjectDelegate[] ma = getMoos();
		ArrayList r = null;
		if (ma != null) {
			for (int i = 0; i < ma.length; i++) {
				NavigatorVO n = ma[i].getNavigator();
				if (n != null) {
					if (n.getDestination() != null && Comp.same(p.getName(), n.getDestination().getPlanet())) {
						if (r == null) r = new ArrayList();
						r.add(ma[i]);
					}
				}
			}
		}
        if (r == null || r.size() == 0) {
            return null;
        } else {
            return (MoveableOwnedObjectDelegate []) r.toArray(new MoveableOwnedObjectDelegate[r.size()]);
        }
	}
	
	public static MoveableOwnedObjectDelegate [] getMoosEnroute(StellarObjectDelegate so) throws ApplicationError {
		if (so == null) return null;
		MoveableOwnedObjectDelegate[] ma = getMoos();
		ArrayList r = null;
		if (ma != null) {
			for (int i = 0; i < ma.length; i++) {
				NavigatorVO n = ma[i].getNavigator();
				if (n != null) {
					if (n.getDestination() != null && Comp.same(so.getName(), n.getDestination().getStellarObject())) {
						if (r == null) r = new ArrayList();
						r.add(ma[i]);
					}
				}
			}
		}
        if (r == null || r.size() == 0) {
            return null;
        } else {
            return (MoveableOwnedObjectDelegate []) r.toArray(new MoveableOwnedObjectDelegate[r.size()]);
        }
	}
	
	public static MoveableOwnedObjectDelegate[] getMOOsInOrbitAt(StellarObjectDelegate so, boolean canBeAtPlanet) throws ApplicationError {
		if (so == null) return null;
        ArrayList r = null;
        MoveableOwnedObjectDelegate[] crafts = getMoos();
        if (crafts != null) {
            for (int i=0; i<crafts.length; i++) {
            	OrbitVO o = crafts[i].getOrbit();
				if (o != null && Comp.same(so.getName(), o.getStellarObject())) {
					if (canBeAtPlanet || o.getPlanet() == null) {						
						if (r  == null) r = new ArrayList();
						r.add(crafts[i]);
					}
				}
            }
        }
        if (r == null || r.size() == 0) {
            return null;
        } else {
            return (MoveableOwnedObjectDelegate []) r.toArray(new MoveableOwnedObjectDelegate[r.size()]);
        }
	}

	public static MoveableOwnedObjectDelegate[] getMOOsInOrbitAt(PlanetDelegate planet) throws ApplicationError {
		if (planet == null) return null;
        ArrayList r = null;
        MoveableOwnedObjectDelegate[] crafts = getMoos();
        if (crafts != null) {
            for (int i=0; i<crafts.length; i++) {
            	OrbitVO o = crafts[i].getOrbit();
				if (o != null && Comp.same(planet.getName(), o.getPlanet())) {
					if (r  == null) r = new ArrayList();
					r.add(crafts[i]);
				}
            }
        }
        if (r == null || r.size() == 0) {
            return null;
        } else {
            return (MoveableOwnedObjectDelegate []) r.toArray(new MoveableOwnedObjectDelegate[r.size()]);
        }
	}

	public static MoveableOwnedObjectDelegate getMostVisibleMooInOrbitAtOwnedBy(OrbitVO orbit, PlayerDelegate owner) throws ApplicationError {
		if (orbit == null || owner == null) return null;
		MoveableOwnedObjectDelegate r = null;
		int visibility = 0;
        MoveableOwnedObjectDelegate[] crafts = getMoos();
        if (crafts != null) {
            for (int i=0; i<crafts.length; i++) {
            	if (crafts[i].isOwnedBy(owner)) {
                	OrbitVO o = crafts[i].getOrbit();
    				if (o != null && o.equals(orbit)) {
    					int cv = crafts[i].getVisibility();
						if (r == null || cv > visibility) {
    						r = crafts[i];
    						visibility = cv;
    					}
    				}
            	}
            }
        }
        return r;
	}
	
	public static MoveableOwnedObjectDelegate[] getEnemyMoosAt(PlayerDelegate owner, OrbitVO orbit) throws ApplicationError {
		if (owner == null || orbit == null) return null;
		Collection<MoveableOwnedObjectDelegate> mooList = moos.values();
		ArrayList<MoveableOwnedObjectDelegate> r = null;
		if (mooList != null && mooList.size() > 0) {
			for (MoveableOwnedObjectDelegate moo : mooList) {
				if (owner.isEnemy(moo.getOwner()) && orbit.equals(moo.getOrbit())) {					
					if (moo instanceof CraftDelegate) {
						if (((CraftDelegate) moo).getFleet() == null) {
							if (r == null) r = new ArrayList();
							r.add(moo);
						}
					} else {
						if (r == null) r = new ArrayList();
						r.add(moo);
					}
				}
			}
		}
        if (r == null || r.size() == 0) {
            return null;
        } else {
            return r.toArray(new MoveableOwnedObjectDelegate[r.size()]);
        }
	}

	
	public static FleetDelegate[] getFleetsAt(PlayerDelegate owner, OrbitVO orbit) throws ApplicationError {
		if (owner == null || orbit == null) return null;
		Collection<MoveableOwnedObjectDelegate> mooList = moos.values();
		ArrayList<FleetDelegate> r = null;
		if (mooList != null && mooList.size() > 0) {
			for (MoveableOwnedObjectDelegate moo : mooList) {
				if (moo.isOwnedBy(owner) && orbit.equals(moo.getOrbit())) {					
					if (moo instanceof FleetDelegate) {
						if (r == null) r = new ArrayList();
						r.add((FleetDelegate)moo);
					}
				}
			}
		}
        if (r == null || r.size() == 0) {
            return null;
        } else {
            return r.toArray(new FleetDelegate[r.size()]);
        }
	}

	public static int getQtyFleetsAt(PlayerDelegate owner, OrbitVO orbit) throws ApplicationError {
		if (owner == null || orbit == null) return 0;
		Collection<MoveableOwnedObjectDelegate> mooList = moos.values();
		int qty = 0;
		if (mooList != null && mooList.size() > 0) {
			for (MoveableOwnedObjectDelegate moo : mooList) {
				if (moo.isOwnedBy(owner) && orbit.equals(moo.getOrbit())) {					
					if (moo instanceof FleetDelegate) {
						qty++;
					}
				}
			}
		}
        return qty;
	}

	public static CraftDelegate[] getCraftsAt(PlayerDelegate owner, OrbitVO orbit) throws ApplicationError {
		if (owner == null || orbit == null) return null;
		Collection<MoveableOwnedObjectDelegate> mooList = moos.values();
		ArrayList<CraftDelegate> r = null;
		if (mooList != null && mooList.size() > 0) {
			for (MoveableOwnedObjectDelegate moo : mooList) {
				if (moo.isOwnedBy(owner) && orbit.equals(moo.getOrbit())) {					
					if (moo instanceof CraftDelegate) {
						if (((CraftDelegate)moo).getFleet() == null) {
							if (r == null) r = new ArrayList();
							r.add((CraftDelegate)moo);
						}
					}
				}
			}
		}
        if (r == null || r.size() == 0) {
            return null;
        } else {
            return r.toArray(new CraftDelegate[r.size()]);
        }
	}

	public static int getQtyCraftsAt(PlayerDelegate owner, OrbitVO orbit) throws ApplicationError {
		if (owner == null || orbit == null) return 0;
		Collection<MoveableOwnedObjectDelegate> mooList = moos.values();
		int qty = 0;
		if (mooList != null && mooList.size() > 0) {
			for (MoveableOwnedObjectDelegate moo : mooList) {
				if (moo.isOwnedBy(owner) && orbit.equals(moo.getOrbit())) {					
					if (moo instanceof CraftDelegate) {
						if (((CraftDelegate)moo).getFleet() == null) {
							qty++;
						}
					}
				}
			}
		}
        return qty;
	}

	public static TransportDelegate[] getTransportsAt(UserPlayerDelegate owner, PlanetDelegate planet) throws ApplicationError {
		if (planet == null) return null;
        ArrayList r = null;
        MoveableOwnedObjectDelegate[] crafts = getMoos();
        if (crafts != null) {
            for (int i=0; i<crafts.length; i++) {
            	if (crafts[i] instanceof TransportDelegate) {            		
            		OrbitVO o = crafts[i].getOrbit();
            		if (o != null && Comp.same(planet.getName(), o.getPlanet())) {
        				if (r  == null) r = new ArrayList();
        				r.add(crafts[i]);
            		}
            	}
            }
        }
        if (r == null || r.size() == 0) {
            return null;
        } else {
            return (TransportDelegate []) r.toArray(new TransportDelegate[r.size()]);
        }
	}

	public static int getQtyTransportsWithEmptySpaceAt(UserPlayerDelegate owner, PlanetDelegate planet, char cargoType) throws ApplicationError {
		if (planet == null) return 0;
        MoveableOwnedObjectDelegate[] crafts = getMoos();
        int qty = 0;
        if (crafts != null) {
            for (int i=0; i<crafts.length; i++) {
            	if (crafts[i] instanceof TransportDelegate) {    
            		TransportDelegate transport = (TransportDelegate) crafts[i];
            		if (transport.getTaskContent() == cargoType && transport.getQty() < transport.getMaxQty()) {            			
            			OrbitVO o = crafts[i].getOrbit();
            			if (o != null && Comp.same(planet.getName(), o.getPlanet())) {
            				qty++;
            			}
            		}
            	}
            }
        }
        return qty;
	}

	public static StellarObjectDelegate getStellarObject(String name) {
		if (name == null) return null;
		StellarObjectDelegate so = (StellarObjectDelegate) sos.get(name);
		return so;
	}
	
	public static StellarObjectDelegate [] getStellarObjects() {
		Collection entrySet = sos.values();
		if (entrySet != null && entrySet.size() > 0) {
			return (StellarObjectDelegate[]) entrySet.toArray(new StellarObjectDelegate[entrySet.size()]);
		} else {
			return null;
		}
	}
	
	public static void addStellarObject(StellarObjectDelegate so) {
//		Logger.logDebug("DCM add SO "+so.getName()+"@"+so.getLocation()+" "+sos.size());
//		if (!so.getLocation().equals(MotEngine.instance.getStellarObjectsNotNull().getStellarObject(so.getName()).getLocation())) {
//			Logger.logStackTrace();
//			Logger.logDebug("DCM add SO "+so.getName());
//		}
		if (so != null) {
			sos.put(so.getName(), so);
		}
	}
	
	public static PlanetDelegate getPlanet(String name) {
		if (name == null) return null;
		PlanetDelegate planet = (PlanetDelegate) planets.get(name);
		return planet;
	}
	
	public static PlanetDelegate [] getPlanets() {
		Collection entrySet = planets.values();
		if (entrySet != null && entrySet.size() > 0) {
			return (PlanetDelegate[]) entrySet.toArray(new PlanetDelegate[entrySet.size()]);
		} else {
			return null;
		}
	}
	
	public static PlanetDelegate [] getPlanets(PlayerDelegate owner) throws ApplicationError {
		Collection<PlanetDelegate> entrySet = planets.values();
		ArrayList r = null;
		if (entrySet != null && entrySet.size() > 0) {
			for (PlanetDelegate pd : entrySet) {
				if (pd.isOwnedBy(owner)) {
					if (r == null) r = new ArrayList();
					r.add(pd);
				}
			}
			if (r != null) {
				return (PlanetDelegate[]) r.toArray(new PlanetDelegate[r.size()]);
			} else {
				return null;
			}
		} else {
			return null;
		}
	}
	
	public static void addPlanet(PlanetDelegate planet) {
		if (planet != null) {
			planets.put(planet.getName(), planet);
		}
	}
	
	public static PlanetDelegate getPlanet(OrbitVO orbit) {
		if (orbit == null) return null;
		if (orbit.getPlanet() == null) return null;
		return getPlanet(orbit.getPlanet());
	}

	public static StellarObjectDelegate getStellarObject(OrbitVO orbit) {
		if (orbit == null) return null;
		if (orbit.getStellarObject() == null) return null;
		return getStellarObject(orbit.getStellarObject());
	}
	
	public static BattleCraftDelegate getBattleCraft(String battle, String craft) {
		if (battle != null && craft != null) {
	        BattleDelegate b = DeligateCacheManager.getBattle(battle);
			BattleDelegateCache delegateCache = b.getDelegateCache();
			return delegateCache.getBattleCraft(craft);
		} else {
			return null;
		}
	}
	
	public static BattleObjectDelegate getBattleObject(String battle, String bo) {
		if (battle != null && bo != null) {
	        BattleDelegate b = DeligateCacheManager.getBattle(battle);
			BattleDelegateCache delegateCache = b.getDelegateCache();
			return delegateCache.getBattleObject(bo);
		} else {
			return null;
		}
	}
	
	public static BattleAutomatonDelegate getBattleAutomaton(String battle, String ba) {
		if (battle != null && ba != null) {
	        BattleDelegate b = DeligateCacheManager.getBattle(battle);
			BattleDelegateCache delegateCache = b.getDelegateCache();
			return delegateCache.getBattleAutomaton(ba);
		} else {
			return null;
		}
	}
	
	public static BattleDelegate getBattle(String name) {
		if (name == null) return null;
		BattleDelegateCache battle = battles.get(name);
		if (battle != null) {
			return battle.getBattle();
		} else {
			return null;
		}
	}

	public static void removeBattle(String name) {
		battles.remove(name);
	}

	public static void removeAllBattles() {
		battles.clear();
	}

	public static void flush() {
		//Logger.logDebug("DeligateCache.flush()");
		players = new HashMap();
		deadPlayers = new HashMap();
		moos = new HashMap();
		sos = new HashMap();
		planets = new HashMap();
		battles = new HashMap<String, BattleDelegateCache>();
		sog = null;
		techsAvailableForResearch = null;
	    galaxyDetails = null;
	    monsterPlayer = null;
	    tradeRoutes = null;
	    relations = null;
	}

	/**
	 * Sector Owners Grid and Planet Images change at the end of each turn so need updating.
	 * @throws ApplicationError 
	 * @throws ValidationError 
	 */
	public static void notifyEndTurn() throws ApplicationError, ValidationError {
		ServerProxy serverProxy = ProxyStore.getInstance();
		updatePlanetImages();
		updateCraftImages();
	}

	public static Technology [] getTechsAvailableForResearch() {
		return techsAvailableForResearch;
	}

	public static void setTechsAvailableForResearch(Technology [] v) {
		techsAvailableForResearch = v;
	}

	public static int getDate() {
		return date;
	}

	public static TradeRouteDelegate [] getTradeRoutes() {
		return tradeRoutes;
	}

	public static RelationDelegate [] getRelations() {
		return relations;
	}

	public static void setDate(int date) {
		DeligateCacheManager.date = date;
	}
	
	public static void update(MotEvent e) throws ApplicationError {
		if (e instanceof PlayerLoseEvent) {
			PlayerLoseEvent event = (PlayerLoseEvent) e;
	        PlayerDelegate player = DeligateCacheManager.getPlayer(event.getPlayer());
	        if (player != null) {
	        	DeligateCacheManager.removePlayer(player);
	        }
		} else if (e instanceof PlayerSurrenderEvent) {
			PlayerSurrenderEvent event = (PlayerSurrenderEvent) e;
	        PlayerDelegate player = DeligateCacheManager.getPlayer(event.getPlayer());
	        if (player != null) {
	        	DeligateCacheManager.removePlayer(player);
	        }
		} else if (e instanceof TradeRouteInvalidEvent) {
			TradeRouteInvalidEvent event = (TradeRouteInvalidEvent) e;
			DeligateCacheManager.removeTradeRoute(event.getSolarSystem1(), event.getSolarSystem2());
		}
		if (e instanceof BattleStateUpdateEventAdapter) {
			update((BattleStateUpdateEventAdapter)e);
		} else if (e instanceof StateContainer) {
			update((StateContainer)e);
		}
	}

	public static void update(BattleStateUpdateEventAdapter event) throws ApplicationError {
		String battle = event.getBattle();
		BattleDelegateCache battleCache = (BattleDelegateCache) battles.get(battle);
		if (battleCache == null) {
			Logger.logError("", new ApplicationError("No battle "+battle+" for event "+event));
		} else {
			battleCache.update(event);
			if (event instanceof StateContainer) {
				battleCache.update((StateContainer)event);
			}
		}
	}
	
	public static void update(StateContainer container) {
		ArrayList<String> moosToDelete = null;
		if (container.getType(FlushCraftCacheVO.class) != null) {
			moosToDelete = Comp.getNamesAsList(getAllMoos());
		}
		if (container.getType(FlushDelegateCacheVO.class) != null) {
			flush();
		}
		if (container instanceof ValueObject) {			
			try {
				_update(null, (ValueObject)container, moosToDelete);
			} catch (Exception e) {
				Logger.logError("Unknown Cache Update "+container.getClass().getName(), e);
			}
		}
		ValueObject[] sua = container.getStateUpdates();
		if (sua != null) {
			for (int i = 0; i < sua.length; i++) {
				try {
					_update(container, sua[i], moosToDelete);
				} catch (Exception e) {
					Logger.logError("Unknown Cache Update "+container.getClass().getName(), e);
				}
			}
		}
		if (moosToDelete != null) {
			for (String moo : moosToDelete) {
				//Logger.logDebug("Delete Moo "+moo);
				moos.remove(moo);
			}
		}
	}

	private static void _update(StateContainer container, ValueObject vo, ArrayList<String> moosToDelete) throws ApplicationError {
		if (vo == null) return;
		//Logger.logDebug("_update "+vo+" - "+Comp.toString(getMoos()));
		if (vo instanceof MoveableOwnedObjectVO) {
			MoveableOwnedObjectDelegate moo = (MoveableOwnedObjectDelegate) moos.get(((MoveableOwnedObjectVO) vo).getName());
			if (moo == null) {
				if (vo instanceof CraftVO) {					
					//Logger.logDebug("XCX  Add "+((CraftVO)vo).getName()+"@"+((CraftVO)vo).getLocation());
					moo = addMoo(new MotCraftDelegate((CraftVO)vo));
				} else if (vo instanceof FleetVO) {					
					moo = addMoo(new MotFleetDelegate((FleetVO)vo));
				} else if (vo instanceof TransportVO) {					
					moo = addMoo(new MotTransportDelegate((TransportVO)vo));
				}
			} else if (moo instanceof MotCraftDelegate) {
				//Logger.logDebug("XCX  Update "+((CraftVO)vo).getName()+"@"+((CraftVO)vo).getLocation());
				((MotCraftDelegate)moo).update((CraftVO)vo);
			} else if (moo instanceof MotFleetDelegate) {
				((MotFleetDelegate)moo).update((FleetVO)vo);
			} else if (moo instanceof MotTransportDelegate) {
				((MotTransportDelegate)moo).update((TransportVO)vo);
			}
			if (moosToDelete != null && moo != null) moosToDelete.remove(moo.getName());
		} else if (vo instanceof StellarObjectVO) {
			StellarObjectDelegate so = (StellarObjectDelegate) sos.get(((StellarObjectVO) vo).getName());
			if (so == null) {
				if (vo instanceof SolarSystemVO) {					
					addStellarObject(new MotSolarSystemDelegate((SolarSystemVO) vo));
				} else if (vo instanceof BlackHoleVO) {
					addStellarObject(new MotBlackHoleDelegate((BlackHoleVO) vo));
				}
			} else if (so instanceof MotSolarSystemDelegate) {
				((MotSolarSystemDelegate)so).update((SolarSystemVO)vo);
			} else if (so instanceof MotBlackHoleDelegate) {
				((MotBlackHoleDelegate)so).update((BlackHoleVO)vo);
			}
		} else if (vo instanceof PlanetVO) {
			PlanetDelegate so = (PlanetDelegate) planets.get(((PlanetVO) vo).getName());
			if (so == null) {
				addPlanet(new MotPlanetDelegate((PlanetVO) vo));
			} else if (so instanceof MotPlanetDelegate) {
				((MotPlanetDelegate)so).update((PlanetVO)vo);
			}
		} else if (vo instanceof PlayerVO) {
			PlayerDelegate player = getPlayer(((PlayerVO) vo).getName());
			if (player == null) {
				if (vo instanceof UserPlayerVO) {
					addPlayer(new MotUserPlayerDelegate((UserPlayerVO)vo));
				} else if (vo instanceof ComputerPlayerVO) {
					addPlayer(new MotComputerPlayerDelegate((ComputerPlayerVO)vo));
				}
			} else if (player instanceof MotUserPlayerDelegate) {
				((MotUserPlayerDelegate)player).update((UserPlayerVO)vo);
			} else if (player instanceof MotComputerPlayerDelegate) {
				((MotComputerPlayerDelegate)player).update((ComputerPlayerVO)vo);
			}
		} else if (vo instanceof ResearchProjectUpdateVO) {
			UserPlayerDelegate player = getUserPlayer(((ResearchProjectUpdateVO) vo).getPlayer());
			if (player == null) {
				Logger.logWarning("No Player for "+vo);
			} else {
				((MotUserPlayerDelegate)player).update((ResearchProjectUpdateVO) vo);
			}
		} else if (vo instanceof PlayerDetailsVO) {
			PlayerDelegate player = getPlayer(((PlayerDetailsVO) vo).getName());
			if (player == null) {
				Logger.logWarning("No Player for "+vo);
			} else if (player instanceof MotUserPlayerDelegate) {
				((MotUserPlayerDelegate)player).update((PlayerDetailsVO)vo);
			} else if (player instanceof MotComputerPlayerDelegate) {
				((MotComputerPlayerDelegate)player).update((PlayerDetailsVO)vo);
			}
		} else if (vo instanceof PlayerConstantsVO) {
			PlayerDelegate player = getPlayer(((PlayerConstantsVO) vo).getName());
			if (player == null) {
				Logger.logWarning("No Player for "+vo);
			} else if (player instanceof MotPlayerDelegate) {
				((MotPlayerDelegate)player).update((PlayerConstantsVO)vo);
			}
		} else if (vo instanceof PlayerTechnologiesVO) {
			PlayerTechnologiesVO pvo = (PlayerTechnologiesVO) vo;
			MotUserPlayerDelegate player = (MotUserPlayerDelegate) getPlayer(pvo.getPlayer());
			if (player != null) player.update(pvo);
		} else if (vo instanceof PlayerTechnologyVO) {
			PlayerTechnologyVO pvo = (PlayerTechnologyVO) vo;
			MotUserPlayerDelegate player = (MotUserPlayerDelegate) getPlayer(pvo.getPlayer());
			if (player != null) player.addTechnology(pvo.getTechnology());
		} else if (vo instanceof CraftDesignsVO) {
			CraftDesignsVO pvo = (CraftDesignsVO) vo;
			PlayerDelegate player = getPlayer(pvo.getPlayer());
			if (player != null && player instanceof MotUserPlayerDelegate) {				
				MotUserPlayerDelegate up = (MotUserPlayerDelegate) getPlayer(pvo.getPlayer());
				up.update(pvo);
			}
		} else if (vo instanceof CraftDesignUpdateVO) {
			CraftDesignUpdateVO cdvo = (CraftDesignUpdateVO) vo;
			PlayerDelegate player = getPlayer(cdvo.getOwner());
			if (player != null && player instanceof MotUserPlayerDelegate) {				
				MotUserPlayerDelegate up = (MotUserPlayerDelegate) player;
				up.update(cdvo);
			}
		} else if (vo instanceof CraftDesignVO) {
			CraftDesignVO cdvo = (CraftDesignVO) vo;
			PlayerDelegate player = MainWindow.getOwner();
			if (player != null && player instanceof MotUserPlayerDelegate) {				
				MotUserPlayerDelegate up = (MotUserPlayerDelegate) player;
				up.update(cdvo);
			}
		} else if (vo instanceof GalaxyDetails) {
			galaxyDetails = (GalaxyDetails) vo;
		} else if (vo instanceof SectorOwnerGrid) {
			sog = (SectorOwnerGrid) vo;
		} else if (vo instanceof TradeRouteInvalidVO) {
			removeTradeRoute(((TradeRouteInvalidVO) vo).getSolarSystem1(), ((TradeRouteInvalidVO) vo).getSolarSystem2());
		} else if (vo instanceof TradeRouteVO) {
			if (tradeRoutes == null) {
				tradeRoutes = new TradeRouteDelegate[1];
				tradeRoutes[0] =  new MotTradeRouteDelegate((TradeRouteVO) vo);
			} else {
				TradeRouteDelegate [] old = tradeRoutes;
				tradeRoutes = new TradeRouteDelegate[old.length+1];
				for (int i = 0; i < old.length; i++) {
					tradeRoutes[i] = old[i];
				}
				tradeRoutes[old.length] = new MotTradeRouteDelegate((TradeRouteVO) vo);
			}
		} else if (vo instanceof TradeRouteListVO) {
			TradeRouteVO[] trl = ((TradeRouteListVO) vo).getTradeRoutes();
			if (trl == null) {
				tradeRoutes = null;
			} else {
				tradeRoutes = new TradeRouteDelegate[trl.length];
				for (int i = 0; i < trl.length; i++) {
					tradeRoutes[i] = new MotTradeRouteDelegate(trl[i]);
				}
			}
		} else if (vo instanceof RelationVO) {
			RelationVO rvo = (RelationVO) vo;
			if (relations == null) {
				relations = new MotRelationDelegate[1];
				relations[0] =  new MotRelationDelegate(rvo);
			} else {
				int index = getRelationIndex(rvo.getPlayer1Name(), rvo.getPlayer2Name());
				if (index >= 0) {
					relations[index] =  new MotRelationDelegate(rvo);
				} else {
					RelationDelegate [] old = relations;
					relations = new RelationDelegate[old.length+1];
					for (int i = 0; i < old.length; i++) {
						relations[i] = old[i];
					}
					relations[old.length] = new MotRelationDelegate(rvo);
				}
			}
		} else if (vo instanceof NewBattleEvent) {
			NewBattleEvent nb = (NewBattleEvent) vo;
			BattleDelegateCache battleCache = new BattleDelegateCache();
			battles.put(nb.getBattle().getName(), battleCache);
			battleCache.setup(nb);
		} else if (vo instanceof BattleEvent) {
			String battle = ((BattleEvent)vo).getBattle();
			BattleDelegateCache battleCache = (BattleDelegateCache) battles.get(battle);
			if (battleCache == null) {
				Logger.logDebug("No battle "+battle+" for event "+vo);
			} else if (vo instanceof BattleStateUpdateEventAdapter) {
				battleCache.update((BattleStateUpdateEventAdapter)vo);
			} else if (vo instanceof StateContainer) {
				battleCache.update((StateContainer)vo);
			}
		} else if (vo instanceof BattleValueObject) {
			String battle = ((BattleValueObject)vo).getBattle();
			BattleDelegateCache battleCache = (BattleDelegateCache) battles.get(battle);
			if (battleCache == null) {
				Logger.logDebug("No battle "+battle+" for event "+vo);
			} else {
				battleCache.addOrUpdate(null, (BattleValueObject)vo);
			}
		} else if (vo instanceof BattleObjectVO) {
			String battle = ((BattleObjectVO)vo).getBattle();
			BattleDelegateCache battleCache = (BattleDelegateCache) battles.get(battle);
			if (battleCache == null) {
				Logger.logDebug("No battle "+battle+" for event "+vo);
			}
			battleCache.update(container, (BattleObjectVO)vo);
		} else if (vo instanceof DateVO) {
			date = ((DateVO)vo).getDate();
		} else if (vo instanceof TechnologyAvailableForResearchVO) {
			TechnologyList list = ((TechnologyAvailableForResearchVO)vo).getAllAsList();
			techsAvailableForResearch = (list == null) ? null : list.getAllAsArray();
		} else if (vo instanceof RenameListVO) {
			RenameListVO v = (RenameListVO) vo;
			if (v.getSolarSystem() != null) {
				MotStellarObjectDelegate so = (MotStellarObjectDelegate) sos.get(v.getSolarSystem().getOldName());
				if (v.getSolarSystem().getNewName() != null) {
					PlanetDelegate[] ssPlanets = null;
					if (so instanceof SolarSystemDelegate) {
						ssPlanets = ((SolarSystemDelegate)so).getPlanets();
					}
					MoveableOwnedObjectDelegate[] moosEnroute = getMoosEnroute(so);
					MoveableOwnedObjectDelegate[] moosInOrbit = getMOOsInOrbitAt(so, false);
					sos.remove(v.getSolarSystem().getOldName());
					so.setName(v.getSolarSystem().getNewName());
					sos.put(so.getName(), so);
					if (ssPlanets != null) {
						for (int i = 0; i < ssPlanets.length; i++) {
							((MotPlanetDelegate)ssPlanets[i]).getPlanetVO().setSolarSystem(v.getSolarSystem().getNewName());
						}
					}
					if (moosEnroute != null) {
						for (int i = 0; i < moosEnroute.length; i++) {
							moosEnroute[i].getNavigator().getDestination().setStellarObject(v.getSolarSystem().getNewName());
						}
					}
					if (moosInOrbit != null) {
						for (int i = 0; i < moosInOrbit.length; i++) {
							moosInOrbit[i].getOrbit().setStellarObject(v.getSolarSystem().getNewName());
						}
					}
				}
			}
			if (v.getPlanets() != null) {
				ArrayList<RenameVO> pl = v.getPlanets();
				for (RenameVO rp : pl) {
					MotPlanetDelegate p = (MotPlanetDelegate) planets.get(rp.getOldName());
					MotPlanetDelegate miner = (MotPlanetDelegate) p.getOwnerOfMiningStation();
					MoveableOwnedObjectDelegate[] moosEnroute = getMoosEnroute(p);
					MoveableOwnedObjectDelegate[] moosInOrbit = getMOOsInOrbitAt(p);
					planets.remove(rp.getOldName());
					p.setName(rp.getNewName());
					planets.put(p.getName(), p);
					if (miner != null) {
						miner.getPlanetVO().setMiningColony(rp.getNewName());
					}
					if (moosEnroute != null) {
						for (int i = 0; i < moosEnroute.length; i++) {
							moosEnroute[i].getNavigator().getDestination().setPlanet(rp.getNewName());
						}
					}
					if (moosInOrbit != null) {
						for (int i = 0; i < moosInOrbit.length; i++) {
							moosInOrbit[i].getOrbit().setStellarObject(p.getSolarSystemName());
							moosInOrbit[i].getOrbit().setPlanet(rp.getNewName());
						}
					}
				}
			}
			if (v.getMoo() != null) {
				RenameVO rm = v.getMoo();
				MotMoveableOwnedObjectDelegate moo = (MotMoveableOwnedObjectDelegate) getMoo(rm.getOldName());
				if (moo != null) {
					CraftDelegate [] crafts = null;
					if (moo instanceof FleetDelegate) {
						crafts = ((FleetDelegate)moo).getCrafts();
					}
					moos.remove(rm.getOldName());
					moo.getMoveableOwnedObjectVO().setName(rm.getNewName());
					moos.put(moo.getName(), moo);
					if (crafts != null) {
						for (int i = 0; i < crafts.length; i++) {							
							((MotCraftDelegate)crafts[i]).getCraftValue().setFleet(rm.getNewName());
						}
					}
				}
			}
		} else if (vo instanceof RemoveMooVO) {
			RemoveMooVO moo = (RemoveMooVO) vo;
			MoveableOwnedObjectDelegate md = getMoo(moo.getName());
			if (md != null && md instanceof CraftDelegate) {
				CraftDelegate cd = (CraftDelegate) md;
				if (cd.getFleet() != null) {
					MoveableOwnedObjectDelegate fd = getMoo(cd.getFleet());
					if (fd instanceof MotFleetDelegate) {
						MotFleetDelegate mfd = (MotFleetDelegate) fd;
						mfd.remove(cd.getName());
						if (mfd.getQtyCrafts() == 0) {
							moos.remove(mfd.getName());
						}
					}					
				}
			}
			moos.remove(moo.getName());
		} else if (vo instanceof FlushCraftCacheVO) {
		} else if (vo instanceof StateUpdateEvent) {
			StateUpdateEvent ue = (StateUpdateEvent) vo;
			ValueObject[] ua = ue.getStateUpdates();
			if (ua != null) {
				for (int i = 0; i < ua.length; i++) {					
					_update(container, ua[i], moosToDelete);
				}
			}
		} else if (vo instanceof DeadPlayerVO) {
			DeadPlayerVO dp = (DeadPlayerVO) vo;
			PlayerDelegate player = deadPlayers.get(dp.getName());
			PlayerVO p = dp.getPlayer();
			if (player == null) {
				if (p instanceof UserPlayerVO) {
					deadPlayers.put(p.getName(), new MotUserPlayerDelegate((UserPlayerVO)p));
				} else if (p instanceof ComputerPlayerVO) {
					deadPlayers.put(p.getName(), new MotComputerPlayerDelegate((ComputerPlayerVO)p));
				}
			} else if (player instanceof MotUserPlayerDelegate) {
				((MotUserPlayerDelegate)player).update((UserPlayerVO)p);
			} else if (player instanceof MotComputerPlayerDelegate) {
				((MotComputerPlayerDelegate)player).update((ComputerPlayerVO)p);
			}
		}
	}

	private static int getRelationIndex(String player1Name, String player2Name) {
		if (relations == null) return -1;
		for (int i = 0; i < relations.length; i++) {
			if (relations[i].equals(player1Name, player2Name)) {
				return i;
			}
		}
		return -1;
	}

	public static RelationDelegate getRelation(String player1Name, String player2Name) {
		if (relations == null) return null;
		for (int i = 0; i < relations.length; i++) {
			if (relations[i].equals(player1Name, player2Name)) {
				return relations[i];
			}
		}
		return null;
	}

	private static void removeDeletedMoos(ValueObject[] ua) {
		ArrayList<MoveableOwnedObjectDelegate> ml = new ArrayList<MoveableOwnedObjectDelegate>(moos.values());
		for (MoveableOwnedObjectDelegate moo : ml) {
			if (contains(moo, ua)) {
				moos.remove(moo.getName());
			}
		}
	}

	private static boolean contains(MoveableOwnedObjectDelegate moo, ValueObject[] ua) {
		if (ua == null) return false;
		for (int i = 0; i < ua.length; i++) {
			if (ua[i] instanceof MoveableOwnedObjectVO) {
				MoveableOwnedObjectVO v = (MoveableOwnedObjectVO) ua[i];
				if (Comp.same(moo.getName(), v.getName())) {
					return true;
				}
			}
		}
		return false;
	}

	public static PlayerDelegate getMonsterPlayer() {
		return monsterPlayer;
	}

}
