/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.deligates.debug;

import mot.client.animation.BattleAnimation;
import mot.client.animation.BattleAnimationList;
import mot.client.swing.animation.CraftMoveAnimation;
import mot.client.swing.animation.CraftTeleportAnimation;
import mot.client.swing.window.battle.BattleWindowConfig;
import mot.client.swing.window.main.MainWindow;
import mot.client.swing.window.main.MainWindowConfig;
import mot.common.bean.Location;
import mot.common.util.Logger;

public class DebugStateBattleMovement implements DeligateDebugState {

	private Location last;
	
	public void notifyDrawBattleObject(Location loc) {
		
		MainWindowConfig activeConfig = MainWindow.getExestingInstance().getActiveConfiguration();
		if (activeConfig instanceof BattleWindowConfig) {
			BattleWindowConfig bwc = (BattleWindowConfig) activeConfig;
			BattleAnimationList animations = bwc.getAnimations();
			if (animations != null) {
				if (last == null) {
					last = loc;
					return;
				}
				BattleAnimation teleport = animations.getActiveAnimationOfClass(CraftTeleportAnimation.class);
				if (teleport != null) {
					last = loc;
					return;
				}
				BattleAnimation move = animations.getActiveAnimationOfClass(CraftMoveAnimation.class);
				if (move != null) {
					last = loc;
					return;
				}
				if (!loc.equals(last)) {
					Logger.logDebug("GOT IT");
				}
			}
		}
		
	}

}
