/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.deligates.mot;

import mot.client.deligates.BattleDroidMineDelegate;
import mot.client.deligates.BattleObjectDelegate;
import mot.client.deligates.PlayerDelegate;
import mot.client.swing.config.ImageConfig;
import mot.client.swing.config.ImageConfigFactory;
import mot.common.bean.Location;
import mot.common.bean.PlayerColor;
import mot.common.bean.Size;
import mot.common.util.ApplicationError;
import mot.common.vo.BattleObjectVO;
import mot.common.vo.DroidMineVO;
import mot.common.vo.ImageObjectVO;
import mot.common.vo.ValueObject;

public class MotBattleDroidMineDelegate extends MotBattleObjectDelegate implements BattleDroidMineDelegate {

	private ImageConfig imageConfig = null;
	private DroidMineVO value;	

	public MotBattleDroidMineDelegate(DroidMineVO vo) {
		value = vo;
	}
	protected BattleObjectVO getBattleObjectValue() { return value;	}
	protected ImageObjectVO getImageObjectValue() {	return value; }
	public void setBattleObjectValue(ValueObject v) { value = (DroidMineVO) v; }

    public ImageConfig getImageConfig() throws ApplicationError {
		if (imageConfig == null) {
			imageConfig = ImageConfigFactory.getInstance().getImageConfig("DroidMine");
		}
    	return imageConfig;
    }
	
	public Size getImageSize() throws ApplicationError {
		return getImageConfig().getImageSize();
	}
	
	public boolean isControlledBy(PlayerDelegate p) throws ApplicationError {
		return false;
	}

    public String getImage() throws ApplicationError {
		ImageConfig ic = getImageConfig();
    	return ic.getImage();
    }
	
    public String getImage(PlayerColor pc, Boolean isVisible) throws ApplicationError {
    	return getImage();
    }
    
	public int getDirection(Location loc) throws ApplicationError {
		return loc.getDirectionFor(getTargetDelegate().getLocation());
	}
	
	public boolean isSelectableBy(PlayerDelegate player) throws ApplicationError {
		return false;
	}

	public BattleObjectDelegate getTargetDelegate() throws ApplicationError {
		return getBattle().getDelegateCache().getBattleObject(value.getTarget());
	}

	public BattleObjectDelegate getOriginDelegate() throws ApplicationError {
		return getBattle().getDelegateCache().getBattleObject(value.getOrigin());
	}
	
	public String getTarget() throws ApplicationError {
		return value.getTarget();
	}

	public String getOrigin() throws ApplicationError {
		return value.getOrigin();
	}

}
