/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.deligates.mot;

import mot.client.deligates.BattleMineDelegate;
import mot.client.deligates.PlayerDelegate;
import mot.client.swing.config.ImageConfig;
import mot.client.swing.config.ImageConfigFactory;
import mot.common.bean.PlayerColor;
import mot.common.bean.Size;
import mot.common.util.ApplicationError;
import mot.common.vo.BattleMineVO;
import mot.common.vo.BattleObjectVO;
import mot.common.vo.ImageObjectVO;
import mot.common.vo.ValueObject;

public class MotBattleMineDelegate extends MotBattleObjectDelegate implements BattleMineDelegate {

	private ImageConfig imageConfig = null;
	private BattleMineVO value;	

	public MotBattleMineDelegate(BattleMineVO vo) {
		value = vo;
	}

	protected BattleObjectVO getBattleObjectValue() { return value;	}
	protected ImageObjectVO getImageObjectValue() {	return value; }
	public void setBattleObjectValue(ValueObject v) { value = (BattleMineVO) v; }

    public ImageConfig getImageConfig() throws ApplicationError {
		if (imageConfig == null) {
			imageConfig = ImageConfigFactory.getInstance().getImageConfig("Mine");
		}
    	return imageConfig;
    }

	public Size getImageSize() throws ApplicationError {
		return getImageConfig().getImageSize();
	}
	
    public String getImage() throws ApplicationError {
		ImageConfig ic = getImageConfig();
    	return ic.getImage();
    }
	
    public String getImage(PlayerColor pc, Boolean isVisible) throws ApplicationError {
    	return getImage();
    }
    
	public boolean isSelectableBy(PlayerDelegate player) throws ApplicationError {
		return false;
	}

}
