/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.deligates.mot;

import mot.client.deligates.BattlePlanetDelegate;
import mot.client.deligates.PlanetDelegate;
import mot.client.deligates.cache.DeligateCacheManager;
import mot.common.bean.PlayerColor;
import mot.common.bean.Size;
import mot.common.factory.PlanetGraphicsFactory;
import mot.common.util.ApplicationError;
import mot.common.vo.BattleObjectVO;
import mot.common.vo.BattlePlanetVO;
import mot.common.vo.ImageObjectVO;
import mot.common.vo.ValueObject;

public class MotBattlePlanetDelegate extends MotBattleObjectDelegate implements BattlePlanetDelegate {

	private BattlePlanetVO value;

	private transient PlanetDelegate planet;
	private transient Size size;
	
	public MotBattlePlanetDelegate(BattlePlanetVO vo) {
		value = vo;
	}

	public boolean hasAsteroids() throws ApplicationError {
		return value.hasAsteroids();
	}

	public PlanetDelegate getPlanet() throws ApplicationError {
		if (planet == null) {
			planet = DeligateCacheManager.getPlanet(value.getName());
		}
		return planet;
	}

	protected BattleObjectVO getBattleObjectValue() { return value;	}
	protected ImageObjectVO getImageObjectValue() { return value; }
	public void setBattleObjectValue(ValueObject v) { value = (BattlePlanetVO) v; }

	public String getImage() throws ApplicationError {
		return getPlanet().getImageForPlanet();
	}

    public String getImage(PlayerColor pc, Boolean isVisible) throws ApplicationError {
    	return getImage();
    }

	public Size getImageSize() throws ApplicationError {
		if (size == null) {
			int maxPlanetSize = PlanetGraphicsFactory.getMaxPlanetSize();
			double scale = PlanetGraphicsFactory.getScale(getPlanet().getSize());
			int d = (int)(maxPlanetSize * scale);
			size = new Size(d, d);
		}
		return size;
	}


}
