/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.deligates.mot;

import mot.client.deligates.BlackHoleDelegate;
import mot.common.bean.GalaxyGraphicsList;
import mot.common.bean.StellarObjectGraphics;
import mot.common.factory.GraphicsFactory;
import mot.common.util.ApplicationError;
import mot.common.vo.BlackHoleVO;
import mot.common.vo.OrbitVO;
import mot.common.vo.StellarObjectVO;

public class MotBlackHoleDelegate extends MotStellarObjectDelegate implements BlackHoleDelegate {

	private BlackHoleVO value;

	private transient StellarObjectGraphics starGraphicsZoomedIn;
	private transient StellarObjectGraphics starGraphicsZoomedOut;

	public MotBlackHoleDelegate() {
	}
	
    public MotBlackHoleDelegate(BlackHoleVO vo) {
		value = vo;
	}

	@Override
	public StellarObjectGraphics getGraphics(boolean zoomedIn) throws ApplicationError {
    	if (starGraphicsZoomedIn == null) {
	        GalaxyGraphicsList galaxyGraphics = GraphicsFactory.getGalaxyGraphicsList();
	        String graphicsName = value.getGraphicsName();
	        starGraphicsZoomedIn = galaxyGraphics.getStellarObjectGraphics(graphicsName, true);
	        starGraphicsZoomedOut = galaxyGraphics.getStellarObjectGraphics(graphicsName, false);
    	}
    	if (zoomedIn) {
    		return starGraphicsZoomedIn;
    	} else {
    		return starGraphicsZoomedOut;
    	}
	}

    @Override
	public String getGraphicsName() throws ApplicationError {
		return value.getGraphicsName();
	}

	@Override
	public OrbitVO getOrbit() {
		return new OrbitVO(getName(), null);
	}

	public float getResearchBonus() {
		return value.getResearchBonus();
	}

	public boolean hasSpaceJumpAbility() {
		return value.isSpaceJumpAbility();
	}

	@Override
	protected StellarObjectVO getStellObjectValue() {
		return value;
	}

	public void update(BlackHoleVO vo) {
		value = vo;
		stellarObjectOrbitalDelegate = null;
		starGraphicsZoomedIn = null;
		starGraphicsZoomedOut = null;
		galaxyMapLabelSizeDetails = null;
	}

	public void update(StellarObjectVO vo) {
		update((BlackHoleVO) vo);
	}

}
