/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.deligates.mot;

import mot.client.deligates.ImageObjectDelegate;
import mot.client.deligates.NamedObjectDelegate;
import mot.client.deligates.UserPlayerDelegate;
import mot.client.swing.window.main.MainWindow;
import mot.common.bean.Area;
import mot.common.bean.ImageObjectSettings;
import mot.common.bean.Location;
import mot.common.bean.Size;
import mot.common.util.ApplicationError;
import mot.common.util.Comp;
import mot.common.util.Logger;
import mot.common.vo.ImageObjectVO;

public abstract class MotImageObjectDelegate implements ImageObjectDelegate {

	protected abstract ImageObjectVO getImageObjectValue();
	public abstract Size getImageSize() throws ApplicationError;
	
	public String getName() {
		ImageObjectVO value = getImageObjectValue();
		return value.getName();
	}
    
	public boolean equals(NamedObjectDelegate other) {
		ImageObjectVO value = getImageObjectValue();
	    return other != null && Comp.same(other.getName(), value.getName());
	}

	public int getDirection(Location loc) throws ApplicationError {
		return getDirection();
	}

	public Area getArea() throws ApplicationError {
		Size size = getImageSize();
		if (size == null) {
			Logger.logWarning("MotImageObjectDelegate - No Size for "+this);
			size = new Size(20,20);
		}
		int imageWidth = size.getX();
		int imageHeight = size.getY();
		Location loc = getLocation();
		int x = loc.getX();
		int y = loc.getY();
		int spaceX = imageWidth/2+ImageObjectSettings.INTER_CRAFT_GAP;
		int spaceY = imageHeight/2+ImageObjectSettings.INTER_CRAFT_GAP;
        int left = x-spaceX;
        int right = x+spaceX;
        int top = y-spaceY;
        int bottom = y+spaceY;
        return new Area(left, top, right, bottom);
	}

	public boolean equals(ImageObjectDelegate other) {
		ImageObjectVO value = getImageObjectValue();
	    return other != null && Comp.same(other.getName(), value.getName());
	}

	public UserPlayerDelegate getPlayer() {
		return MainWindow.getOwner();
	}
	
	public String getPlayerName() {
		return MainWindow.getOwnerName();
	}
	
	public String toString() {
		return getName();
	}
	
}
