/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.deligates.mot;

import mot.client.deligates.RelationDelegate;
import mot.common.bean.DiplomaticHistory;
import mot.common.util.ApplicationError;
import mot.common.util.Comp;
import mot.common.util.Logger;
import mot.common.vo.RelationResearchAgreementVO;
import mot.common.vo.RelationTradeAgreementVO;
import mot.common.vo.RelationVO;

public class MotRelationDelegate implements RelationDelegate {
	
	private RelationVO value;
 	
	public MotRelationDelegate(RelationVO value) {
		this.value = value;
	}
	
	public String getPlayerName1() {
		return value.getPlayer1Name();
	}

	public String getPlayerName2() {
		return value.getPlayer2Name();
	}

	public int getValue() {
		return value.getValue();
	}

	public int getValuePlayer1() {
		int v = value.getValue() + value.getPlayer1Rating();
		if (v < 0) v = 0;
		if (v > 100) v = 100;
		return v;
	}
	
	public int getValuePlayer2() {
		int v = value.getValue() + value.getPlayer2Rating();
		if (v < 0) v = 0;
		if (v > 100) v = 100;
		return v;
	}

	public int getValueOtherPlayer(String owner) {
		if (Comp.same(owner, value.getPlayer1Name())) {
			return getValuePlayer2();
		} else {
			return getValuePlayer1();
		}
	}

    public boolean canHaveWarTreaty() {
		return !isWar();
	}
    
    public boolean canHaveTradeTreaty() {
		return !isWar() && !hasTradeAgreement();
	}
    
    public boolean canHaveResearchTreaty() {
		return !isWar() && !hasResearchAgreement();
	}
    
    public boolean canHavePeaceTreaty() {
		return isWar();
	}
    
    public boolean canHaveNonAgressionTreaty() {
		return !isWar();
	}
    
    public boolean canHaveAllianceTreaty() {
		return !isWar();
	}

	public boolean isWar() {
		return value.isWar();
	}
	
	public boolean isNonAgression() {
		return value.isNonAgression();
	}
	
	public boolean isPeace() {
		return value.isPeace();
	}
	
	public boolean isAliance() {
		return value.isAliance();
	}
	
	public boolean hasTradeAgreement() {
		return getTradeAgreement() != null;
	}
	
	public boolean hasResearchAgreement() {
		return getResearchAgreement() != null;
	}
	
	public RelationTradeAgreementVO getTradeAgreement() {
		return value.getTradeAgreement();
	}
	
	public RelationResearchAgreementVO getResearchAgreement() {
		return value.getResearchAgreement();
	}

	public RelationTradeAgreementVO isTrade() throws ApplicationError {
		return value.getTradeAgreement();
	}

	public DiplomaticHistory getDiplomaticHistory() {
		return value.getDiplomaticHistory();
	}

	public boolean equals(String player1Name, String player2Name) {
		return Comp.same(value.getPlayer1Name(), player1Name) && Comp.same(value.getPlayer2Name(), player2Name) ||
			   Comp.same(value.getPlayer1Name(), player2Name) && Comp.same(value.getPlayer2Name(), player1Name);
	}
	
	public boolean contains(String playerName) {
		return Comp.same(value.getPlayer1Name(), playerName) || Comp.same(value.getPlayer2Name(), playerName);	
	}

	public String getOtherPlayerName(String playerName) {
		if (Comp.same(value.getPlayer1Name(), playerName)) {
			return value.getPlayer2Name();
		} else if (Comp.same(value.getPlayer2Name(), playerName)) {
			return value.getPlayer1Name();
		}
		Logger.logWarning("MotRelationDelegate.getOtherPlayerName() No other name for "+playerName+" in "+this); 
		return null;
	}
	
}