/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.deligates.mot;

import java.util.ArrayList;

import mot.client.deligates.PlanetDelegate;
import mot.client.deligates.SolarSystemDelegate;
import mot.client.deligates.cache.DeligateCacheManager;
import mot.common.bean.GalaxyGraphicsList;
import mot.common.bean.StellarObjectGraphics;
import mot.common.factory.GraphicsFactory;
import mot.common.util.ApplicationError;
import mot.common.util.Comp;
import mot.common.vo.OrbitVO;
import mot.common.vo.SolarSystemVO;
import mot.common.vo.StellarObjectVO;

public class MotSolarSystemDelegate extends MotStellarObjectDelegate implements SolarSystemDelegate {

	private SolarSystemVO value;
	
	private transient boolean rebuildPlanets = true;
	private transient PlanetDelegate[] planets;
	private transient StellarObjectGraphics starGraphicsZoomedIn;
	private transient StellarObjectGraphics starGraphicsZoomedOut;
	
	public MotSolarSystemDelegate() {
	}
	
    public MotSolarSystemDelegate(SolarSystemVO vo) {
		value = vo;
	}

	@Override
	public StellarObjectGraphics getGraphics(boolean zoomedIn) throws ApplicationError {
    	if (starGraphicsZoomedIn == null) {
	        GalaxyGraphicsList galaxyGraphics = GraphicsFactory.getGalaxyGraphicsList();
	        String starType = value.getStarType();
	        starGraphicsZoomedIn = galaxyGraphics.getStellarObjectGraphics(starType, true);
	        starGraphicsZoomedOut = galaxyGraphics.getStellarObjectGraphics(starType, false);
    	}
    	if (zoomedIn) {
    		return starGraphicsZoomedIn;
    	} else {
    		return starGraphicsZoomedOut;
    	}
	}

    @Override
	public String getGraphicsName() throws ApplicationError {
		return value.getStarType();
	}

	@Override
	public PlanetDelegate[] getPlanets() throws ApplicationError {
		if (rebuildPlanets) {
			planets = null;
			ArrayList pl = null;
			PlanetDelegate[] pa = DeligateCacheManager.getPlanets();
			for (int i = 0; i < pa.length; i++) {
				if (Comp.same(pa[i].getSolarSystemName(), value.getName())) {
					if (pl == null) pl = new ArrayList();
					pl.add(pa[i]);
				}
			}
			planets = (PlanetDelegate[]) ((pl != null) ? pl.toArray(new PlanetDelegate[pl.size()]) : null);
			rebuildPlanets = false;
		}
		return planets;
	}

	@Override
	public PlanetDelegate[] getColonies() throws ApplicationError {
		PlanetDelegate[] pa = getPlanets();
		if (pa == null || pa.length == 0) {			
			return null;
		} else {
			ArrayList r = null;
			for (int i = 0; i < pa.length; i++) {
				if (pa[i].hasOwner()) {
					if (r == null) r = new ArrayList();
					r.add(pa[i]);
				}
			}
			return (PlanetDelegate[]) ((r != null) ? r.toArray(new PlanetDelegate[r.size()]) : null);
		}
	}

	@Override
	public boolean canCreateTradeRoute() {
		return value.isCanCreateTradeRoute();
	}

	@Override
	public OrbitVO getOrbit() {
		return new OrbitVO(getName(), null);
	}

	@Override
	protected StellarObjectVO getStellObjectValue() {
		return value;
	}

	public void update(SolarSystemVO vo) {
		value = vo;
		rebuildPlanets = true;
		planets = null;
		stellarObjectOrbitalDelegate = null;
		starGraphicsZoomedIn = null;
		starGraphicsZoomedOut = null;	
		galaxyMapLabelSizeDetails = null;
	}

	public void update(StellarObjectVO vo) {
		update((SolarSystemVO) vo);
	}

	@Override
	public String toString() {
		return  value.getName() ;
	}

}
