/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.deligates.mot;
import mot.client.deligates.NamedObjectDelegate;
import mot.client.deligates.SolarSystemDelegate;
import mot.client.deligates.TradeRouteDelegate;
import mot.client.deligates.cache.DeligateCacheManager;
import mot.common.util.Comp;
import mot.common.util.NameValuePairList;
import mot.common.util.ValidationError;
import mot.common.vo.TradeRouteVO;

public class MotTradeRouteDelegate implements TradeRouteDelegate {

	private TradeRouteVO value;
	
	private SolarSystemDelegate solarSystem1;
	private SolarSystemDelegate solarSystem2;

	public MotTradeRouteDelegate(TradeRouteVO value) {
		this.value = value;
	}

	@Override
	public String toString() {
		return "MotTradeRouteDelegate [ss1=" + solarSystem1 + ", ss2=" + solarSystem2 + "]";
	}

	public SolarSystemDelegate getSolarSystem1() {
		if (solarSystem1 != null) return solarSystem1;
		String name = value.getSolarSystem1();
		if (name == null) return null;
		solarSystem1 = (SolarSystemDelegate) DeligateCacheManager.getStellarObject(name);
		return solarSystem1;
	}

	public String getSolarSystem1Name() {
		return value.getSolarSystem1();
	}

	public SolarSystemDelegate getSolarSystem2() {
		if (solarSystem2 != null) return solarSystem2;
		String name = value.getSolarSystem2();
		if (name == null) return null;
		solarSystem2 = (SolarSystemDelegate) DeligateCacheManager.getStellarObject(name);
		return solarSystem2;
	}

	public String getSolarSystem2Name() {
		return value.getSolarSystem2();
	}

	public int getStartDate() {
		return value.getStartDate();
	}

	public boolean contains(String solarSystemName) {
		getSolarSystem1();
		getSolarSystem2();
		return Comp.same(solarSystemName, solarSystem1) || Comp.same(solarSystemName, solarSystem2);
	}

	@Override
	public boolean equals(NamedObjectDelegate other) {
		return Comp.same(getName(), other.getName());
	}

	@Override
	public String getName() {
		return value.getSolarSystem1() + value.getSolarSystem2();
	}

	public int getTotalIndustryOutput() {
		// TODO Auto-generated method stub
		return 0;
	}

	public NameValuePairList getIndustryOutput() {
		return value.getProductionOutput();
	}

	public int getIndustryOutput(String planetName) {
		NameValuePairList v = value.getProductionOutput();
		if (v == null) return 0;
		try {
			return v.getParameterAsInt(planetName);
		} catch (ValidationError e) {
			return 0;
		}
	}

	public int getTotalResearchOutput() {
		// TODO Auto-generated method stub
		return 0;
	}

	public NameValuePairList getResearchOutput() {
		return value.getResearchOutput();
	}

	public int getResearchOutput(String planetName) {
		NameValuePairList v = value.getResearchOutput();
		if (v == null) return 0;
		try {
			return v.getParameterAsInt(planetName);
		} catch (ValidationError e) {
			return 0;
		}
	}

	@Override
	public boolean equals(String solarSystem1, String solarSystem2) {
		return Comp.same(solarSystem1, value.getSolarSystem1()) && Comp.same(solarSystem2, value.getSolarSystem2());
	}

}