/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.deligates.other;

import mot.client.deligates.mot.MotStellarObjectDelegate;
import mot.common.bean.GalaxyGraphicsList;
import mot.common.bean.StellarObjectGraphics;
import mot.common.bean.StellarObjectSummary;
import mot.common.factory.GraphicsFactory;
import mot.common.util.ApplicationError;
import mot.common.vo.OrbitVO;
import mot.common.vo.StellarObjectVO;

public class SummaryStellarObjectDeligate extends MotStellarObjectDelegate {

    protected StellarObjectSummary stellarObjectSummary;

	public SummaryStellarObjectDeligate(StellarObjectSummary stellarObjectSummary) {
		this.stellarObjectSummary = stellarObjectSummary;
	}

	@Override
	public StellarObjectGraphics getGraphics(boolean zoomedIn) throws ApplicationError {
        GalaxyGraphicsList galaxyGraphics = GraphicsFactory.getGalaxyGraphicsList();
        String starType = getGraphicsName();
		return galaxyGraphics.getStellarObjectGraphics(starType, false);
	}

	@Override
	public String getGraphicsName() throws ApplicationError {
		return stellarObjectSummary.getStarType();
	}
	
	@Override
	protected StellarObjectVO getStellObjectValue() {
		return stellarObjectSummary.getStellarObjectVO();
	}

	@Override
	public OrbitVO getOrbit() {
		return new OrbitVO(getName(), null);
	}

	@Override
	public void update(StellarObjectVO vo) {
		galaxyMapLabelSizeDetails = null;
	}

}