/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.event;

import mot.common.event.LinkedEventBase;
import mot.common.event.MotEvent;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

/**
 * This is the interface for all classes that receive and process mot events from the server
 * on behalf of a client. I would expect one implementation of this for each type of user interface.
 * Currently there is only a Swing implementation!
 */
public interface MotEventConsumer {
	/**
	 * Processes this event.
	 * @param e The event to process
	 * @param parent The parent of this event if this is a linked event. Null otherwise! 
	 * @throws ApplicationError
	 * @throws ValidationError
	 */
	void process(MotEvent e,  LinkedEventBase parent) throws ApplicationError, ValidationError;
	
	//SwingEventHandler getEventHandler(MotEvent e);
}