/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.online;

import javax.swing.JDialog;
import javax.swing.JFrame;
import javax.swing.UIManager;

import mot.client.MotCommandLineOptions;
import mot.client.swing.config.AnimationConfigFactory;
import mot.client.swing.config.ImageConfigFactory;
import mot.client.swing.window.etc.LoadProgressWindow;
import mot.client.swing.window.etc.StartupWindow;
import mot.client.swing.window.main.MainWindow;
import mot.common.bean.Settings;
import mot.common.designs.CraftDesigns;
import mot.common.factory.GraphicsFactory;
import mot.common.gifts.AncientGiftsFactory;
import mot.common.leaders.GeneralDetailsList;
import mot.common.leaders.GovenorDetailsList;
import mot.common.morals.MoralChoices;
import mot.common.setup.RelicsFactory;
import mot.common.technology.Technologies;
import mot.common.technology.TechnologyTree;
import mot.common.util.Logger;
import mot.common.util.PropertyManager;

public class WebStartMain {
    public static void main(String[] args) {
    	System.out.println("IN 3");
    	String music = MotCommandLineOptions.getMusic();
    	if (music == null) music = "sounds/background.wav";
    	Settings.newInstance(20, 1280, 1024, music, "SpacialDistortion,DroidMine,Detonator,SalvageBeam", 4);
        sleep();
    	if (MotCommandLineOptions.getLogToStdOut()) {
        	System.out.println("LOG TO STDOUT");
    		Logger.setLogToStdOut(true);
    	} else {
    		Logger.setSilent();
    	}
		Logger.setFull();
		Logger.setLogLevelLoaded();
		Logger.setLogToStdOut(true);
    	System.out.println("MUSIC");
        sleep();
    	System.out.println("TEST LOGGING (is in memory "+Logger.isInMemory()+") (Log to StdOut (is in memory "+Logger.isLogToStdOut()+")");
		Logger.setFull();
		Logger.logDebug("TEST LOGGING");;
        try {
        	System.out.println("Technologies - Pre load");
        	Technologies.preLoad();
        	System.out.println("Setup Options - Pre load");
        	TechnologyTree.preLoad();
        	System.out.println("AncientGiftsFactory - Pre load");
        	AncientGiftsFactory.preLoad();
        	System.out.println("GalaxyGraphicsList - Pre load");
        	GraphicsFactory.preLoadGalaxyGraphics();
        	System.out.println("RaceGraphicsList - Pre load");
        	GraphicsFactory.preLoadRaceGraphics();
        	System.out.println("ImageConfigFactory - Pre load");
        	ImageConfigFactory.preLoad();
        	System.out.println("GeneralDetailsList - Pre load");
        	GeneralDetailsList.preLoad();
        	System.out.println("GovenorDetailsList - Pre load");
        	GovenorDetailsList.preLoad();
        	System.out.println("MoralChoiceList - Pre load");
        	MoralChoices.preLoad();
        	System.out.println("Relics - Pre load");
        	RelicsFactory.preLoad();
        	System.out.println("Animation Config - Pre load");
        	AnimationConfigFactory.preLoad();
        	System.out.println("CraftDesigns - Pre load");
        	CraftDesigns.preLoad();
        	
        	System.out.println("UI");
            sleep();
            UIManager.setLookAndFeel(PropertyManager.getMandatory("look.and.feel"));
            JFrame.setDefaultLookAndFeelDecorated(true);	// to decorate frames
            JDialog.setDefaultLookAndFeelDecorated(true);	// to decorate dialogs
            if (!MotCommandLineOptions.getSkipLoadProgressWindow()) {
            	System.out.println("LOAD PROGRESS");
                sleep();
            	new LoadProgressWindow(null);
            }
        	System.out.println("MAIN WINDOW");
            sleep();
            MainWindow.getInstance();
        	System.out.println("STARTUP WINDOW");
            sleep();
            new StartupWindow();
        } catch (Exception e) {
        	System.out.println(e);
        	e.printStackTrace();
            sleep();
            Logger.logError("WebStartMain.Main() Failed due to error ",e);
            sleep();
            sleep();
        }
        sleep();
    }

	private static void sleep() {
		try {
			Thread.sleep(1000);
		} catch (InterruptedException e) {
			e.printStackTrace();
		}
	}
}