/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.proxy;

import mot.client.deligates.MoveableOwnedObjectDelegate;
import mot.client.deligates.PlanetDelegate;
import mot.client.deligates.PlayerDelegate;
import mot.client.deligates.SolarSystemDelegate;
import mot.client.deligates.StellarObjectDelegate;
import mot.common.util.ApplicationError;
import mot.engine.MotEngine;
import mot.engine.common.EngineVoFactory;
import mot.engine.common.MoveableOwnedObject;
import mot.engine.common.MoveableOwnedObjects;
import mot.engine.common.StellarObject;
import mot.engine.planets.Planet;
import mot.engine.planets.Planets;
import mot.engine.planets.SolarSystem;
import mot.engine.planets.StellarObjects;
import mot.engine.players.Player;
import mot.engine.players.Players;

public class LocalServerProxy {

	public MoveableOwnedObject getMoveableOwnedObject(String name) throws ApplicationError {
		if (name == null) return null;
		MoveableOwnedObjects crafts = MotEngine.instance.getMoveableOwnedObjects();
		if (crafts == null) return null;
		return crafts.getMOO(name);
	}

	public MoveableOwnedObject getMoveableOwnedObject(MoveableOwnedObjectDelegate c) throws ApplicationError {
		if (c == null) return null;
		return getMoveableOwnedObject(c.getName());
	}
	
	public Planet getPlanet(String name) {
		if (name == null) return null;
		Planets planets = MotEngine.instance.getPlanets();
		if (planets == null) return null;
		return planets.getPlanet(name);
	}

	public Planet getPlanet(PlanetDelegate p) {
		if (p == null) return null;
		return getPlanet(p.getName());
	}
	
	public SolarSystem getSolarSystem(String name) {
		if (name == null) return null;
		StellarObjects stellarObjects = MotEngine.instance.getStellarObjects();
		if (stellarObjects == null) return null;
		return (SolarSystem) stellarObjects.getStellarObject(name);
	}

	public SolarSystem getSolarSystem(SolarSystemDelegate s) {
		if (s == null) return null;
		return getSolarSystem(s.getName());
	}
	
	public Player getPlayer(String name) throws ApplicationError {
		if (name == null) return null;
		Players players = MotEngine.instance.getPlayers();
		if (players == null) return null;
		return players.getPlayer(name);
	}

	public Player getPlayer(PlayerDelegate p) throws ApplicationError {
		if (p == null) return null;
		return getPlayer(p.getName());
	}

	public StellarObject getStellarObject(String name) {
		if (name == null) return null;
		StellarObjects stellarObjects = MotEngine.instance.getStellarObjects();
		if (stellarObjects == null) return null;
		return stellarObjects.getStellarObject(name);
	}

	public StellarObject getStellarObject(StellarObjectDelegate s) {
		if (s == null) return null;
		return getStellarObject(s.getName());
	}

	public MoveableOwnedObjectDelegate[] getMoos() throws ApplicationError {
		MotEngine engine = MotEngine.getInstance();
		MoveableOwnedObject [] moos = engine.getMoveableOwnedObjects().getMOOs(null, false, true);
		if (moos == null) return null;
		return EngineVoFactory.getMooDelegates(moos, null);
	}

	public MotEngine getEngine() {
		return MotEngine.instance;
	}

}
