/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.proxy;

import java.util.ArrayList;

import mot.client.swing.window.main.MainWindow;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.Logger;

public class MotServerProxyCommandList {

	private ArrayList<MotServerProxyCommand> commands = new ArrayList<MotServerProxyCommand>();
	private ArrayList<MotServerProxyCommand> lostCommands = new ArrayList<MotServerProxyCommand>();
	
	public void add(MotServerProxyCommand c) throws ApplicationError {
		commands.add(c);
	}
	
	public MotServerProxyCommand getCommand(int sequence, boolean remove) {
		for (MotServerProxyCommand command : commands) {
			if (command != null && command.sequence == sequence) {
				if (remove) {
					commands.remove(command);
				}
				return command;
			}
		}
		for (MotServerProxyCommand command : lostCommands) {
			if (command != null && command.sequence == sequence) {
				Logger.logWarning("Command Recovered from Lost List "+command.sequence+" : "+command.command);
				if (remove) {
					lostCommands.remove(command);
				}
				return command;
			}
		}
		return null;
	}

	public int getQuantity() {
		return commands.size();
	}

	public void processTimeouts() throws ApplicationError {
		long timeNow = System.currentTimeMillis();
		if (commands.size() > 0) {			
			MotServerProxyCommand[] ca = commands.toArray(new MotServerProxyCommand[commands.size()]);
			for (int i = 0; i < ca.length; i++) {
				if (ca[i] != null) {			
					if (timeNow - ca[i].time > MotServerProxy.TIME_OUT_PEROID) {
						MainWindow.getInstance().showTemporaryMessage(L.LAST_COMMAND_CANCELLED, true, null, 0);
						Logger.logWarning("Command Time Out "+ca[i].sequence+" : "+ca[i].command);
						commands.remove(ca[i]);
						lostCommands.add(ca[i]);
					}
				}
			}
		}
		if (lostCommands.size() > 0) {			
			MotServerProxyCommand[] ca = lostCommands.toArray(new MotServerProxyCommand[commands.size()]);
			for (int i = 0; i < ca.length; i++) {
				if (ca[i] != null) {			
					if (timeNow - ca[i].time > MotServerProxy.DELETE_PEROID) {
						Logger.logWarning("Command Deleted "+ca[i].sequence+" : "+ca[i].command);
						lostCommands.remove(ca[i]);
					}
				}
			}
		}
	}
	
}
