/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.proxy;

import mot.common.util.ApplicationError;

/**
 * 
 * Client must instantiate an instance of proxy store before starting a Game.
 * The Proxy store is used to fetch
 *  - A Proxy to the server that allows the user interface components to talk to the server.
 *  - A Client Proxy Factory. Every new game created or loaded a new instance of the main window
 *    will be created and then a new Client Proxy will need to be registered with the server.
 */
public class ProxyStore  {

    private static ServerProxy instance;
    public static ServerProxy getInstance() throws ApplicationError {
//    	if (instance == null) {
//    		instance = new MotServerProxy(false);
//    	}
        return instance;
    }

    public ProxyStore(ServerProxy v) {
        instance = v;
    }
    
    public static boolean hasInstance() {
        return (instance != null);
    }
    
    public static void removeInstance() {
        instance = null;
    }

    /**
     * Remote servers support multiple clients while local clients do not.
     * @return True if this server supports multiple clients.
     */
	public static boolean canHaveMultipleUsers() {
		try {
			return getServerSocketClass() != null;
		} catch (Exception e) {
			return false;
		}
	}

	public static Class getServerSocketClass() {
		try {
			return Class.forName("mot.mp.ServerSocketThread");
		} catch (Exception e) {
			return null;
		}
	}
}