/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */

package mot.client.sounds;

import mot.common.util.ApplicationError;

/**
 * Play a sound in the game. There are two types of sound:
 * 	Sound effects - such as explosions, weapons fire etc
 *  Background - music
 * These are both types of sound.
 * If you want to know when the sound has finished playing,
 * add a listener. If you want to stop the sound before its
 * finished, call stop. You may call play and stop as many 
 * times as you like!
 */
public interface Sound {

	/**
	 * Start to play this sound (from the beginning) IF IT IS NOT PAUSED
	 * @throws ApplicationError 
	 */
	void replay() throws ApplicationError;
	
	/**
	 * Start to play this sound (from the beginning)
	 * @throws ApplicationError 
	 */
	void play() throws ApplicationError;
	
	/**
	 * Stop playing this sound it its playing
	 */
	void stop();
	
	/**
	 * Notify me when this sound completed
	 * @param l The listener that will be called when this sound finishes
	 */
	void addListener(SoundFinishedEventListener l);
	
	/**
	 * Sets the volume for this sound.
	 * @param v A value between 0.0 (silent) and 1.0 (loud)
	 */
	void setVolume(double v);

	
}
