/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.sounds;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Set;

import mot.common.util.ApplicationError;
import mot.common.xml.XMLDocumentHandler;

public class SoundConfigFactory {

	private static SoundConfigFactory instance;
	
	public static SoundConfigFactory getInstance() throws ApplicationError {
		if (instance == null) {
			instance = (SoundConfigFactory)XMLDocumentHandler.parseResource("xml/sound_config.xml");
		}
		return instance;
	}
	
	
	
	/**
	 * Maps the name of the animation type to the name of a sound used while animating.
	 */
	private HashMap<String, SoundConfig> soundNames = new HashMap<String,SoundConfig>();

	/**
	 * Maps the name of the animation type to the name of a sound used while animating.
	 */
	private HashMap<String, DamageSoundConfig> damageSounds = new HashMap<String,DamageSoundConfig>();

	public String [] getAllSoundNames() {
		Set<String> keys = soundNames.keySet();
		ArrayList<String> r = new ArrayList();
		for (Iterator i = keys.iterator(); i.hasNext();) {
			String name = (String) i.next();
			r.add(name);
		}
		return r.toArray(new String[r.size()]);
	}
	
	public String getSoundFile(String name) {
		if (soundNames == null) {
			return null;
		} else {
			SoundConfig soundConfig = soundNames.get(name);
			if (soundConfig != null) {
				return soundConfig.getValue();
			} else {
				return null;
			}
		}
	}
	
	public DamageSoundConfig getDamageSoundConfig(String name) {
		if (damageSounds == null) {
			return null;
		} else {
			return damageSounds.get(name);
		}
	}
	
	public void setSoundConfig(SoundConfig v) {
		soundNames.put(v.getName(), v);
	}
	
	public void setDamageSoundConfig(DamageSoundConfig v) {
		damageSounds.put(v.getName(), v);
	}
	
}
