/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.animation;

import mot.client.animation.EventAnimation;
import mot.client.animation.GraphicalAnimationContainer;
import mot.client.deligates.BattleCraftDelegate;
import mot.client.deligates.BattleObjectDelegate;
import mot.client.deligates.PlayerDelegate;
import mot.client.deligates.cache.DeligateCacheManager;
import mot.client.sounds.Sound;
import mot.common.bean.Area;
import mot.common.bean.CraftState;
import mot.common.bean.Location;
import mot.common.bean.Size;
import mot.common.event.BattleCraftMoveEvent;
import mot.common.util.ApplicationError;

/**
 * This is a base class for different animations moving a craft. A movement 
 * may be a shift or a turn.
 */
public class CraftMoveAnimation extends EventAnimation {

    protected BattleCraftDelegate craft;
    protected GraphicalAnimationContainer container;
    protected CraftState state;

    public CraftMoveAnimation(BattleCraftMoveEvent event, CraftState state, int life, GraphicalAnimationContainer container, Sound sound) throws ApplicationError {
        super(event, life, true, 0, container, sound);
        this.craft = DeligateCacheManager.getBattleCraft(event.getBattle(), event.getName());
        this.state = state;
        this.container = container;
    }

    /**
     * No other animation should be played at the same time as this animation.
     */
    public boolean isExclusive() {
        return true;
    }

    /**
     * Move Craft animation does not want the craft drawn because this
     * animation draws it.
     */
    public boolean vetoDrawObject(BattleObjectDelegate bo) {
        return bo.equals(craft) || super.vetoDrawObject(bo);
    }

	public CraftState getState() {
		return state;
	}

	public void setState(CraftState state) {
		this.state = state;
	}

	public void toString(StringBuffer sb) {
		sb.append("CraftMoveAnimation(");
		sb.append(craft.getName());
		linkedAnimationsToString(sb);
		sb.append(")");
	}
	
	public Area getArea() throws ApplicationError {
		Location loc = state.getLocation();
        Size imageSize = craft.getImageSize();
		return new Area(loc, imageSize.getX(), imageSize.getY());
	}

	public BattleCraftDelegate getCraft() {
		return craft;
	}

	public PlayerDelegate getAnimatedObjectOwner() throws ApplicationError {
		if (craft != null) {
			return DeligateCacheManager.getPlayer(craft.getOwner());
		} else {
			return null;
		}
	}

}