/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.animation;

import java.awt.Graphics2D;

import mot.client.animation.BattleAnimation;
import mot.client.animation.GraphicalAnimationContainer;
import mot.client.swing.animation.images.SpaceDistortionImage;
import mot.client.swing.common.ImageUtils;
import mot.common.bean.AnimatedBattleAreaDetails;
import mot.common.bean.Location;
import mot.common.bean.SpaceDistortionDetails;
import mot.common.util.ApplicationError;

public class CreateSpacialDistortionAnimation extends LinkedAnimation {
	
	private SpaceDistortionDetails spacialDistortion;
    private GraphicalAnimationContainer container;
    private SpaceDistortionImage spaceDistortionImage;

	public CreateSpacialDistortionAnimation(GraphicalAnimationContainer container, SpaceDistortionDetails sdd, BattleAnimation parent, boolean mustWait) throws ApplicationError {
		super(parent, mustWait, null);
		this.container = container;
		this.spacialDistortion = sdd;
		this.spaceDistortionImage = new SpaceDistortionImage(spacialDistortion.getWidth(), spacialDistortion.getHeight(), spacialDistortion.getCenterLocation());
	}

	public void paintActive(Object painter) throws ApplicationError {
        Graphics2D graphics = (Graphics2D) painter;
        
        Location loc = spaceDistortionImage.getLocation();
        int direction = spaceDistortionImage.getDirection();
        int width = spaceDistortionImage.getWidth() / getLife() * getStage();
        int height = spaceDistortionImage.getHeight() / getLife() * getStage();
        int imageLeft = loc.getX()-width/2;
        int imageTop = loc.getY()-height/2;
        String imageName = spaceDistortionImage.getImage();
        
        ImageUtils.drawRotatedImage(container.getContainer(), graphics, imageName, imageLeft, imageTop, width, height, loc, direction);
		//System.out.println("SD = "+area);
	}

	public boolean vetoDrawAnimatedArea(AnimatedBattleAreaDetails sdd) {
		if (sdd == null || spacialDistortion == null) return false;
		return sdd == spacialDistortion || spacialDistortion.equals(sdd);
	}
	

	public void toString(StringBuffer sb) {
		sb.append("CreateSpacialDistortionAnimation");
	}
	

}
