/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.animation;

import mot.client.animation.BattleAnimationList;
import mot.client.animation.GraphicalAnimationContainer;
import mot.client.deligates.BattleObjectDelegate;
import mot.client.deligates.cache.DeligateCacheManager;
import mot.client.swing.animation.decorator.SpinCAD;
import mot.client.swing.config.AnimationConfigFactory;
import mot.common.bean.CraftState;
import mot.common.bean.Location;
import mot.common.event.BattleDamageEvent;
import mot.common.event.BattleWeaponFireEvent;
import mot.common.technology.Weapon;
import mot.common.util.ApplicationError;
import mot.common.util.Comp;

public class DamageAnimationFactory  {

    public static void create(BattleWeaponFireEvent event, GraphicalAnimationContainer container, BattleAnimationList al) throws ApplicationError {
        AnimationConfigFactory configs = AnimationConfigFactory.getInstance();
        if (Comp.in(event.getWeaponTechnology().getGroup(), configs.getNoDamageAnimation())) {
            return;
        }
        if (event.getTarget() != null) {
        	BattleObjectDelegate target = DeligateCacheManager.getBattleObject(event.getBattle(), event.getTarget());
        	if (event.getTargetDescription() != null) {
        		create(event, container, target,  event.getOldTargetState(), event.getNewTargetState(), al, true);
        	}
        	if (event.getSourceDescription() != null) {
            	BattleObjectDelegate source = DeligateCacheManager.getBattleObject(event.getBattle(), event.getSource());
        		create(event, container, source, event.getOldSourceState(), event.getNewSourceState(), al, false);
        	}
        } else if (event.getTargetLocation(null) != null) {
        	if (event.getTargetDescription() != null) {
        		create(event, container, event.getTargetLocation(null), al, event.getTargetDescription());
        	}
        	if (event.getSourceDescription() != null) {
        		create(event, container, event.getTargetLocation(null), al, event.getSourceDescription());
        	}
        }
    }

    public static void create(BattleWeaponFireEvent event, GraphicalAnimationContainer container, BattleObjectDelegate bo, CraftState oldState, CraftState newState, BattleAnimationList al, boolean isAtTarget) throws ApplicationError {
        Weapon weapon = event.getWeaponTechnology();
		String group = weapon.getGroup();
    	if (al.getActiveAnimationFromBackOfClass(DamageAnimation.class, bo) != null) {
        	al.add(new DelayAnimation());
    	}
        DamageAnimation da = new DamageAnimation(event, container, bo, oldState, newState, isAtTarget, weapon);
        al.add( da );
        if (Comp.same(group, Weapon.GROUP_GIRATOR) && event.getWeaponDamage() > 0.0) {
            SpinCAD decortor = new SpinCAD(45);
            da.setCraftDecorator(decortor);
            al.add(new DelayAnimation());
            // Because of delay craft will not be painted by CraftDestroyed animation
            // so we must make sure damage animation does
            da.setDestroyed(false);
        }
    }

    public static void create(BattleWeaponFireEvent event, GraphicalAnimationContainer container, Location targetLoc, BattleAnimationList al, String damageDescription) throws ApplicationError {
        Weapon weapon = event.getWeaponTechnology();
		String group = weapon.getGroup();
		MessageAtLocationAnimation da = new MessageAtLocationAnimation(event, container, targetLoc, damageDescription, weapon);
        al.add( da );
    }

    public static void create(BattleDamageEvent event, GraphicalAnimationContainer container, BattleAnimationList al, boolean isAtTarget) throws ApplicationError {
        if (event.getOldTargetState() != null) {
        	BattleObjectDelegate target = DeligateCacheManager.getBattleObject(event.getBattle(), event.getTarget());
            create(event, container, target, event.getOldTargetState(), event.getNewTargetState(), al, isAtTarget);
        }
    }

    public static void create(BattleDamageEvent event, GraphicalAnimationContainer container, BattleObjectDelegate bo, CraftState oldState, CraftState newState, BattleAnimationList al, boolean isAtTarget) throws ApplicationError {
    	if (al.getActiveAnimationFromBackOfClass(DamageAnimation.class, bo) != null) {
        	al.add(new DelayAnimation());
    	}
        DamageAnimation da = new DamageAnimation(event, container, bo, oldState, newState, isAtTarget, null);
        al.add( da );
    }

}