/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.animation;

import mot.client.animation.BattleAnimationList;
import mot.client.animation.EventAnimation;
import mot.client.deligates.BattleCraftDelegate;
import mot.client.deligates.BattleObjectDelegate;
import mot.client.deligates.ImageObjectDelegate;
import mot.client.deligates.cache.DeligateCacheManager;
import mot.client.swing.window.battle.BattleWindowConfig;
import mot.client.swing.window.main.MainWindow;
import mot.common.event.BattleDamageEvent;
import mot.common.event.BattleDestroyedEvent;
import mot.common.event.MotEvent;
import mot.common.util.ApplicationError;
import mot.common.util.Comp;
import mot.common.util.ValidationError;

public class ExplodeAnimationFactory {
	
	public static EventAnimation create(BattleDestroyedEvent event, BattleAnimationList al, boolean drawWhenNonActive) throws ApplicationError, ValidationError {
		EventAnimation r = null;
		MainWindow mainWindow = MainWindow.getInstance();
        if (event.isHologram()) {
        	r = new HologramDestroyedAnimation(event, mainWindow);
            al.add(r);
        } else {
        	r = new ExplodeAnimation(event, drawWhenNonActive);
            al.add(r);
        }
        ImageObjectDelegate selection = mainWindow.getImageSelection();
        if (selection != null && Comp.same(selection.getName(), event.getTarget())) {
            BattleWindowConfig config = mainWindow.getBattleWinConfig();
            config.getListener().select(null, false);
        }
        MotEvent[] links = event.getLinkedEvents();
        if (links != null) {
            for (int i=0; i<links.length; i++) {
                if (links[i] instanceof BattleDestroyedEvent) {
                	BattleDestroyedEvent subEvent = (BattleDestroyedEvent)links[(i)];
                	create(subEvent, al, false);
                }
            }
        }
        return r;
	}
	
	public static void create(BattleDamageEvent event, BattleAnimationList al) throws ApplicationError {
		MainWindow mainWindow = MainWindow.getInstance();
		BattleObjectDelegate target = DeligateCacheManager.getBattleObject(event.getBattle(), event.getTarget());
        if (target instanceof BattleCraftDelegate && ((BattleCraftDelegate)target).isHologram() ) {
            al.add( new HologramDestroyedAnimation(event, (BattleCraftDelegate) target, event.getOldTargetState(), mainWindow) );
        } else {
            al.add( new ExplodeAnimation(event, target, false) );
        }
	}
}
