/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.animation;

import java.awt.Graphics2D;

import mot.client.animation.EventAnimation;
import mot.client.animation.GraphicalAnimationContainer;
import mot.client.deligates.BattleObjectDelegate;
import mot.client.deligates.cache.DeligateCacheManager;
import mot.client.sounds.SoundEffect;
import mot.client.swing.common.ImageUtils;
import mot.client.swing.config.ImageAnimationConfig;
import mot.common.bean.Area;
import mot.common.bean.CraftState;
import mot.common.bean.Location;
import mot.common.bean.Size;
import mot.common.event.BattleObjectTriggerEvent;
import mot.common.util.ApplicationError;

/**
 * Causes craft turning movement to be animated on the screen.
 */
public class ImageSequenceAnimation extends EventAnimation {

	private GraphicalAnimationContainer container;
    private ImageAnimationConfig config;
    private BattleObjectDelegate target;
    private CraftState state;
	private Double sizePercent;
    
    
    public ImageSequenceAnimation(BattleObjectTriggerEvent event, GraphicalAnimationContainer container, ImageAnimationConfig config, Double sizePercent, SoundEffect soundEffect) throws ApplicationError {
        super(event, config.getQtyImages(), true, 1, soundEffect);
        
        this.target = DeligateCacheManager.getBattleObject(event.getBattle(), event.getBattleObject());
        this.state = event.getOriginalState();
        this.sizePercent = sizePercent;
        this.container = container;
        this.config = config;
    }

    /**
     * paints this animation on the screen.
     * This object is part of the local swing GUI interface implementation so
     * object must be a Graphics2D object.
     */
    public void paintActive(Object painter) throws ApplicationError {
        Graphics2D graphics = (Graphics2D) painter;
        String image = config.getActualImage();
    	Location loc = state.getLocation();
    	if (sizePercent != null) {
            Size imageSize = target.getImageSize();
    		int width = (int) (imageSize.getX() * sizePercent);
    		int height = (int) (imageSize.getY() * sizePercent);
    		ImageUtils._drawImageCenteredAt(container.getContainer(), graphics, image, loc.getX(), loc.getY(), width, height);
    	} else {
            Size imageSize = target.getImageSize();
    		ImageUtils._drawImageCenteredAt(container.getContainer(), graphics, image, loc.getX(), loc.getY(), imageSize.getX(), imageSize.getY());
    	}
    }

    public boolean isExclusive() {
        return false;
    }

	public void toString(StringBuffer sb) {
		sb.append("ImageSequenceAnimation(");
		sb.append(target.getName());
		sb.append(")");	
	}

	public Area getArea() throws ApplicationError {
        Size imageSize = target.getImageSize();
		return new Area(state.getLocation(), imageSize.getX(), imageSize.getY());
	}

}
