/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.animation;

import mot.client.animation.BattleAnimation;
import mot.client.animation.BattleAnimationList;
import mot.client.animation.GraphicalAnimationContainer;
import mot.client.deligates.BattleObjectDelegate;
import mot.client.deligates.cache.DeligateCacheManager;
import mot.common.bean.CraftState;
import mot.common.event.BattleObjectNotificationEvent;
import mot.common.event.BattleObjectTriggerEvent;
import mot.common.technology.Weapon;
import mot.common.util.ApplicationError;
import mot.common.util.Comp;
import mot.common.util.Logger;

public class MessageAnimationFactory  {

    public static void create(BattleObjectNotificationEvent event, GraphicalAnimationContainer container, BattleAnimationList al) throws ApplicationError {
    	BattleObjectDelegate target = DeligateCacheManager.getBattleObject(event.getBattle(), event.getTarget());
        create(event, container, target, event.getOldTargetState(), event.getNewTargetState(), al);
    }

    public static void create(BattleObjectNotificationEvent event, GraphicalAnimationContainer container, BattleObjectDelegate bo, CraftState oldState, CraftState newState, BattleAnimationList al) throws ApplicationError {
        if (al.containsActiveAnimationForFromBack(bo)) {
        	al.add(new DelayAnimation(1));
        } else if (al.getQuantity() > 0) {
        	BattleAnimation aa = al.getAnimationOfClassFromBackOrLastActive(MessageAnimation.class);
        	if (aa != null && aa.getClass() != MessageAnimation.class || (aa instanceof MessageAnimation && ((MessageAnimation)aa).getType() != event.getType())) {
        		al.add(new DelayAnimation(1));
        	}
        }
        MessageAnimation ma = new MessageAnimation(event, container, bo, oldState, newState);
        al.add( ma );
    }

    public static void create(BattleObjectTriggerEvent event, GraphicalAnimationContainer container, BattleObjectDelegate bo, CraftState oldState, CraftState newState, BattleAnimationList al) throws ApplicationError {
    	if (Comp.same(event.getType(), Weapon.GROUP_DAMAGE_BOT)) {
            if (al.containsActiveAnimationForFromBack(bo)) {
            	al.add(new DelayAnimation(1));
            } else if (al.getQuantity() > 0) {
            	BattleAnimation aa = al.getAnimationOfClassFromBackOrLastActive(BotAttackAnimation.class);
            	if (aa != null && aa.getClass() != BotAttackAnimation.class && !al.lastAnimationIsExplodeFor(bo,0)) {
            		al.add(new DelayAnimation(1));
            	} else if (!al.lastAnimationsInList(BotAttackAnimation.class, DamageAnimation.class)) {
            		al.add(new DelayAnimation(1));
            	}
            }
            al.add(new BotAttackAnimation(event, container));
            al.add(new DamageAnimation(container, event));
    	} else if (Comp.same(event.getType(), Weapon.GROUP_PLAGUE)) {
            if (al.containsActiveAnimationForFromBack(bo)) {
            	al.add(new DelayAnimation(1));
            } else if (al.getQuantity() > 0) {
            	BattleAnimation aa = al.getAnimationOfClassFromBackOrLastActive(PlagueStrikeAnimation.class);
            	if (aa == null || aa != null && aa.getClass() != PlagueStrikeAnimation.class) {
            		al.add(new DelayAnimation(1));
            	} else if (!al.lastAnimationsInList(PlagueStrikeAnimation.class, DamageAnimation.class)) {
            		al.add(new DelayAnimation(1));
            	}
            }
            al.add(new PlagueStrikeAnimation(event, container));
            al.add(new DamageAnimation(container, event));
    	} else if (Comp.same(event.getType(), Weapon.GROUP_SLEEP)) {
            if (al.containsActiveAnimationForFromBack(bo)) {
            	al.add(new DelayAnimation(1));
            } else if (al.getQuantity() > 0) {
            	BattleAnimation aa = al.getAnimationOfClassFromBackOrLastActive(SleepStrikeAnimation.class);
            	if (aa != null && aa.getClass() != SleepStrikeAnimation.class) {
            		al.add(new DelayAnimation(1));
            	} else if (!al.lastAnimationsInList(SleepStrikeAnimation.class, DamageAnimation.class)) {
            		al.add(new DelayAnimation(1));
            	}
            }
            al.add(new SleepStrikeAnimation(event, container));
            al.add(new DamageAnimation(container, event));
    	} else {
    		Logger.logWarning("Type not handled "+event.getType());
    	}
    }

}