/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.animation;

import java.awt.Color;
import java.awt.Graphics2D;

import mot.client.animation.EventAnimation;
import mot.client.animation.GraphicalAnimationContainer;
import mot.client.swing.common.PenUtils;
import mot.client.swing.config.AnimationConfig;
import mot.common.bean.Location;
import mot.common.event.MotEvent;
import mot.common.technology.Weapon;
import mot.common.util.ApplicationError;
import mot.common.util.Logger;

/**
 * Causes damage to a craft to be display on the screen.
 */
public class MessageAtLocationAnimation extends EventAnimation {

    private GraphicalAnimationContainer container;

    /**
     * This is the the location the damage occurred at. 
     */
    private Location target;
    
    /**
     * The message displayed to users.
     */
    private String message;
    
    /**
     * The weapon that caused the damage
     */
	private Weapon weapon;
	
    public MessageAtLocationAnimation(MotEvent event, GraphicalAnimationContainer container, Location targetLoc, String message, Weapon weapon) throws ApplicationError {
        super(event, AnimationConfig.damageAnimation(), true, 0, null);
        this.target = targetLoc;
        this.message = message;
		this.weapon = weapon;
        if (Logger.isDebug()) {
       		Logger.logDebug("MessageAtLocationAnimation.init() "+target+" "+message);
        }
	}
    
    /**
     * Paints the damage animation and the target craft with its current damage
     */
    public void paintActive(Object painter) throws ApplicationError {
		super.paintActive(painter);
        Graphics2D graphics = (Graphics2D) painter;
        PenUtils.setFontBold(graphics);
        graphics.setColor(Color.RED);
        int stage = getStage();
        graphics.drawString(message, target.getX()-message.length()*4, target.getY()-stage*3);
    }

	public void toString(StringBuffer sb) {
		sb.append("MessageAtLocationAnimation(");
		if (target != null) {
			sb.append(target);
		}
		linkedAnimationsToString(sb);
		sb.append(")");
	}


}