/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.animation;

import java.awt.Color;
import java.awt.Graphics2D;

import mot.client.animation.EventAnimation;
import mot.client.animation.GraphicalAnimationContainer;
import mot.client.deligates.BattleObjectDelegate;
import mot.client.deligates.ImageObjectDelegate;
import mot.client.deligates.PlayerDelegate;
import mot.client.deligates.cache.DeligateCacheManager;
import mot.client.sounds.Sounds;
import mot.common.bean.Location;
import mot.common.event.BattleWeaponMissEvent;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.Logger;

/**
 * Causes Miss Target message to be animated above the firing craft.
 * Does not animate weapon fire!
 */
public class MissTargetAnimation2 extends EventAnimation {


	private GraphicalAnimationContainer container;

    /**
     * This is the craft that has missed its target
     */
    private ImageObjectDelegate io;
    private BattleObjectDelegate sourceCraft;
    
    /**
     * The message displayed to users.
     */
    private String message;

    /**
     * The location of the craft when this missile was launched.
     */
	private Location location;
    
    public MissTargetAnimation2(BattleWeaponMissEvent event, GraphicalAnimationContainer container, Location location) throws ApplicationError {
        super(event, 20, true, 0, Sounds.getSound("WeaponMiss"));
		this.location = location;
		this.io = DeligateCacheManager.getBattleObject(event.getBattle(), event.getSource());
		this.sourceCraft = null;
        this.container = container;
        this.message = L.NO_LOCK;
        
        if (io instanceof BattleObjectDelegate) sourceCraft = (BattleObjectDelegate) io;
        
    	if (Logger.isDebug()) {
            Logger.logDebug("MissTargetAnimation2.init() "+io.getName());
        }
    }

    /**
     * Paints the damage animation and the target craft with its current damage
     */
    public void paintActive(Object painter) throws ApplicationError {
        Graphics2D graphics = (Graphics2D) painter;
        graphics.setColor(Color.ORANGE);
        int stage = getStage();
        graphics.drawString(message, location.getX()-message.length()*4, location.getY()-stage*3);
    }
    
	public boolean isExclusive() {
		return true;
	}

	public PlayerDelegate getAnimatedObjectOwner() throws ApplicationError {
		if (sourceCraft != null) {
			return sourceCraft.getOwnerDelegate();
		} else {
			return null;
		}
	}
	
	public void toString(StringBuffer sb) {
		sb.append("MissTargetAnimation2");
	}

}