/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.animation;

import java.util.ArrayList;

import mot.client.animation.EventAnimation;
import mot.client.bean.BattleCraftDeligateStateTupple;
import mot.client.deligates.BattleCraftDelegate;
import mot.client.deligates.BattleObjectDelegate;
import mot.client.deligates.cache.DeligateCacheManager;
import mot.client.sounds.Sound;
import mot.common.event.BattleDamageEvent;
import mot.common.event.MotEvent;
import mot.common.util.ApplicationError;

/**
 * Causes a shock wave animation from a single point outwards until its damage is zero.
 */
public abstract class MultiDamageAnimation extends EventAnimation {

	public MultiDamageAnimation(MotEvent event, int life, boolean after, int interval, Sound sound) throws ApplicationError {
		super(event, life, after, interval, sound);
	}

	private ArrayList<BattleCraftDeligateStateTupple> damagedObjects = new ArrayList();

	public void addDamagedBattleObject(MotEvent event) {
		if (event instanceof BattleDamageEvent) {
			BattleDamageEvent de = (BattleDamageEvent) event;
			BattleObjectDelegate target = DeligateCacheManager.getBattleObject(de.getBattle(), de.getTarget());
			if (target != null && target instanceof BattleCraftDelegate) {
				if (de.getCraftState() != null) {
					// Must use New State because craft may be destroyed and we
					// need to know
					damagedObjects.add(new BattleCraftDeligateStateTupple((BattleCraftDelegate) target, de.getNewTargetState()));
				}
			}
		}
	}

	public BattleCraftDeligateStateTupple[] getDamagedObjects() {
		return damagedObjects.toArray(new BattleCraftDeligateStateTupple[damagedObjects.size()]);
	}

}