/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.animation;

import mot.client.animation.GraphicalAnimationContainer;
import mot.client.sounds.Sounds;
import mot.client.swing.config.AnimationConfigFactory;
import mot.common.event.BattleObjectTriggerEvent;
import mot.common.util.ApplicationError;
import mot.common.util.Logger;

/**
 * Causes craft turning movement to be animated on the screen.
 */
public class SleepStrikeAnimation extends ImageSequenceAnimation {

    private static final String ANIMATION_CONFIG_NAME = "SleepStrike";
    private static final String SOUND_NAME = "WeaponFireSleep";

    public SleepStrikeAnimation(BattleObjectTriggerEvent event, GraphicalAnimationContainer container) throws ApplicationError {
        super(event, container, AnimationConfigFactory.getInstance().getImageAnimationConfig(ANIMATION_CONFIG_NAME), 0.75, Sounds.getSound(SOUND_NAME));

        if (Logger.isDebug()) {
            Logger.logDebug("SleepStrikeAnimation.init() "+event.getBattleObject());
        }
    }
}
