/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.animation;

import java.awt.Graphics2D;
import java.awt.Image;
import java.awt.Window;

import mot.client.animation.EventAnimation;
import mot.client.animation.GraphicalAnimationContainer;
import mot.client.deligates.BattleObjectDelegate;
import mot.client.deligates.PlayerDelegate;
import mot.client.deligates.cache.DeligateCacheManager;
import mot.client.swing.animation.images.TimeWarpImage;
import mot.client.swing.common.ImageCache;
import mot.client.swing.common.ImageUtils;
import mot.client.swing.config.AnimationConfigFactory;
import mot.client.swing.config.WeaponFireAnimationConfig;
import mot.common.bean.CraftState;
import mot.common.event.BattleWeaponFireEvent;
import mot.common.util.ApplicationError;
import mot.common.util.Logger;

public class TimeWarpAnimation extends EventAnimation  {

    private GraphicalAnimationContainer container;
    private BattleObjectDelegate target;
    private CraftState state;
    private TimeWarpImage image;

    public TimeWarpAnimation(WeaponFireAnimationConfig config, BattleWeaponFireEvent event, GraphicalAnimationContainer container) throws ApplicationError {
        super(event, AnimationConfigFactory.getInstance().getQtyImagesAnimationConfig(TimeWarpImage.NAME), true, 1, null);
        this.target = DeligateCacheManager.getBattleObject(event.getBattle(), event.getSource());
        this.state = event.getOldSourceState();
        this.container = container;
        
        if (state != null) {
        	this.image = new TimeWarpImage(state.getLocation());
        } else {
        	this.image = new TimeWarpImage(target.getLocation());
        }

        if (Logger.isDebug()) {
            Logger.logDebug("TimeWarpAnimation.init() "+target.getName()+" @ "+image.getLocation());
        }
    }

    /**
     * paints this animation on the screen.
     * This object is part of the local swing GUI interface implementation so
     * object must be a Graphics2D object.
     */
    public void paintActive(Object painter) throws ApplicationError {
        Graphics2D graphics = (Graphics2D) painter;
        image.setIndex(getStage()+1);
        ImageUtils.drawRotatedImage(container.getContainer(), graphics, image);
        //Logger.logDebug("TimeWarpAnimation.paintActive() "+((WeaponFireEvent)getEvent()).getCraft().getName());
    }
    
    public static void loadAllImages(Window window) throws ApplicationError {
    	TimeWarpImage timeWarp = new TimeWarpImage();
        for (int i=1; i<AnimationConfigFactory.getInstance().getQtyImagesAnimationConfig(TimeWarpImage.NAME); i++) {
        	timeWarp.setIndex(i);
            String imageName = timeWarp.getImage();
            Image image = ImageCache.getImage(window.getToolkit(), imageName);
            window.getGraphics().drawImage(image, 1100, 1100, 2, 2, window);
        }
    }

	public PlayerDelegate getAnimatedObjectOwner() throws ApplicationError {
		if (target != null) {
			return target.getOwnerDelegate();
		} else {
			return null;
		}
	}
	

	public void toString(StringBuffer sb) {
		sb.append("TimeWarpAnimation(");
		sb.append(target.getName());
		sb.append(")");
	}

}