/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */

package mot.client.swing.animation.images;
import mot.client.deligates.BattleObjectDelegate;
import mot.client.swing.config.AnimationConfigFactory;
import mot.client.swing.config.ImageAnimationConfig;
import mot.common.bean.CraftState;
import mot.common.bean.ImageObject;
import mot.common.bean.Location;
import mot.common.bean.Size;
import mot.common.util.ApplicationError;

public class HoloGoneImage extends ImageObject {

	public static final String NAME = "hologram_destroyed";
    private ImageAnimationConfig config;
    
    /**
     * The size of this image
     */
    private Size size;

    /**
     * The index of the image to display.
     */
    private int index;

    public HoloGoneImage(BattleObjectDelegate craft, CraftState state) throws ApplicationError {
        this(craft.getImageSize(), state == null ? craft.getLocation() : state.getLocation());
    }

    public HoloGoneImage(Size size, Location location) throws ApplicationError {
        super("HoloGoneImage", location);
        this.size = size;
        config = AnimationConfigFactory.getInstance().getImageAnimationConfig(NAME);
    }

    public String getDescription() {
        return "Hologram Destroyed";
    }

    public Size getSize() throws ApplicationError {
        return size;
    }

    public void setIndex(int index) {
        this.index = index;
    }

    public int getIndex() {
        return index;
    }

    public String getElementName() { return null; }

    public String getImage() throws ApplicationError {
        return config.getImage()+index+config.getImageType();
    }

    public int getDirection() { return mot.client.swing.common.ImageUtils.NO_ROTATION_DIRECTION; }
}