/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.animation.images;

import mot.client.swing.common.ImageUtils;
import mot.client.swing.config.AnimationConfigFactory;
import mot.client.swing.config.ImageAnimationConfig;
import mot.common.bean.ImageObject;
import mot.common.bean.Location;
import mot.common.bean.Size;
import mot.common.util.ApplicationError;

public class TimeWarpImage extends ImageObject {

	public static final String NAME = "time_warp";

    private ImageAnimationConfig config;

    /**
     * The index of the image to display.
     */
    private int index;

    public TimeWarpImage() throws ApplicationError {
        config = AnimationConfigFactory.getInstance().getImageAnimationConfig(NAME);
    }
    
    public TimeWarpImage(Location location) throws ApplicationError {
    	super(NAME, location);
        config = AnimationConfigFactory.getInstance().getImageAnimationConfig(NAME);
    }

    public String getImage() {
        return config.getImage()+index+config.getImageType();
    }
    
    public Size getSize() throws ApplicationError {
        return config.getImageSize();
    }
    
    public void setIndex(int index) {
        this.index = index;
    }


    public int getIndex() {
        return index;
    }
    
    public int getDirection() { return ImageUtils.NO_ROTATION_DIRECTION; }

    public String getDescription() {
		return null;
	}

	protected String getElementName() {
		return null;
	}

}
