/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.animation.strokes;

import java.awt.BasicStroke;
import java.awt.Color;
import java.awt.Container;
import java.awt.Graphics2D;

import mot.client.swing.config.WeaponFireAnimationConfig;
import mot.common.bean.Location;
import mot.common.util.ApplicationError;

/**
 * This is the stroke used by beam weapons such as Fusion Beams, Phasors etc.
 */
public class BeamStroke implements WeaponStroke {

    BasicStroke stroke;
    private Color color;

    public BeamStroke() {
        stroke = new BasicStroke(1.0f);
        color = Color.YELLOW;
    }

    public BeamStroke(WeaponFireAnimationConfig config) {
        stroke = new BasicStroke(1.0f);
        color = config.getStrokeColorColor();
        if (color == null) {
        	color = Color.YELLOW;
        }
        
    }

    public void paint(Container container, Graphics2D graphics, int stage, Location source, Location destination) throws ApplicationError {
        graphics.setColor(color);
        graphics.setStroke(stroke);
        graphics.drawLine(source.getX(), source.getY(), destination.getX(), destination.getY());
    }
    
    public boolean isCacheable() { return true; }

}