/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.animation.strokes;

import java.awt.Container;
import java.awt.Graphics2D;

import mot.common.bean.Location;
import mot.common.util.ApplicationError;

/**
 * Defines the interface to all lines that are used to render weapon fire animations.
 */
public interface WeaponStroke {

    /**
     * Creates the stroke to be used to draw this weapon
     * @param stage The stage in the animation this stroke is being used at.
     * @return The stroke to use.
     */
    public void paint(Container container, Graphics2D graphics, int stage, Location source, Location destination) throws ApplicationError;
    
    /**
     * Strokes that contain animation specific animation such as locatiopns are not cacheable!
     * e.g. DamageBot and Plague
     * @return True if this stroke can be created once and used for all animations afterwards.
     */
    public boolean isCacheable();
}