/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.buttons;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import mot.client.swing.window.main.MainWindow;
import mot.common.util.ApplicationError;
import mot.common.util.Logger;
import mot.common.util.ValidationError;

public class GenericAction implements ActionListener {

	/**
	 * Some windows want to be notified when an action has been executed - say to refresh 
	 * their contents. If this is not null then the () method will be called AFTER the
	 * action has been performed.
	 */
	private ActionObserver notifier;
	
	public GenericAction() {
	}
	
	public GenericAction(ActionObserver notifier) {
		this.notifier = notifier;
	}
	
    public void actionPerformed(ActionEvent e) {
        runAction();
    }

	private void runAction() {
        if (Logger.isDebug()) {
            Logger.logDebug("GenericAction.runAction() Action="+getClass().getName());
        }
        try {
        	doPreAction();
        	_doAction();
        	doPostAction();
        } catch (ValidationError ex) {
            MainWindow.getExestingInstance().reportValidationError(ex);
        } catch (Exception ex) {
        	MainWindow.getExestingInstance().reportApplicationError(ex);
        }
    }

    protected void doPreAction() throws ApplicationError, ValidationError { }
    protected void _doAction() { };
    protected void doPostAction() throws ApplicationError, ValidationError {
    	if (notifier != null) {
    		notifier.actionNotification();
    	}
    }

}
