/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.buttons;

import mot.client.proxy.ClientErrorHandler;
import mot.client.sounds.SoundEffect;
import mot.client.sounds.Sounds;
import mot.client.swing.window.main.MainWindow;
import mot.common.util.ApplicationError;
import mot.common.util.Logger;
import mot.common.util.ValidationError;

/**
 * DO not use this class directly.
 * Please use one of 
 * 	1) MotActionListsner for buttons / actions
 *  2) MotActionSelectionListener for lists
 *  3) MotActionClickListener for lists
 */
public abstract class MotAction implements ClientErrorHandler {

	protected boolean playSound() { return true; }
	
	public void runAction() {
        if (Logger.isDebug()) {
            Logger.logDebug("MotAction.runAction() Action="+getClass().getName());
        }
        if (playSound()) {
    		try {
    			SoundEffect sound = Sounds.getActionSound();
    			if (sound != null && !sound.isPlaying()) {
    				sound.play();
    			}
    		} catch (ApplicationError ex) {
            	Logger.logError("Play action sound failed", ex);
    		}
        }
        try {
        	_doAction();
        } catch (ValidationError ex) {
        	reportValidationError(ex);
        } catch (Exception ex) {
        	reportApplicationError(ex);
        }
    }

	public void reportValidationError(ValidationError ex) {
		try {
			SoundEffect sound = Sounds.getActionSound();
			if (sound != null && !sound.isPlaying()) {
				sound.play();
			}
		} catch (ApplicationError e) {
			Logger.logError("Stop Sound failed", e);
		}
        MainWindow.getExestingInstance().reportValidationError(ex);
	}
	
	public void reportApplicationError(Exception ex) {
    	MainWindow.getExestingInstance().reportApplicationError(ex);
	}

    protected abstract void _doAction() throws ApplicationError, ValidationError;
	
}
