/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.buttons;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.JCheckBox;

import mot.client.swing.window.battle.actions.MotBattleMapActions;
import mot.client.swing.window.galaxy.MotGalaxyMapActions;
import mot.client.swing.window.main.MainWindow;
import mot.common.util.ApplicationError;
import mot.common.util.Logger;
import mot.common.util.ValidationError;

public abstract class MotCheckBox extends JCheckBox implements ActionListener, MotGalaxyMapActions, MotBattleMapActions {

	public MotCheckBox() {
		addActionListener(this);
	}
	
	public MotCheckBox(String text) {
		super(text);
		addActionListener(this);
	}
	
    public void actionPerformed(ActionEvent e) {
        runAction();
    }

	private void runAction() {
        if (Logger.isDebug()) {
            Logger.logDebug("MotCheckBox.runAction() Action="+getClass().getName());
        }
        try {
        	_doAction();
        } catch (ValidationError ex) {
            MainWindow.getExestingInstance().reportValidationError(ex);
        } catch (Exception ex) {
        	MainWindow.getExestingInstance().reportApplicationError(ex);
        }
    }

    protected abstract void _doAction() throws ApplicationError, ValidationError;
    
	
}
