/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.buttons;

import java.awt.Color;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;

import javax.swing.JLabel;
import javax.swing.JPanel;

import mot.client.sounds.Sound;
import mot.client.sounds.Sounds;
import mot.client.swing.common.ComponentTable;
import mot.client.swing.config.ImageConfigFactory;
import mot.client.swing.config.MenuConfig;
import mot.client.swing.window.main.MainWindow;
import mot.common.util.ApplicationError;
import mot.common.util.Logger;
import mot.common.util.ValidationError;

/**
 * A JLabel that is used to display the name of on the screen.
 */
public abstract class MotLabelButton extends ComponentTable implements MouseListener {

	/**
	 * The object this button is about.
	 */
	private Object subject;
	
    /**
     * If this is not null then it is displayed as a helpful tip.
     */
    private String tipText;

	private JLabel label;

	private static Color tipBackground;
	
	static {
		try {
			MenuConfig menuConfig = ImageConfigFactory.getInstance().getMenuConfig();
			tipBackground = menuConfig.getTipBackground().getColor();
		} catch (Exception e) {
			Logger.logError("", e);
		}
	}

//    public void repaint(long tm, int x, int y, int width, int height) {
//    	Logger.logDebug("MotLabelButton.repaint() label="+(label == null ? "null" : label.getText())+" "+System.currentTimeMillis()); 
//    	super.repaint(tm, x, y, width, height);
//    	
//
//    }
//
//    public void paint(Graphics g) {
//    	Logger.logDebug("MotLabelButton.paint() label="+(label == null ? "null" : label.getText())+" "+System.currentTimeMillis()); 
//    	super.paint(g);
//
//    }
//
//    public void paintComponent(Graphics g) {
//    	Logger.logDebug("MotLabelButton.paintComponent() label="+(label == null ? "null" : label.getText())+" "+System.currentTimeMillis()); 
//    	super.paintComponent(g);
//
//    }


    public MotLabelButton(JPanel icon, JLabel label, String tipText, Object subject) {
    	super((icon != null && label != null) ? "HV,HCSP" : "HVSP", 1, (icon != null && label != null) ? 2 : 1, 1,2,0);
    	this.subject = subject;
    	this.label = label;
    	
        setToolTipText(tipText);
        addMouseListener(this);
        
        if (icon != null) add(icon);
		if (label != null) add(label);
		
    }

	private void runAction() {
        if (Logger.isDebug()) {
            Logger.logDebug("MotImageButton.runAction() Action="+label.getText());
        }
    	try {
    		Sound sound = Sounds.getActionSound();
    		if (sound != null) {
    			sound.play();
    		}
    	} catch (Exception ex) {
    		Logger.logError("No Sound", ex);
    	}
        try {
        	_doAction();
        } catch (ValidationError ex) {
            MainWindow.getExestingInstance().reportValidationError(ex);
        } catch (Exception ex) {
        	MainWindow.getExestingInstance().reportApplicationError(ex);
        }
    }

    protected abstract void _doAction() throws ApplicationError, ValidationError;

	private void runDoubleClickAction() {
        if (Logger.isDebug()) {
            Logger.logDebug("MotImageButton.runDoubleClickAction() Action="+label.getText());
        }
        try {
        	_doDoubleClickAction();
        } catch (ValidationError ex) {
            MainWindow.getExestingInstance().reportValidationError(ex);
        } catch (Exception ex) {
        	MainWindow.getExestingInstance().reportApplicationError(ex);
        }
    }

    protected void _doDoubleClickAction() throws ApplicationError, ValidationError {
    }

    public void mouseClicked(MouseEvent e) {
    }

	public void mousePressed(MouseEvent e) {
    	if (e.getClickCount() == 1) {
            if (e.getButton() == MouseEvent.BUTTON1) {
            	runAction();
            } else if (e.getButton() == MouseEvent.BUTTON3) {
            	runAction();
            }
    	} else if (e.getClickCount() == 2) {
            if (e.getButton() == MouseEvent.BUTTON1) {
            	runDoubleClickAction();
            } else if (e.getButton() == MouseEvent.BUTTON3) {
            	runDoubleClickAction();
            }
    	}
	}
    public void mouseReleased(MouseEvent e) { }
	public void mouseEntered(MouseEvent e) { }
	public void mouseExited(MouseEvent e) { }
	
	public void setTipText(String tipText, boolean useClassicToolTip) {
		this.tipText = tipText;
		setToolTipText(tipText);
	}

	public String getTipText() {
		return tipText;
	}

	public Object getSubject() {
		return subject;
	}

	public void setSubject(Object subject) {
		this.subject = subject;
	}
	
	
}