/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.buttons;

import java.awt.event.MouseEvent;

public abstract class MotRolloverImageButton extends MotImageButton {

	private static String ROLL_OVER = "_rollover";
	private static String EXTENSION = ".png";
	
	private String rolloverImage;

	/**
	 * This is true when the mouse is inside the component.
	 * Use to roll-over tipping of information!
	 */
	private boolean rollover;
	
	
	public MotRolloverImageButton(String image, int size, String command) {
		super(image+EXTENSION, size, command);
		this.rolloverImage = image+ROLL_OVER+EXTENSION;
	}

	protected String getImage() {
		return rollover ? rolloverImage : super.getImage();
	}
	
	public void mouseEntered(MouseEvent e) {
		rollover = true;
		repaint();
	}

	public void mouseExited(MouseEvent e) {
		rollover = false;
		repaint();
	}
	
	public boolean containsMouse() {
		return rollover;
	}
}
