/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.buttons;

import java.awt.Color;
import java.awt.event.MouseEvent;

import javax.swing.JLabel;
import javax.swing.JPanel;

import mot.common.util.ApplicationError;
import mot.common.util.PropertyManager;

/**
 * This is the base class for all buttons in the game that are constructed using
 * two images - one for normal display and one for roll over display. These are
 * not 'real' buttons, they do not extends JButton.
 */
public abstract class MotRolloverLabelButton extends MotLabelButton  {

	private Color background;
	private Color rolloverBackground;
    private Color oldBackground;
	private boolean rollover;

	public MotRolloverLabelButton(JPanel icon, JLabel text, String tip, Object subject) throws ApplicationError {
		super(icon, text, tip, subject);
		this.background = PropertyManager.getMandatoryAsColor("button_label.background.color");
		this.rolloverBackground = PropertyManager.getMandatoryAsColor("button_label.rollover_background.color");
		this.oldBackground = background;
		setBackground(background);
		setOpaque(true);
		
		// clicking on icon does not do anything but this did not fix it
		//icon.addMouseListener(this);
	}

	public void mouseEntered(MouseEvent e) {
		super.mouseEntered(e);
		oldBackground = getBackground();
		setBackground(rolloverBackground);
	}

	public void mouseExited(MouseEvent e) {
		super.mouseExited(e);
		setBackground(oldBackground);
	}

	public boolean containsMouse() {
		return rollover;
	}

}
