/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.buttons;

import javax.swing.JRadioButton;

import mot.common.setup.SetupOption;
import mot.common.setup.SetupOptions;
import mot.common.util.ApplicationError;
import mot.common.util.Comp;

/**
 * This is used on the SetupWindow to display on race option to the user.
 */
public class OptionCheckBox extends JRadioButton {

    private SetupOption option;

    public OptionCheckBox(SetupOption option) {
        super(option.getLabel()+" ["+option.getCost()+"]");
        this.option = option;
    }

    public SetupOption getOption() {
        return option;
    }
    
    /** 
     * Sets the state of this button to the correct value from the list of properties
     * in the SetupOptions passed in
     */
    public void set(SetupOptions options) throws ApplicationError {
       String name = option.getName();
       String value = option.getValue();
       String raceValue = options.getStringForName(name);
       SetupOption[] ol = options.getAllForName(name);
       if (ol == null) {
           if (option.getCost() == 0 && Comp.isEmpty(raceValue)) {
               setSelected(true);
           }
       } else {
           for (int i=0; i < ol.length; i++) {
               if ( Comp.same(value, ol[i].getValue()) ) {
                   setSelected(true);
               }
           }
       }
    }
}