/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.combos;

import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;
import java.util.Iterator;

import javax.swing.JComboBox;
import javax.swing.JLabel;

import mot.client.swing.config.ImageConfig;
import mot.client.swing.config.ImageConfigFactory;
import mot.client.swing.renderers.CellRendererImageConfig;
import mot.common.bean.RaceGraphics;
import mot.common.bean.RaceGraphicsList;
import mot.common.bean.Size;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.Comp;

public class AncientRaceCombo extends JComboBox implements ItemListener {

	private JLabel descriptionLabel;

    public AncientRaceCombo(RaceGraphicsList graphicsList, JLabel descriptionLabel, Size size) throws ApplicationError {
    	this(graphicsList, size);
    	this.descriptionLabel = descriptionLabel;
    	descriptionLabel.setText(getDescription());
    	addItemListener(this);
    }
    
    public AncientRaceCombo(RaceGraphicsList graphicsList, Size size) throws ApplicationError {
    	setRenderer(new CellRendererImageConfig(size));
        ImageConfigFactory imageConfig = ImageConfigFactory.getInstance();
        addItem(imageConfig.getRaceImageConfig(L.NONE));
        Iterator it = graphicsList.getGraphics().iterator();
        while (it.hasNext()) {
            RaceGraphics race = (RaceGraphics) it.next();
            if (Comp.same(race.getType(), RaceGraphics.TYPE_ANCIENT)) {
                String name = race.getName();
				ImageConfig config = imageConfig.getRaceImageConfig(name);
   				addItem(config);
            }
        }
        setSelectedIndex(0);
    }

    public String getRace() {
    	ImageConfig config = (ImageConfig) getSelectedItem();
        if (Comp.same(config.getName(), L.NONE)) {
            return null;
        } else {
            return config.getName();
        }
    }

    public String getDescription() {
    	Object selection = getSelectedItem();
    	if (selection == null || !(selection instanceof ImageConfig)) {
    		return null;
    	}
    	ImageConfig config = (ImageConfig) selection;
    	return getDescription(config.getName());
    }

    public String getDescription(String name) {
        if (name == null || Comp.same(name, L.NONE)) {
        	return L.NOT_ALIGNED_TO_ANY_OF_THE_ANCIENT_RACES;
        } else {
        	return L.ALIGNED_TO_THE_ANCIENT_RACE_OF_+name+L._THIS_RACE_WILL_GIVE_YOU_SPECIAL_TECHNOLOGIES_BUT_DOES_NOT_APROVE_OF_HOSTILITY_TOWARDS_PLAYERS_OF_THE_SAME_ALIGNMENT_;
        }
    }

    public void itemStateChanged(ItemEvent e) {
    	if (e.getStateChange() == ItemEvent.SELECTED) {
	    	if (descriptionLabel != null) {
	        	descriptionLabel.setText(getDescription());
	    	}
    	}
    }

}