/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.combos;

import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;

import javax.swing.JComboBox;

import mot.client.swing.config.ImageConfig;
import mot.client.swing.config.ImageConfigFactory;
import mot.client.swing.renderers.CellRendererImageConfig;
import mot.common.bean.PlayerColor;
import mot.common.bean.Size;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.Comp;

public class ColourCombo extends JComboBox implements ItemListener {

    public ColourCombo(Size size) throws ApplicationError {
    	setRenderer(new CellRendererImageConfig(size));
        ImageConfigFactory imageConfig = ImageConfigFactory.getInstance();
		addItem(imageConfig.getFlagConfig(L.COLOUR_BLUE));
		addItem(imageConfig.getFlagConfig(L.COLOUR_RED));
		addItem(imageConfig.getFlagConfig(L.COLOUR_GREEN));
		addItem(imageConfig.getFlagConfig(L.COLOUR_ORANGE));
		addItem(imageConfig.getFlagConfig(L.COLOUR_YELLOW));
		addItem(imageConfig.getFlagConfig(L.COLOUR_PINK));
		addItem(imageConfig.getFlagConfig(L.COLOUR_GREY));
        setSelectedIndex(0);
    	addItemListener(this);
    }

    public PlayerColor getPlayerColor() throws ApplicationError {
    	ImageConfig config = (ImageConfig) getSelectedItem();
    	return PlayerColor.getColorForName(config.getName());
    }
    
    public void setPlayerColor(PlayerColor pc) throws ApplicationError {
    	if (pc == null) {
    		setSelectedIndex(-1);
    	} else if (Comp.same(pc.getName(), L.COLOUR_BLUE)) {
    		setSelectedIndex(0);
    	} else if (Comp.same(pc.getName(), L.COLOUR_RED)) {
    		setSelectedIndex(1);
    	} else if (Comp.same(pc.getName(), L.COLOUR_GREEN)) {
    		setSelectedIndex(2);
    	} else if (Comp.same(pc.getName(), L.COLOUR_ORANGE)) {
    		setSelectedIndex(3);
    	} else if (Comp.same(pc.getName(), L.COLOUR_YELLOW)) {
    		setSelectedIndex(4);
    	} else if (Comp.same(pc.getName(), L.COLOUR_PINK)) {
    		setSelectedIndex(5);
    	} else if (Comp.same(pc.getName(), L.COLOUR_GREY)) {
    		setSelectedIndex(6);
    	} else {
    		setSelectedIndex(-1);    		
    	}
    }
    
    public void itemStateChanged(ItemEvent e) {
    	if (e.getStateChange() == ItemEvent.SELECTED) {
    	}
    }
}