/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.combos;

import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;

import javax.swing.JComboBox;
import javax.swing.JLabel;

import mot.client.swing.config.ImageConfig;
import mot.client.swing.config.ImageConfigFactory;
import mot.client.swing.renderers.CellRendererImageConfig;
import mot.common.bean.Size;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.Comp;
import mot.common.util.PropertyManager;

public class GalaxySizeCombo extends JComboBox implements ItemListener {

	private JLabel descriptionLabel;

    public GalaxySizeCombo(JLabel descriptionLabel) throws ApplicationError {
    	this();
    	this.descriptionLabel = descriptionLabel;
    	descriptionLabel.setText(getDescription());
    	addItemListener(this);
    }
    
    public GalaxySizeCombo() throws ApplicationError {
    	setRenderer(new CellRendererImageConfig(new Size(100,100)));
        ImageConfigFactory imageConfig = ImageConfigFactory.getInstance();
		addItem(imageConfig.getGalaxySizeIconConfig().getImageConfig(L.GALAXY_SIZE_TINY));
		addItem(imageConfig.getGalaxySizeIconConfig().getImageConfig(L.GALAXY_SIZE_SMALL));
		addItem(imageConfig.getGalaxySizeIconConfig().getImageConfig(L.GALAXY_SIZE_MEDIUM));
		addItem(imageConfig.getGalaxySizeIconConfig().getImageConfig(L.GALAXY_SIZE_LARGE));
		addItem(imageConfig.getGalaxySizeIconConfig().getImageConfig(L.GALAXY_SIZE_HUGE));
        setSelectedIndex(1);
    }

    public int getQtyPlanets() {
    	ImageConfig config = (ImageConfig) getSelectedItem();
        int qtyPlanets = 25;
        String size = config.getName();
        if (Comp.same(size, L.GALAXY_SIZE_TINY)) {
            qtyPlanets = 25;
        } else if (Comp.same(size, L.GALAXY_SIZE_SMALL)) {
            qtyPlanets = 42;
        } else if (Comp.same(size, L.GALAXY_SIZE_MEDIUM)) {
            qtyPlanets =60;
        } else if (Comp.same(size, L.GALAXY_SIZE_LARGE)) {
            qtyPlanets = 75;
        } else if (Comp.same(size, L.GALAXY_SIZE_HUGE)) {
            qtyPlanets = 90;
        }
        return qtyPlanets;
    }

    public int getQtyNebula() {
    	ImageConfig config = (ImageConfig) getSelectedItem();
        int qtyNebula = 1;
        String size = config.getName();
        if (Comp.same(size, L.GALAXY_SIZE_TINY)) {
            qtyNebula = 1;
        } else if (Comp.same(size, L.GALAXY_SIZE_SMALL)) {
            qtyNebula = 2;
        } else if (Comp.same(size, L.GALAXY_SIZE_MEDIUM)) {
            qtyNebula =3;
        } else if (Comp.same(size, L.GALAXY_SIZE_LARGE)) {
            qtyNebula = 4;
        } else if (Comp.same(size, L.GALAXY_SIZE_HUGE)) {
            qtyNebula = 5;
        }
        return qtyNebula;
    }

    public Size getGalaxySize() {
    	ImageConfig config = (ImageConfig) getSelectedItem();
        Size galaxySize = null;
        String size = config.getName();
        if (Comp.same(size, L.GALAXY_SIZE_TINY)) {
            galaxySize = new Size(500, 400);
        } else if (Comp.same(size, L.GALAXY_SIZE_SMALL)) {
            galaxySize = new Size(600, 500);
        } else if (Comp.same(size, L.GALAXY_SIZE_MEDIUM)) {
            galaxySize = new Size(700, 600);
        } else if (Comp.same(size, L.GALAXY_SIZE_LARGE)) {
            galaxySize = new Size(800, 700);
        } else if (Comp.same(size, L.GALAXY_SIZE_HUGE)) {
            galaxySize = new Size(1000, 900);
        }
        return galaxySize;
    }

	private static final int SECTOR_SIZE = PropertyManager.getMandatoryNoErrorAsInt("sector.size");
    
    public String getDescription() {
    	Object selection = getSelectedItem();
    	if (selection == null || !(selection instanceof ImageConfig)) {
    		return null;
    	}
    	ImageConfig config = (ImageConfig) selection;
    	Size size = getGalaxySize();
    	int qtySectors = size.getX()/SECTOR_SIZE * size.getY()/SECTOR_SIZE;
       	return L.THE_NEW_GALAXY_WILL_HAVE_+qtySectors+L._SECTORS_CONTAINING_+getQtyPlanets()+L._PLANETS;
    }

    public void itemStateChanged(ItemEvent e) {
    	if (e.getStateChange() == ItemEvent.SELECTED) {
	    	if (descriptionLabel != null) {
	        	descriptionLabel.setText(getDescription());
	    	}
    	}
    }
}