/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.combos;

import javax.swing.JComboBox;

import mot.client.deligates.NamedObjectDelegate;
import mot.client.swing.renderers.CellRendererNamedObject;
import mot.common.util.Comp;

public class NamedObjectCombo extends JComboBox {

	private NamedObjectDelegate[] content;
	private NamedObjectDelegate none;
	private boolean addNone;

	public NamedObjectCombo(NamedObjectDelegate [] content, boolean addNone) {
		this.addNone = addNone;
		setRenderer(new CellRendererNamedObject());
		none = new NamedObjectDelegate() {
			public String getName() { return "None"; }
			public boolean equals(NamedObjectDelegate other) { return other != null && Comp.same(other.getName(),"None"); }
		};
		if (addNone) addItem(none);
		setContent(content);
	}
	
	public void setContent(NamedObjectDelegate [] content) {
		this.content = content;
		if (content == null) {
			clear();
			return;
		}
		for (int i = 0; i < content.length; i++) {			
			addItem(content[i]);
		}
	}

    public NamedObjectDelegate getNamedObject() {
    	NamedObjectDelegate v = (NamedObjectDelegate) getSelectedItem();
    	if (Comp.same(none, v)) {
    		return null;
    	}
    	return v;
    }
    
    public void setSelection(NamedObjectDelegate v) {
    	if (v == null) {
    		clear();
    		return;
    	}
    	if (content != null) {    		
    		for (int i = 0; i < content.length; i++) {
    			if (content[i].equals(v)) {
    				if (addNone) {
    					setSelectedIndex(i+1);
    				} else {
    					setSelectedIndex(i);
    				}
    				return;
    			}
    		}
    	}
    	clear();
    }

	public void clear() {
		if (addNone) {
			setSelectedIndex(0);
		} else {
			setSelectedIndex(-1);
		}
	}


}
