/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.combos;

import java.util.ArrayList;

import javax.swing.JComboBox;

import mot.client.deligates.NamedObjectDelegate;
import mot.client.deligates.PlanetDelegate;
import mot.client.deligates.SolarSystemDelegate;
import mot.client.deligates.StellarObjectDelegate;
import mot.client.deligates.cache.DeligateCacheManager;
import mot.client.swing.renderers.CellRendererOrbit;
import mot.common.bean.Size;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.engine.command_handlers.MessageHandlerBase;
import mot.engine.common.Orbit;
import mot.engine.common.StellarObject;
import mot.engine.planets.Planet;

public class OrbitCombo extends JComboBox {

	private NamedObjectDelegate[] content;
	private NamedObjectDelegate none;
	private boolean includeNone;

	public OrbitCombo(Size size, boolean includeNone) throws ApplicationError {
		this.includeNone = includeNone;
		
		setRenderer(new CellRendererOrbit(size, true));
				
	}
	
	public void setContent(boolean includeStellarObjects, boolean includePlanets) throws ApplicationError {
		StellarObjectDelegate[] stellarObjects = DeligateCacheManager.getStellarObjects();
		ArrayList<NamedObjectDelegate> nol = new ArrayList<NamedObjectDelegate>();
		for (int i = 0; i < stellarObjects.length; i++) {
			if (includeStellarObjects) nol.add(stellarObjects[i]);
			if (includePlanets) {
				if (stellarObjects[i] instanceof SolarSystemDelegate) {
					SolarSystemDelegate sd = (SolarSystemDelegate) stellarObjects[i];
					PlanetDelegate[] pa = sd.getPlanets();
					if (pa != null) {
						for (int j = 0; j < pa.length; j++) {
							nol.add(pa[j]);
						}
					}
				}
			}
		}
		NamedObjectDelegate[] noa = nol.toArray(new NamedObjectDelegate[nol.size()]);

		setContent(noa);
	}
	

	public void setContent(NamedObjectDelegate [] content) {
		this.content = content;
		
		if (includeNone) {
			addItem(L.NONE);
		}

		if (content != null) {
			for (int i = 0; i < content.length; i++) {			
				addItem(content[i]);
			}
		}
	}

    public NamedObjectDelegate getNamedObject() {
    	Object s = getSelectedItem();
    	if (s instanceof NamedObjectDelegate) {
    		return (NamedObjectDelegate)s;
    	}
   		return null;
    }
    
    public Orbit getOrbit() throws ApplicationError {
    	NamedObjectDelegate o = getNamedObject();
    	if (o == null) {
    		return null;
    	} else if (o instanceof PlanetDelegate) {
    		Planet planet = MessageHandlerBase.getPlanet(o.getName());
    		return new Orbit(planet);
    	} else if (o instanceof StellarObjectDelegate) {
    		StellarObject so = MessageHandlerBase.getStellarObject(o.getName());
    		return new Orbit(so);
    	}
		return null;
   }
    
    public void setSelection(NamedObjectDelegate v) {
    	if (v == null) {
    		clear();
    		return;
    	}
    	if (content != null) {    		
    		for (int i = 0; i < content.length; i++) {
    			if (content[i].equals(v)) {
    				if (includeNone) {
    					setSelectedIndex(i+1);
    				} else {
    					setSelectedIndex(i);
    				}
    				return;
    			}
    		}
    	}
    	clear();
    }

	public void clear() {
		if (includeNone) {
			setSelectedIndex(0);
		} else {
			setSelectedIndex(-1);
		}
	}


}
