/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.combos;

import javax.swing.JComboBox;
import javax.swing.ListCellRenderer;

import mot.client.deligates.PlayerDelegate;
import mot.client.deligates.cache.DeligateCacheManager;
import mot.client.swing.renderers.CellRendererPlayer;
import mot.client.swing.renderers.CellRendererPlayerName;
import mot.common.bean.Size;
import mot.common.lang.L;
import mot.common.util.ApplicationError;

public class PlayerCombo extends JComboBox {

	public PlayerCombo(Size iconSize, boolean includeNone, boolean includeMonster) throws ApplicationError {
		this(new CellRendererPlayer(iconSize, true), includeNone, includeMonster);
	}
	
	public PlayerCombo(boolean includeNone, boolean includeMonster) throws ApplicationError {
		this(new CellRendererPlayerName(), includeNone, includeMonster);
	}
	
	public PlayerCombo(ListCellRenderer renderer, boolean includeNone, boolean includeMonster) throws ApplicationError {
		setRenderer(renderer);
		PlayerDelegate[] players = DeligateCacheManager.getPlayers();
		if (players == null) return;
		if (includeNone) addItem(L.NONE);
		if (includeMonster) {
			PlayerDelegate monsterPlayer = DeligateCacheManager.getMonsterPlayer();
			addItem(monsterPlayer);
		}
		for (int i = 0; i < players.length; i++) {			
			addItem(players[i]);
		}
	}

    public PlayerDelegate getSelectedPlayer() {
    	Object selectedItem = getSelectedItem();
    	if (selectedItem instanceof PlayerDelegate) {
    		PlayerDelegate v = (PlayerDelegate) selectedItem;
    		return v;
    	} else {
    		return null;
    	}
    }
    
    public void setSelection(PlayerDelegate v) {
    	if (v == null) {
    		setSelectedItem(L.NONE);
    	} else {
    		setSelectedItem(v);
    	}
    }

	public void clear() {
		setSelectedIndex(0);
	}
}
