/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.combos;

import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;

import javax.swing.JComboBox;
import javax.swing.JLabel;

import mot.client.swing.config.ImageConfig;
import mot.client.swing.config.ImageConfigFactory;
import mot.client.swing.renderers.CellRendererImageConfig;
import mot.common.bean.Size;
import mot.common.lang.L;
import mot.common.util.ApplicationError;

public class QtyComputerPlayersCombo extends JComboBox implements ItemListener {

	private JLabel descriptionLabel;

    public QtyComputerPlayersCombo(JLabel descriptionLabel) throws ApplicationError {
    	this();
    	this.descriptionLabel = descriptionLabel;
    	descriptionLabel.setText(getDescription());
    	addItemListener(this);
    }
    
    public QtyComputerPlayersCombo() throws ApplicationError {
    	setRenderer(new CellRendererImageConfig(new Size(100,100)));
        ImageConfigFactory imageConfig = ImageConfigFactory.getInstance();
		addItem(imageConfig.getQtyPlayersIconConfig().getImageConfig(L.QTY_COMP_PLAYERS_1));
		addItem(imageConfig.getQtyPlayersIconConfig().getImageConfig(L.QTY_COMP_PLAYERS_2));
		addItem(imageConfig.getQtyPlayersIconConfig().getImageConfig(L.QTY_COMP_PLAYERS_3));
		addItem(imageConfig.getQtyPlayersIconConfig().getImageConfig(L.QTY_COMP_PLAYERS_4));
		addItem(imageConfig.getQtyPlayersIconConfig().getImageConfig(L.QTY_COMP_PLAYERS_5));
        setSelectedIndex(2);
    }

    public int getQtyPlayers() {
    	ImageConfig config = (ImageConfig) getSelectedItem();
        int qty = Integer.parseInt(config.getName());
        return qty;
    }

    public String getDescription() {
    	Object selection = getSelectedItem();
    	if (selection == null || !(selection instanceof ImageConfig)) {
    		return null;
    	}
    	ImageConfig config = (ImageConfig) selection;
    	return L.THERE_WILL_BE_+config.getName()+L._COMPUTER_PLAYERS_IN_THIS_GAME;
    }

    public void itemStateChanged(ItemEvent e) {
    	if (e.getStateChange() == ItemEvent.SELECTED) {
	    	if (descriptionLabel != null) {
	        	descriptionLabel.setText(getDescription());
	    	}
    	}
    }

}