/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.combos;

import javax.swing.JComboBox;

import mot.common.util.ApplicationError;

public class ScreenResolutionCombo extends JComboBox {

    private static final String TIMES = "X";
    
    public ScreenResolutionCombo() throws ApplicationError {
        addItem("1024"+TIMES+"768");
        addItem("1280"+TIMES+"1024");
        addItem("1600"+TIMES+"900");
        addItem("1920"+TIMES+"1080");
    }

    public int getScreenWidth() throws ApplicationError {
        String name = (String) getSelectedItem();
        if (name == null) return -1;
        int index = name.lastIndexOf(TIMES);
        if (index > 0) {
            name = name.substring(0, index);
            try {
                return Integer.parseInt(name);
            } catch (NumberFormatException ex) {
                throw new ApplicationError("Invalid "+name);
            }
        }
        return -1;
    }
    
    public int getScreenHeight() throws ApplicationError {
        String name = (String) getSelectedItem();
        if (name == null) return -1;
        int index = name.lastIndexOf(TIMES);
        if (index > 0) {
            name = name.substring(index+1);
            try {
                return Integer.parseInt(name);
            } catch (NumberFormatException ex) {
                throw new ApplicationError("Invalid "+name);
            }
        }
        return -1;
    }
    
}