/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.combos;

import javax.swing.JComboBox;

import mot.client.swing.models.TechnologyListComboModel;
import mot.client.swing.renderers.TechnologyComboRenderer;
import mot.common.technology.GeneralTechnologyList;
import mot.common.technology.Technology;
import mot.common.technology.TechnologyList;
import mot.common.util.ApplicationError;

public class TechnologyCombo extends JComboBox {

    private TechnologyListComboModel model;

	public TechnologyCombo(TechnologyList data, boolean useFullname) {
		model = new TechnologyListComboModel(data);
        setModel(model);
        setRenderer(new TechnologyComboRenderer(useFullname));
        setSelectedIndex(data.getQuantity()-1);
    }

    public TechnologyCombo(TechnologyList data, String group, boolean useFullname) throws ApplicationError {
        if (data == null) return;
        if (group != null) {
            Technology [] techs  = data.getAllWithGroup(group);
            if (techs != null) {
                model = new TechnologyListComboModel(new GeneralTechnologyList(techs));
				setModel(model);
                setSelectedIndex(techs.length-1);
            }
        } else {
            if (data != null && data.getQuantity() > 0) {
                model = new TechnologyListComboModel(data);
				setModel(model);
                setSelectedIndex(data.getQuantity()-1);
            }
        }
        setRenderer(new TechnologyComboRenderer(useFullname));
    }

    public Technology getSelectedTech() {
//    	if (model != null) {
//    		return (Technology) model.getSelectedItem();
//    	} else {
//    		return null;
//    	}
    	int i = getSelectedIndex();
    	if (model != null && i >= 0 && i < model.getSize()) {
    		return (Technology) model.getElementAt(i);
    	} else {
    		return null;
    	}
    }

}