/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.combos;

import java.util.Iterator;

import javax.swing.JComboBox;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;

import mot.client.swing.buttons.MotActionListener;
import mot.client.swing.lists.FakeList;
import mot.client.swing.window.common.SelectTechByTypeWindow;
import mot.common.technology.Technologies;
import mot.common.technology.TechnologyContainer;
import mot.common.util.ApplicationError;
import mot.common.util.Comp;
import mot.common.util.ValidationError;

public class TechnologyTypeCombo extends JComboBox {

	private FakeList subList;
	private TechnologyContainer owner;
	private ChangeListener changeListener;
	
	public TechnologyTypeCombo(FakeList subList, TechnologyContainer owner, ChangeListener changeListener) {
		this();
		this.subList = subList;
		this.owner = owner;
		this.changeListener = changeListener;
		
		if (subList != null) {
			addActionListener(new MotActionListener() {
				protected void _doAction() throws ApplicationError, ValidationError {
					populateSubList();
				}
			});
		}
	}

	public TechnologyTypeCombo() {
        Iterator i = SelectTechByTypeWindow.getAllTechTypeList().iterator();
        while (i.hasNext()) {
            String name = (String) i.next();
            addItem(name);
        }
        setSelectedIndex(0);
	}
	
	public String getTechnologyType() {
		String techType = (String) getSelectedItem();
		return techType; 
	}
	
    /**
     * The tech type list has changed value
     * Set the sub list to be the list of techs discovered by the owner of this type
     */
    private void populateSubList() throws ApplicationError {
        String techType = getTechnologyType();
        if (Comp.same(techType, Technologies.TECH_TYPE_FACTORY)) {
            if (owner.getFactories() != null) {
                subList.setContent(owner.getFactories().getAllAsArray(),0);
            } else {
            	subList.setContent(null, null);
            }
        } else if (Comp.same(techType, Technologies.TECH_TYPE_LABORATORY)) {
            if (owner.getLaboratories() != null) {
                subList.setContent(owner.getLaboratories().getAllAsArray(),0);
            } else {
            	subList.setContent(null, null);
            }
        } else if (Comp.same(techType, Technologies.TECH_TYPE_BIOTECHNOLOGY)) {
            if (owner.getBiotechnologies() != null) {
                subList.setContent(owner.getBiotechnologies().getAllAsArray(),0);
            } else {
            	subList.setContent(null, null);
            }
        } else if (Comp.same(techType, Technologies.TECH_TYPE_HULL)) {
            if (owner.getHulls() != null) {
                subList.setContent(owner.getHulls().getAllAsArray(),0);
            } else {
            	subList.setContent(null, null);
            }
        } else if (Comp.same(techType, Technologies.TECH_TYPE_COMPUTER)) {
            if (owner.getComputers() != null) {
                subList.setContent(owner.getComputers().getAllAsArray(),0);
            } else {
            	subList.setContent(null, null);
            }
        } else if (Comp.same(techType, Technologies.TECH_TYPE_WEAPON)) {
            if (owner.getWeapons() != null) {
                subList.setContent(owner.getWeapons().getAllAsArray(),0);
            } else {
            	subList.setContent(null, null);
            }
        } else if (Comp.same(techType, Technologies.TECH_TYPE_SHIELD)) {
            if (owner.getShields() != null) {
                subList.setContent(owner.getShields().getAllAsArray(),0);
            } else {
            	subList.setContent(null, null);
            }
        } else if (Comp.same(techType, Technologies.TECH_TYPE_SCANNER)) {
            if (owner.getScanners() != null) {
                subList.setContent(owner.getScanners().getAllAsArray(),0);
            } else {
            	subList.setContent(null, null);
            }
        } else if (Comp.same(techType, Technologies.TECH_TYPE_SPECIAL)) {
            if (owner.getSpecials() != null) {
                subList.setContent(owner.getSpecials().getAllAsArray(),0);
            } else {
            	subList.setContent(null, null);
            }
        } else if (Comp.same(techType, Technologies.TECH_TYPE_ENGINE)) {
            if (owner.getEngines() != null) {
                subList.setContent(owner.getEngines().getAllAsArray(),0);
            } else {
            	subList.setContent(null, null);
            }
        } else if (Comp.same(techType, Technologies.TECH_TYPE_MISC)) {
            if (owner.getMiscTechnologies() != null) {
                subList.setContent(owner.getMiscTechnologies().getAllAsArray(),0);
            } else {
            	subList.setContent(null, null);
            }
        } else if (Comp.same(techType, Technologies.TECH_TYPE_MODULE)) {
            if (owner.getModules() != null) {
                subList.setContent(owner.getModules().getAllAsArray(),0);
            } else {
            	subList.setContent(null, null);
            }
        } else if (Comp.same(techType, Technologies.TECH_TYPE_LABORATORY)) {
            if (owner.getLaboratories() != null) {
                subList.setContent(owner.getLaboratories().getAllAsArray(),0);
            } else {
            	subList.setContent(null, null);
            }
        } else if (Comp.same(techType, Technologies.TECH_TYPE_FACTORY)) {
            if (owner.getFactories() != null) {
                subList.setContent(owner.getFactories().getAllAsArray(),0);
            } else {
            	subList.setContent(null, null);
            }
        } else if (Comp.same(techType, Technologies.TECH_TYPE_HUMANITIES)) {
            if (owner.getHumanities() != null) {
                subList.setContent(owner.getHumanities().getAllAsArray(),0);
            } else {
            	subList.setContent(null, null);
            }
        }
        changeListener.stateChanged(new ChangeEvent(subList));
    }
	
}
