/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.combos;

import javax.swing.JComboBox;

import mot.client.deligates.BattleObjectDelegate;
import mot.common.lang.L;
import mot.common.technology.Weapon;
import mot.common.util.ApplicationError;
import mot.common.util.Comp;
import mot.common.vo.WeaponInstanceVO;

public class WeaponCombo extends JComboBox {

    private static final String TIMES = " X ";
    
    private BattleObjectDelegate bo;

    public WeaponCombo(BattleObjectDelegate bo) throws ApplicationError {
        this.bo = bo;
        
        update(true);
    }
    
    public void update(BattleObjectDelegate bo) throws ApplicationError {
        if (this.bo == bo) {
            update(false);
        } else {
            this.bo = bo;
            update(true);
        }
    }
    
    public void update(boolean reselect) throws ApplicationError {
        String selectedItem = (String) getSelectedItem();
        removeAllItems();
        addItem(L.ALL);
        if (bo == null) {
            setSelectedIndex(0);
            return;
        }
        WeaponInstanceVO[] weapons = bo.getWeapons();
        if (weapons != null) {
            for (int i=0; i<weapons.length; i++) {
                if (weapons[i].hasWeaponsToFire()) {
                    String n = weapons[i].getWeapon().getName();
                    if (weapons[i].getWeapon().isMissile()) {
                        int qtyToFire = weapons[i].getQty() - weapons[i].getQtyFired();
                        if (qtyToFire > 1) {
                            String n2 = n + TIMES + qtyToFire;
                            addItem(n2);
                        } else if (qtyToFire > 0) {
                            addItem(n);
                        }
                    } else {
                        addItem(n);
                        int qtyToFire = weapons[i].getQty() - weapons[i].getQtyFired();
                        if (qtyToFire > 16) {
                            String n3 = n + TIMES + (qtyToFire/4+1);
                            addItem(n3);
                        }
                        if (qtyToFire > 8) {
                            String n3 = n + TIMES + (qtyToFire/2+1);
                            addItem(n3);
                        }
                        if (qtyToFire > 1) {
                            String n2 = n + TIMES + qtyToFire;
                            addItem(n2);
                        }
                    }
                }
            }
        }
        if (reselect) {
            setSelectedIndex(0);
        } else {
            setSelectedIndex(0);
            setSelectedItem(selectedItem);
        }
    }

    public Weapon getWeapon() throws ApplicationError {
        String name = (String) getSelectedItem();
        int index = name.lastIndexOf(TIMES);
        if (index > 0) {
            name = name.substring(0, index);
        }
        if (bo == null) {
        	return null;
        }
        WeaponInstanceVO[] weapons = bo.getWeapons();
        if (weapons != null) {
            for (int i=0; i<weapons.length; i++) {
                String n = weapons[i].getWeapon().getName();
                if (Comp.same(name, n) && weapons[i].hasWeaponsToFire()) {
                    return weapons[i].getWeapon();
                }
            }
        }
        return null;
    }
    
    public int getQty() throws ApplicationError {
        String name = (String) getSelectedItem();
        int index = name.lastIndexOf(TIMES);
        if (index > 0) {
            String qty = name.substring(index+3);
            try {
                return Integer.parseInt(qty);
            } catch (NumberFormatException ex) {
                throw new ApplicationError("Invalid quantity "+qty);
            }
        } else {
            return 1;                    
        }
    }
    
    // DO not want the combo using keys because will conflict with express keys
    public boolean selectWithKeyChar(char keyChar) {
    	return false;
    }

}