/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.common;

import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import java.awt.LayoutManager;

import javax.swing.BoxLayout;
import javax.swing.JComponent;
import javax.swing.JPanel;

/**
 * A swing layout manager like BoxLayout except it maximises the components to fill the
 * space available.
 */
public class BoxLayout2
{
    private int axis;
    private JComponent component;

    private GridBagLayout gridbag;
    private GridBagConstraints gridBagConstraints;

    public void setAlignment(int v) {    
        gridBagConstraints.anchor = v;
    }
    
    public BoxLayout2(JComponent component, int axis, int fill) {
        this(component, axis, 0, GridBagConstraints.NORTHWEST, fill);
    }
    
    public BoxLayout2(JComponent component, int axis, int padding, int fill) {
        this(component, axis, padding, GridBagConstraints.NORTHWEST, fill);
    }
    
    public BoxLayout2(JComponent component, int axis, int padding, int alignment, int fill) {
        this.component = component;
        this.axis = axis;

        gridbag = new GridBagLayout();
        component.setLayout(gridbag);

        gridBagConstraints = new GridBagConstraints();
        gridBagConstraints.insets = new Insets(padding,padding,padding,padding);
        gridBagConstraints.fill = fill;
        gridBagConstraints.weightx = 0;
        gridBagConstraints.weighty = 0;
        gridBagConstraints.anchor = alignment;
        if (axis == BoxLayout.X_AXIS) {
            gridBagConstraints.gridwidth = 1;
            gridBagConstraints.gridheight = GridBagConstraints.REMAINDER;
        } else {
            gridBagConstraints.gridwidth = GridBagConstraints.REMAINDER;
            gridBagConstraints.gridheight = 1;
        }

        gridbag.setConstraints(component, gridBagConstraints);
    }
    
    public void add(JPanel panel, JComponent component) {
        gridbag.setConstraints(component, gridBagConstraints);
        panel.add(component);
    }

    public void add(JPanel panel, JComponent component, boolean last) {
        gridBagConstraints.weightx = 1;
        gridBagConstraints.weighty = 1;
        add(panel, component);
    }

     public LayoutManager getLayout() {
         return gridbag;
     }
}