/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.common;

import java.awt.event.KeyEvent;
import java.awt.event.KeyListener;

import mot.client.swing.window.main.MainWindow;
import mot.client.swing.window.main.MotConditionalAction;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

/**
 * Executes the action passed in when the default button is pressed.
 * The Default Button is ENTER.
 */
public class DefaultButtonListener implements KeyListener {

	private MotConditionalAction action;
	
	public DefaultButtonListener(MotConditionalAction action) {
		this.action = action;
	}

	public void keyPressed(KeyEvent e) {
		if (e.getKeyCode() == KeyEvent.VK_ENTER) {
			try {
				action.execute();
			} catch (ApplicationError exception) {
				MainWindow.getExestingInstance().reportApplicationError(exception);
			} catch (ValidationError exception) {
				MainWindow.getExestingInstance().reportValidationError(exception);
			}
		}
	}

	public void keyReleased(KeyEvent e) {
	}

	public void keyTyped(KeyEvent e) {
	}

}
