/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.common;

import mot.common.event.MotEvent;
import mot.common.util.ApplicationError;

/**
 * Interface that defines an object that listens for server events of a particular type arriving from the server.
 * To listen for events register an observer by calling  MotInternalWindow.pollForEventOfType().  
 * The events will be removed from the client event queue and passed to the observer by calling the method
 * eventNotification(MotEvent event)
 * NOTE - These events will be processed before other events in the clients event queue.
 * 
 * Requirement:
 * When the diplomacy window is open, in response to processing an event the user may request treaties and we want
 * to fetch the responses.
 */
public interface EventObserver {
	void eventNotification(MotEvent event) throws ApplicationError;
}
