/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.common;

import java.awt.*;
import java.net.URL;
import java.util.*;
import javax.swing.ImageIcon;

import mot.client.swing.window.main.MainWindow;
import mot.common.util.ApplicationError;
import mot.common.util.Logger;

public class ImageCache  {

	/**
	 * Caches the images once they have been created so they are not created multiple times.
	 */
    private static HashMap cache = new HashMap();

	/**
	 * Caches the images once they have been created so they are not created multiple times.
	 */
    private static HashMap translucentCache = new HashMap();

    public ImageCache() {
    }

    public static Image getImage(Toolkit toolkit, String name) {
	    Image image = (Image) cache.get(name);
	    if (image == null) {
	    	URL url = ClassLoader.getSystemResource(name);
	    	//Do not do this because it is asynchronous
        	//image = toolkit.createImage(name);
	    	if (url != null) {
	            image = new ImageIcon(url).getImage();
	        	cache.put(name, image);
//	        	if (Logger.isDebug()) {
//        			Logger.logDebug("Cache Image "+name+" ("+cache.size()+")");
//	        	}
	    	}
        	if (Logger.isDebug()) {
        		if (image == null || image.getWidth(null) < 1) {
        			Logger.logWarning("*********** WARNING *************Image "+name+" does not exist!");
        		}
        	}
		}
		return image;
    }
    
    public static void purge(String name) {
    	cache.remove(name);
    }
    
    public static Image getTranslucentImage(Toolkit toolkit, String name) throws ApplicationError {
	    Image image = (Image) translucentCache.get(name);
	    if (image == null) {
	    	MainWindow main = MainWindow.getInstance();
	    	Image normalImage = getImage(toolkit, name);
	    	int w = normalImage.getWidth(null);
	    	int h = normalImage.getHeight(null);
	    	image = main.getWindow().getGraphicsConfiguration().createCompatibleImage(w, h, Transparency.TRANSLUCENT);
	        Graphics2D g = (Graphics2D) image.getGraphics();
	        Composite alpha = AlphaComposite.getInstance(AlphaComposite.SRC_OVER, 0.5f);
	        g.setComposite(alpha);
	        g.drawImage(normalImage, 0, 0, null);
	        g.dispose();
	        translucentCache.put(name, image);
		}
		return image;
    }

}