/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.common;

import java.awt.Color;

import javax.swing.BorderFactory;
import javax.swing.JComponent;
import javax.swing.border.Border;
import javax.swing.border.EtchedBorder;
import javax.swing.border.TitledBorder;

import mot.common.bean.Size;
import mot.common.util.ApplicationError;
import mot.common.util.PropertyManager;

public class MotBorder extends ComponentTable {

	private Color borderColorHighlight;
	private Color borderColorShadow;

	public MotBorder(JComponent panel, String panelName) throws ApplicationError {
		this(panel, panelName, null);
	}
	
	public MotBorder(JComponent panel, String panelName, Color backgroundColor) throws ApplicationError {
		super("SPHV",1,1,0,0,0);
		add(panel);
		
        if (borderColorHighlight == null) {
            borderColorHighlight = PropertyManager.getMandatoryAsColor("border.color.highlight");
        }
        if (borderColorShadow == null) {
            borderColorShadow = PropertyManager.getMandatoryAsColor("border.color.shadow");
        }
        Border etched = BorderFactory.createEtchedBorder(EtchedBorder.RAISED, borderColorHighlight, borderColorShadow);
        if (panelName != null) {
        	TitledBorder border = new TitledBorder(etched, panelName, TitledBorder.LEFT, TitledBorder.TOP);
			setBorder( border );
        } else {
            setBorder( etched );
        }
        
        if (backgroundColor != null) {
        	setBackground(backgroundColor);
        	setOpaque(true);
        }
	}

	public MotBorder(JComponent panel) throws ApplicationError {
		this(panel, null);
	}

	public MotBorder(JComponent panel, String panelName, Color backgroundColor, Size size) throws ApplicationError {
		this(panel, panelName, backgroundColor);
		PanelUtils.setTheBloodySize(this, size);
	}
	
	public void setPanelName(String v) {
		TitledBorder border = (TitledBorder) getBorder();
		border.setTitle(v);
	}


}
