/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.common;

import java.util.ArrayList;

import mot.client.swing.window.common.MotDialog;

/**
 * In Full Wnidow System mode the games used the custom rendering loop
 * (@see MotGraphicsEnvironment and MainWindow fro details).
 * The custom look needs to know the list of dialogs that are currently open 
 * so each can be painted. This class maintains a Z Order for the open dialogs
 * that needs painging in the loop.
 */
public class MotDialogStack {

	private ArrayList dialogs = new ArrayList();
	
	private transient MotDialog [] _dialogs = null;
	
	public void add(MotDialog d) {
		_dialogs = null;
		dialogs.add(d);
	}
	
	public void remove(MotDialog d) {
		_dialogs = null;
		dialogs.remove(d);
	}

	public MotDialog getTop() {
		if (dialogs.size() <= 0) {
			return null;
		} else {
			return (MotDialog) dialogs.get(dialogs.size()-1);
		}
	}

	public MotDialog [] getDialogs() {
		if (dialogs.size() <= 0) {
			return null;
		} else {
			return (MotDialog []) dialogs.toArray( new MotDialog [dialogs.size()] );
		}
	}
}
