/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.common;

import java.awt.Point;
import java.awt.Window;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;
import java.awt.event.MouseMotionListener;

import javax.swing.JComponent;
import javax.swing.JToolTip;
import javax.swing.Popup;
import javax.swing.PopupFactory;
import javax.swing.SwingUtilities;
import javax.swing.Timer;

public class MotToolTip {

	private static JComponent insideComponent;

	private static transient Popup tipWindow;
	private static Window window;
	private static JToolTip tip;
    
    private static Timer insideTimer;
    private static MotToolTipMouseListener mouseListener;
    
    public static void showTipWindow(JComponent component, int x, int y, String tipText) {
    	if (!component.isShowing()) return;
    	
        hideTipWindow();

        insideComponent = component;
		
		insideTimer = new Timer(4000, new InsideTimerAction());
        insideTimer.setRepeats(false);

        tip = insideComponent.createToolTip();
        tip.setTipText(tipText);
        Point screenLocation = component.getLocationOnScreen();

		PopupFactory popupFactory = PopupFactory.getSharedInstance();
		
        tipWindow = popupFactory.getPopup(insideComponent, tip, (int)screenLocation.getX() + x, (int)screenLocation.getY() + y);
        tipWindow.show();

        Window componentWindow = SwingUtilities.windowForComponent(insideComponent);

        window = SwingUtilities.windowForComponent(tip);

        mouseListener = new MotToolTipMouseListener();
        
        window.addMouseListener(mouseListener);
        window.addMouseMotionListener(mouseListener);
        
        insideTimer.start();
    }

    public static void hideTipWindow() {
        if (tipWindow != null) {
            if (window != null) {
                window.removeMouseListener(mouseListener);
                window.removeMouseMotionListener(mouseListener);
                window = null;
            }
            tipWindow.hide();
            tipWindow = null;
            tip = null;
            mouseListener = null;
            insideTimer.stop();
        }
    }
}

class InsideTimerAction implements ActionListener {
	public void actionPerformed(ActionEvent e) {
        MotToolTip.hideTipWindow();
	} 	
}

class MotToolTipMouseListener implements MouseListener, MouseMotionListener {
	@Override
	public void mouseClicked(MouseEvent e) {
		MotToolTip.hideTipWindow();
	}
	
	@Override
	public void mousePressed(MouseEvent e) {
		MotToolTip.hideTipWindow();
	}
	
	@Override
	public void mouseReleased(MouseEvent e) {
		MotToolTip.hideTipWindow();
	}
	
	@Override
	public void mouseEntered(MouseEvent e) {
		MotToolTip.hideTipWindow();
	}
	
	@Override
	public void mouseExited(MouseEvent e) {
		MotToolTip.hideTipWindow();
	}
	
	@Override
	public void mouseDragged(MouseEvent e) {
		MotToolTip.hideTipWindow();
	}
	
	@Override
	public void mouseMoved(MouseEvent e) {
		MotToolTip.hideTipWindow();
	}
}

