/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.common;

import java.awt.Color;
import java.awt.Dimension;
import java.awt.Font;
import java.awt.Graphics;

import javax.swing.JLabel;

import mot.client.swing.icons.MotImageIcon;
import mot.client.telemetry.Telemetry;
import mot.common.bean.Size;

public class MotTransparentLabel extends JLabel {

	public MotTransparentLabel() {
	}

	public MotTransparentLabel(String text) {
		this (text, JLabel.LEFT);
	}
	
	public MotTransparentLabel(String text, String toolTipText) {
		this (text, JLabel.LEFT);
		if (toolTipText != null) {
			setToolTipText(toolTipText);
		}
	}
	
	public MotTransparentLabel(String text, String toolTipText, int sizeDiff, int alignment, boolean bold) {
		this (text, sizeDiff, alignment, bold);
		if (toolTipText != null) {
			setToolTipText(toolTipText);
		}
	}
	
	public MotTransparentLabel(String text, int sizeDiff, boolean bold) {
		this (text, sizeDiff, JLabel.LEFT, bold);
	}
	
	public MotTransparentLabel(String text, int sizeDiff, boolean bold, Color foregroundColor) {
		this (text, sizeDiff, JLabel.LEFT, bold);
		setForeground(foregroundColor);
	}
	
	/**
	 * @param text The text 
	 * @param alignment One of JLabel.RIGHT, JLabel.LEFT
	 */
	public MotTransparentLabel(String text, int alignment) {
		this(text, 0, null, null, alignment, false);
	}

	public MotTransparentLabel(String text, int sizeDiff, int alignment, boolean bold) {
		this(text, sizeDiff, null, null, alignment, bold);
	}

	public MotTransparentLabel(String text, int sizeDiff, Dimension min, Dimension pref, int alignment, boolean bold) {
		this(text, sizeDiff, null, null, alignment, bold, null, null);
	}
	
	public MotTransparentLabel(String text, int sizeDiff, Dimension min, Dimension pref, int alignment, boolean bold, Color fontColor, String toolTipText) {
        super(text);
        if (sizeDiff != 0 || bold) {
            Font font = getFont();
            int style = font.getStyle();
            if (bold) {
                style = Font.BOLD;
            }
            setFont(new Font(font.getName(), style, font.getSize()+sizeDiff));
        }
        if (fontColor != null) {
        	setForeground(fontColor);
        }
        if (min != null) {
            setMinimumSize(min);
        }
        if (pref != null) {
            setPreferredSize(pref);
        }
        setHorizontalAlignment(alignment);
		if (toolTipText != null) {
			setToolTipText(toolTipText);
		}
		setOpaque(false);
	}

	public MotTransparentLabel(String text, int sizeDiff, Dimension min, Dimension pref, int alignment, boolean bold, String toolTipText) {
		this(text, sizeDiff, min, pref, alignment, bold, null, toolTipText);
		
	}
	
	public MotTransparentLabel(MotImageIcon i) {
		super(i);
	}

	public MotTransparentLabel(MotImageIcon i, Size s) {
		super(i);
		PanelUtils.setTheBloodySize(this, s);
	}

	public void paint(Graphics g) {
		 if (Telemetry.ON) Telemetry.qtyPaintLebel++;
		 super.paint(g); 
	 }

	public void setFontColor(Color c) {
		setForeground(c);
	}
	
}
