/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.common;

import java.awt.Color;
import java.awt.Component;
import java.awt.Insets;

import javax.swing.BoxLayout;
import javax.swing.JPanel;

public class PadPanel extends JPanel {

    int left;
    int right;
    int top;
    int bottom;

    public PadPanel() {
        this.left = 0;
        this.right = 0;
        this.top = 0;
        this.bottom = 0;
        setLayout(new BoxLayout(this, BoxLayout.Y_AXIS));
        setOpaque(false);
    }

    public PadPanel(Component component, int padding, Color color) {
    	this(component, padding);
    	setBackground(color);
    }
    
    public PadPanel(Component component) {
        this(component, 5);
    }

    public PadPanel(int padding) {
        this(null, 5);
    }

    public PadPanel(int padding, boolean opaque) {
        this(null, 5);
        setOpaque(opaque);
    }

    public PadPanel(Component component, int padding) {
        this.left = padding;
        this.right = padding;
        this.top = padding;
        this.bottom = padding;
        setLayout(new BoxLayout(this, BoxLayout.Y_AXIS));
        if (component != null) {
        	add(component);
        }
        setOpaque(false);
    }

    public PadPanel(Component component, int hpad, int vpad) {
        this.left = hpad;
        this.right = hpad;
        this.top = vpad;
        this.bottom = vpad;
        setLayout(new BoxLayout(this, BoxLayout.Y_AXIS));
        if (component != null) {
        	add(component);
        }
        setOpaque(false);
    }

    public PadPanel(Component component, int hpad, int vpad, boolean opaque) {
        this(component, hpad, vpad);
        setOpaque(opaque);
    }


    public PadPanel(int horizontal, int vertical) {
		this.left = horizontal;
		this.right = horizontal;
		this.top = vertical;
		this.bottom = vertical;
        setOpaque(false);
	}

    public PadPanel(int left, int right, int top, int bottom) {
		this.left = left;
		this.right = right;
		this.top = top;
		this.bottom = bottom;
        setOpaque(false);
	}

    public PadPanel(Component component, int left, int right, int top, int bottom) {
		this.left = left;
		this.right = right;
		this.top = top;
		this.bottom = bottom;
        setLayout(new BoxLayout(this, BoxLayout.Y_AXIS));
        if (component != null) {
        	add(component);
        }
        setOpaque(false);
	}

	public Insets getInsets() {
        return new Insets(top,left,bottom,right);
    }

	public void removeAllAndAdd(JPanel p) {
		removeAll();
		add(p);
	}
}