/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.common;
import java.awt.Component;
import javax.swing.JPanel;
import javax.swing.SpringLayout;

public class SpringPanel extends JPanel {

    private SpringLayout layout;
    private int vpadding;
    private int hpadding;
    
    private Component previousItem;
    private Component previousRow;
    
    public static final Integer NONE = null;
    public static final Integer ALIGN = new Integer(1);
    public static final Integer DEFINE = new Integer(2);

    public SpringPanel(int vpadding, int hpadding) {
        this.vpadding = vpadding;
        this.hpadding = hpadding;
        layout = new SpringLayout();
        setLayout(layout);
    }
    
    public SpringPanel(int padding) {
        this.vpadding = padding;
        this.hpadding = padding;
        layout = new SpringLayout();
        setLayout(layout);
    }
    
    public Component add(Component c) {
        return add(c, false, null, null);
    }
    
    public Component add(Component c, boolean endLine, Integer right, Integer bottom) {
        if (previousItem == null) {
            layout.putConstraint(SpringLayout.WEST, c, hpadding, SpringLayout.WEST, this);
        } else {
            layout.putConstraint(SpringLayout.WEST, c, hpadding, SpringLayout.EAST, previousItem);
        }
        if (previousRow == null) {
            layout.putConstraint(SpringLayout.NORTH, c, vpadding, SpringLayout.NORTH, this);
        } else {
            layout.putConstraint(SpringLayout.NORTH, c, vpadding, SpringLayout.SOUTH, previousRow);
        }
        if (right == ALIGN) {
            layout.putConstraint(SpringLayout.EAST, c, hpadding, SpringLayout.EAST, this);
        } else if (right == DEFINE) {
            layout.putConstraint(SpringLayout.EAST, this, hpadding, SpringLayout.EAST, c);
        }
        if (bottom == ALIGN) {
            layout.putConstraint(SpringLayout.SOUTH, c, vpadding, SpringLayout.SOUTH, this);
        } else if (bottom == DEFINE) {
            layout.putConstraint(SpringLayout.SOUTH, this, vpadding, SpringLayout.SOUTH, c);
        }
        super.add(c);
        previousItem = c;
        if (endLine) {
            newLine();
        }
        return null;
    }

    public void setBottom() {
        if (previousItem != null) {
            layout.putConstraint(SpringLayout.SOUTH, this, vpadding, SpringLayout.SOUTH, previousItem);
        } else if (previousRow != null) {
            layout.putConstraint(SpringLayout.SOUTH, this, vpadding, SpringLayout.SOUTH, previousRow);
        }
    }
    
    public void newLine() {
        previousRow = previousItem;   
        previousItem = null;
    }
    
    public void removeAll() {
        previousRow = null;   
        previousItem = null;
        super.removeAll();
    }


    public void setVpadding(int vpadding) {
        this.vpadding = vpadding;
    }


    public int getVpadding() {
        return vpadding;
    }


    public void setHpadding(int hpadding) {
        this.hpadding = hpadding;
    }


    public int getHpadding() {
        return hpadding;
    }
}