/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.common;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.SwingUtilities;
import javax.swing.Timer;

import mot.client.swing.window.main.MainWindow;
import mot.common.bean.Settings;
import mot.common.util.ApplicationError;
import mot.common.util.Logger;
import mot.common.util.ValidationError;

public abstract class TimerAbstract implements ActionListener {

    public Timer timer;

    public TimerAbstract(int interval) throws ApplicationError {
        timer = new Timer(interval, this);
        timer.start();
    	//Logger.logDebug("START "+this);
	}

    public TimerAbstract() throws ApplicationError {
		int fps = Settings.getInstance().getFramesPerSecond();
        timer = new Timer(1000/fps, this);
        timer.start();
    	//Logger.logDebug("START "+this);
	}

    protected abstract void handleTick() throws ApplicationError, ValidationError;
    
    public void actionPerformed(ActionEvent e) {
    	if (Logger.isDebug()) {
    		if (!SwingUtilities.isEventDispatchThread()) {
    			Logger.logError("", new Exception("NOT IN EVENT THREAD"));
    		}
    	}
    	//Logger.logDebug("TICK "+this);
        try {
            try {
	            if (e.getSource() instanceof Timer) {
	            	handleTick();
	            }
	        } catch (ValidationError ex) {
	            MainWindow.getExestingInstance().reportValidationError(ex);
	        }
        } catch (Exception ex) {
        	try {
        		MainWindow.getInstance().reportApplicationError(ex);
        	} catch (Exception subError) {
        		Logger.logError("No Main Window to show error", ex);
        	}
        }
    }

    public void stop() {
    	//Logger.logDebug("STOP "+this);
    	timer.stop();
    }
	
}
