/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.common;

import mot.client.event.EventMailBox;
import mot.client.swing.window.main.MainWindow;
import mot.common.event.MotEvent;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class TimerEventPolling extends TimerAbstract {

    private Class eventClass;
	private EventObserver observer;

	public TimerEventPolling() throws ApplicationError {
		super();
	}

	public TimerEventPolling(Class eventClass, EventObserver observer, int interval) throws ApplicationError {
		super(interval);
		this.eventClass = eventClass;
		this.observer = observer;
	}

	protected void handleTick() throws ApplicationError, ValidationError {
    	//Logger.logDebug("TimerEventPolling.handleTick()");
    	MainWindow mainWin = MainWindow.getInstance();
    	if (mainWin == null) return;
        EventMailBox eventMailBox = mainWin.getEventMailBox();
//    	if (eventMailBox == null) {
//    		SwingMotEventConsumer eventConsumer = new SwingMotEventConsumer(mainWin);
//    		ProxyStore.getInstance().register(null, false, eventConsumer, null, null);
//    		eventMailBox = mainWin.getEventMailBox();
//    	}
		if (observer == null) {
			eventMailBox.processFirstEventType(eventClass);
		} else {    			
			MotEvent event = eventMailBox.fetchFirstEventType(eventClass);
			if (event != null) {
				observer.eventNotification(event);
			}
		}
    }

}
