/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.common;

import java.awt.Rectangle;

import javax.swing.JPanel;

/**
 * This defined a hot zone to be a horizontal strip in the parent panel whose
 * top is the top of the child and whose bottom is the bottom of the child.
 */
public class ZoneProviderPanelHStrip extends ZoneProviderBase {

	/**
	 * Panel in which this zone is defined
	 */
	private JPanel parent;
	
	/**
	 * Panel that is contained in parent, and whose y and y+height (top
	 * and bottom) define the location of the horizontal strip defined
	 * here.
	 */
	private JPanel child;

	
	public ZoneProviderPanelHStrip(JPanel parent, JPanel child) {
		this.parent = parent;
		this.child = child;
	}

	public boolean contains(int x, int y) {
		Rectangle bounds = child.getBounds();
		int top = bounds.y;
		int bottom = top + bounds.height;
		return y >= top && y <= bottom;
	}

}
