/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.config;

import mot.common.bean.Size;
import mot.common.util.ApplicationError;
import mot.common.xml.DomNode;
import mot.common.xml.XMLInput;

/**
 * This is the details of an image that is used to animate an event. Typically this
 * image is moved, such as the fear animation that rises the image above the craft.
 * e.g. Fear
 */
public class ImageConfig implements XMLInput {

	/**
	 * This is the name of this image
	 */
	private String name;
	
	/**
	 * This is the name of the image including the directory and the file extension.
	 */
	private String image;
	
	/**
	 * This is the size of these images. All images MUST be the same size.
	 */
	private Size imageSize;
	
	/**
	 * This is the quantity of images in this animation. The index that is used
	 * to make this animation of a number between 1 and qtyImages inclusive.
	 */
	private int life;

	/**
	 * An optional description of this image
	 */
	private String description;
	
	public ImageConfig() {
	}

	public ImageConfig(String name, String image, Size imageSize, int life) {
		super();
		this.name = name;
		this.image = image;
		this.imageSize = imageSize;
		this.life = life;
	}

	public ImageConfig(DomNode n) throws ApplicationError {
		name = n.getNodeValueByName_String("name");
		image = n.getNodeValueByName_String("image");
		imageSize = n.getNodeValueByName_Size("image-size");
		description = n.getNodeValueByName_String("description");
		life = n.getNodeValueByName_Int("life");
	}

	public String getImage() {
		return image;
	}

	public void setImage(String image) {
		this.image = image;
	}

	public Size getImageSize() {
		return imageSize;
	}

	public void setImageSize(Size imageSize) {
		this.imageSize = imageSize;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public int getLife() {
		return life;
	}

	public void setLife(int life) {
		this.life = life;
	}

	public String getDescription() {
		return description;
	}

	public void setDescription(String description) {
		this.description = description;
	}
	
	
}
