/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.config;

import java.util.Collection;
import java.util.HashMap;

import mot.common.util.ApplicationError;
import mot.common.xml.DomNode;

public class ImageConfigList {

	/**
	 * Maps the name of the image to the config details for that image.
	 * List of ImageConfig.
	 */
	private HashMap imageConfigs = new HashMap();

	public ImageConfigList() {
	}
	
	public ImageConfigList(DomNode n) throws ApplicationError {
		DomNode[] na = n.getNodesByName("image-config");
		if (na != null) {
			for (int i = 0; i < na.length; i++) {
				setImageConfig(new ImageConfig(na[i]));
			}
		}
	}

	public ImageConfigList(ImageConfig[] ca) {
		if (ca != null) {
			for (int i = 0; i < ca.length; i++) {
				setImageConfig(ca[i]);
			}
		}
	}

	public void setImageConfig(ImageConfig v) {
		imageConfigs.put(v.getName(), v);
	}
	
	public ImageConfig getImageConfig(String name) {
		ImageConfig r = (ImageConfig) imageConfigs.get(name);
		return r;
	}

	public int getQty() {
		return imageConfigs.size();
	}
	
	public ImageConfig [] getImageConfigArray() {
		if (imageConfigs.size() > 0) {
			Collection c = imageConfigs.values();
			ImageConfig[] ca = (ImageConfig[]) c.toArray(new ImageConfig[c.size()]);
			return ca;
		} else {
			return null;
		}
	}

}
