/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.config;
import mot.common.bean.Size;
import mot.common.util.ApplicationError;
import mot.common.xml.DomNode;
import mot.common.xml.XMLInput;

/**
 * This class holds configuration information for aninations that are built from moving
 * images.
 */
public class ImageDuelStrokeAnimationConfig implements XMLInput {

	/**
	 * The name of the weapon this config refers to. The name does not include the group
	 * name it is the simple technology name
	 */
	private String name;
	
	/**
	 * This is the quantity of frames this animation stays alive
	 * A zero value indicates the animation is continuous.
	 */
	private int life;
	
	/**
	 * This is the quantity of frames between this animation takes to move to the next
	 * stage (picture) of the animation
	 */
	private int interval;

	/**
	 * This is the name of the image to use for this stroke.
	 * Note this may be null - some strokes use lines or other custom configs.
	 */
	private String strokeImage1;
	private String strokeImage2;
	
	/**
	 * This is the size of the image for this stroke
	 */
	private Size strokeSize;
	
    /**
     * This is the gap between the start of an image and the start of the next image to be 
     * drawn in the stroke.
     */
    private int strokeGap;
    
    /**
     * This is the quantity of pixels forward that the images will be drawn each iteration 
     * of animation. 
     */
    private int strokeStep;

	public ImageDuelStrokeAnimationConfig() {
	}

	public ImageDuelStrokeAnimationConfig(DomNode n) throws ApplicationError {
		this.name = n.getNodeValueByName_String("name");
		this.life = n.getNodeValueByName_Int("life");
		this.interval = n.getNodeValueByName_Int("interval");
		this.strokeImage1 = n.getNodeValueByName_String("stroke-image1");
		this.strokeImage2 = n.getNodeValueByName_String("stroke-image2");
		this.strokeSize = n.getNodeValueByName_Size("stroke-size");
		this.strokeGap = n.getNodeValueByName_Int("stroke-gap");
		this.strokeStep = n.getNodeValueByName_Int("stroke-step");
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public int getStrokeGap() {
		return strokeGap;
	}

	public void setStrokeGap(int strokeGap) {
		this.strokeGap = strokeGap;
	}

	public String getStrokeImage1() {
		return strokeImage1;
	}

	public void setStrokeImage1(String strokeImage) {
		this.strokeImage1 = strokeImage;
	}

	public String getStrokeImage2() {
		return strokeImage2;
	}

	public void setStrokeImage2(String strokeImage) {
		this.strokeImage2 = strokeImage;
	}

	public Size getStrokeSize() {
		return strokeSize;
	}

	public void setStrokeSize(Size strokeSize) {
		this.strokeSize = strokeSize;
	}

	public int getStrokeStep() {
		return strokeStep;
	}

	public void setStrokeStep(int strokeStep) {
		this.strokeStep = strokeStep;
	}

	public int getInterval() {
		return interval;
	}

	public void setInterval(int interval) {
		this.interval = interval;
	}

	public int getLife() {
		return life;
	}

	public void setLife(int life) {
		this.life = life;
	}

	
}
