/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.config;

import mot.common.bean.Size;
import mot.common.util.ApplicationError;
import mot.common.xml.DomNode;

/**
 * This is the details of an image that is used to animate an event. Typically this
 * image is moved, such as the fear animation that rises the image above the craft.
 * e.g. Fear
 */
public class MenuImageConfig {

	/**
	 * This is the name of this image
	 */
	private String name;
	
	/**
	 * This is the name of the image including the directory and the file extension.
	 */
	private String image;
	
	/**
	 * The size of this menu image (may be null then the default menu image size is used from menu config)
	 */
	private Size imageSize;
	
	public MenuImageConfig() {
	}

	public MenuImageConfig(String name, String image) {
		super();
		this.name = name;
		this.image = image;
	}

	public MenuImageConfig(DomNode n) throws ApplicationError {
		name = n.getNodeValueByName_String("name");
		image = n.getNodeValueByName_String("image");
		imageSize = n.getNodeValueByName_Size("image-size");
	}

	public String getImage() {
		return image;
	}

	public void setImage(String image) {
		this.image = image;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public Size getImageSize() {
		return imageSize;
	}

	public void setImageSize(Size imageSize) {
		this.imageSize = imageSize;
	}

	
	
}
