/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.config;

import mot.common.xml.*;
import mot.common.bean.Size;
import mot.common.util.*;

/**
 * Used to describe the size of the images used to animate a weapon fire between crafts.
 * Usually weapon fire is a fixed width between source and target - in which case distance of not 
 * used and x and y are the size of ther images to use.
 * Some weaponsd have their beam get wider or narrower allong the beam from source to target. For these
 * animations we use several StrokeSizes. In each the distance describes the start position of the next
 * image size to use.
 * 
 *  NB - distance is a percentage (a value between 0 and 100) of the distance from source to target.
 *
 */
public class StrokeSize extends Size {

	private int distance;

	public StrokeSize() {
	}

	public StrokeSize(int x, int y) {
		super(x,y);
	}

	public StrokeSize(int x, int y, int distance) {
		super(x,y);
		this.distance = distance;
	}

	public StrokeSize(DomNode n) {
		super(n.getNodeValueByName_Int("x"),n.getNodeValueByName_Int("y"));
		this.distance = n.getNodeValueByName_Int("distance");
	}

	public boolean equals(StrokeSize o) { return o != null && o.getX() == getX() && o.getY() == getY() && o.getDistance() == distance; }

	protected void encode(XMLWriter writer) throws ApplicationError {
		super.encode(writer);
		writer.addElement("distance", distance);
	}
	protected String getElementName() { return "stroke-size"; }
	
	public void setDistance(int distance) {
		this.distance = distance;
	}

	public int getDistance() {
		return distance;
	}
}