/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.event;

import mot.client.event.MotEventConsumer;
import mot.common.event.LinkedEventBase;
import mot.common.event.MotEvent;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public interface SwingEventHandler {

	/**
	 * This method is called by the framework to request this handler process the event e that has been recieved by the client. The handler should 
	 * generate all necessary user notifications / animations to handle this event.
	 * @param e The event to process.
	 * @param swingMotEventProcessor The processor that requested this event be processed.
	 * @param parent The parent of this event (if the event was a linked event inside another event).
	 * @throws ApplicationError
	 * @throws ValidationError
	 */
	public void process(MotEvent e, MotEventConsumer swingMotEventProcessor, LinkedEventBase parent) throws ApplicationError, ValidationError;
	
}
