/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.event;

import java.util.HashMap;

import mot.client.event.MotEventConsumer;
import mot.client.swing.event.processors.BattleAutomateSwingEventProcessor;
import mot.client.swing.event.processors.BattleCraftUpdateEventProcessor;
import mot.client.swing.event.processors.BattleObjectNotificationSwingEventProcessor;
import mot.client.swing.event.processors.BattleObjectTriggerSwingEventProcessor;
import mot.client.swing.event.processors.BattlePulseEventProcessor;
import mot.client.swing.event.processors.BattleStateUpdateEventProcessor;
import mot.client.swing.event.processors.ColonisePlanetSwingEventProcessor;
import mot.client.swing.event.processors.CraftLeaveBattleSwingEventProcessor;
import mot.client.swing.event.processors.CraftMoveSwingEventProcessor;
import mot.client.swing.event.processors.CraftSurrenderSwingEventProcessor;
import mot.client.swing.event.processors.CraftTeleportSwingEventProcessor;
import mot.client.swing.event.processors.DamageRingEventProcessor;
import mot.client.swing.event.processors.DamageSwingEventProcessor;
import mot.client.swing.event.processors.DestroyColonyEventProcessor;
import mot.client.swing.event.processors.DestroyedSwingEventProcessor;
import mot.client.swing.event.processors.DiplomaticRequestSwingEventProcessor;
import mot.client.swing.event.processors.DiplomaticResponseSwingEventProcessor;
import mot.client.swing.event.processors.DroidMineLaunchSwingEventProcessor;
import mot.client.swing.event.processors.DroidMineMoveSwingEventProcessor;
import mot.client.swing.event.processors.EndBattleSwingEventProcessor;
import mot.client.swing.event.processors.EndTurnSwingEventProcessor;
import mot.client.swing.event.processors.FearEventProcessor;
import mot.client.swing.event.processors.FundsGoneSwingEventProcessor;
import mot.client.swing.event.processors.FundsLowSwingEventProcessor;
import mot.client.swing.event.processors.GameEndSwingEventProcessor;
import mot.client.swing.event.processors.InvadePlanetSwingEventProcessor;
import mot.client.swing.event.processors.LeaderGainLevelSwingEventProcessor;
import mot.client.swing.event.processors.MessageSwingEventProcessor;
import mot.client.swing.event.processors.MissTargetSwingEventProcessor;
import mot.client.swing.event.processors.MissileLaunchSwingEventProcessor;
import mot.client.swing.event.processors.MissileMoveSwingEventProcessor;
import mot.client.swing.event.processors.NewBattleSwingEventProcessor;
import mot.client.swing.event.processors.NewBattleTurnSwingEventProcessor;
import mot.client.swing.event.processors.NewCraftSwingEventProcessor;
import mot.client.swing.event.processors.NewGameUserPlayerEventProcessor;
import mot.client.swing.event.processors.NewSpySwingEventProcessor;
import mot.client.swing.event.processors.NoProjectSwingEventProcessor;
import mot.client.swing.event.processors.NoResearchProjectSwingEventProcessor;
import mot.client.swing.event.processors.OfferLeaderSwingEventProcessor;
import mot.client.swing.event.processors.PlanetBombardedSwingEventProcessor;
import mot.client.swing.event.processors.PlanetColonisedSwingEventProcessor;
import mot.client.swing.event.processors.PlanetConqueredSwingEventProcessor;
import mot.client.swing.event.processors.PlanetCrisisSwingEventProcessor;
import mot.client.swing.event.processors.PlayerLoseSwingEventProcessor;
import mot.client.swing.event.processors.PlayerSurrenderSwingEventProcessor;
import mot.client.swing.event.processors.PlayersWaitingForBattleAutomateEventProcessor;
import mot.client.swing.event.processors.PlayersWaitingForEndTurnEventProcessor;
import mot.client.swing.event.processors.PrizeSwingEventProcessor;
import mot.client.swing.event.processors.RecommendMoralChoiceSwingEventProcessor;
import mot.client.swing.event.processors.RoutedSwingEventProcessor;
import mot.client.swing.event.processors.SabotageSwingEventProcessor;
import mot.client.swing.event.processors.ServerConnectionErrorSwingEventProcessor;
import mot.client.swing.event.processors.StartGameEventProcessor;
import mot.client.swing.event.processors.StartTurnSwingEventProcessor;
import mot.client.swing.event.processors.StateUpdateEventProcessor;
import mot.client.swing.event.processors.TechnologyDiscoveredSwingEventProcessor;
import mot.client.swing.event.processors.TechnologyStolenSwingEventProcessor;
import mot.client.swing.event.processors.TooManySpiesSwingEventProcessor;
import mot.client.swing.event.processors.TradeRouteInvalidEventProcessor;
import mot.client.swing.event.processors.WeaponFireSwingEventProcessor;
import mot.client.swing.window.main.MainWindow;
import mot.common.event.BattleAutomateEvent;
import mot.common.event.BattleCraftLeaveEvent;
import mot.common.event.BattleCraftMoveEvent;
import mot.common.event.BattleCraftNewEvent;
import mot.common.event.BattleCraftSurrenderEvent;
import mot.common.event.BattleCraftTeleportEvent;
import mot.common.event.BattleCraftUpdateEvent;
import mot.common.event.BattleDamageEvent;
import mot.common.event.BattleDamageRingEvent;
import mot.common.event.BattleDestroyedEvent;
import mot.common.event.BattleDroidMineLaunchEvent;
import mot.common.event.BattleDroidMineMoveEvent;
import mot.common.event.BattleEndEvent;
import mot.common.event.BattleFearEvent;
import mot.common.event.BattleMissileLaunchEvent;
import mot.common.event.BattleMissileMoveEvent;
import mot.common.event.BattleNewTurnEvent;
import mot.common.event.BattleObjectNotificationEvent;
import mot.common.event.BattleObjectTriggerEvent;
import mot.common.event.BattlePulseEvent;
import mot.common.event.BattleStateUpdateContainerEvent;
import mot.common.event.BattleWeaponFireEvent;
import mot.common.event.BattleWeaponMissEvent;
import mot.common.event.ColonisePlanetEvent;
import mot.common.event.DestroyColonyEvent;
import mot.common.event.DiplomaticRequestEvent;
import mot.common.event.DiplomaticResponseEvent;
import mot.common.event.EndTurnEvent;
import mot.common.event.FundsGoneEvent;
import mot.common.event.FundsLowEvent;
import mot.common.event.GameEndEvent;
import mot.common.event.LeaderGainLevelEvent;
import mot.common.event.LinkedEventBase;
import mot.common.event.MessageEvent;
import mot.common.event.MotEvent;
import mot.common.event.NewBattleEvent;
import mot.common.event.NewGameUserPlayerEvent;
import mot.common.event.NewSpyEvent;
import mot.common.event.NoProjectEvent;
import mot.common.event.NoResearchProjectEvent;
import mot.common.event.OfferLeaderEvent;
import mot.common.event.OfferMoralChoiceEvent;
import mot.common.event.PlanetBombardedEvent;
import mot.common.event.PlanetColonisedEvent;
import mot.common.event.PlanetConqueredEvent;
import mot.common.event.PlanetCrisisEvent;
import mot.common.event.PlanetInvadeEvent;
import mot.common.event.PlayerLoseEvent;
import mot.common.event.PlayerSurrenderEvent;
import mot.common.event.PlayersWaitingForBattleAutomateEvent;
import mot.common.event.PlayersWaitingForEndTurnEvent;
import mot.common.event.PrizeGiftEvent;
import mot.common.event.RoutedEvent;
import mot.common.event.SabotageEvent;
import mot.common.event.ServerConnectionErrorEvent;
import mot.common.event.StartGameEvent;
import mot.common.event.StartTurnEvent;
import mot.common.event.StateUpdateEvent;
import mot.common.event.TechnologyDiscoveredEvent;
import mot.common.event.TechnologyStolenEvent;
import mot.common.event.TooManySpiesEvent;
import mot.common.event.TradeRouteInvalidEvent;
import mot.common.util.ApplicationError;
import mot.common.util.Logger;
import mot.common.util.ValidationError;

public class SwingMotEventConsumer implements MotEventConsumer {

	private HashMap handlerMap = new HashMap();
	
    public SwingMotEventConsumer(MainWindow mainWindow) {
    	handlerMap.put(ColonisePlanetEvent.class.getName(), new ColonisePlanetSwingEventProcessor());
    	handlerMap.put(PlanetColonisedEvent.class.getName(), new PlanetColonisedSwingEventProcessor());
    	handlerMap.put(PlanetBombardedEvent.class.getName(), new PlanetBombardedSwingEventProcessor());
    	handlerMap.put(PlanetCrisisEvent.class.getName(), new PlanetCrisisSwingEventProcessor());
    	handlerMap.put(MessageEvent.class.getName(), new MessageSwingEventProcessor());
    	// Delete GetNextCraftOrdersEvent when doing next big change
    	handlerMap.put(BattleWeaponFireEvent.class.getName(), new WeaponFireSwingEventProcessor());
    	handlerMap.put(BattleDamageEvent.class.getName(), new DamageSwingEventProcessor());
    	handlerMap.put(BattleWeaponMissEvent.class.getName(), new MissTargetSwingEventProcessor());
    	handlerMap.put(BattleDamageRingEvent.class.getName(), new DamageRingEventProcessor());
    	handlerMap.put(BattleObjectTriggerEvent.class.getName(), new BattleObjectTriggerSwingEventProcessor());
    	handlerMap.put(BattleObjectNotificationEvent.class.getName(), new BattleObjectNotificationSwingEventProcessor());
    	handlerMap.put(BattleCraftMoveEvent.class.getName(), new CraftMoveSwingEventProcessor());
    	handlerMap.put(BattleCraftTeleportEvent.class.getName(), new CraftTeleportSwingEventProcessor());
    	handlerMap.put(BattleMissileLaunchEvent.class.getName(), new MissileLaunchSwingEventProcessor());
    	handlerMap.put(BattleMissileMoveEvent.class.getName(), new MissileMoveSwingEventProcessor());
    	handlerMap.put(BattlePulseEvent.class.getName(), new BattlePulseEventProcessor());
    	handlerMap.put(PlanetInvadeEvent.class.getName(), new InvadePlanetSwingEventProcessor());
    	handlerMap.put(BattleAutomateEvent.class.getName(), new BattleAutomateSwingEventProcessor());
    	handlerMap.put(PlanetConqueredEvent.class.getName(), new PlanetConqueredSwingEventProcessor());
    	handlerMap.put(BattleCraftLeaveEvent.class.getName(), new CraftLeaveBattleSwingEventProcessor());
    	handlerMap.put(BattleCraftNewEvent.class.getName(), new NewCraftSwingEventProcessor());
    	handlerMap.put(BattleDestroyedEvent.class.getName(), new DestroyedSwingEventProcessor());
    	handlerMap.put(BattleCraftSurrenderEvent.class.getName(), new CraftSurrenderSwingEventProcessor());
    	handlerMap.put(BattleFearEvent.class.getName(), new FearEventProcessor());
    	handlerMap.put(NoProjectEvent.class.getName(), new NoProjectSwingEventProcessor());
    	handlerMap.put(NoResearchProjectEvent.class.getName(), new NoResearchProjectSwingEventProcessor());
    	handlerMap.put(TechnologyDiscoveredEvent.class.getName(), new TechnologyDiscoveredSwingEventProcessor());
    	handlerMap.put(DiplomaticResponseEvent.class.getName(), new DiplomaticResponseSwingEventProcessor());
    	handlerMap.put(DiplomaticRequestEvent.class.getName(), new DiplomaticRequestSwingEventProcessor());
    	handlerMap.put(NewBattleEvent.class.getName(), new NewBattleSwingEventProcessor());
    	handlerMap.put(BattleEndEvent.class.getName(), new EndBattleSwingEventProcessor());
    	handlerMap.put(BattleNewTurnEvent.class.getName(), new NewBattleTurnSwingEventProcessor());
    	handlerMap.put(TechnologyStolenEvent.class.getName(), new TechnologyStolenSwingEventProcessor());
    	handlerMap.put(SabotageEvent.class.getName(), new SabotageSwingEventProcessor());
    	handlerMap.put(TooManySpiesEvent.class.getName(), new TooManySpiesSwingEventProcessor());
    	handlerMap.put(NewSpyEvent.class.getName(), new NewSpySwingEventProcessor());
    	handlerMap.put(OfferLeaderEvent.class.getName(), new OfferLeaderSwingEventProcessor());
    	handlerMap.put(LeaderGainLevelEvent.class.getName(), new LeaderGainLevelSwingEventProcessor());
    	handlerMap.put(PlayerLoseEvent.class.getName(), new PlayerLoseSwingEventProcessor());
    	handlerMap.put(FundsLowEvent.class.getName(), new FundsLowSwingEventProcessor());
    	handlerMap.put(PrizeGiftEvent.class.getName(), new PrizeSwingEventProcessor());
    	handlerMap.put(FundsGoneEvent.class.getName(), new FundsGoneSwingEventProcessor());
    	handlerMap.put(GameEndEvent.class.getName(), new GameEndSwingEventProcessor());
    	handlerMap.put(RoutedEvent.class.getName(), new RoutedSwingEventProcessor());
    	handlerMap.put(PlayerSurrenderEvent.class.getName(), new PlayerSurrenderSwingEventProcessor());
    	handlerMap.put(OfferMoralChoiceEvent.class.getName(), new RecommendMoralChoiceSwingEventProcessor());
    	handlerMap.put(DestroyColonyEvent.class.getName(), new DestroyColonyEventProcessor());
    	handlerMap.put(BattleDroidMineLaunchEvent.class.getName(), new DroidMineLaunchSwingEventProcessor());
    	handlerMap.put(BattleDroidMineMoveEvent.class.getName(), new DroidMineMoveSwingEventProcessor());
    	handlerMap.put(StateUpdateEvent.class.getName(), new StateUpdateEventProcessor());
    	handlerMap.put(BattleStateUpdateContainerEvent.class.getName(), new BattleStateUpdateEventProcessor());
    	handlerMap.put(BattleCraftUpdateEvent.class.getName(), new BattleCraftUpdateEventProcessor());
    	handlerMap.put(EndTurnEvent.class.getName(), new EndTurnSwingEventProcessor());
    	handlerMap.put(StartTurnEvent.class.getName(), new StartTurnSwingEventProcessor());
    	handlerMap.put(NewGameUserPlayerEvent.class.getName(), new NewGameUserPlayerEventProcessor());
    	handlerMap.put(StartGameEvent.class.getName(), new StartGameEventProcessor());
    	handlerMap.put(ServerConnectionErrorEvent.class.getName(), new ServerConnectionErrorSwingEventProcessor());
    	handlerMap.put(PlayersWaitingForEndTurnEvent.class.getName(), new PlayersWaitingForEndTurnEventProcessor());
    	handlerMap.put(PlayersWaitingForBattleAutomateEvent.class.getName(), new PlayersWaitingForBattleAutomateEventProcessor());
    	handlerMap.put(TradeRouteInvalidEvent.class.getName(), new TradeRouteInvalidEventProcessor());
    }

	public void process(MotEvent e, LinkedEventBase parent) throws ApplicationError, ValidationError {
		String key = e.getClass().getName();
		SwingEventHandler handler = (SwingEventHandler) handlerMap.get(key);
		if (handler == null) {
			Logger.logError("No Handler for "+key, new ApplicationError("NO key "+key));
			return;
		}
		if (Logger.isDebug()) {
			Logger.logDebug("SwingMotEventConsumer() process event "+e.toString());
		}
		handler.process(e, this, parent);
	}
}