/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.event.processors;

import mot.client.animation.BattleAnimationList;
import mot.client.deligates.BattleObjectDelegate;
import mot.client.deligates.cache.DeligateCacheManager;
import mot.client.event.MotEventConsumer;
import mot.client.swing.animation.MessageAnimationFactory;
import mot.client.swing.event.SwingEventHandler;
import mot.client.swing.window.battle.BattleWindowConfig;
import mot.client.swing.window.main.MainWindow;
import mot.common.event.BattleObjectTriggerEvent;
import mot.common.event.LinkedEventBase;
import mot.common.event.MotEvent;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class BattleObjectTriggerSwingEventProcessor implements SwingEventHandler {

	public void process(MotEvent e, MotEventConsumer processor, LinkedEventBase parent) throws ApplicationError, ValidationError {
		MainWindow mainWindow = MainWindow.getInstance();
    	BattleObjectTriggerEvent event = (BattleObjectTriggerEvent) e;
        BattleWindowConfig config = mainWindow.getBattleWinConfig();
        if (config != null) {
	        BattleAnimationList al = config.getListener().getState().getAnimations(); 
	        BattleObjectDelegate bo = DeligateCacheManager.getBattleObject(event.getBattle(), event.getBattleObject());
	        MessageAnimationFactory.create(event, mainWindow, bo, event.getOriginalState(), event.getNewState(), al);
        }
	}

}
