/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.event.processors;

import mot.client.animation.BattleAnimationList;
import mot.client.animation.EventAnimation;
import mot.client.deligates.BattleObjectDelegate;
import mot.client.deligates.cache.DeligateCacheManager;
import mot.client.event.MotEventConsumer;
import mot.client.swing.animation.DelayAnimation;
import mot.client.swing.animation.ExplodeAnimationFactory;
import mot.client.swing.animation.PulseAnimation;
import mot.client.swing.window.battle.BattleWindowConfig;
import mot.client.swing.window.main.MainWindow;
import mot.common.event.BattleDestroyedEvent;
import mot.common.event.BattlePulseEvent;
import mot.common.event.LinkedEventBase;
import mot.common.event.MotEvent;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class BattlePulseEventProcessor extends BattleSwingEventProcessor {

	public void process(MotEvent e, MotEventConsumer processor, LinkedEventBase parent) throws ApplicationError, ValidationError {
		BattlePulseEvent event = (BattlePulseEvent)e;
		MainWindow mainWindow = MainWindow.getInstance();
        BattleWindowConfig config = mainWindow.getBattleWinConfig();
        if (config != null && !hasRecievedEndBattleEvent(config)) {
        	BattleObjectDelegate source = DeligateCacheManager.getBattleObject(event.getBattle(), event.getSource());
            BattleAnimationList al = config.getListener().getState().getAnimations();
            if (!al.lastAnimationIsExplodeFor(source, 0)) {
            	al.add( new DelayAnimation() );
            }
           	al.add( new PulseAnimation(event, mainWindow) );
            MotEvent[] links = event.getLinkedEvents();
            if (links != null) {
                for (int i=0; i<links.length; i++) {
                    if (links[i] instanceof BattleDestroyedEvent) {
                    	BattleDestroyedEvent cde = (BattleDestroyedEvent)links[(i)];
                    	EventAnimation dea = ExplodeAnimationFactory.create(cde, al, false);
                    } else {
                    	processor.process(links[i], event);                    	
                    }
                }
            }
            al.add( new DelayAnimation() );
        }
	}

}
