/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.event.processors;

import mot.client.deligates.CraftDelegate;
import mot.client.deligates.PlanetDelegate;
import mot.client.deligates.SolarSystemDelegate;
import mot.client.deligates.StellarObjectDelegate;
import mot.client.deligates.cache.DeligateCacheManager;
import mot.client.event.MotEventConsumer;
import mot.client.swing.event.SwingEventHandler;
import mot.client.swing.window.main.MainWindow;
import mot.client.tutorials.TutorialSystem;
import mot.common.event.ColonisePlanetEvent;
import mot.common.event.LinkedEventBase;
import mot.common.event.MotEvent;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;
import mot.common.vo.OrbitVO;

public class ColonisePlanetSwingEventProcessor implements SwingEventHandler {

	public void process(MotEvent e, MotEventConsumer processor, LinkedEventBase parent) throws ApplicationError, ValidationError {
		MainWindow mainWindow = MainWindow.getInstance();
        ColonisePlanetEvent event = (ColonisePlanetEvent)e;
        CraftDelegate craft = DeligateCacheManager.getCraft(event.getCraft());
        mainWindow.getGalaxyMapListener().clearSelection();
        OrbitVO orbit = craft.getOrbit();
		if (orbit != null) {
			StellarObjectDelegate so = DeligateCacheManager.getStellarObject(orbit.getStellarObject());
			if (so instanceof SolarSystemDelegate) {
	            SolarSystemDelegate ss = (SolarSystemDelegate)so;
	            PlanetDelegate pd = mainWindow.getGalaxyMapListener().openSelectPlanetForColonisation(ss, craft, false);
	            if (pd != null && TutorialSystem.isActive()) {
	            	TutorialSystem.notifyPlanetColonised(pd);
	            }
			}
		}
	}

}
