/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.event.processors;

import mot.client.animation.BattleAnimationList;
import mot.client.deligates.BattleCraftDelegate;
import mot.client.deligates.CraftDelegate;
import mot.client.deligates.cache.DeligateCacheManager;
import mot.client.event.MotEventConsumer;
import mot.client.swing.animation.DelayAnimation;
import mot.client.swing.animation.MessageAnimation;
import mot.client.swing.window.battle.BattleWindowConfig;
import mot.client.swing.window.main.MainWindow;
import mot.common.event.BattleCraftSurrenderEvent;
import mot.common.event.BattleObjectNotificationType;
import mot.common.event.LinkedEventBase;
import mot.common.event.MotEvent;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class CraftSurrenderSwingEventProcessor extends BattleSwingEventProcessor {

	public void process(MotEvent e, MotEventConsumer processor, LinkedEventBase parent) throws ApplicationError, ValidationError {
        BattleCraftSurrenderEvent event = (BattleCraftSurrenderEvent)e;
		MainWindow mainWindow = MainWindow.getInstance();
        BattleWindowConfig config = mainWindow.getBattleWinConfig();
        BattleCraftDelegate battleCraft = DeligateCacheManager.getBattleCraft(event.getBattle(), event.getCraft());
		MainWindow.getInstance().showMessageBothPassive(L.CRAFT_+battleCraft.getName()+L.HAS_SURENDERED, true, null);
        if (config != null && !hasRecievedEndBattleEvent(config)) {
        	BattleAnimationList al = config.getListener().getState().getAnimations();
            al.add( new DelayAnimation(5) );
            al.add( new MessageAnimation(event, mainWindow, battleCraft, event.getOldState(), event.getNewState(), L.SURENDERED, BattleObjectNotificationType.surrender, 35) );
            al.add( new DelayAnimation(5) );
        }
        CraftDelegate craft = battleCraft.getCraft();
        if (craft != null) {
        	battleCraft.flushCache();
        }
	}

}
