/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.event.processors;

import mot.client.deligates.PlayerDelegate;
import mot.client.deligates.UserPlayerDelegate;
import mot.client.deligates.cache.DeligateCacheManager;
import mot.client.event.MotEventConsumer;
import mot.client.proxy.ProxyStore;
import mot.client.proxy.ServerProxy;
import mot.client.swing.buttons.MotAction;
import mot.client.swing.event.SwingEventHandler;
import mot.client.swing.window.empire.RelationsWindow;
import mot.client.swing.window.main.MainWindow;
import mot.common.bean.DiplomaticProposal;
import mot.common.event.DiplomaticRequestEvent;
import mot.common.event.LinkedEventBase;
import mot.common.event.MotEvent;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.Logger;
import mot.common.util.ValidationError;

public class DiplomaticRequestSwingEventProcessor implements SwingEventHandler {

	private DiplomaticRequestEvent event;
	private RelationsWindow win;

	public void process(MotEvent e, MotEventConsumer processor, LinkedEventBase parent) throws ApplicationError, ValidationError {
		event = (DiplomaticRequestEvent)e;
		UserPlayerDelegate owner = MainWindow.getOwner();
        boolean mustWait = !RelationsWindow.hasShowingInstance();
        win = RelationsWindow.getInstanceNotNull(null, (UserPlayerDelegate)owner);
        win.setStopEndTurnButton(true);
        
        DiplomaticProposal proposal = event.getProposal();
        
        if (event.getMessage() != null) {
            String msg = L.PLAYER_+event.getPlayer()+" : "+event.getMessage();
            MainWindow.getInstance().showMessageGalaxy(msg, true);
        } else {
        	String msg = proposal.getGalaxyWindowRequestMessage(event.getPlayer());
            MainWindow.getInstance().showMessageGalaxy(msg, true);
        }
        
        PlayerDelegate player = DeligateCacheManager.getPlayer(event.getPlayer());
        if (!owner.hasDiplomaticRelationsWith(player)) {
        	Logger.logWarning("DiplomaticRequestSwingEventProcessor.process() Got diplomatic request "+event+ " but have no contect"); 
        	return;
        }

        if (proposal.isWar() && proposal.getWanted() == null) {
			win.setDiplomaticMsg(event.getPlayer(), proposal.getGalaxyWindowRequestMessage(event.getPlayer()), true);
        } else {
        	MotAction noAction = new MotAction() {
    			protected void _doAction() throws ApplicationError, ValidationError {
    		        DiplomaticProposal proposal = event.getProposal();
    	        	String msg = proposal.getGalaxyWindowEnemyResponseMessage(event.getPlayer(), false);
    				MainWindow.getInstance().showMessageGalaxy(msg, true);
    				RelationsWindow.close();
    				PlayerDelegate player = DeligateCacheManager.getPlayer(event.getPlayer());
    				ServerProxy serverProxy = ProxyStore.getInstance();
    	            serverProxy.rejectDiplomaticRequest(player, proposal, msg, null, this);
    			}
    		};
    		MotAction yesAction = new MotAction() {
    			protected void _doAction() throws ApplicationError, ValidationError {
    		        DiplomaticProposal proposal = event.getProposal();
    	        	String msg = proposal.getGalaxyWindowEnemyResponseMessage(event.getPlayer(), true);
    				MainWindow.getInstance().showMessageGalaxy(msg, true);
    				RelationsWindow.close();
    				PlayerDelegate player = DeligateCacheManager.getPlayer(event.getPlayer());
    				ServerProxy serverProxy = ProxyStore.getInstance();
    	            serverProxy.acceptDiplomaticRequest(player, proposal, null, null, this);
    			}
    		};
			win.askQuestion(event.getPlayer(), proposal, yesAction, noAction);
        }
        
		if (mustWait) {
			win.waitUntilClosed();
		}
	}

	@Override
	public String toString() {
		return "DiplomaticRequestSwingEventProcessor [event=" + event + "]";
	}

}
