/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.event.processors;

import mot.client.deligates.PlayerDelegate;
import mot.client.deligates.UserPlayerDelegate;
import mot.client.event.MotEventConsumer;
import mot.client.proxy.ProxyStore;
import mot.client.swing.event.SwingEventHandler;
import mot.client.swing.window.empire.RelationsWindow;
import mot.client.swing.window.main.MainWindow;
import mot.common.bean.DiplomaticProposal;
import mot.common.event.DiplomaticResponseEvent;
import mot.common.event.LinkedEventBase;
import mot.common.event.MotEvent;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class DiplomaticResponseSwingEventProcessor implements SwingEventHandler {

	public DiplomaticResponseSwingEventProcessor() {
	}

	public void process(MotEvent e, MotEventConsumer processor, LinkedEventBase parent) throws ApplicationError, ValidationError {
		DiplomaticResponseEvent event = (DiplomaticResponseEvent)e;
        PlayerDelegate owner = ProxyStore.getInstance().getOwner();
        boolean mustWait = !RelationsWindow.hasShowingInstance();
        RelationsWindow win = RelationsWindow.getInstanceNotNull(null, (UserPlayerDelegate)owner);

        DiplomaticProposal proposal = event.getProposal();
        if (event.isAccept()) proposal.setExecuted(true);

        String galaxyWindowMessage = getGalaxyWindowMyResponseMessage(proposal, event.getPlayer(), event.getResponseVerb());
        String responseMesssage = galaxyWindowMessage;

        MainWindow mainWin = MainWindow.getInstance();
        mainWin.getGalaxyMapConfiguration().getGalaxyView().getStatusPanel().updateStatus(MainWindow.getOwner());

        
        if (galaxyWindowMessage != null) {
        	mainWin.showMessageGalaxy(galaxyWindowMessage, true);
        }
        
		win.addDiplomaticMsg(event.getPlayer(), responseMesssage, event.isAccept() ? "green" : "red");
		if (mustWait) {
			win.waitUntilClosed();
		}
	}

	private String getGalaxyWindowMyResponseMessage(DiplomaticProposal proposal, String playerName, String responseVerb) throws ApplicationError {
		if (proposal.isWar()) {
			return "You are now at war with "+playerName;
		} else if (proposal.isAlliance()) {
			return L.PLAYER_+playerName+L.HAS+responseVerb+L.YOUR_ALLIANCE_OFFER;
		} else if (proposal.isNonAggression()) {
			return L.PLAYER_+playerName+L.HAS+responseVerb+L.YOUR_NON_AGRESSION_OFFER;
		} else if (proposal.isPeace()) {
			return L.PLAYER_+playerName+L.HAS+responseVerb+L.YOUR_PEACE_OFFER;
		} else if (proposal.isTrade()) {
			return L.PLAYER_+playerName+L.HAS+responseVerb+L.YOUR_TRADE_OFFER;
		} else if (proposal.isResearch()) {
			return L.PLAYER_+playerName+L.HAS+responseVerb+L.YOUR_RESEARCH_TREATY_OFFER;
		} else {
			if (proposal.getWanted() != null && proposal.getOffered() != null) {
				return L.PLAYER_+playerName+L.HAS+responseVerb+" your exchange treaty";
			} else if (proposal.getOffered() != null) {
				return L.PLAYER_+playerName+L.HAS+responseVerb+" your gift";
			} else if (proposal.getWanted() != null){
				return L.PLAYER_+playerName+L.HAS+responseVerb+" your demand";
			} else {
				return "Received unknown diplomatic request from "+playerName;
			}
		}
	}

}
