/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.event.processors;

import mot.client.deligates.BattleDelegate;
import mot.client.deligates.PlanetDelegate;
import mot.client.deligates.UserPlayerDelegate;
import mot.client.deligates.cache.DeligateCacheManager;
import mot.client.event.MotEventConsumer;
import mot.client.swing.window.battle.BattleWindowConfig;
import mot.client.swing.window.main.MainWindow;
import mot.common.event.BattleEndEvent;
import mot.common.event.LinkedEventBase;
import mot.common.event.MotEvent;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class EndBattleSwingEventProcessor extends BattleSwingEventProcessor {


	public void process(MotEvent e, MotEventConsumer processor, LinkedEventBase parent) throws ApplicationError, ValidationError {
        BattleEndEvent event = (BattleEndEvent)e;
        MainWindow mainWindow = MainWindow.getInstance();
        BattleDelegate battle = DeligateCacheManager.getBattle(event.getBattle());
        if (battle != null) {
            BattleWindowConfig config = mainWindow.getBattleWinConfig();
            if (config != null) {
            	config.getListener().setEndBattleRecieved(true);
                if (config.getListener().isShowingAnimations()) {
                	displayEndBattleMessage(mainWindow, battle, event);
                	// The BattleWindowsListener will close the battle window
                	return;
                }
            }
            
            // Make sure galaxy map is rebuilt in case any crafts (active rectangles)
            // have been destroyed
            mainWindow.toGalaxyWindow();
            
            displayEndBattleMessage(mainWindow, battle, event);
        }  
        
	}

	private void displayEndBattleMessage(MainWindow mainWindow, BattleDelegate battle, BattleEndEvent event) throws ApplicationError {
		UserPlayerDelegate owner = mainWindow.getWindowOwner();
        String battleName = battle.getBattleName();
        if (battle.containsStartingPlayer(owner)) {
            if (battle.isWinner(owner)) {
            	PlanetDelegate planet = DeligateCacheManager.getPlanet(battle.getOrbit());
            	if (planet != null && planet.isBlockaded()) {
            		mainWindow.showMessageGalaxy(L.YOU_SURVIVED_THE+battleName, false);
            	} else {
            		mainWindow.showMessageGalaxy(L.YOU_WON_THE+battleName, false);
            	}
                //mainWindow.showMessage("Craft Destroyed "+event.getCraftDestroydAsDescription(), false);
            } else {
                mainWindow.showMessageGalaxy(L.YOU_LOST_THE+battleName, false);
            }
        } else {
            //mainWindow.showMessageGalaxy(battleName+" has ended", false);
        }
	}

}
