/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.event.processors;

import mot.client.event.MotEventConsumer;
import mot.client.swing.event.SwingEventHandler;
import mot.client.swing.window.main.MainWindow;
import mot.client.swing.window.solarsystem.InvadeGraphicWindow;
import mot.common.event.LinkedEventBase;
import mot.common.event.MotEvent;
import mot.common.event.PlanetInvadeEvent;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.Comp;
import mot.common.util.ValidationError;

public class InvadePlanetSwingEventProcessor implements SwingEventHandler {

	public void process(MotEvent e, MotEventConsumer processor, LinkedEventBase parent) throws ApplicationError, ValidationError {
        // Computer players use this notification as a trigger to send Troop
        // For user players we just display the results of the battle!
        PlanetInvadeEvent event = (PlanetInvadeEvent)e;
		MainWindow mainWindow = MainWindow.getInstance();
		//GalaxyWindowListener.validateGalaxyCraftList();
        new InvadeGraphicWindow(null, event, mainWindow.getWindowOwner());
        if (Comp.same(mainWindow.getWindowOwnerName(), event.getAttackerRace())) {
        	// Owner is the attacker
            if (event.getRemainingDefenders() == 0) {
    	       	String msg = L.SUCCESSFUL_GROUND_ASSAULT_AT+event.getTarget()+L.REMAINING_ATTACKERS+event.getRemainingAttackers()+L.REMAINING_DEFENDERS+event.getRemainingDefenders()+"\n";
    	       	mainWindow.showMessageGalaxy(msg, true);
            } else {
    	       	String msg = L.FAILED_GROUND_ASSAULT_AT+event.getTarget()+L.REMAINING_ATTACKERS+event.getRemainingAttackers()+L.REMAINING_DEFENDERS+event.getRemainingDefenders()+"\n";        	
    	       	mainWindow.showMessageGalaxy(msg, true);
           }
        } else {
        	// Owner is the victim
            if (event.getRemainingAttackers() == 0) {
    	       	String msg = L.SUCCESSFUL_GROUND_ASSAULT_AT+event.getTarget()+L.REMAINING_ATTACKERS+event.getRemainingAttackers()+L.REMAINING_DEFENDERS+event.getRemainingDefenders()+"\n";
    	       	mainWindow.showMessageGalaxy(msg, true);
            } else {
    	       	String msg = L.FAILED_GROUND_ASSAULT_AT+event.getTarget()+L.REMAINING_ATTACKERS+event.getRemainingAttackers()+L.REMAINING_DEFENDERS+event.getRemainingDefenders()+"\n";        	
    	       	mainWindow.showMessageGalaxy(msg, true);
           }
        }
       if (mainWindow.isGalaxyMapConfigurationActive()) {
    	   mainWindow.getGalaxyMapConfiguration().getGalaxyMapPanel().updateMooList(null);
       }
	}

}
