/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.event.processors;


import mot.client.animation.BattleAnimationList;
import mot.client.deligates.BattleDelegate;
import mot.client.deligates.cache.DeligateCacheManager;
import mot.client.event.MotEventConsumer;
import mot.client.swing.animation.DelayAnimation;
import mot.client.swing.window.battle.BattleWindowConfig;
import mot.client.swing.window.main.MainWindow;
import mot.common.bean.NameList;
import mot.common.event.LinkedEventBase;
import mot.common.event.MotEvent;
import mot.common.event.NewBattleEvent;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class NewBattleSwingEventProcessor extends BattleSwingEventProcessor {


	public void process(MotEvent e, MotEventConsumer processor, LinkedEventBase parent) throws ApplicationError, ValidationError {
        NewBattleEvent event = (NewBattleEvent)e;
        BattleDelegate battle = DeligateCacheManager.getBattle(event.getBattle().getName()); // battles.getActiveBattle();
		MainWindow mainWindow = MainWindow.getInstance();
        if (battle != null && battle.containsStartingPlayer(mainWindow.getWindowOwner())) {
            BattleWindowConfig config = mainWindow.getBattleWinConfig();
            if (config != null) {
                config.getListener().getState().init();
                config.getListener().setEndBattleRecieved(false);
            }
        	mainWindow.toBattleWindow(battle);
            config = mainWindow.getBattleWinConfig();
           	BattleAnimationList al = config.getListener().getState().getAnimations();
            al.add( new DelayAnimation(10) );
            
            String battleName = battle.getBattleName();
            NameList aggressors = battle.getAggressors();
            NameList victims = battle.getVictims();
            
            if (aggressors != null && victims != null) {
            	victims.remove(aggressors);
                String victimStr = victims.getNamesSeparated(" & ");
                String r = (victimStr == null) ? L.ATTACK_EACHOTHER : L.ATTACK+victimStr;
				mainWindow.showMessageBothActive(battleName+L.STARTS1+aggressors.getNamesSeparated(" & ")+r, false, null);
            } else {
                mainWindow.showMessageBothActive(battleName+L.STARTS2, false, null);            	
            }
        }
	}

}
