/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.event.processors;

import mot.client.event.MotEventConsumer;
import mot.client.swing.event.SwingEventHandler;
import mot.client.swing.window.common.MotInternalWindow;
import mot.client.swing.window.etc.NewGameWindow;
import mot.client.swing.window.galaxy.GalaxyWindowConfig;
import mot.client.swing.window.main.MainWindow;
import mot.client.swing.window.main.MainWindowConfig;
import mot.common.event.LinkedEventBase;
import mot.common.event.MotEvent;
import mot.common.event.NewGameUserPlayerEvent;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class NewGameUserPlayerEventProcessor implements SwingEventHandler {

	public NewGameUserPlayerEventProcessor() {
	}
	
	public void process(MotEvent e, MotEventConsumer processor, LinkedEventBase parent) throws ApplicationError, ValidationError {
		NewGameUserPlayerEvent event = (NewGameUserPlayerEvent)e;
        MainWindow mainWin = MainWindow.getExestingInstance();
        if (mainWin == null) {
        	return;
        }
        MainWindowConfig activeConfiguration = mainWin.getActiveConfiguration();
        if (activeConfiguration instanceof GalaxyWindowConfig) {
        	GalaxyWindowConfig gwc = (GalaxyWindowConfig) activeConfiguration;
        	MotInternalWindow openDialog = gwc.getGalaxyView().getTopWindow();
        	if (openDialog instanceof NewGameWindow) {
        		NewGameWindow ngWin = (NewGameWindow) openDialog;
        		ngWin.getOtherPlayersList().addUserPlayer(event.getClientId(), event.getUserData());
        	}
        }
	}

}
