/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.event.processors;

import mot.client.deligates.NamedObjectDelegate;
import mot.client.deligates.PlanetDelegate;
import mot.client.deligates.cache.DeligateCacheManager;
import mot.client.event.MotEventConsumer;
import mot.client.proxy.ProxyStore;
import mot.client.proxy.ServerProxy;
import mot.client.swing.event.SwingEventHandler;
import mot.client.swing.window.main.MainWindow;
import mot.client.swing.window.solarsystem.SolarSystemWindow;
import mot.common.event.LinkedEventBase;
import mot.common.event.MotEvent;
import mot.common.event.NoProjectEvent;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class NoProjectSwingEventProcessor implements SwingEventHandler {

	public void process(MotEvent e, MotEventConsumer processor, LinkedEventBase parent) throws ApplicationError, ValidationError {
        NoProjectEvent event = (NoProjectEvent)e;
        PlanetDelegate planet = DeligateCacheManager.getPlanet(event.getPlanet());
		MainWindow mainWindow = MainWindow.getInstance();
        if (event.getReason() != null) {
        	mainWindow.getActiveConfiguration().getView().showMessage(event.getReason(), false, null, null);
        }
        // Is the project already set by a previous no project event?
        if ( !planet.getOwnerWantsNoProject() && planet.getProjectDesign() == null) {
        	// If planet is selected on GalaxyMap may need to update its context
        	NamedObjectDelegate selection = mainWindow.getGalaxyMapListener().getSelection();
        	if (selection != null && selection instanceof PlanetDelegate) {
        		PlanetDelegate selectedPlanet = (PlanetDelegate) selection;
        		if (selectedPlanet.equals(planet)) {
        			mainWindow.getGalaxyMapListener().getView().getContextPanel().showPlanet(planet);
        		}
        	}
            SolarSystemWindow ssw = new SolarSystemWindow(null, planet, mainWindow.getWindowOwner());
            ssw.setStopEndTurnButton(true);
            ssw.waitUntilClosed();
            ServerProxy serverProxy = ProxyStore.getInstance();
            serverProxy.setPlanetWantsNoProjectCmd(planet, (planet.getProjectDesign() == null), null, mainWindow);
        }
	}

}
