/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.event.processors;

import mot.client.deligates.UserPlayerDelegate;
import mot.client.event.MotEventConsumer;
import mot.client.proxy.CompletedCallback;
import mot.client.proxy.ProxyStore;
import mot.client.proxy.ServerProxy;
import mot.client.swing.event.SwingEventHandler;
import mot.client.swing.window.common.MotConfirmationDialogPopup;
import mot.client.swing.window.empire.EmpireWindow;
import mot.client.swing.window.main.MainWindow;
import mot.client.swing.window.main.MotConditionalAction;
import mot.common.event.LinkedEventBase;
import mot.common.event.MotEvent;
import mot.common.event.OfferLeaderEvent;
import mot.common.lang.L;
import mot.common.leaders.LeaderDetails;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class OfferLeaderSwingEventProcessor implements SwingEventHandler {

	private OfferLeaderEvent event;

	public void process(MotEvent e, MotEventConsumer processor, LinkedEventBase parent) throws ApplicationError, ValidationError {
        event = (OfferLeaderEvent)e;
        LeaderDetails ld = mot.engine.leaders.LeaderFactory.getLeader(event.getLeader());
        UserPlayerDelegate owner = ProxyStore.getInstance().getOwner();
        EmpireWindow empireWin = new EmpireWindow(owner);
        empireWin.setStopEndTurnButton(true);
        String msg = L.A_FAMOUS_AND_GIFTED_LEADER_CALLED+event.getLeader()+L.HAS_OFFERED_TO_JOIN_YOU_DO_YOU_WISH_TO_ACCEPT+ld.getDescription();
        MotConditionalAction yesAction = new MotConditionalAction() {
        	private EmpireWindow empireWin;
			MotConditionalAction init(EmpireWindow empireWin) { this.empireWin = empireWin; return this; };
			public void execute() throws ApplicationError, ValidationError {
	            ServerProxy serverProxy = ProxyStore.getInstance();
	            MainWindow mainWindow = MainWindow.getExestingInstance();
	            CompletedCallback callback = new CompletedCallback() {
					public void complete(Object result) throws ApplicationError, ValidationError {
						empireWin.update();
					}
				};
				serverProxy.acceptLeader(event.getLeader(), callback, mainWindow);
			}
		}.init(empireWin);
		MotConfirmationDialogPopup questionDialog = new MotConfirmationDialogPopup(empireWin, ld.getPicture(), msg, L.EVENT_NOTIFICATION, yesAction, null);
		questionDialog.show();
		questionDialog.waitUntilClosed();
	}

}
