/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.event.processors;

import mot.client.deligates.UserPlayerDelegate;
import mot.client.event.MotEventConsumer;
import mot.client.swing.event.SwingEventHandler;
import mot.client.swing.window.main.MainWindow;
import mot.client.swing.window.solarsystem.BombardGraphicWindow;
import mot.common.event.LinkedEventBase;
import mot.common.event.MotEvent;
import mot.common.event.PlanetBombardedEvent;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.Formatter;
import mot.common.util.ValidationError;

public class PlanetBombardedSwingEventProcessor implements SwingEventHandler {


	public void process(MotEvent e, MotEventConsumer processor, LinkedEventBase parent) throws ApplicationError, ValidationError {
        PlanetBombardedEvent event = (PlanetBombardedEvent)e;
		MainWindow mainWindow = MainWindow.getInstance();
		UserPlayerDelegate owner = mainWindow.getWindowOwner();
		String msg = L.PLANET+" "+event.getTarget()+L.HAS_BEEN_BOMBARDED_POPULATION_DESTROYED+Formatter.fraction(event.getPopulationDestroyed())+L.FACTORIES_DESTROYED+Formatter.fraction(event.getFactoriesDestroyed());
        mainWindow.showMessageBothPassive(msg, true, null);
        new BombardGraphicWindow(null, event.getTarget(), owner, msg);
	}

}
