/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.event.processors;

import mot.client.deligates.UserPlayerDelegate;
import mot.client.event.MotEventConsumer;
import mot.client.proxy.ProxyStore;
import mot.client.swing.event.SwingEventHandler;
import mot.client.swing.window.common.MotConfirmationDialogPopup;
import mot.client.swing.window.empire.EmpireWindow;
import mot.client.swing.window.main.MainWindow;
import mot.client.swing.window.main.MotConditionalAction;
import mot.common.event.LinkedEventBase;
import mot.common.event.MotEvent;
import mot.common.event.OfferMoralChoiceEvent;
import mot.common.lang.L;
import mot.common.morals.MoralChoice;
import mot.common.morals.MoralChoices;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class RecommendMoralChoiceSwingEventProcessor implements SwingEventHandler {

	private String name;

	public void process(MotEvent e, MotEventConsumer processor, LinkedEventBase parent) throws ApplicationError, ValidationError {
		MainWindow mainWindow = MainWindow.getInstance();
		OfferMoralChoiceEvent event = (OfferMoralChoiceEvent)e;
		name = event.getName();
		MoralChoice mc = MoralChoices.getMoralChoice(name);
		String msg = L.A_CIVIL_SERVANT_HAS_BEEN_WORKING_ON_A_NEW_POLICY_CALLED+name+L.DESCRIPTION+mc.getDescription();
        MotConditionalAction yesAction = new MotConditionalAction() {
			public void execute() throws ApplicationError, ValidationError {
				ProxyStore.getInstance().acceptMoralChoiceCmd(name, null, null);
			}
		};
        UserPlayerDelegate owner = ProxyStore.getInstance().getOwner();
        EmpireWindow empireWin = new EmpireWindow(owner);
        empireWin.setStopEndTurnButton(true);
		MotConfirmationDialogPopup questionDialog = new MotConfirmationDialogPopup(empireWin, msg, L.EVENT_NOTIFICATION, yesAction, null);
		questionDialog.show();
		questionDialog.waitUntilClosed();
		empireWin.update();
	}

}
