/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.event.processors;

import javax.swing.JDesktopPane;
import javax.swing.JInternalFrame;

import mot.client.alarms.AlarmSystem;
import mot.client.deligates.UserPlayerDelegate;
import mot.client.deligates.cache.DeligateCacheManager;
import mot.client.event.MotEventConsumer;
import mot.client.swing.event.SwingEventHandler;
import mot.client.swing.window.galaxy.GalaxyWindowContextPanel;
import mot.client.swing.window.galaxy.GalaxyWindowListener;
import mot.client.swing.window.galaxy.GalaxyWindowView;
import mot.client.swing.window.galaxy.actions.EndTurnButtonListener;
import mot.client.swing.window.main.MainWindow;
import mot.client.tutorials.TutorialSystem;
import mot.common.event.LinkedEventBase;
import mot.common.event.MotEvent;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class StartTurnSwingEventProcessor implements SwingEventHandler {

	public void process(MotEvent e, MotEventConsumer processor, LinkedEventBase parent) throws ApplicationError, ValidationError {
		MainWindow mainWindow = MainWindow.getInstance();
		if (mainWindow.isGalaxyMapConfigurationActive()) {
			UserPlayerDelegate owner = mainWindow.getWindowOwner();
			GalaxyWindowView view = mainWindow.getGalaxyMapConfiguration().getGalaxyView();
			view.updateStatus(owner);
			view.getStatusPanel().getEndTurnButton().notifyTurnStarted();
			JDesktopPane desktopPane = view.getDesktopPane();
			if (desktopPane != null) {
				// Tis displaying a dialog box - get it to update its content.
				JInternalFrame[] dialogBoxes = desktopPane.getAllFrames();
				if (dialogBoxes != null) {
					for (int i = 0; i < dialogBoxes.length; i++) {
						if (dialogBoxes[i] instanceof EndTurnButtonListener) {
							((EndTurnButtonListener)dialogBoxes[i]).notifyEndTurnButtonPressed();
						}
					}
				}
			}
			AlarmSystem.getInstance().notifyEndTurnButtonPressed();
	    	view.getMapPanel().rebuildContent();
			view.getRadarPanel().repaint();
			GalaxyWindowContextPanel contextPanel = view.getContextPanel();
			if (contextPanel != null) {
				contextPanel.updateSelectionState();
			}
		}
		GalaxyWindowListener.validateGalaxyCraftList();
		DeligateCacheManager.notifyEndTurn();
		if (TutorialSystem.isActive()) {			
			TutorialSystem.notifyEndTurn();
		}
	}

}
