/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.event.processors;

import mot.client.event.MotEventConsumer;
import mot.client.proxy.ProxyStore;
import mot.client.swing.event.SwingEventHandler;
import mot.client.swing.window.galaxy.GalaxyWindowView;
import mot.client.swing.window.main.MainWindow;
import mot.client.swing.window.main.MainWindowMessageDiscoveredTech;
import mot.client.swing.window.main.MainWindowMessageList;
import mot.client.swing.window.tech.DiscoverTechWindow;
import mot.common.event.LinkedEventBase;
import mot.common.event.MotEvent;
import mot.common.event.TechnologyDiscoveredEvent;
import mot.common.lang.L;
import mot.common.technology.Technology;
import mot.common.util.ApplicationError;
import mot.common.util.Logger;
import mot.common.util.ValidationError;

public class TechnologyDiscoveredSwingEventProcessor implements SwingEventHandler {

	DiscoverTechWindow win = null;

	public void process(MotEvent e, MotEventConsumer processor, LinkedEventBase parent) throws ApplicationError, ValidationError {
        TechnologyDiscoveredEvent event = (TechnologyDiscoveredEvent)e;
        Technology tech = event.getTechnology();
        win = null;
        if (tech == null) {
            Logger.logWarning("LocalProxy.process() No tech!!!");
            return;
        }

    	if (event.isFromSalvage()) {
    		MainWindow.getInstance().showMessageGalaxy(L.DISCOVERED_FROM_SALVAGE+" "+" "+tech.getName(), false);
    	} else {
    		MainWindow.getInstance().showMessageGalaxy(L.DISCOVERED_+tech.getTechType()+" "+tech.getName(), false);
    	}

    	GalaxyWindowView view = MainWindow.getInstance().getGalaxyMapConfiguration().getGalaxyView();
    	view.getStatusPanel().updateStatus(MainWindow.getOwner());

        if (ProxyStore.getInstance().isResearchProjectAuto()) {
        	MainWindowMessageDiscoveredTech mwm = new MainWindowMessageDiscoveredTech(tech);
			MainWindowMessageList ml = view.getMessageList();
    		ml.addTemporaryMessage(mwm);
        }
//        if (win == null && event.isFromSalvage()) {
//        	win = new DiscoverTechWindow(null, MainWindow.getOwner(), tech, null, null, null, event.isFromSalvage());
//            win.showAndWait();
//        }
	}

}
