/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.event.processors;

import mot.client.deligates.UserPlayerDelegate;
import mot.client.event.MotEventConsumer;
import mot.client.swing.event.SwingEventHandler;
import mot.client.swing.window.main.MainWindow;
import mot.client.swing.window.tech.StealTechnologyWindow;
import mot.common.event.LinkedEventBase;
import mot.common.event.MotEvent;
import mot.common.event.TechnologyStolenEvent;
import mot.common.lang.L;
import mot.common.technology.Technology;
import mot.common.util.ApplicationError;
import mot.common.util.Comp;
import mot.common.util.ValidationError;

public class TechnologyStolenSwingEventProcessor implements SwingEventHandler {


	public void process(MotEvent e, MotEventConsumer processor, LinkedEventBase parent) throws ApplicationError, ValidationError {
        TechnologyStolenEvent event = (TechnologyStolenEvent)e;
        Technology technology = event.getTechnology();
		MainWindow mainWindow = MainWindow.getInstance();
        UserPlayerDelegate owner = mainWindow.getWindowOwner();
		if (Comp.same(owner.getName(), event.getGiver())) {
			MainWindow.getInstance().showMessageGalaxy(L.PLAYER_+event.getReceiver()+L.HAS_STOLEN_TECHNOLOGY+technology.getFullName()+L.FROM_YOU, true);
        } else {
        	MainWindow.getInstance().showMessageGalaxy(L.YOU_HAVE_STOLEN_TECHNOLOGY+technology.getFullName()+L.FROM+event.getGiver(), true);
        	new StealTechnologyWindow(null, owner, event);
        }
	}


}
