/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.labels;

import mot.client.sounds.Sound;
import mot.client.sounds.Sounds;
import mot.client.swing.window.main.MainWindow;
import mot.common.technology.Technology;
import mot.common.util.ApplicationError;
import mot.common.util.Logger;
import mot.common.util.ValidationError;

public abstract class AbstractTechnologyLabelClickListener implements TechnologyLabelClickListener {

    public abstract void handleRightClick(Technology technology) throws ApplicationError, ValidationError;
    public abstract void handleLeftClick(Technology technology) throws ApplicationError, ValidationError;

    	/**
     * Called when a technology label is right clicked on.
     * @param technology The technology this label contained.
     */
    public void rightClick(Technology technology) {
    	try {
    		Sound sound = Sounds.getActionSound();
    		if (sound != null) {
    			sound.play();
    		}
    	} catch (Exception ex) {
    		Logger.logError("No Sound", ex);
    	}
        try {
        	handleRightClick(technology);
        } catch (ValidationError ex) {
        	MainWindow.getExestingInstance().reportValidationError(ex);
        } catch (ApplicationError ex) {
        	MainWindow.getExestingInstance().reportApplicationError(ex);
        }
    }

    /**
     * Called when a technology label is left clicked on.
     * @param technology The technology this label contained.
     */
    public void leftClick(Technology technology) {
    	try {
    		Sound sound = Sounds.getActionSound();
    		if (sound != null) {
    			sound.play();
    		}
    	} catch (Exception ex) {
    		Logger.logError("No Sound", ex);
    	}
        try {
        	handleLeftClick(technology);
        } catch (ValidationError ex) {
        	MainWindow.getExestingInstance().reportValidationError(ex);
        } catch (ApplicationError ex) {
        	MainWindow.getExestingInstance().reportApplicationError(ex);
        }
    }

}
