/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.labels;

import java.awt.Font;

import javax.swing.Icon;
import javax.swing.JLabel;

import mot.client.swing.window.common.MessagePanel;

public class HtmlLabel extends JLabel {

	
	
	public HtmlLabel() {
		super();
	}

	public HtmlLabel(int horizontalAlignment) {
		super((Icon)null, horizontalAlignment);
	}

	public HtmlLabel(int horizontalAlignment, int sizeDifference, boolean bold) {
		super((Icon)null, horizontalAlignment);
        if (sizeDifference != 0 || bold) {
            Font font = getFont();
            int style = font.getStyle();
            if (bold) {
                style = Font.BOLD;
            }
            setFont(new Font(font.getName(), style, font.getSize()+sizeDifference));
        }
	}

	public HtmlLabel(Icon image, int horizontalAlignment) {
		super(image, horizontalAlignment);
	}

	public HtmlLabel(String text, int horizontalAlignment) {
		super(text, horizontalAlignment);
	}

	public HtmlLabel(String text) {
		super(text);
	}

	public void setText(String txt) {
		if (txt != null) {
			super.setText("<HTML>"+txt+"</HTML>");
		} else {
			super.setText("");
		}
	}
	
	public void setTextCentered(String txt) {
		if (txt != null) {
			super.setText("<HTML><center>"+txt+"</center></HTML>");
		} else {
			super.setText("");
		}
	}
	
	public void setTextCentered(String txt, int maxCharsPerLine) {
		if (txt != null) {
			super.setText(MessagePanel.toHtml(txt, maxCharsPerLine, true));
		} else {
			super.setText("");
		}
	}
}
