/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.labels;

import java.awt.Color;
import java.awt.event.MouseEvent;
import java.awt.event.MouseMotionListener;

import javax.swing.JLabel;

import mot.common.util.ApplicationError;
import mot.common.util.Logger;
import mot.common.util.PropertyManager;

public class RolloverLabel extends JLabel implements MouseMotionListener {

	private Color background;
	private Color rolloverBackground;
    private Color oldBackground;
	private boolean rollover;

	public RolloverLabel(String text) {
        super(text);
		try {
			this.background = PropertyManager.getMandatoryAsColor("button_label.background.color");
			this.rolloverBackground = PropertyManager.getMandatoryAsColor("button_label.rollover_background.color");
		} catch (ApplicationError e) {
			Logger.logError("Unable to get colours", e);
		}
		setOpaque(true);
		setBackground(background);
		addMouseMotionListener(this);
	}

	public void mouseEntered(MouseEvent e) {
		if (rolloverBackground != null) {
			oldBackground = getBackground();
			setBackground(rolloverBackground);
			//repaint();
		}
	}

	public void mouseExited(MouseEvent e) {
		if (oldBackground != null) {
			setBackground(oldBackground);
			//repaint();
		}
	}

	public boolean containsMouse() {
		return rollover;
	}

	public void mouseDragged(MouseEvent e) {
	}

	public void mouseMoved(MouseEvent e) {
	}

	
}
