/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.lists;

import java.awt.Color;

import javax.swing.JLabel;

import mot.client.deligates.MoveableOwnedObjectDelegate;
import mot.client.swing.buttons.MotActionClickListener;
import mot.client.swing.common.ComponentTable;
import mot.client.swing.common.PadPanel;
import mot.client.swing.common.PanelUtils;
import mot.client.swing.panels.MooImagePanel;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class FakeMooListMooPanel extends PadPanel {
	
	public static final Color backgroundColor = Color.BLACK;
	public static final Color selectedBackgroundColor = new Color(29,34,52);
	
	private MoveableOwnedObjectDelegate moo;
	private MooListOwner owner;

    public FakeMooListMooPanel(MoveableOwnedObjectDelegate moo, MooListOwner owner) throws ApplicationError {
        this(moo, owner, true);
    }
    
    public FakeMooListMooPanel(MoveableOwnedObjectDelegate pMoo, MooListOwner pOwner, boolean withRemove) throws ApplicationError {
    	super(0, 0);
    	
        this.moo = pMoo;
        this.owner = pOwner;
        
        //setBorder(BorderFactory.createEtchedBorder(EtchedBorder.RAISED));
        
        MotActionClickListener mal = new MotActionClickListener() {
			protected void _doAction() throws ApplicationError, ValidationError {
				if (clickCount > 1) {
					owner.executeMoo(moo);
				} else {
					owner.selectMoo(moo);
				}
			}
        };
        addMouseListener(mal);

        MooImagePanel craftLabel = new MooImagePanel(moo, true, null);

    	ComponentTable content = new ComponentTable("-", 2, 1, 0, 0, 0);
        content.add(craftLabel,"HV");
        content.add(PanelUtils.createLabel(moo.getName(), JLabel.CENTER), "HVT");
        content.setOpaque(false);
        
        add(content);

        setOpaque(true);
    }
    
    public void setSelected(boolean v) {
    	if (v) {
    		setBackground(selectedBackgroundColor);
    	} else {
    		setBackground(backgroundColor);
    	}
    }

}
