/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.lists;

import mot.client.swing.renderers.CellRendererTechnologyLabel;
import mot.common.command_results.TechnologyListCR;
import mot.common.technology.Technology;
import mot.common.technology.TechnologyBundle;
import mot.common.technology.TechnologyList;
import mot.common.util.ApplicationError;

public class FakeTechnologyLabelList extends FakeList {
	
    public FakeTechnologyLabelList() {
    }
    
    public FakeTechnologyLabelList(CellRendererTechnologyLabel renderer) {
    	super(renderer);
    }
    
    public FakeTechnologyLabelList(TechnologyList techs, Technology selection, CellRendererTechnologyLabel renderer) {
    	super(techs == null ? null : techs.getAllAsArray(), selection, renderer);
    }

    public FakeTechnologyLabelList(Technology []  techs, Technology selection, CellRendererTechnologyLabel renderer) {
    	super(techs, selection, renderer);
    }
    
    public FakeTechnologyLabelList(TechnologyBundle []  techs, Technology selection, CellRendererTechnologyLabel renderer) {
    	super(techs, selection, renderer);
    }
    
    public void setContent(TechnologyList tl, Technology selection) {
    	if (tl == null || tl.getQuantity() == 0) {
    		super.setContent(null, null);
    	} else {
    		super.setContent(tl.getDistinct(), selection);
    	}
    }

    public void setContent(TechnologyListCR tl) throws ApplicationError {
    	if (tl == null) {
    		setContent((Technology[])null, null);
    	} else {
    		TechnologyList t = tl.getResultAsList();
    		if (t== null || t.getQuantity() == 0) {
        		setContent((Technology[])null, null);
    		} else {
    			Technology[] ta = t.getAllAsArray();
    			setContent(ta, null);
    		}
    	}
    }
    
    public Technology [] getContent() {
    	return (Technology[]) super.getContent();
    }
    
}