/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.lists;

import mot.client.actions.TechnologyAction;
import mot.client.swing.renderers.CellRendererTechnologyImage;
import mot.common.bean.Size;
import mot.common.technology.Technology;
import mot.common.technology.TechnologyList;
import mot.common.util.ApplicationError;

public class FakeTechnologyList extends FakeList {

    public FakeTechnologyList(Size size, boolean displayName, boolean displayDiscription, boolean discriptionAsToolTip, TechnologyAction action) throws ApplicationError {
        super(new CellRendererTechnologyImage(size, displayName, displayDiscription, discriptionAsToolTip, action));
    }
    
    public void setContent(TechnologyList techList) throws ApplicationError {
    	if (techList == null) {
        	setContent(null, null);
    		return;
    	}
    	
    	Technology[] techs = techList.getAllAsArray();
        
        if (techs != null) {
        	setContent(techs, null);
        } else {
        	setContent(null, null);
        }

		revalidate();
	}
    
}

