/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.lists;

import java.awt.Component;

import javax.swing.BoxLayout;
import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JList;
import javax.swing.ListCellRenderer;

import mot.client.deligates.PlanetDelegate;
import mot.client.swing.window.common.MotInternalWindow;
import mot.client.swing.window.solarsystem.PlanetAnimationPanelWithDescription;
import mot.common.util.ApplicationError;
import mot.common.util.Logger;

public class PlanetListCellRenderer extends JButton implements ListCellRenderer {


	private static final int PADDING = 2;

    private MotInternalWindow owner;

    public PlanetListCellRenderer(MotInternalWindow owner) {
        this.owner = owner;
    }
     
    public Component getListCellRendererComponent(JList list,
                                                   Object value,            // value to display
                                                   int index,               // cell index
                                                   boolean isSelected,      // is the cell selected
                                                   boolean cellHasFocus		// the list and the cell have the focus
                                                  )    
    {
        removeAll();

        PlanetDelegate planet = (PlanetDelegate)value;
        
        setLayout(new BoxLayout(this, BoxLayout.Y_AXIS));
        
        try {
			add(new PlanetAnimationPanelWithDescription(owner, planet));
		} catch (ApplicationError e) {
			Logger.logError("", e);
			add(new JLabel("Error"));
		}

        if (isSelected) {
            setBackground(list.getSelectionBackground());
            setForeground(list.getSelectionForeground());
        } else {
            setBackground(list.getBackground());
            setForeground(list.getForeground());
        }
        
        setEnabled(list.isEnabled());
        setOpaque(true);
        setBorder(null);
        return this;
    }
 }

