/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.lists;

import java.awt.Dimension;
import java.util.ArrayList;
import java.util.Iterator;

import javax.swing.BorderFactory;
import javax.swing.BoxLayout;
import javax.swing.ButtonGroup;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.border.EtchedBorder;
import javax.swing.event.ChangeListener;

import mot.client.swing.buttons.OptionCheckBox;
import mot.client.swing.common.MotLabel;
import mot.client.swing.window.common.MessagePanel;
import mot.common.bean.Settings;
import mot.common.setup.OptionsFactory;
import mot.common.setup.SetupOption;
import mot.common.setup.SetupOptions;
import mot.common.util.ApplicationError;
import mot.common.util.Comp;

public class SetupOptionsList extends JScrollPane {

    private JPanel optionsPanel = new JPanel();
    private ArrayList optionBoxList;
    private Settings settings;
    
    public SetupOptionsList() throws ApplicationError {
        setBorder(BorderFactory.createEtchedBorder(EtchedBorder.LOWERED));
        setVerticalScrollBarPolicy(JScrollPane.VERTICAL_SCROLLBAR_ALWAYS);
        optionsPanel.setBorder(BorderFactory.createEtchedBorder(EtchedBorder.LOWERED));
        optionsPanel.setLayout(new BoxLayout(optionsPanel, BoxLayout.Y_AXIS));
        getViewport().add(optionsPanel, null);
        setPreferredSize(new Dimension(200,300));
        setMinimumSize(new Dimension(150,200));
        
        settings = Settings.getInstance();
    }

    public void createOptions(ChangeListener listener) throws ApplicationError {
		SetupOptions raceOptions = mot.common.setup.OptionsFactory.getGeneralOptions();
        SetupOption[] options = raceOptions.getOptionsAsArray();
        if (options == null) {
            return;
        }
        ArrayList names = new ArrayList();
        for (int i=0; i<options.length; i++) {
            String name = options[i].getName();
            if (!names.contains(name)) {
                names.add(name);
            }
        }

        optionBoxList = new ArrayList();
        Iterator i = names.iterator(); 
        while (i.hasNext()) {
            String name = (String) i.next();
            SetupOption[] o = raceOptions.getAllForName(name);
            if (o != null && o.length > 1) {
                String description = raceOptions.getDescriptionForName(name);
        		String html = MessagePanel.toHtml(description, 25, false);
        		MotLabel label = new MotLabel(html, 2, JLabel.LEFT, true);
                ButtonGroup bg = new ButtonGroup();
                optionsPanel.add(label);
                String explanation = raceOptions.getExplanationForName(name);
                if (explanation != null) {
                	label.setToolTipText(explanation);
                }
                for (int j=0; j<o.length; j++) {
                    OptionCheckBox box = new OptionCheckBox(o[j]);
                    bg.add(box);
                    optionsPanel.add(box);
                    optionBoxList.add(box);
                    box.addChangeListener(listener);
                }
            }
        }
    }

    public void setOptionsFromLast() throws ApplicationError {
        if (optionBoxList != null) {
            Iterator i = optionBoxList.iterator();
            while (i.hasNext()) {
                OptionCheckBox box = (OptionCheckBox)i.next();
                SetupOption option = box.getOption();
                String gs = settings.getGenericSetting(option.getName());
				if (Comp.same(gs, option.getValue())) {
                	box.setSelected(true);
                }
            }
        }
    }

    public void changeRace(String race) throws ApplicationError {
    	if (race != null) {    		
    		SetupOptions options = OptionsFactory.getSetupOptions(race);
    		if (optionBoxList != null) {
    			Iterator i = optionBoxList.iterator();
    			while (i.hasNext()) {
    				OptionCheckBox box = (OptionCheckBox)i.next();
    				box.set(options);
    			}
    		}
    	}
    }

    public SetupOptions getOptions() throws ApplicationError {
        SetupOptions raceOptions = new SetupOptions();
        if (optionBoxList != null) {
            Iterator i = optionBoxList.iterator();
            while (i.hasNext()) {
                OptionCheckBox box = (OptionCheckBox)i.next();
                if (box.isSelected()) {
                    raceOptions.setOption(box.getOption());
                }
            }
        }
        return raceOptions;
    }

	public void saveSelection() throws ApplicationError {
        Settings settings = Settings.getInstance();

        if (optionBoxList != null) {
            Iterator i = optionBoxList.iterator();
            while (i.hasNext()) {
                OptionCheckBox box = (OptionCheckBox)i.next();
                if (box.isSelected()) {
                	SetupOption option = box.getOption();
                	if (option != null) {                		
                		settings.addGenericSetting(option.getName(), option.getValue());
                	}
                }
            }
        }
		
	}
    
}