/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.lists;

import java.awt.Dimension;
import java.util.Vector;

import javax.swing.JList;
import javax.swing.JScrollPane;
import javax.swing.event.ListSelectionListener;

import mot.common.technology.Technology;
import mot.common.technology.TechnologyList;

public class TechList extends JList {

    private boolean useFullName;
    private Technology [] content;

    public TechList(TechnologyList p, Dimension size, ListSelectionListener listener, boolean useFullName) {
        this.useFullName = useFullName;
        update(p);
        if (size != null) {
            setPreferredSize(size);
        }
        if (listener != null) {
            addListSelectionListener(listener);
        }
    }

    public void update(TechnologyList p) {
        if ( p != null ) {
            update(p.getAllAsArray(true));
        }
    }

    public void update(Technology [] p) {
    	content = p;
        Vector model = new Vector();
        if ( p != null ) {
            for (int i=0; i<p.length; i++) {
                if (useFullName) {
                    model.add(p[i].getFullName());
                } else {
                    model.add(p[i].getName());
                }
            }
        }
        setListData(model);
        repaint();
    }

    public Technology getSelectedTech() {
    	int index = getSelectedIndex();
    	if (content != null && index >= 0 && index < content.length) {
    		return content[index];
    	} else {
    		return null;
    	}
    }
    
    public JScrollPane getScrollPane() {
        return getScrollPane(null, false, false);
    }
    
    public JScrollPane getScrollPane(Dimension size, boolean withVScrolls, boolean withHScrolls) {
        JScrollPane panel =  new JScrollPane(this,
                                             withVScrolls ? JScrollPane.VERTICAL_SCROLLBAR_ALWAYS : JScrollPane.VERTICAL_SCROLLBAR_AS_NEEDED,
                                             withHScrolls ? JScrollPane.HORIZONTAL_SCROLLBAR_ALWAYS : JScrollPane.HORIZONTAL_SCROLLBAR_AS_NEEDED );
        if (size != null) {
            panel.setPreferredSize(size);
            panel.setMinimumSize(new Dimension(75, 100));
            //panel.setMaximumSize(size);
        }
        return panel;
    }

}