/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.lists;

import javax.swing.JLabel;
import javax.swing.JPanel;

import mot.client.deligates.TransportDelegate;
import mot.client.swing.common.ComponentTable;
import mot.client.swing.common.MotLabel;
import mot.client.swing.panels.ImagePanel;
import mot.common.bean.Size;
import mot.common.util.ApplicationError;

public class TransportList extends ComponentTable {

	private TransportDelegate[] transports;

	public TransportList() {
		super("HV,HVSP", 1, 2, 2, 10, 0);
	}

	public void setContent(TransportDelegate [] transports) throws ApplicationError {
		this.transports = transports;
		removeAll();
		if (transports != null) {
			setQtyRows(transports.length+1);
			for (int i=0; i < transports.length; i++ ) {
				if (transports[i].containsColonists()) {
					int qty = transports[i].getQty();
					add(new ImagePanel(transports[i].getImage(), new Size(30,30)));
					add(new MotLabel("Colonists "+qty, 0, JLabel.LEFT, true));
				}
			}
			for (int i=0; i < transports.length; i++ ) {
				if (transports[i].containsTroops()) {
					int qty = transports[i].getQty();
					add(new ImagePanel(transports[i].getImage(), new Size(30,30)));
					add(new MotLabel("Troops "+qty, 0, JLabel.LEFT, true));
				}
			}
			add(new JPanel(), "HVS");
			revalidate();
		}
	}

}
