/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.models;
import javax.swing.DefaultListModel;

import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.Comp;

public class TreatyListModel extends DefaultListModel {
	private boolean verbose;

    public TreatyListModel(boolean verbose) {
        this.verbose=verbose;
    }

    public TreatyListModel(boolean verbose, String [] treaties) throws ApplicationError {
        this.verbose=verbose;
        update(treaties);
    }

    public void update(String [] treaties) throws ApplicationError {
        removeAllElements();
        if (treaties != null) {
            for (int i=0; i<treaties.length; i++) {
                if (verbose) {
                    addTreaty(treaties[i]);
                } else {
                    addElement(treaties[i]);
                }
            }
        }
    }

    public void addTreaty(String treaty) {
        if (Comp.same(L.TREATY_WAR, treaty)) {
            addElement(L.YOU_ARE_AT_WAR);
        } else if (Comp.same(L.TREATY_ALLIANCE, treaty)) {
            addElement(L.YOU_HAVE_AN_ALLIANCE);
        } else if (Comp.same(L.TREATY_NON_AGRESSION, treaty)) {
            addElement(L.YOU_HAVE_AN_NON_AGRESSION_TREATY);
        } else if (Comp.same(L.TREATY_PEACE, treaty)) {
            addElement(L.YOU_HAVE_AN_PEACE_TREATY);
        }

        if (Comp.same(L.TREATY_TRADE, treaty)) {
            addElement(L.YOU_HAVE_A_TRADE_TREATY);
        } else if (Comp.same(L.TREATY_RESEARCH, treaty)) {
            addElement(L.YOU_HAVE_A_RESEARCH_TREATY);
        }
    }
}