/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.panels;

import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.Graphics2D;

import mot.client.swing.common.ComponentTable;
import mot.client.swing.common.ImageUtils;
import mot.client.swing.common.PanelUtils;
import mot.client.swing.config.ImageConfig;

public class ComponentTableWithBackground extends ComponentTable {

	private String image;

	public ComponentTableWithBackground(String colConstraints, int qtyRows, int qtyCols, int margin, int cellHGap, int cellVGap, ImageConfig image) {
		this(colConstraints, qtyRows, qtyCols, margin, cellHGap, cellVGap, image == null ? null : image.getImage());
		if (image != null) {
			PanelUtils.setTheBloodySize(this, image.getImageSize());
		}
	}
	
	public ComponentTableWithBackground(String colConstraints, int qtyRows, int qtyCols, int margin, int cellHGap, int cellVGap, String image) {
		super(colConstraints, qtyRows, qtyCols, margin, cellHGap, cellVGap);
		this.image = image;
		
		setOpaque(false);
	}


    public void paint(Graphics graphics) {
        Graphics2D g = (Graphics2D) graphics;
        if (image != null) {
            Dimension winSize = getSize();
            int width = (int)winSize.getWidth();
            int height = (int)winSize.getHeight();
            ImageUtils.drawImage(this, g, image, 0, 0, width, height);
        }
        super.paint(graphics);
    }

}
