/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.panels;

import java.awt.Color;
import java.awt.Dimension;
import java.awt.Graphics2D;

import mot.client.swing.common.PaintedPanel;
import mot.common.util.ApplicationError;
import mot.common.util.PropertyManager;

public class DamageBarPanel extends PaintedPanel {

	private double damagePercent;
	private Color borderColor;
	private Color barColor;

	public DamageBarPanel(double damagePercent, int healthBarHeight) throws ApplicationError {
		this(damagePercent, healthBarHeight, PropertyManager.getMandatoryAsColor("damagebar.color"), PropertyManager.getMandatoryAsColor("outline.color"));
	}
	
	public DamageBarPanel(double damagePercent, int healthBarHeight, Color barColor, Color borderColor) throws ApplicationError {
		this.damagePercent = damagePercent;
		this.barColor = barColor;
		this.borderColor = borderColor;
		
		setPreferredSize(new Dimension(50, healthBarHeight));
		setMinimumSize(new Dimension(25, healthBarHeight));
	}
	
	protected void drawContent(Graphics2D g) {
		Dimension size = getSize();
		int height = (int) size.getHeight();
		int width = (int) size.getWidth();
        g.setColor(borderColor);
		g.drawRect(0, 0, width, height);
        g.setColor(barColor);
        int border = (int)((width-1) * (1.0-damagePercent));
		g.fillRect(1, 1, border, height-1);
        g.setColor(getBackground());
		g.fillRect(border, 1, width-1, height-1);
	}

	public double getDamagePercent() {
		return damagePercent;
	}

	public void setDamagePercent(double damagePercent) {
		this.damagePercent = damagePercent;
	}

}
