/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.panels;

import java.awt.Color;
import java.awt.Dimension;
import java.awt.Graphics2D;
import java.awt.Image;

import mot.client.bean.CraftGraphicsWrapper;
import mot.client.swing.common.ImageCache;
import mot.client.swing.common.PaintedPanel;
import mot.client.swing.common.PanelUtils;
import mot.common.bean.CraftGraphics;
import mot.common.bean.Rectangle;
import mot.common.bean.Size;
import mot.common.factory.GraphicsFactory;
import mot.common.technology.Hull;
import mot.common.util.ApplicationError;

public class HullImagePanel extends PaintedPanel {
	
	private Hull hull;
	private double scale;
	private CraftGraphics craftGraphics;

	public HullImagePanel(Hull hull, double scale, Color background) throws ApplicationError {
        this.hull = hull;
		this.scale = scale;
    	this.craftGraphics = GraphicsFactory.getRaceGraphicsList().getHullGraphics(null, hull.getName());
    	
		if (background != null) {
            setBackground(background);
            setOpaque(true);
        } else {
            setOpaque(false);
        }
        
		PanelUtils.setTheBloodySize(this, new Size(20, 20));
	}
	
	protected Rectangle getMooImageRect() throws ApplicationError {
		Dimension size = getSize();
		int panelHeight = (int) size.getHeight();
		int panelWidth = (int) size.getWidth();
		
        Size imageSize = craftGraphics.getSize();
        int imageWidth = (int) (imageSize.getX()*scale);
        int imageHeight = (int) (imageSize.getY()*scale);
        
		int spareWidth = panelWidth - imageWidth;
		int spareHeight = panelHeight - imageHeight;
        int xd = (spareWidth == 0) ? 0 : spareWidth/2;
        int yd = (spareHeight == 0) ? 0 : spareHeight/2;
        
		return new Rectangle(xd, yd, imageWidth, imageHeight);
	}
	
	protected void drawContent(Graphics2D g) throws ApplicationError {
		if (isOpaque()) {
	        Color background = getBackground();
			Dimension size = getSize();
			int panelHeight = (int) size.getHeight();
			int panelWidth = (int) size.getWidth();
			g.setColor(background);
			g.fillRect(0, 0, panelWidth, panelHeight);
		}
		
		String imageName = CraftGraphicsWrapper.getImage(craftGraphics, null);
        Image image = ImageCache.getImage(getToolkit(), imageName);
        
        Rectangle mr = getMooImageRect();        
        
        g.drawImage(image, mr.getLeft(), mr.getTop(), mr.getWidth(), mr.getHeight(), this);
        
	}


}
