/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.panels;

import java.awt.Color;

import javax.swing.SwingConstants;

import mot.client.swing.common.IconSequence;
import mot.common.util.ApplicationError;
import mot.common.util.PropertyManager;

public class IconPanelMoney extends IconPanel {

    private static final String IMAGE_NAME_GOLD = "images/icons/gold.png";
    private static final String IMAGE_NAME_SILVER = "images/icons/silver.png";

    private static final String LOSS_IMAGE_NAME_GOLD = "images/icons/lost_gold.png";
    private static final String LOSS_IMAGE_NAME_SILVER = "images/icons/lost_silver.png";

    private static final int QTY_PER_ICON1 = 100;
    private static final int QTY_PER_ICON2 = 10;
    private static final int QTY_PER_ICON3 = 1;

    public IconPanelMoney(int value, Color background) throws ApplicationError {
        super(  new IconSequence(IMAGE_NAME_GOLD, value/QTY_PER_ICON1, 12, 15),
                new IconSequence(IMAGE_NAME_GOLD, (value%QTY_PER_ICON1)/QTY_PER_ICON2, 9, 12),
                new IconSequence(IMAGE_NAME_SILVER, (value%QTY_PER_ICON2)/QTY_PER_ICON3, 8, 10) );
        if (value < 0) {
        	value = -value;
        	getIcon1().setQty(value/QTY_PER_ICON1);
        	getIcon2().setQty((value%QTY_PER_ICON1)/QTY_PER_ICON2);
        	getIcon3().setQty((value%QTY_PER_ICON2)/QTY_PER_ICON3);
        }
    	setBackground(background);
    }

    
    public IconPanelMoney(int value, int lossValue) {
        super(  new IconSequence(IMAGE_NAME_GOLD, value/QTY_PER_ICON1, 14, 20),
                new IconSequence(IMAGE_NAME_GOLD, (value%QTY_PER_ICON1)/QTY_PER_ICON2, 9, 12),
                new IconSequence(IMAGE_NAME_SILVER, (value%QTY_PER_ICON2)/QTY_PER_ICON3, 8, 10) );
        setAlignmentY(SwingConstants.BOTTOM);

        setLossIcons(new IconSequence(LOSS_IMAGE_NAME_GOLD, lossValue/QTY_PER_ICON1, 14, 20),
                	 new IconSequence(LOSS_IMAGE_NAME_GOLD, (lossValue%QTY_PER_ICON1)/QTY_PER_ICON2, 9, 12),
                	 new IconSequence(LOSS_IMAGE_NAME_SILVER, (lossValue%QTY_PER_ICON2)/QTY_PER_ICON3, 8, 10));
    }

    public void update(int value, int lossValue) throws ApplicationError {
        if (value < 0) {
        	value = -value;
            Color negativeBackground = PropertyManager.getMandatoryAsColor("negative_icon_panal.color");
        	setBackground(negativeBackground);
        } else {
        	setBackground(Color.BLACK);
        }
        getIcon1().setQty(value/QTY_PER_ICON1);
        getIcon2().setQty((value%QTY_PER_ICON1)/QTY_PER_ICON2);
        getIcon3().setQty((value%QTY_PER_ICON2)/QTY_PER_ICON3);
        getLossIcon1().setQty(lossValue/QTY_PER_ICON1);
        getLossIcon2().setQty((lossValue%QTY_PER_ICON1)/QTY_PER_ICON2);
        getLossIcon3().setQty((lossValue%QTY_PER_ICON2)/QTY_PER_ICON3);
        repaint();
    }

}