/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.panels;

import javax.swing.SwingConstants;

import mot.client.swing.common.IconSequence;

public class IconPanelProduction extends IconPanel {

    private static final String IMAGE_NAME = "images/icons/hammer.png";
    
    private static final String LOSS_IMAGE_LARGE_NAME = "images/icons/lost_production_large.png";
    private static final String LOSS_IMAGE_NAME = "images/icons/lost_production.png";

    private static final int QTY_PER_ICON1 = 10;
    private static final int QTY_PER_ICON2 = 1;

    public IconPanelProduction(int value) {
        super(  new IconSequence(IMAGE_NAME, value/QTY_PER_ICON1, 10, 28),
                new IconSequence(IMAGE_NAME, (value%QTY_PER_ICON1)/QTY_PER_ICON2, 7, 12),
                null );
        
        setLossIcons(new IconSequence(LOSS_IMAGE_NAME, value/QTY_PER_ICON1, 10, 28),
           	 		 new IconSequence(LOSS_IMAGE_LARGE_NAME, (value%QTY_PER_ICON1)/QTY_PER_ICON2, 7, 12),
           	 		 null);
   
        setAlignmentY(SwingConstants.BOTTOM);        
    }

    public void update(int value, int lossValue) {
        getIcon1().setQty(value/QTY_PER_ICON1);
        getIcon2().setQty((value%QTY_PER_ICON1)/QTY_PER_ICON2);
        getLossIcon1().setQty(lossValue/QTY_PER_ICON1);
        getLossIcon2().setQty((lossValue%QTY_PER_ICON1)/QTY_PER_ICON2);
        repaint();
    }

}