/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.panels;

import java.awt.Color;
import java.awt.Dimension;
import java.awt.Graphics2D;
import java.awt.Image;

import mot.client.bean.CraftGraphicsWrapper;
import mot.client.deligates.CraftDelegate;
import mot.client.deligates.MoveableOwnedObjectDelegate;
import mot.client.swing.common.ImageCache;
import mot.client.swing.common.ImageUtils;
import mot.client.swing.common.PaintedPanel;
import mot.client.swing.config.ImageConfigFactory;
import mot.common.bean.Size;
import mot.common.util.ApplicationError;
import mot.common.util.PropertyManager;

public class Moo3dImagePanel extends PaintedPanel {
	
	private MoveableOwnedObjectDelegate moo;
	
	private String backgroundImage;
	private Color healthBarBorderColor;
	private Color healthBarColor;
	private int barHeight;

	public Moo3dImagePanel(MoveableOwnedObjectDelegate moo, boolean withHealthBar) throws ApplicationError {
        this.moo = moo;
        this.backgroundImage = ImageConfigFactory.getImageForConfig("3d_moo_background");
        
        if (withHealthBar) {
	        this.healthBarColor = PropertyManager.getMandatoryAsColor("damagebar.color");
	        this.healthBarBorderColor = PropertyManager.getMandatoryAsColor("outline.color");
	        this.barHeight = 2;
        }
	}
	
	public Moo3dImagePanel(boolean withHealthBar) throws ApplicationError {
        this.backgroundImage = ImageConfigFactory.getImageForConfig("3d_moo_background");
        
        if (withHealthBar) {
	        this.healthBarColor = PropertyManager.getMandatoryAsColor("damagebar.color");
	        this.healthBarBorderColor = PropertyManager.getMandatoryAsColor("outline.color");
	        this.barHeight = 2;
        }
	}
	
	public void setContent(MoveableOwnedObjectDelegate moo) {
		this.moo = moo;
	}
	
	private void drawHealthBar(Graphics2D g, CraftDelegate craft) throws ApplicationError {
		double damagePercent = craft.getDamageAsPercent();
		if (damagePercent > 0.0) {
			Dimension size = getSize();
			int panelHeight = (int) size.getHeight();
			int panelWidth = (int) size.getWidth();
	        int topBar = panelHeight-barHeight-1;
	        int barWidth = panelWidth-2;
	        
	        g.setColor(healthBarColor);
			g.fillRect(1, topBar, (int)(barWidth * damagePercent), barHeight);
		}
	}

	protected void drawContent(Graphics2D g) throws ApplicationError {
		Dimension size = getSize();
		int panelHeight = (int) size.getHeight();
		int panelWidth = (int) size.getWidth();
		ImageUtils.drawImage(this, g, backgroundImage, 0, 0, panelWidth, panelHeight);
		
		if (moo != null) {
			String imageName = moo.get3DImage();
	        Image image = ImageCache.getImage(getToolkit(), imageName);
	
	        Size imageSize = moo.getImageSize();
	        int imageWidth = imageSize.getX();
	        Size biggestImage = CraftGraphicsWrapper.getBiggestImage();
	        double percentSize = ((double)imageWidth) / ((double)biggestImage.getX());  
	
	        int actualX = (int) (panelWidth * percentSize); 
	        int actualY = (int) (panelHeight * percentSize); 
	        int remainingX = panelWidth - actualX; 
	        int remainingY = panelHeight - actualY; 
	        
	        g.drawImage(image, remainingX/2, remainingY/2, actualX, actualY, this);
	        
			if (moo instanceof CraftDelegate && healthBarColor != null) {
				drawHealthBar(g, (CraftDelegate) moo);
			}
		}
	}


}
