/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.panels;

import java.awt.Color;
import java.awt.Dimension;

import mot.client.swing.config.ImageConfig;
import mot.common.bean.Size;

public class PicturePanel extends PlainTextBackgroundImagePanel {

	private String image;
	
	public PicturePanel(String image, String text, double percentTop, double percentHeight, double percentIndent, double percentWidth) {
		super(text, percentTop, percentHeight, percentIndent, percentWidth);
		this.image = image;
	}

	public PicturePanel(String image, String text, Color textColor, int textSizeDiff, boolean textBold) {
		super(text, textColor, textSizeDiff, textBold);
		this.image = image;
	}

	public PicturePanel(ImageConfig image, String text) {
		super(text);
		if (image != null) {
			this.image = image.getImage();
			Size imageSize = image.getImageSize();
			setPreferredSize(new Dimension(imageSize.getX(), imageSize.getY()));
		}
	}

	public PicturePanel(ImageConfig image) {
		if (image != null) {
			this.image = image.getImage();
			Size imageSize = image.getImageSize();
			setPreferredSize(new Dimension(imageSize.getX(), imageSize.getY()));
		}
	}

	public PicturePanel() {
	}

	public PicturePanel(String image) {
		this.image = image;
	}

	protected String getImage() {
		return image;
	}

	public void setImage(String image) {
		this.image = image;
		validate();
	}

	public void setImageAndText(String image, String text) {
		this.image = image;
		setText(text);
		validate();
	}

}
