/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.panels;

import java.awt.Color;
import java.awt.Dimension;
import java.awt.Graphics2D;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;

import mot.client.actions.MotAction;
import mot.client.swing.common.PaintedPanel;
import mot.client.swing.window.main.MainWindow;
import mot.client.tutorials.TutorialSystem;
import mot.common.util.ApplicationError;
import mot.common.util.PropertyManager;
import mot.common.util.ValidationError;

public class ProgressBarPanel extends PaintedPanel implements MouseListener {

	private Color progressBarDoneColour;
	private Color progressBarRemainingColour;
	
	private int maxValue = 0;
	private int currentValue;

    public ProgressBarPanel(MotAction action) throws ApplicationError {
    	this();
    	clickAction = action;
	}

	public ProgressBarPanel() throws ApplicationError {
        this.progressBarDoneColour = PropertyManager.getMandatoryAsColor("progressbar.done.color");
        this.progressBarRemainingColour = PropertyManager.getMandatoryAsColor("progressbar.remaining.color");
		
        setOpaque(false);
        addMouseListener(this);
	}
	
	public void updateStatus(int maxValue, int currentValue) throws ApplicationError {
    	this.maxValue = maxValue;
    	this.currentValue = currentValue;
    	repaint();
    }
    
	protected void drawContent(Graphics2D g) throws ApplicationError {
		Dimension size = getSize();
		int panelHeight = (int) size.getHeight();
		int panelWidth = (int) size.getWidth();
		if (maxValue > 0.0) {
			int boundary = (int)(panelWidth * (double)currentValue / (double)maxValue);
	        g.setColor(progressBarDoneColour);
			g.fillRect(0, 0, boundary, panelHeight);
	        g.setColor(progressBarRemainingColour);
			g.fillRect(boundary, 0, panelWidth, panelHeight);
		} else {
	        g.setColor(progressBarRemainingColour);
			g.fillRect(0, 0, panelWidth, panelHeight);
		}
	}

    private MotAction clickAction;
	public void motMouseClicked(MouseEvent e) throws ApplicationError, ValidationError {
		if (clickAction != null) {
			clickAction.click();
		}
 	}

	public void mouseClicked(MouseEvent e) {
	}

	public void mousePressed(MouseEvent e) {
    	if (e.getClickCount() == 1) {
    		try {
    			if (TutorialSystem.isActive()) {
    				TutorialSystem.validateProgressBarClicked(this);
    			}
    			motMouseClicked(e);
    		} catch (ValidationError e1) {
    			MainWindow.getExestingInstance().reportValidationError(e1);
    		} catch (Exception e1) {
    			MainWindow.getExestingInstance().reportApplicationError(e1);
    		}
    	}
	}

	public void mouseReleased(MouseEvent e) {
	}

	public void mouseEntered(MouseEvent e) {
	}

	public void mouseExited(MouseEvent e) {
	}


}
