/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.panels;

import java.awt.Dimension;

import javax.swing.BoxLayout;

import mot.client.actions.MotAction;
import mot.client.deligates.PlanetDelegate;
import mot.client.swing.common.ComponentTable;
import mot.client.swing.common.MotLabel;
import mot.client.swing.common.PanelUtils;
import mot.client.swing.window.galaxy.GalaxyMapProject;
import mot.common.bean.Size;
import mot.common.designs.ProjectDesign;
import mot.common.lang.L;
import mot.common.util.ApplicationError;

public class ProjectProgressBar extends ProgressBarPanel {

	private static final String IMAGES_ICONS_HAMMER_PNG = "images/icons/hammer.png";
	
	private MotLabel projectNameLabel;
	private ImagePanel icon;

	public ProjectProgressBar(boolean withIcon, MotAction action) throws ApplicationError {
		super(action);
		
		projectNameLabel = new MotLabel();
		projectNameLabel.setOpaque(false);
		
        setLayout(new BoxLayout(this, BoxLayout.X_AXIS));
//        MotBorder border = new MotBorder(technologyNameLabel, null);
//        border.setOpaque(false);
        if (withIcon) {
        	ComponentTable content = new ComponentTable("C, HVSP", 1, 2, 0, 4, 0);
        	content.setOpaque(false);
        	icon = new ImagePanel(IMAGES_ICONS_HAMMER_PNG, new Size(10,15));
        	content.add(icon);
        	content.add(projectNameLabel);
        	add(content);
        	icon.addMouseListener(this);
        	projectNameLabel.addMouseListener(this);
        } else {        	
        	add(projectNameLabel);
        	projectNameLabel.addMouseListener(this);
        }
		
		setMinimumSize(new Dimension(50, 20));
		setPreferredSize(new Dimension(50, 20));
	}
	
    public void updateStatus(PlanetDelegate planet) throws ApplicationError {
    	ProjectDesign project = planet.getProjectDesign();
    	if (project != null) {
    		int maxValue = planet.getCostToBuild();
    		int currentValue = planet.getProduction();
    		updateStatus(maxValue, currentValue);
			int qtyTurns = planet.getTurnsToCompleteProject();
    		projectNameLabel.setText(project.getName()+" ("+qtyTurns+" turns)");
    		icon.setImage(GalaxyMapProject._getImage(project));
    		PanelUtils.setTheBloodySize(icon, new Size(15,15));
    	} else {
    		updateStatus(0, 0);
    		projectNameLabel.setText(L.NO_PROJECT);
    		icon.setImage(IMAGES_ICONS_HAMMER_PNG);
    		PanelUtils.setTheBloodySize(icon, new Size(10,15));
    	}
    }
    
    public void clear(String text) throws ApplicationError {
		updateStatus(0, 0);
		projectNameLabel.setText(text);
    }

}
