/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.panels;

import java.awt.Color;

import mot.client.deligates.PlayerDelegate;
import mot.client.swing.common.PanelUtils;
import mot.client.swing.config.ImageConfig;
import mot.client.swing.config.ImageConfigFactory;
import mot.common.bean.Size;
import mot.common.util.ApplicationError;
import mot.common.util.Logger;

/**
 * This is a picture panel that displays the image of an ancient race.
 * Note picture panel are fixed size panel - they do not resize with the container.
 */
public class RacePicturePanel extends PicturePanel {

    private String message;

	public RacePicturePanel() {
    }
    
    public RacePicturePanel(String imageName) {
        super(imageName);
    }

    public RacePicturePanel(PlayerDelegate player, boolean withName) throws ApplicationError {
        super(getImageForRace(player), withName ? player.getName() : null, null, 5, false);
    }
    
    public RacePicturePanel(String raceName, boolean withName) throws ApplicationError {
        super(getImageForRace(raceName), withName ? raceName : null, null, 5, false);
    }
    
    public RacePicturePanel(String raceName, String message, Color textColor, int textSizeDiff, boolean textBold) throws ApplicationError {
        super(getImageForRace(raceName), message, textColor, textSizeDiff, textBold);
		this.message = message;
    }
    
    public RacePicturePanel(String raceName, boolean withName, Size size) throws ApplicationError {
		this(raceName, withName);
		PanelUtils.setTheBloodySize(this, size);
	}

	public void setRace(String name, boolean withName) throws ApplicationError {
        setImage(getImageForRace(name));
        if (withName) setText(name);
    }


    public static String getImageForRace(PlayerDelegate race) throws ApplicationError {
        if (race == null) {
            return getImageForRace((String)null);
        } else {
        	if (race.isMonsterPlayer()) {
        		return ImageConfigFactory.getInstance().getRaceImageConfig("BlankPlayer").getImage();
        	} else {
        		return getImageForRace(race.getName());
        	}
        }
    }
    
    public static String getImageForRace(String raceName) throws ApplicationError { 
        if (raceName == null) {
        	return ImageConfigFactory.getInstance().getRaceImageConfig("None").getImage();
        } else {
        	ImageConfig raceIconConfig = ImageConfigFactory.getInstance().getRaceImageConfig(raceName);
        	if (raceIconConfig == null) {
        		Logger.logError("No Race Image for "+raceName, new ApplicationError());
    			return null;
        	} else {
    			return raceIconConfig.getImage();
        	}
        }
    }

}