/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.panels;

import java.awt.Graphics;
import java.awt.Image;

import mot.client.deligates.PlayerDelegate;
import mot.client.swing.common.ImageCache;
import mot.client.swing.config.ImageConfigFactory;
import mot.common.util.ApplicationError;

public class RacePicturePanelWithFlag extends RacePicturePanel {

    private static final int INDENT = 5;
    private static final int FLAG_WIDTH = 30;
    private static final int FLAG_HEIGHT = 30;

    private String flagImage;
    private String ancientImage;

    private int indent = 5;
    private int flagWidth = 30;
    private int flagHeight = 30;

    public RacePicturePanelWithFlag(PlayerDelegate player) throws ApplicationError {
    	this(player, INDENT, FLAG_WIDTH, FLAG_HEIGHT);
    }
    
    public RacePicturePanelWithFlag(PlayerDelegate player, int indent, int flagWidth, int flagHeight) throws ApplicationError {
        super(player, true);
        indent = INDENT;
        flagWidth = FLAG_WIDTH;
        flagHeight = FLAG_HEIGHT;
        
        if (!player.isMonsterPlayer()) {
	        flagImage = ImageConfigFactory.getInstance().getFlagConfig(player.getColorName()).getImage();
	        String alignment = player.getAlignment();
	        if (alignment != null) {        	
	        	ancientImage = ImageConfigFactory.getInstance().getImageConfig(alignment).getImage();
	        }
        }
    }
    
    public void paintComponent(Graphics g) {
        super.paintComponent(g);
        if (flagImage != null) {
	        Image image = ImageCache.getImage(getToolkit(), flagImage);
	        int width = getWidth();
	        int height = getHeight();
	        g.drawImage(image, width-flagWidth-indent, indent, flagWidth, flagHeight, this);
	
	        if (ancientImage != null) {        	
	        	image = ImageCache.getImage(getToolkit(), ancientImage);
	        	g.drawImage(image, width-flagWidth-indent, indent + flagHeight + indent, flagWidth, flagHeight, this);
	        }
        }
    }
}