/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.panels;

import java.awt.Dimension;

import javax.swing.BoxLayout;

import mot.client.actions.MotAction;
import mot.client.deligates.ResearchProjectDelegate;
import mot.client.deligates.UserPlayerDelegate;
import mot.client.swing.common.ComponentTable;
import mot.client.swing.common.MotLabel;
import mot.common.bean.Size;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class ResearchProgressBar extends ProgressBarPanel {

	private MotLabel technologyNameLabel;
	private ImagePanel tubeIcon;

	public ResearchProgressBar(boolean withIcon, MotAction action) throws ApplicationError {
		super(action);
		
		technologyNameLabel = new MotLabel();
		technologyNameLabel.setOpaque(false);
		
        setLayout(new BoxLayout(this, BoxLayout.X_AXIS));
//        MotBorder border = new MotBorder(technologyNameLabel, null);
//        border.setOpaque(false);
        
        if (withIcon) {
        	ComponentTable content = new ComponentTable("C, HVSP", 1, 2, 0, 4, 0);
        	content.setOpaque(false);
        	tubeIcon = new ImagePanel("images/icons/tube.png", new Size(10,15));
        	content.add(tubeIcon);
        	content.add(technologyNameLabel);
        	add(content);
        	tubeIcon.addMouseListener(this);
        	technologyNameLabel.addMouseListener(this);
        } else {        	
        	add(technologyNameLabel);
        	technologyNameLabel.addMouseListener(this);
        }
        
		
		setMinimumSize(new Dimension(50, 20));
		setPreferredSize(new Dimension(50, 20));
	}
	
    public void updateStatus(UserPlayerDelegate owner) throws ApplicationError, ValidationError {
    	ResearchProjectDelegate researchProject = owner.getResearchProject();
    	if (researchProject != null) {
    		int maxValue = researchProject.getCostToResearch();
    		int currentValue = researchProject.getWork();
    		updateStatus(maxValue, currentValue);
    		technologyNameLabel.setText(researchProject.getTechnology().getName());
    		technologyNameLabel.setToolTipText(researchProject.getTechnology().getDescription());
    		if (tubeIcon != null) tubeIcon.setToolTipText(researchProject.getTechnology().getDescription());
    		setToolTipText(researchProject.getTechnology().getDescription());
    	} else {
    		updateStatus(0, 0);
    		technologyNameLabel.setText(null);
    		technologyNameLabel.setToolTipText(null);
    		if (tubeIcon != null) tubeIcon.setToolTipText(null);
    		setToolTipText(null);
    	}
    }
    
}
