/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.panels;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.ButtonGroup;
import javax.swing.JRadioButton;

import mot.client.deligates.BattleObjectDelegate;
import mot.client.swing.combos.WeaponCombo;
import mot.client.swing.common.ComponentTable;
import mot.client.swing.common.MotButtonPanel;
import mot.client.swing.common.PadPanel;
import mot.client.swing.common.PanelUtils;
import mot.common.technology.Weapon;
import mot.common.util.ApplicationError;

public class SelectWeaponPanel extends ComponentTable {
    WeaponCombo weaponCombo;
    JRadioButton speedx1;
    JRadioButton speedx2;
    JRadioButton speedx4;
	private int speed = 1;
    
    public SelectWeaponPanel(BattleObjectDelegate bo) throws ApplicationError {
    	super("HV", 2,1, 0,0,0);
        init(bo);
    }
    
    private void init(BattleObjectDelegate bo) throws ApplicationError {
    	ButtonGroup bg = new ButtonGroup(); 
    	speedx1 = PanelUtils.createRadioButton("Normal", null, bg, true);
    	speedx2 = PanelUtils.createRadioButton("Fast", null, bg, true);
    	speedx4 = PanelUtils.createRadioButton("Turbo", null, bg, true);
    	MotButtonPanel speedPanel = new MotButtonPanel(speedx1, speedx2, speedx4);
    	
        add(weaponCombo = new WeaponCombo(bo));
        add(new PadPanel(speedPanel, 2));
        
        speedx1.setSelected(true);
        speedx1.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				speed = 1;
			}
		});
        speedx2.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				speed = 2;
			}
		});
        speedx4.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				speed = 4;
			}
		});
    }

    public void update(BattleObjectDelegate bo) throws ApplicationError {
        weaponCombo.update(bo);
    }

    public Weapon getWeapon() throws ApplicationError {
        return weaponCombo.getWeapon();
    }
    
    public int getQty() throws ApplicationError {
        return weaponCombo.getQty();
    }
    
    public int getSpeed() throws ApplicationError {
        return speed;
    }

}
