/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.panels;

import mot.client.deligates.PlanetDelegate;
import mot.client.deligates.PlayerDelegate;
import mot.client.swing.window.common.MotInternalWindow;
import mot.common.designs.Orbital;
import mot.common.util.ApplicationError;

public class StationAnimationPanel extends AnimationPanel {

	
    public StationAnimationPanel(MotInternalWindow container) throws ApplicationError {
        super(container, null, null, null);
    }

    public StationAnimationPanel(MotInternalWindow container, PlayerDelegate owner, Orbital orbital) throws ApplicationError {
        this(container, owner, orbital, false);
    }

    public StationAnimationPanel(MotInternalWindow container, PlayerDelegate owner, Orbital orbital, boolean withDescription) throws ApplicationError {
        super(container, null, orbital.getImage(owner.getName(), owner.getColor()), null );
        if (withDescription) {
        	setText(orbital.getHullTech().getDescription());
        }
    }
    
    public void setStation(PlayerDelegate owner, Orbital orbital) throws ApplicationError {
    	if (orbital == null) {
    		setName(null);
    	} else {
    		setName(orbital.getImage(owner.getName(), owner.getColor()));
    	}
    }

    public void setStation(PlanetDelegate planet) throws ApplicationError {
    	if (planet == null) {
			setName(null);
			setText((String)null);
			return;
    	}
    	Orbital orbital = planet.getOrbital();
		if (orbital != null) {
			PlayerDelegate owner = planet.getOwner();
	        setName(orbital.getImage(owner.getName(), owner.getColor()));
		} else {
			setName(null);
			setText((String)null);
		}
    }

    protected int getRotation() {
        return getStage();
    }

    protected boolean infinate() { return true; }
}