/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.panels;

import java.awt.Color;

import javax.swing.SwingConstants;

import mot.client.deligates.PlanetDelegate;
import mot.client.deligates.PlayerDelegate;
import mot.client.swing.common.ComponentTable;
import mot.client.swing.common.PanelUtils;
import mot.client.swing.labels.HtmlLabel;
import mot.client.swing.window.common.MotInternalWindow;
import mot.common.bean.Size;
import mot.common.designs.Orbital;
import mot.common.util.ApplicationError;

public class StationAnimationPanelWithDescription extends ComponentTable {

	private StationAnimationPanel battleStationPanel;
    private HtmlLabel battleStationLabel = new HtmlLabel("", SwingConstants.CENTER);
    
	private boolean showDescription;
	private boolean showName;
	private boolean showDescriptionInToolTip;
	
    public StationAnimationPanelWithDescription(MotInternalWindow parent, Size size, boolean showDescription, boolean showName, boolean showDescriptionInToolTip) throws ApplicationError {
        super("HVSP", 2, 1, 0, 0, 0);
		this.showDescription = showDescription;
		this.showName = showName;
		this.showDescriptionInToolTip = showDescriptionInToolTip;

        battleStationPanel = new StationAnimationPanel(parent);
        PanelUtils.setTheBloodySize(battleStationPanel, size);
        
        battleStationLabel.setBackground(Color.BLACK);
        battleStationLabel.setOpaque(true);
        
        add(PanelUtils.createFrame(battleStationPanel, Color.BLACK));
        add(battleStationLabel, "HV");
    }

    public void setStation(PlayerDelegate owner, Orbital orbital) throws ApplicationError {
    	if (orbital == null) {
        	battleStationPanel.setStation(owner, null);
   			battleStationLabel.setText(null);
   			battleStationPanel.setToolTipText(null);
    	} else {
        	battleStationPanel.setStation(owner, orbital);
    		if (showDescription) {
    			battleStationLabel.setTextCentered(orbital.getHullTech().getDescription());
    		} else if (showName) {
    			battleStationLabel.setTextCentered(orbital.getHullTech().getName());
    		} else {
    			battleStationLabel.setText(null);
    		}
    		if (showDescriptionInToolTip) {
    			battleStationLabel.setToolTipText(orbital.getHullTech().getDescription());
    			battleStationPanel.setToolTipText(orbital.getHullTech().getDescription());
    		} else {
    			battleStationLabel.setToolTipText(null);
    			battleStationPanel.setToolTipText(null);
    		}
    	}
    }

    public void setStation(PlanetDelegate planet) throws ApplicationError {
    	battleStationPanel.setStation(planet);
    	if (planet == null) {
			battleStationLabel.setText(null);
			return;
    	}
    	Orbital orbital = planet.getOrbital();
		if (orbital != null) {
			if (showDescription) {
				battleStationLabel.setTextCentered(orbital.getHullTech().getDescription());
			} else if (showName) {
				battleStationLabel.setTextCentered(orbital.getHullTech().getName());
			} else {
				battleStationLabel.setText(null);
			}
			if (showDescriptionInToolTip) {
				battleStationLabel.setToolTipText(orbital.getHullTech().getDescription());
			} else {
				battleStationLabel.setToolTipText(null);
			}
		} else {
			battleStationLabel.setText(null);
		}
    }

	public void handleTick() throws ApplicationError {
		if (battleStationPanel != null) {
			battleStationPanel.handleTick();
		}
	}

}