/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.panels;

import mot.client.deligates.TransportDelegate;
import mot.client.swing.common.ComponentTable;
import mot.client.swing.common.MotLabel;
import mot.client.swing.common.PanelUtils;
import mot.client.swing.config.ImageConfigFactory;
import mot.common.bean.Size;
import mot.common.lang.L;
import mot.common.technology.Hull;
import mot.common.util.ApplicationError;
import mot.common.util.Formatter;

public class TransportCargoPanel extends ComponentTable {
	
	public TransportCargoPanel() throws ApplicationError {
		super("HV", 1, 1, 0, 0, 0);
    }
    
    public void setSelection(TransportDelegate transport) throws ApplicationError {
    	if (transport == null) {
    		removeAll();
    	} else {
    		if (transport.containsColonists()) {
    			ComponentTable content = new ComponentTable("HV,HV", 2, 2, 1, 5, 0);
    			int qty = transport.getQty();
    			IconPanelPopulation iconPanel = new IconPanelPopulation(qty);
    			PanelUtils.setTheBloodySize(iconPanel,new Size(100, 25));
				content.add(iconPanel, "HV2F");
				content.add(new MotLabel(L.COLONISTS));
				content.add(new MotLabel(""+qty));
        		removeAll();
        		add(content);
    		} else if (transport.containsTroops()) {
    			ComponentTable content = new ComponentTable("HV,HV", 2, 2, 1, 5, 0);
    			int qty = transport.getQty();
    			IconPanelTroops iconPanel = new IconPanelTroops(qty);
    			PanelUtils.setTheBloodySize(iconPanel,new Size(100, 25));
				content.add(iconPanel, "HV2F");
				content.add(new MotLabel(L.TROOPS));
				content.add(new MotLabel(""+qty));
    			removeAll();
    			add(content);
    		} else if (transport.containsSpaceStation()) {
    			ComponentTable content = new ComponentTable("HV,HVP", 3, 2, 1, 5, 0);
    			Hull spaceStation = transport.getOrbitalHullTech();
    			String image = spaceStation.getImage();
    			ImagePanel imagePanel = new ImagePanel(image);
    			PanelUtils.setTheBloodySize(imagePanel, new Size(100, 100));
				content.add(imagePanel, "HV2F");
	   			content.add(new MotLabel(L.HULL));
	   			content.add(new MotLabel(spaceStation.getName()));
	   			content.add(new MotLabel(L.ORIGIN));
	   			content.add(new MotLabel(transport.getOrigin()));
        		removeAll();
        		add(content," HVSP");
    		} else if (transport.containsTradeRoute()) {
    			ComponentTable content = new ComponentTable("HV,HVP", 3, 2, 1, 5, 0);
    			String image = ImageConfigFactory.getInstance().getImageConfig("TradeRoute").getImage();
    			ImagePanel imagePanel = new ImagePanel(image);
    			PanelUtils.setTheBloodySize(imagePanel, new Size(100, 100));
				content.add(imagePanel, "HV2F");
				String bonus = Formatter.percentLabel(transport.getOwnerDelegate().getTradeRouteBonus());
	   			content.add(new MotLabel(L.TRADE_ROUTE));
	   			content.add(new MotLabel(bonus));
	   			content.add(new MotLabel(L.ORIGIN));
	   			content.add(new MotLabel(transport.getOrigin()));
        		removeAll();
        		add(content," HVSP");
    		} else {
        		removeAll();
    		}
    	}
    }

}