/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.renderers;

import java.awt.Color;
import java.awt.Component;

import javax.swing.JComponent;
import javax.swing.JLabel;
import javax.swing.JList;
import javax.swing.JPanel;
import javax.swing.ListCellRenderer;
import javax.swing.border.LineBorder;

import mot.client.actions.CraftAction;
import mot.client.bean.CraftDelegateBundle;
import mot.client.deligates.CraftDelegate;
import mot.client.swing.common.PadPanel;
import mot.client.swing.common.PanelUtils;
import mot.client.swing.panels.CraftPicturePanel;
import mot.client.swing.window.galaxy.actions.ActionButtonCraftLeaveFleet;
import mot.client.swing.window.main.MainWindow;
import mot.common.bean.Size;
import mot.common.technology.Hull;
import mot.common.util.Logger;
import mot.common.util.PropertyManager;

public class CellRendererCraft extends JPanel implements ListCellRenderer {

	private Size size;
	private boolean displayDesignName;
	private int textSizeDiff;
	private boolean textBold;
	private CraftAction action;
	
	private Color textColour;
	private Color backgroundColour;
	
	private boolean addLeaveFleetButton;
	
	
    public CellRendererCraft(Size size, boolean displayDesignName, int textSizeDiff, boolean textBold, Color textColour, CraftAction action, boolean addLeaveFleetButton) {
		this.size = size;
		this.displayDesignName = displayDesignName;
		this.textSizeDiff = textSizeDiff;
		this.textBold = textBold;
		this.textColour = textColour;
		this.action = action;
		this.addLeaveFleetButton = addLeaveFleetButton;
    }
    
     public Component getListCellRendererComponent(JList list,
                                                   Object value,            // value to display
                                                   int index,               // cell index
                                                   boolean isSelected,      // is the cell selected
                                                   boolean cellHasFocus)    // the list and the cell have the focus
     {
    	 try {
    		 int qty = 0;
        	 if (value instanceof CraftDelegateBundle) {
        		 qty = ((CraftDelegateBundle) value).getQuantity();
        		 value = ((CraftDelegateBundle) value).getCraft(0);
        	 } else if (!(value instanceof CraftDelegate)) {
        		 Logger.logError("Not a Craft : "+((value == null) ? "NULL" : value.getClass().getName()), new Exception());
        		 return new JLabel("ERROR");
        	 }
        	 
        	 CraftDelegate craft = (CraftDelegate) value;
        	 Hull hull = craft.getCraftDesign().getHullTech();

        	 String text = null;
             if (craft != null) {
            	 String name = displayDesignName ? craft.getCraftDesign().getName() : craft.getName();
         		if (qty <= 1) {
         			text = name;
         		} else{
         			text = name + " x " + qty;
         		}
             }
             

        	 CraftPicturePanel hullImagePanel = new CraftPicturePanel(2,true);
    		 PanelUtils.setTheBloodySize(hullImagePanel, size);
    		 hullImagePanel.update(craft, text, false);
    		 hullImagePanel.setCraftAction(action);
    		 
    		 if (addLeaveFleetButton && craft.isOwnedBy(MainWindow.getOwner())) {
    			 ActionButtonCraftLeaveFleet leaveButton = new ActionButtonCraftLeaveFleet(craft, MainWindow.getExestingInstance().getGalaxyMapListener());
    			 hullImagePanel.addLeaveFleetButton(leaveButton);
    		 }
    		 
    		 return new PadPanel(hullImagePanel, 2);
       	 } catch (Exception e) {
    		 Logger.logError("", e);
    		 return new JLabel("ERROR");
    	 }

     }

	private void setBackground(boolean isSelected, JComponent component) {
		Color selectedBackgroundColor = PropertyManager.getSelectedBackgroundColor();
		if (isSelected) {
			if (selectedBackgroundColor != null) {
				component.setOpaque(true);
				component.setBackground(selectedBackgroundColor);
				component.setBorder(new LineBorder(Color.WHITE));
			}
		} else {
			if (backgroundColour != null) {
				component.setOpaque(true);
				component.setBackground(backgroundColour);
			}
		}
	}
 }
