/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.renderers;

import java.awt.Component;
import java.net.URL;

import javax.swing.ImageIcon;
import javax.swing.JLabel;
import javax.swing.JList;
import javax.swing.ListCellRenderer;

import mot.client.deligates.NamedObjectDelegate;
import mot.client.deligates.PlanetDelegate;
import mot.client.deligates.StellarObjectDelegate;
import mot.client.swing.common.ComponentTable;
import mot.client.swing.common.MotBorder;
import mot.client.swing.common.MotLabel;
import mot.client.swing.common.PanelUtils;
import mot.client.swing.config.ImageConfigFactory;
import mot.client.swing.icons.ScaledImageIcon;
import mot.common.bean.Size;
import mot.common.lang.L;
import mot.common.util.Comp;
import mot.common.util.Logger;

public class CellRendererOrbit extends JLabel implements ListCellRenderer {

	private Size size;
	private boolean displayLabel = false;
	
    public CellRendererOrbit() {
    }
    
    public CellRendererOrbit(Size size) {
    	this.size = size;
    }
    
    public CellRendererOrbit(Size size, boolean displayLabel) {
    	this.size = size;
		this.displayLabel = displayLabel;
    }
    
     public Component getListCellRendererComponent(JList list,
                                                   Object value,            // value to display
                                                   int index,               // cell index
                                                   boolean isSelected,      // is the cell selected
                                                   boolean cellHasFocus)    // the list and the cell have the focus
     {
    	 if (value == null || value instanceof String && Comp.same(L.NONE,(String)value)) {
    		 String image = ImageConfigFactory.getImageConfigNoError("None").getImage();
			 return getContent(image, "None");
    	 }
    	 if (!(value instanceof NamedObjectDelegate)) {
    		 Logger.logError("Object not an ImageConfig : "+((value == null) ? "NULL" : value.getClass().getName()), new Exception());
    		 return new JLabel("ERROR");
    	 }
		 try { 
	    	 NamedObjectDelegate orbit = ((NamedObjectDelegate)value);
	    	 String image = null;
	 		 if (orbit instanceof PlanetDelegate) image = ((PlanetDelegate)orbit).getImageForPlanet();
	 		 if (orbit instanceof StellarObjectDelegate) image = ((StellarObjectDelegate)orbit).getImage();
	 		 if (image == null) {
	 			 Logger.logDebug("No Image : "+value.getClass().getName());
	 			 return new MotBorder(new JLabel(orbit.getName()));
	 		 }
	 		 return getContent(image, orbit.getName());
		 } catch (Exception ex) {
    		 Logger.logError("Object not an ImageConfig : "+((value == null) ? "NULL" : value.getClass().getName()), ex);
    		 return new JLabel("ERROR");
		 }
     }
     
     private Component getContent(String image, String name) {
    	 //Logger.logDebug(image);
    	 URL url = ClassLoader.getSystemResource(image);
    	 ImageIcon imageIcon = new ImageIcon(url);
    	 if (size != null) imageIcon = new ScaledImageIcon(imageIcon.getImage(), size);
		 JLabel label = new JLabel(imageIcon);
    	 if (size != null) {
    		 PanelUtils.setTheBloodySize(label, size);
    	 }
    	 if (displayLabel) {
	        ComponentTable panel = new ComponentTable("RC,HVSP", 1, 2, 0, 3, 0);
	        panel.setOpaque(false);
	        panel.add(label);
	        panel.add(new MotLabel(name));
	        return panel;
    	 } else {
    		 try { 
    			 return new MotBorder(label);
    		 } catch (Exception ex) { }
    		 return label;
    	 }

     }
}
