/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.renderers;

import java.awt.Component;

import javax.swing.JLabel;
import javax.swing.JList;
import javax.swing.ListCellRenderer;

import mot.common.lang.L;
import mot.common.util.Logger;
import mot.engine.prizes.BoraliumPrize;
import mot.engine.prizes.CraftPrize;
import mot.engine.prizes.MoneyPrize;
import mot.engine.prizes.Prize;
import mot.engine.prizes.RelicPrize;
import mot.engine.prizes.TechnologyPrize;

public class CellRendererPrize extends JLabel implements ListCellRenderer {


	public CellRendererPrize() {
    }
    
     public Component getListCellRendererComponent(JList list,
                                                   Object value,            // value to display
                                                   int index,               // cell index
                                                   boolean isSelected,      // is the cell selected
                                                   boolean cellHasFocus)    // the list and the cell have the focus
     {
    	 JLabel label;
    	 if (value instanceof MoneyPrize) {
   			 MoneyPrize p = (MoneyPrize)value;
			 String text = L.MONEY_+p.getAmount();
   			 label = new JLabel(text);
    	 } else if (value instanceof CraftPrize) {
    		 CraftPrize p = (CraftPrize)value;
			 String text = L.CRAFT_;
   			 label = new JLabel(text);
    	 } else if (value instanceof TechnologyPrize) {
    		 TechnologyPrize p = (TechnologyPrize)value;
			 String text = L.TECH_+((p.getTech() == null)?L.UNKNOWN:p.getTech().getName());
   			 label = new JLabel(text);
    	 } else if (value instanceof CraftPrize) {
    		 CraftPrize p = (CraftPrize)value;
			 String text = L.CRAFT_;
   			 label = new JLabel(text);
    	 } else if (value instanceof BoraliumPrize) {
    		 BoraliumPrize p = (BoraliumPrize)value;
			 String text = L.BORALIUM+" +"+p.getAmount();
   			 label = new JLabel(text);
    	 } else if (value instanceof RelicPrize) {
    		 RelicPrize p = (RelicPrize)value;
			 String text = L.RELIC + " " +((p.getRelic() == null)?L.UNKNOWN:p.getRelic().getName());
   			 label = new JLabel(text);
    	 } else if (value instanceof Prize) {
   	   		 String text = L.NONE;
   	   		 label = new JLabel(text);
       	 } else if (value == null) {
    		 return new JLabel();
    	 } else {
    		 Logger.logError("Object not an ImageConfig : "+((value == null) ? "NULL" : value.getClass().getName()), new Exception());
    		 return new JLabel("ERROR");
    	 }
    	 return label;
     }
 }
