/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.renderers;

import java.awt.Component;

import javax.swing.JLabel;
import javax.swing.JList;
import javax.swing.ListCellRenderer;

import mot.common.lang.L;
import mot.common.util.Formatter;
import mot.common.util.Logger;

public class CellRendererResearchBonus extends JLabel implements ListCellRenderer {

    private boolean isBonus;

	public CellRendererResearchBonus() {
    }
    
     public Component getListCellRendererComponent(JList list,
                                                   Object value,            // value to display
                                                   int index,               // cell index
                                                   boolean isSelected,      // is the cell selected
                                                   boolean cellHasFocus)    // the list and the cell have the focus
     {
    	 JLabel label;
    	 if (value instanceof Double) {
   			 String text = getResearchBonusName(((Double)value));
   			 label = new JLabel(text);
    	 } else {
    		 Logger.logError("Object not an ImageConfig : "+((value == null) ? "NULL" : value.getClass().getName()), new Exception());
    		 return new JLabel("ERROR");
    	 }
    	 return label;
     }
 
 	public static String getResearchBonusName(double bonus) {
		if (bonus == 0.0) return L.NONE;
		return Formatter.changeLabel(L.RESEARCH,L.ARTIFACTS,bonus);
	}
}
