/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.renderers;

import java.awt.Component;

import javax.swing.JLabel;
import javax.swing.JList;
import javax.swing.ListCellRenderer;

import mot.client.actions.TechnologyAction;
import mot.client.swing.common.PadPanel;
import mot.client.swing.common.PanelUtils;
import mot.client.swing.panels.TechnologyPicturePanel;
import mot.client.swing.window.common.MessagePanel;
import mot.common.bean.Size;
import mot.common.technology.Technology;
import mot.common.util.Logger;

public class CellRendererTechnologyImage implements ListCellRenderer {

	private Size size;
	private boolean displayName;
	private boolean displayDiscription;
	private boolean discriptionAsToolTip;
	private TechnologyAction action;
	
    public CellRendererTechnologyImage(Size size, boolean displayName, boolean displayDiscription, boolean discriptionAsToolTip, TechnologyAction action) {
		this.size = size;
		this.displayName = displayName;
		this.displayDiscription = displayDiscription;
		this.discriptionAsToolTip = discriptionAsToolTip;
		this.action = action;
    }
    
     public Component getListCellRendererComponent(JList list,
                                                   Object value,            // value to display
                                                   int index,               // cell index
                                                   boolean isSelected,      // is the cell selected
                                                   boolean cellHasFocus)    // the list and the cell have the focus
     {
    	 try {
        	 if (!(value instanceof Technology)) {
        		 Logger.logError("Not a Technology : "+((value == null) ? "NULL" : value.getClass().getName()), new Exception());
        		 return new JLabel("ERROR");
        	 }
        	 
        	 Technology tech = (Technology) value;
        	 
        	 TechnologyPicturePanel imagePanel = new TechnologyPicturePanel(null, false, displayDiscription, displayName, false, tech, null);
        	 if (discriptionAsToolTip) {
        		 imagePanel.setToolTipText(MessagePanel.toHtml(tech.getDescription(), size.getX()/10, true));
        	 }
     		 PanelUtils.setTheBloodySize(imagePanel, size);
    		 
    		 return new PadPanel(imagePanel, 2);
       	 } catch (Exception e) {
    		 Logger.logError("", e);
    		 return new JLabel("ERROR");
    	 }

     }

//	private void setBackground(boolean isSelected, JComponent component) {
//		Color selectedBackgroundColor = PropertyManager.getSelectedBackgroundColor();
//		if (isSelected) {
//			if (selectedBackgroundColor != null) {
//				component.setOpaque(true);
//				component.setBackground(selectedBackgroundColor);
//				component.setBorder(new LineBorder(Color.WHITE));
//			}
//		} else {
//			if (backgroundColour != null) {
//				component.setOpaque(true);
//				component.setBackground(backgroundColour);
//			}
//		}
//	}
 }
