/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.renderers;

import java.awt.Component;

import javax.swing.JLabel;

import mot.client.swing.common.ComponentTable;
import mot.client.swing.icons.TargetIcon;
import mot.client.swing.window.craft.actions.CraftDesignButtonMax;
import mot.client.swing.window.craft.actions.CraftDesignButtonMinus;
import mot.client.swing.window.craft.actions.CraftDesignButtonPlus;
import mot.client.swing.window.craft.actions.CraftDesignButtonZero;
import mot.common.technology.Computer;
import mot.common.technology.Scanner;
import mot.common.technology.Shield;
import mot.common.technology.Special;
import mot.common.technology.Technology;
import mot.common.technology.Weapon;
import mot.common.util.ApplicationError;
import mot.common.util.Logger;

public class ListItemControlPanelFactoryTechnology implements ListItemControlPanelFactory {

	private ListItemControlPanelListener parent;
	private boolean allTechsHaveMinusAndZero;

	public ListItemControlPanelFactoryTechnology(ListItemControlPanelListener parent, boolean allTechsHaveMinusAndZero) {
		this.parent = parent;
		this.allTechsHaveMinusAndZero = allTechsHaveMinusAndZero;
	}

	public Component getControlPanel(Object selection) {
		try {
			if (selection instanceof Technology) {
				Technology tech = (Technology) selection;
				if (allTechsHaveMinusAndZero) {
					ComponentTable component = new ComponentTable("HV,HV", 1, 2, 0, 0, 0);
					component.setOpaque(false);
					component.add(new CraftDesignButtonZero(parent, tech));
					component.add(new CraftDesignButtonMinus(parent, tech));
					return component;
				} else {
					if (tech instanceof Weapon) {
						ComponentTable component = new ComponentTable("HV,HV,HV,HV", 1, 4, 0, 0, 0);
						component.setOpaque(false);
						component.add(new CraftDesignButtonZero(parent, tech));
						component.add(new CraftDesignButtonMinus(parent, tech));
						component.add(new CraftDesignButtonPlus(parent, tech));
						component.add(new CraftDesignButtonMax(parent, tech));
						return component;
					} else if (selection instanceof Shield) {
						return new CraftDesignButtonMinus(parent, tech);
					} else if (selection instanceof Scanner) {
						return new CraftDesignButtonMinus(parent, tech);
					} else if (selection instanceof Special) {
						return new CraftDesignButtonMinus(parent, tech);
					} else if (selection instanceof Computer) {
						return new CraftDesignButtonMinus(parent, tech);
					}
				}
			}	
			TargetIcon targetIcon = TargetIcon.getInstance();
			return new JLabel(targetIcon);
		} catch (ApplicationError e) {
			Logger.logError("", e);
			return new JLabel("-");
		}
	}

}
