/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.tables;

import mot.common.technology.Biotechnologies;

public class BiotechnologyTableModel extends TechnologyTableModel {
    private Biotechnologies content;
    private boolean includeCosts;

    public BiotechnologyTableModel(Biotechnologies content) {
        this(content, false);
    }

    public BiotechnologyTableModel(Biotechnologies content, boolean includeCosts) {
        super(content);
        this.content = content;
        this.includeCosts = includeCosts;
    }

    public int getColumnCount() {
        int qty = 2;
        if (includeCosts) qty+=2;
        return qty;
    }

    public int getRowCount() { return content.getQuantity(); }
    public Class getColumnClass(int c) { return (c != 4) ? String.class :  getValueAt(0, c).getClass(); }
    public String getColumnName(int column) {
        switch (column) {
        case 0:
            return "Name";
        case 1:
            return "Description";
        case 2:
            return "Cost";
        case 3:
            return "Space";
        case 4:
            return "";
        }
        return "X";
    }
    public Object getValueAt(int row, int col) {
        switch (col) {
        case 0:
            return content.getBiotechnologyAtIndex(row).getName();
        case 1:
            if (content.getBiotechnologyAtIndex(row).getDescription() != null) {
                return content.getBiotechnologyAtIndex(row).getDescription();
            }
            String description = "";
            Double teraform = content.getBiotechnologyAtIndex(row).getTerraformRating();
            if (teraform != null) {
                description += "Terraform planets to increase their maximum population by "+teraform;
            }
            Integer psi = content.getBiotechnologyAtIndex(row).getPsiRating();
            if (psi != null) {
                description += "Improve the owner's psi rating by "+psi;
            }
            Double fert = content.getBiotechnologyAtIndex(row).getReproductionBonus();
            if (fert != null) {
                description += "Improve the owner's fertility rating by "+fert;
            }
            return description;
        case 2:
            return ""+content.getBiotechnologyAtIndex(row).getCostToBuild();
        case 3:
            return ""+content.getBiotechnologyAtIndex(row).getSpace();
        }
        return null;
    }
    public void setValueAt(Object value, int row, int col) {
    }
}
