/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.tables;

import java.awt.Component;

import javax.swing.JComponent;
import javax.swing.JRadioButton;
import javax.swing.JTable;
import javax.swing.JToggleButton;
import javax.swing.table.TableCellRenderer;

public class ButtonTableCellRenderer implements TableCellRenderer  {

    private JToggleButton defaultButton = null;

    public ButtonTableCellRenderer() {
        defaultButton = new JRadioButton("", false);        
    }
    
    public ButtonTableCellRenderer(JToggleButton button) {
        this.defaultButton = button;
    }
    
    public Component getTableCellRendererComponent(JTable table, Object value,
                                            boolean isSelected, boolean hasFocus, 
                                            int row, int column) 
    {
        Object o = table.getModel().getValueAt(row, column);
        if (o instanceof JComponent) {
            return (JComponent) o;
        }
        return defaultButton;
    }
    
    public JToggleButton getDefaultButton() {
        return defaultButton;
    }
}