/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.tables;

import mot.common.technology.Computers;

public class ComputerTableModel extends TechnologyTableModel {
    private Computers content;
    private boolean includeCosts;

    public ComputerTableModel(Computers content) {
        this(content, false);
    }

    public ComputerTableModel(Computers content, boolean includeCosts) {
        super(content);
        this.content = content;
        this.includeCosts = includeCosts;
    }

    public int getColumnCount() { 
        int qty = 5; 
        if (includeCosts) qty+=2;
        return qty;
    }

    public int getRowCount() { return content.getQuantity(); }
    public Class getColumnClass(int c) { return (c != 4) ? String.class :  getValueAt(0, c).getClass(); } 
    public boolean isCellEditable(int row, int col) { return (col == 4); }
    public String getColumnName(int column) {
        switch (column) {
        case 0:
            return "Name";
        case 1:
            return "Power";
        case 2:
            return "Influence";
        case 3:
            return "Commerce";
        case 4:
            return "Cost";
        case 5:
            return "Space";
        case 6:
            return "Description";
        case 7:
            return "";
        }
        return "X";
    }
    public Object getValueAt(int row, int col) {
        switch (col) {
        case 0:
            return content.getComputerAtIndex(row).getName();
        case 1:
            return ""+content.getComputerAtIndex(row).getPowerAsInt();
        case 2:
            return ""+content.getComputerAtIndex(row).getInfluenceAsInt();
        case 3:
            return ""+content.getComputerAtIndex(row).getCommerceAsInt();
        case 4:
            return ""+content.getComputerAtIndex(row).getCostToBuild(); 
        case 5:
            return ""+content.getComputerAtIndex(row).getSpace(); 
        case 6:
            return ""+content.getComputerAtIndex(row).getDescription(); 
        }
        return null;
    }
    public void setValueAt(Object value, int row, int col) {
    }
}
