/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.tables;

import javax.swing.JPanel;
import javax.swing.event.ListSelectionListener;

import mot.common.technology.Engine;
import mot.common.technology.Engines;
import mot.common.technology.Hull;

public class EngineTable extends TechnologyTable {

    public static TechnologyTablePanel createWithHeader(Engine content, Hull hull) {
        TechnologyTable table = new EngineTable(new Engines(content), false, hull);
        return new TechnologyTablePanel(table, table.getTableHeader());
    }

    public static TechnologyTablePanel createWithHeader(Engine content, boolean includeCosts, ListSelectionListener listener, Hull hull) {
        TechnologyTable table = new EngineTable(new Engines(content), includeCosts, hull);
        table.getSelectionModel().addListSelectionListener(listener);
        return new TechnologyTablePanel(table, table.getTableHeader());
    }
    
    public static TechnologyTablePanel createWithHeader(Engines content, Hull hull) {
        TechnologyTable table = new EngineTable(content, false, hull);
        return new TechnologyTablePanel(table, table.getTableHeader());
    }

    public static JPanel createWithHeader(Engines content, boolean includeCosts, ListSelectionListener listener, Hull hull) {
        TechnologyTable table = new EngineTable(content, includeCosts, hull);
        table.getSelectionModel().addListSelectionListener(listener);
        return new TechnologyTablePanel(table, table.getTableHeader());
    }
    
    public EngineTable(Engines content, boolean includeCosts, Hull hull) {
        super(content, includeCosts, new EngineTableModel(content, includeCosts, hull));
       
        getColumnModel().getColumn(0).setMinWidth(mot.client.swing.tables.CraftDesignTable.MIN_NAME_WIDTH);
        getColumnModel().getColumn(0).setMaxWidth(mot.client.swing.tables.CraftDesignTable.MIN_NAME_WIDTH);
        
        if (includeCosts) {
            getColumnModel().getColumn(6).setMaxWidth(mot.client.swing.tables.CraftDesignTable.MAX_COST_WIDTH);
            getColumnModel().getColumn(7).setMaxWidth(mot.client.swing.tables.CraftDesignTable.MAX_COST_WIDTH);
        }
    }






//	public static void main(String [] args) throws Exception {
//        JFrame win = new JFrame("Test");
//        win.setSize(500,200);
//        EngineTable table = new EngineTable(Technologies.getEngines(), true, Technologies.getHulls().getBiggestCraftHull());
//        //win.getContentPane().add(table.getTableHeader());
//        win.getContentPane().add(table);
//        win.show();
//    }
}