/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.tables;

import mot.common.technology.Engine;
import mot.common.technology.Engines;
import mot.common.technology.Hull;

public class EngineTableModel extends TechnologyTableModel {
    private Engines content;
    private boolean includeCosts;
    private Hull hull;

    public EngineTableModel(Engines content, Hull hull) {
        this(content, false, hull);
    }

    public EngineTableModel(Engines content, boolean includeCosts, Hull hull) {
        super(content);
        this.content = content;
        this.includeCosts = includeCosts;
        this.hull = hull;
    }

    public int getColumnCount() { 
        int qty = 6; 
        if (includeCosts) qty+=2;
        return qty;
    }

    public int getRowCount() { return content.getQuantity(); }
    public Class getColumnClass(int c) { return (c != 8) ? String.class :  getValueAt(0, c).getClass(); } 
    public boolean isCellEditable(int row, int col) { return (col == 8); }
    public String getColumnName(int column) {
        switch (column) {
        case 0:
            return "Name";
        case 1:
            return "Distance";
        case 2:
            return "Warp Speed";
        case 3:
            return "Move Speed";
        case 4:
            return "Turn Speed";
        case 5:
            return "Build Factor";
        case 6:
            return "Build Cost";
        case 7:
            return "Space";
        case 8:
            return "";
        }
        return "X";
    }
    public Object getValueAt(int row, int col) {
        switch (col) {
        case 0:
            return content.getEngineAtIndex(row).getName();
        case 1:
            return ""+content.getEngineAtIndex(row).getMaxTravelDistance();
        case 2:
            return ""+content.getEngineAtIndex(row).getWarpSpeed();
        case 3:
            return ""+content.getEngineAtIndex(row).getImpulseSpeed();
        case 4:
            return ""+content.getEngineAtIndex(row).getTurningSpeed();
        case 5:
            return ""+content.getEngineAtIndex(row).getCostToBuildFactor();
        case 6:
            Engine engine = content.getEngineAtIndex(row);
            if (engine.getUseBuildCostHullFactor()) {
                return ""+engine.getCostToBuild(hull.getCostToBuildFactor()); 
            } else {
                return ""+engine.getCostToBuild(); 
            }
        case 7:
            engine = content.getEngineAtIndex(row);
            if (engine.getUseBuildCostHullFactor()) {
                return ""+engine.getSpace(hull.getCostToBuildFactor()); 
            } else {
                return ""+engine.getSpace(); 
            }
        }
        return null;
    }
    
    public void setValueAt(Object value, int row, int col) {
    }
}
