/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.tables;

import javax.swing.event.ListSelectionListener;

import mot.common.technology.Factories;
import mot.common.technology.Factory;

public class FactoryTable extends TechnologyTable {

    public static TechnologyTablePanel createWithHeader(Factory content) {
        TechnologyTable table = new FactoryTable(new Factories(content), false);
        return new TechnologyTablePanel(table, table.getTableHeader());
    }

    public static TechnologyTablePanel createWithHeader(Factories content) {
        TechnologyTable table = new FactoryTable(content, false);
        return new TechnologyTablePanel(table, table.getTableHeader());
    }

    public static TechnologyTablePanel createWithHeader(Factories content, boolean includeCosts, ListSelectionListener listener) {
        TechnologyTable table = new FactoryTable(content, includeCosts);
        table.getSelectionModel().addListSelectionListener(listener);
        return new TechnologyTablePanel(table, table.getTableHeader());
    }

    public FactoryTable(Factories content, boolean includeCosts) {
        super(content, includeCosts, new FactoryTableModel(content, includeCosts));

        getColumnModel().getColumn(0).setMinWidth(mot.client.swing.tables.CraftDesignTable.MIN_NAME_WIDTH);
        getColumnModel().getColumn(0).setMaxWidth(mot.client.swing.tables.CraftDesignTable.MIN_NAME_WIDTH);

        if (includeCosts) {
            getColumnModel().getColumn(4).setMaxWidth(mot.client.swing.tables.CraftDesignTable.MAX_COST_WIDTH);
            getColumnModel().getColumn(5).setMaxWidth(mot.client.swing.tables.CraftDesignTable.MAX_COST_WIDTH);
        }
    }






/*
    public static void test1(Factories content) {
        JFrame win = new JFrame("Test");
        win.setSize(200,200);
        FactoryTable table = new FactoryTable(content, new Rectangle(4, 5, 190, 200));
        //win.getContentPane().add(table.getTableHeader());
        win.getContentPane().add(table);
        win.show();
    }
*/
}