/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.tables;
import mot.common.technology.Factories;

public class FactoryTableModel extends TechnologyTableModel {
    private Factories content;
    private boolean includeCosts;

    public FactoryTableModel(Factories content) {
        this(content, false);
    }

    public FactoryTableModel(Factories content, boolean includeCosts) {
        super(content);
        this.content = content;
        this.includeCosts = includeCosts;
    }

    public int getColumnCount() {
        int qty = 6;
        if (includeCosts) qty+=2;
        return qty;
    }

    public int getRowCount() { return content.getQuantity(); }
    public Class getColumnClass(int c) { return (c != 6) ? String.class :  getValueAt(0, c).getClass(); }
    public String getColumnName(int column) {
        switch (column) {
        case 0:
            return "Name";
        case 1:
            return "Qty/Pop";
        case 2:
            return "Min Eco";
        case 3:
            return "Production";
        case 4:
            return "Bld Qlty";
        case 5:
            return "Propaganda";
        case 6:
            return "Cost";
        case 7:
            return "Space";
        case 8:
            return "";
        }
        return "X";
    }
    public Object getValueAt(int row, int col) {
        switch (col) {
        case 0:
            return content.getFactoryAtIndex(row).getName();
        case 1:
            return ""+content.getFactoryAtIndex(row).getQtyPerPopulation();
        case 2:
            return ""+content.getFactoryAtIndex(row).getMinEcologyWork();
        case 3:
            return ""+content.getFactoryAtIndex(row).getProduction();
        case 4:
            return ""+content.getFactoryAtIndex(row).getBuildQuality();
        case 5:
            return ""+content.getFactoryAtIndex(row).getPropaganda();
        case 6:
            return ""+content.getFactoryAtIndex(row).getCostToBuild();
        case 7:
            return ""+content.getFactoryAtIndex(row).getSpace();
        }
        return null;
    }
    public void setValueAt(Object value, int row, int col) {
    }
}
