/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.tables;

import javax.swing.table.AbstractTableModel;

import mot.common.technology.Technology;
import mot.common.util.ApplicationError;
import mot.common.util.NameValuePair;

public class GeneralTechnologyTableModel extends AbstractTableModel {
    private Technology content;
    
    private NameValuePair [] data = null;

    public GeneralTechnologyTableModel(Technology content) throws ApplicationError {
        this.content = content;
        data = content.getAsData();
    }

    public int getColumnCount() { return 2; }
    public int getRowCount() { return data == null ? 0 : data.length; }
    public Class getColumnClass(int c) { return  String.class; } 
    public boolean isCellEditable(int row, int col) { return false; }
    public String getColumnName(int column) { 
        switch (column) {
        case 0:
            return "Attribute Name";
        case 1:
            return "Attribute Value";
        }
        return "X";
    } 
    public Object getValueAt(int row, int col) {
        if (data != null && data.length > row) {
        	if (data[row] == null) return "Err "+row+","+col+" on "+content;
        	if (col == 0) {
        		return data[row].getName();
        	} else {
        		return data[row].getValue();
        	}
        }
        return null;
    }
    public void setValueAt(Object value, int row, int col) {
    }
}
