/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.tables;

import javax.swing.JRadioButton;

import mot.common.technology.Hulls;

public class HullTableModel extends TechnologyTableModel {
    private Hulls content;
    private boolean includeCosts;

    public HullTableModel(Hulls content, boolean includeCosts) {
        super(content);
        this.content = content;
        this.includeCosts = includeCosts;
    }

    public int getColumnCount() { 
        int qty = 5; 
        if (includeCosts) qty+=2;
        return qty;
    }

    public int getRowCount() { return content.getQuantity(); }
    public Class getColumnClass(int c) { return (c != 7) ? String.class :  getValueAt(0, c).getClass(); } 
    public boolean isCellEditable(int row, int col) { return (col == 7); }
    public String getColumnName(int column) {
        switch (column) {
        case 0:
            return "Name";
        case 1:
            return "Turn";
        case 2:
            return "Move";
        case 3:
            return "Max Dam";
        case 4:
            return "Bld Factor";
        case 5:
            return "Bld Cost";
        case 6:
            return "Space";
        case 7:
            return "";
        }
        return "X";
    }
    public Object getValueAt(int row, int col) {
        switch (col) {
        case 0:
            return content.getHullAtIndex(row).getName();
        case 1:
            return ""+content.getHullAtIndex(row).getBattleTurningCost();
        case 2:
            return ""+content.getHullAtIndex(row).getBattleMovementCost();
        case 3:
            return ""+content.getHullAtIndex(row).getMaxDamage();
        case 4:
            return ""+content.getHullAtIndex(row).getCostToBuildFactor();
        case 5:
            return ""+content.getHullAtIndex(row).getCostToBuild(); 
        case 6:
            return ""+content.getHullAtIndex(row).getSpace(); 
        case 7:
            JRadioButton button = new JRadioButton("");
            button.setActionCommand(content.getHullAtIndex(row).getFullName());
            return button; 
        }
        return null;
    }
    public void setValueAt(Object value, int row, int col) {
    }
}
