/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.tables;

import javax.swing.event.ListSelectionListener;

import mot.common.technology.Scanner;
import mot.common.technology.Scanners;

public class ScannerTable extends TechnologyTable {
    
    public static TechnologyTablePanel createWithHeader(Scanner content) {
        TechnologyTable table = new ScannerTable(new Scanners(content), false);
        return new TechnologyTablePanel(table, table.getTableHeader());
    }

    public static TechnologyTablePanel createWithHeader(Scanners content) {
        TechnologyTable table = new ScannerTable(content, false);
        return new TechnologyTablePanel(table, table.getTableHeader());
    }

    public static TechnologyTablePanel createWithHeader(Scanners content, boolean includeCosts, ListSelectionListener listener) {
        TechnologyTable table = new ScannerTable(content, includeCosts);
        table.getSelectionModel().addListSelectionListener(listener);
        return new TechnologyTablePanel(table, table.getTableHeader());
    }
    
    protected ScannerTable(Scanners content, boolean includeCosts) {
        super(content, includeCosts, new ScannerTableModel(content, includeCosts));

        getColumnModel().getColumn(0).setMinWidth(mot.client.swing.tables.CraftDesignTable.MIN_NAME_WIDTH);
        getColumnModel().getColumn(0).setMaxWidth(mot.client.swing.tables.CraftDesignTable.MIN_NAME_WIDTH);
        
        if (includeCosts) {
            getColumnModel().getColumn(2).setMaxWidth(mot.client.swing.tables.CraftDesignTable.MAX_COST_WIDTH);
            getColumnModel().getColumn(3).setMaxWidth(mot.client.swing.tables.CraftDesignTable.MAX_COST_WIDTH);
        }
    }
    
    
    
    
    
    
/*    
    public static void test1(Scanners content) {
        JFrame win = new JFrame("Test");
        win.setSize(200,200);
        ScannerTable table = new ScannerTable(content, new Rectangle(4, 5, 190, 200));
        //win.getContentPane().add(table.getTableHeader());
        win.getContentPane().add(table);
        win.show();
    }
*/    
}