/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.tables;

import javax.swing.event.ListSelectionListener;

import mot.common.technology.Shield;
import mot.common.technology.Shields;

public class ShieldTable extends TechnologyTable {
    
    public static TechnologyTablePanel createWithHeader(Shield content) {
        TechnologyTable table = new ShieldTable(new Shields(content), false);
        return new TechnologyTablePanel(table, table.getTableHeader());
    }

    public static TechnologyTablePanel createWithHeader(Shields content) {
        TechnologyTable table = new ShieldTable(content, false);
        return new TechnologyTablePanel(table, table.getTableHeader());
    }

    public static TechnologyTablePanel createWithHeader(Shields content, boolean includeCosts, ListSelectionListener listener) {
        TechnologyTable table = new ShieldTable(content, includeCosts);
        table.getSelectionModel().addListSelectionListener(listener);
        return new TechnologyTablePanel(table, table.getTableHeader());
    }

    public ShieldTable(Shields content, boolean includeCosts) {
        super(content, includeCosts, new ShieldTableModel(content, includeCosts));

        getColumnModel().getColumn(0).setMinWidth(mot.client.swing.tables.CraftDesignTable.MIN_NAME_WIDTH);
        getColumnModel().getColumn(0).setMaxWidth(mot.client.swing.tables.CraftDesignTable.MIN_NAME_WIDTH);
        
        if (includeCosts) {
            getColumnModel().getColumn(6).setMaxWidth(mot.client.swing.tables.CraftDesignTable.MAX_COST_WIDTH);
            getColumnModel().getColumn(7).setMaxWidth(mot.client.swing.tables.CraftDesignTable.MAX_COST_WIDTH);
        }
    }
    
    
    
    
    
    
/*    
    public static void test1(Shields content) {
        JFrame win = new JFrame("Test");
        win.setSize(200,200);
        ShieldTable table = new ShieldTable(content, new Rectangle(4, 5, 190, 200));
        //win.getContentPane().add(table.getTableHeader());
        win.getContentPane().add(table);
        win.show();
    }
*/    
}