/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.tables;

import mot.common.technology.Shields;

public class ShieldTableModel extends TechnologyTableModel {
    private Shields content;
    private boolean includeCosts;

    public ShieldTableModel(Shields content) {
        this(content, false);
    }
    
    public ShieldTableModel(Shields content, boolean includeCosts) {
        super(content);
        this.content = content;
        this.includeCosts = includeCosts;
    }

    public int getColumnCount() { 
        int qty = 7; 
        if (includeCosts) qty+=2;
        return qty;
    }
    
    public int getRowCount() { return content.getQuantity(); }
    public boolean isCellEditable(int row, int col) { return (col == 9); }
    public Class getColumnClass(int c) { return (c != 9) ? String.class :  getValueAt(0, c).getClass(); } 
    public String getColumnName(int column) { 
        switch (column) {
        case 0:
            return "Name";
        case 1:
            return "Damage Blocked";
        case 2:
            return "Power";
        case 3:
            return "Charge";
        case 4:
            return "Psi";
        case 5:
            return "Discharge";
        case 6:
            return "Cloak";
        case 7:
            return "Cost";
        case 8:
            return "Space";
        case 9:
            return "";
        }
        return "X";
    } 
    public Object getValueAt(int row, int col) {
        switch (col) {
        case 0:
            return content.getShieldAtIndex(row).getName(); 
        case 1:
            return ""+content.getShieldAtIndex(row).getDamageBlocked(); 
        case 2:
            return ""+content.getShieldAtIndex(row).getPower(); 
        case 3:
            return ""+content.getShieldAtIndex(row).getRechargeRate(); 
        case 4:
            return ""+content.getShieldAtIndex(row).getPsiRating(); 
        case 5:
            return ""+content.getShieldAtIndex(row).getDischargeRate(); 
        case 6:
            return ""+content.getShieldAtIndex(row).getCloakLevel(); 
        case 7:
            return ""+content.getShieldAtIndex(row).getCostToBuild(); 
        case 8:
            return ""+content.getShieldAtIndex(row).getSpace(); 
        }
        return null;
    }
    public void setValueAt(Object value, int row, int col) {
    }
}
