/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.tables;

import mot.common.technology.Specials;
import mot.common.util.Formatter;

public class SpecialTableModel extends TechnologyTableModel {
    private Specials content;
    private boolean includeCosts;

    public SpecialTableModel(Specials content, boolean includeCosts) {
        super(content);
        this.content = content;
        this.includeCosts = includeCosts;
    }

    public int getColumnCount() { 
        int qty = 2; 
        if (includeCosts) qty+=2;
        return qty;
    }

    public int getRowCount() { return content.getQuantity(); }
    public Class getColumnClass(int c) { return (c != 4) ? String.class :  getValueAt(0, c).getClass(); } 
    public boolean isCellEditable(int row, int col) { return (col == 4); }
    public String getColumnName(int column) {
        switch (column) {
        case 0:
            return "Name";
        case 1:
            return "Description";
        case 2:
            return "Cost";
        case 3:
            return "Space";
        case 4:
            return "";
        }
        return "X";
    }
    public Object getValueAt(int row, int col) {
        switch (col) {
        case 0:
            return content.getSpecialAtIndex(row).getName();
        case 1:
            if (content.getSpecialAtIndex(row).getDescription() != null) {
                return content.getSpecialAtIndex(row).getDescription();
            }
            String description = "";
            Double speed = content.getSpecialAtIndex(row).getSpeedBonus();
            if (speed != null) {
                description += "Increased Speed by "+speed;
            }
            Double battleTurning = content.getSpecialAtIndex(row).getBattleTurningBonus();
            if (battleTurning != null) {
                if (description.length() != 0) description += " ";
                description += "Increased Battle Turning Speed by "+battleTurning;
            }
            Double battleSpeed = content.getSpecialAtIndex(row).getBattleSpeedBonus();
            if (battleSpeed != null) {
                if (description.length() != 0) description += " ";
                description += "Increased Battle Speed by "+battleSpeed;
            }
            Double defenderModification = content.getSpecialAtIndex(row).getDefenderModification();
            if (defenderModification != null) {
                if (description.length() != 0) description += " ";
                description += "Decrease Damage by "+Formatter.percentLabel(defenderModification.doubleValue());
            }
            Double attackerModification = content.getSpecialAtIndex(row).getAttackerModification();
            if (attackerModification != null) {
                if (description.length() != 0) description += " ";
                description += "Increase Damage by "+Formatter.percentLabel(attackerModification.doubleValue());
            }
            Double initiative = content.getSpecialAtIndex(row).getInitiativeBonus();
            if (initiative != null) {
                if (description.length() != 0) description += " ";
                description += "Increased Initiative by "+initiative;
            }
            Double maxDamage = content.getSpecialAtIndex(row).getMaxDamageBonus();
            if (maxDamage != null) {
                if (description.length() != 0) description += " ";
                description += "Increased Maximum Damage by "+maxDamage;
            }
            Double colonise = content.getSpecialAtIndex(row).getCanColoniseRating();
            if (colonise != null) {
                if (description.length() != 0) description += " ";
                description += "Allow colonisation of environments >= "+colonise;
            }
            Double rangeModification = content.getSpecialAtIndex(row).getRangeModification();
            if (rangeModification != null) {
                if (description.length() != 0) description += " ";
                description += "Increase weapons range by "+Formatter.percentLabel(rangeModification.doubleValue());
            }
            Integer qtyBerths = content.getSpecialAtIndex(row).getQtyBerths();
            if (qtyBerths != null) {
                if (description.length() != 0) description += " ";
                description += "Carry soldiers "+qtyBerths.intValue();
            }
            return description;
        case 2:
            return ""+content.getSpecialAtIndex(row).getCostToBuild(); 
        case 3:
            return ""+content.getSpecialAtIndex(row).getSpace(); 
        }
        return null;
    }
    public void setValueAt(Object value, int row, int col) {
    }
}
