/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.tables;

import javax.swing.DefaultListSelectionModel;
import javax.swing.JTable;

import mot.common.technology.Technology;
import mot.common.technology.TechnologyList;

public class TechnologyListSelectionModel extends DefaultListSelectionModel {

    /**
     * List of technologies that are in the list!
     */
    private TechnologyList available;

    /**
     * The table from which the selection has been made!
     */
    private JTable source;

    public TechnologyListSelectionModel(TechnologyList available, JTable source) {
        this.available = available;
        this.source = source;
    }
    
    public Technology getSelectedTechnology() {
        int index = getMinSelectionIndex();
        if (index < 0) return null;
        if (source.getModel() instanceof TechnologyTableModel) {
            TechnologyTableModel model = (TechnologyTableModel) source.getModel();
            Technology tech = model.getContentAtIndex(index);
            return tech;
        } else {
            return available.getTechnologyAtIndex(index);
        }
    }

    public void setSelectedTechnology(Technology tech) {
        int index = -1;
        if (source.getModel() instanceof TechnologyTableModel) {
            TechnologyTableModel model = (TechnologyTableModel) source.getModel();
            index = model.getIndexOfTechnology(tech);
        } else {
            index = available.getIndexOfTechnology(tech);
        }
        if (index == -1) return;
        setSelectionInterval(index, index);
    }

    public TechnologyList getAvailable() {
        if (source.getModel() instanceof TechnologyTableModel) {
            TechnologyTableModel model = (TechnologyTableModel) source.getModel();
            return model.getContents();
        } else {
            return available;
        }
    }


    public JTable getSource() {
        return source;
    }
}