/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.tables;

import javax.swing.JTable;
import javax.swing.ListSelectionModel;

import mot.common.technology.Technology;
import mot.common.technology.TechnologyList;

public class TechnologyTable extends JTable {

    private TechnologyTableModel model;
    private TechnologyListSelectionModel selectionModel;

    public TechnologyTable(TechnologyList content, boolean includeCosts, TechnologyTableModel model) {
        setOpaque(true);
        setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
        setRowSelectionAllowed(includeCosts);
        setColumnSelectionAllowed(false);
        selectionModel = new TechnologyListSelectionModel(content, this);
        setSelectionModel(selectionModel);
        setModel(model);
        //getTableHeader().setReorderingAllowed(false);
        
        this.model = model;
    }
    
    public Technology getSelectedTechnology() {
        return selectionModel.getSelectedTechnology();
    }
    
    public void setSelectedTechnology(Technology tech) {
        selectionModel.setSelectedTechnology(tech);
    }

    public TechnologyTableModel getTechnologyModel() {
        return model;
    }

    public void updateModel(TechnologyList techs) {
        model.updateModel(techs);
    }
}