/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.tables;

import mot.common.technology.Biotechnology;
import mot.common.technology.Computer;
import mot.common.technology.Engine;
import mot.common.technology.Factory;
import mot.common.technology.Hull;
import mot.common.technology.Laboratory;
import mot.common.technology.Scanner;
import mot.common.technology.Shield;
import mot.common.technology.Special;
import mot.common.technology.Technology;
import mot.common.technology.Theory;
import mot.common.technology.Weapon;

public class TechnologyTableFactory  {

    public static TechnologyTablePanel createTechnologyTable(Technology tech) {
        if (tech == null) { 
            return null;
        } else if (tech instanceof Hull) {
            return HullTable.createWithHeader((Hull)tech);
        } else if (tech instanceof Engine) {
            return EngineTable.createWithHeader((Engine)tech, null);
        } else if (tech instanceof Computer) {
            return ComputerTable.createWithHeader((Computer)tech);
        } else if (tech instanceof Weapon) {
            return WeaponTable.createWithHeader((Weapon)tech);
        } else if (tech instanceof Shield) {
            return ShieldTable.createWithHeader((Shield)tech);
        } else if (tech instanceof Scanner) {
            return ScannerTable.createWithHeader((Scanner)tech);
        } else if (tech instanceof Special) {
            return SpecialTable.createWithHeader((Special)tech);
        } else if (tech instanceof Factory) {
            return FactoryTable.createWithHeader((Factory)tech);
        } else if (tech instanceof Laboratory) {
            return LaboratoryTable.createWithHeader((Laboratory)tech);
        } else if (tech instanceof Biotechnology) {
            return BiotechnologyTable.createWithHeader((Biotechnology)tech);
        } else if (tech instanceof Theory) {
            return TheoryTable.createWithHeader((Theory)tech);
        }
        return null;
    }
}