/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.tables;

import javax.swing.JPanel;
import javax.swing.JTable;
import javax.swing.ListSelectionModel;
import javax.swing.event.ListSelectionListener;

import mot.common.designs.TransportDesign;

public class TransportTable extends JTable {

    public static JPanel createWithHeader(TransportDesign content) {
        JTable table = new TransportTable(content, false);
        return new TablePanel(table, table.getTableHeader());
    }

    public static JPanel createWithHeader(TransportDesign content, boolean includeCosts, ListSelectionListener listener) {
        JTable table = new TransportTable(content, includeCosts);
        table.getSelectionModel().addListSelectionListener(listener);
        return new TablePanel(table, table.getTableHeader());
    }

    public TransportTable(TransportDesign content, boolean includeCosts) {
        setModel(new TransportTableModel(content, includeCosts));
        setOpaque(true);
        setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
        setRowSelectionAllowed(includeCosts);
        //setSelectionModel(new TechnologyListSelectionModel(content));

        getColumnModel().getColumn(0).setMinWidth(CraftDesignTable.MIN_NAME_WIDTH);
        getColumnModel().getColumn(0).setMaxWidth(CraftDesignTable.MIN_NAME_WIDTH);

        if (includeCosts) {
            getColumnModel().getColumn(2).setMaxWidth(CraftDesignTable.MAX_COST_WIDTH);
            getColumnModel().getColumn(3).setMaxWidth(CraftDesignTable.MAX_COST_WIDTH);
        }
    }






/*
    public static void test1(Transports content) {
        JFrame win = new JFrame("Test");
        win.setSize(200,200);
        TransportTable table = new TransportTable(content, new Rectangle(4, 5, 190, 200));
        //win.getContentPane().add(table.getTableHeader());
        win.getContentPane().add(table);
        win.show();
    }
*/
}