/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.tables;

import javax.swing.BoxLayout;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTable;
import javax.swing.event.ListSelectionListener;

import mot.client.swing.common.PanelUtils;
import mot.common.designs.WeaponBayDesign;
import mot.common.designs.WeaponBaysDesign;
import mot.common.technology.Technology;
import mot.common.util.ApplicationError;

public class WeaponBayTable extends JPanel{

    public WeaponTable [] tables;

    public WeaponBayTable(WeaponBaysDesign content) throws ApplicationError {
        this(content, false, null);
    }
    
    private JLabel getListLabel(String text) {
        JLabel label = PanelUtils.createLabel(text);
        //label.setBackground(Color.BLACK);
        //label.setForeground(Color.WHITE);
        label.setOpaque(true);
        //label.setHorizontalAlignment(JLabel.LEFT);
        //label.setMaximumSize(new Dimension(panel.getWidth(), 20));
        //label.setMinimumSize(new Dimension(panel.getWidth(), 20));
        return label;
    }

    public WeaponBayTable(WeaponBaysDesign content, boolean includeCosts, ListSelectionListener listener) throws ApplicationError {
        setLayout(new BoxLayout(this, BoxLayout.Y_AXIS));
        WeaponBayDesign[] bays = content.getBaysAsArray();
        tables = new WeaponTable [bays.length];
        boolean first = true;
        for (int i=0; i<bays.length; i++) {
            if (bays.length > 1) {
                add(getListLabel("Weapons Bay "+i), null);
            } else {
                add(getListLabel("Weapons"), null);
            }
            if (first) {
                TechnologyTablePanel panel = WeaponTable.createWithHeader(bays[i].getWeaponsList(), includeCosts, listener);
                tables[i] = (WeaponTable) panel.getTable();
                add(panel, null);
                first = false;
            } else {
                tables[i] = (WeaponTable) WeaponTable.create(bays[i].getWeaponsList(), includeCosts, listener);
                add(tables[i], null);
            }
        }
    }

    public void clearSelection(JTable table) {
        if (tables == null) return;
        for (int i=0; i<tables.length; i++) {
            if (table != tables[i]) {
                tables[i].getSelectionModel().clearSelection();
            }
        }
    }

    public void clearSelection() {
        if (tables == null) return;
        for (int i=0; i<tables.length; i++) {
            tables[i].getSelectionModel().clearSelection();
        }
    }

    public Technology getSelectedTechnology() {
        if (tables == null) return null;
        for (int i=0; i<tables.length; i++) {
            Technology selected = tables[i].getSelectedTechnology();
            if (selected != null) {
                return selected;
            }
        }
        return null;
    }

    public void setSelectedTechnology(Technology tech) {
        if (tables == null) return;
        for (int i=0; i<tables.length; i++) {
            if (tables[i].getTechnologyModel().contains(tech)) {
                tables[i].setSelectedTechnology(tech);
            }
        }
    }

    public void updateModel(WeaponBaysDesign cd) throws ApplicationError {
        if (tables == null) return;
        WeaponBayDesign [] bays = cd.getBaysAsArray();
        for (int i=0; i<tables.length; i++) {
            tables[i].getTechnologyModel().updateModel(bays[i].getWeaponsList());
        }
    }

}