/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.tables;

import javax.swing.event.ListSelectionListener;

import mot.common.technology.Weapon;
import mot.common.technology.Weapons;

public class WeaponTable extends TechnologyTable {

    public static TechnologyTablePanel createWithHeader(Weapon content) {
        TechnologyTable table = new WeaponTable(new Weapons(content), false);
        return new TechnologyTablePanel(table, table.getTableHeader());
    }

    public static TechnologyTablePanel createWithHeader(Weapons content) {
        TechnologyTable table = new WeaponTable(content, false);
        return new TechnologyTablePanel(table, table.getTableHeader());
    }

    public static TechnologyTablePanel createWithHeader(Weapons content, boolean includeCosts, ListSelectionListener listener) {
        TechnologyTable table = new WeaponTable(content, includeCosts);
        table.getSelectionModel().addListSelectionListener(listener);
        return new TechnologyTablePanel(table, table.getTableHeader());
    }
    
    public static WeaponTable create(Weapons content, boolean includeCosts, ListSelectionListener listener) {
        WeaponTable table = new WeaponTable(content, includeCosts);
        table.getSelectionModel().addListSelectionListener(listener);
        return table;
    }
    
    public WeaponTable(Weapons content, boolean includeCosts) {
        super(content, includeCosts, new WeaponTableModel(content, includeCosts));

        getColumnModel().getColumn(0).setMaxWidth(mot.client.swing.tables.CraftDesignTable.MAX_QTY_WIDTH);
        getColumnModel().getColumn(1).setMinWidth(mot.client.swing.tables.CraftDesignTable.MIN_NAME_WIDTH);
        getColumnModel().getColumn(1).setMaxWidth(mot.client.swing.tables.CraftDesignTable.MIN_NAME_WIDTH);
        
        if (includeCosts) {
            getColumnModel().getColumn(7).setMaxWidth(mot.client.swing.tables.CraftDesignTable.MAX_COST_WIDTH);
            getColumnModel().getColumn(8).setMaxWidth(mot.client.swing.tables.CraftDesignTable.MAX_COST_WIDTH);
        }
    }


   
//    public static void main(String [] args) throws Exception {
//        JFrame win = new JFrame("Test");
//        win.setSize(500,200);
//        //WeaponTable table = new WeaponTable(Technologies.getWeapons(), true);
//        //win.getContentPane().add(table);
//        win.getContentPane().add(WeaponTable.createWithHeader(Technologies.getWeapons(), true, null));
//        win.show();
//    }
 
}