/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.tables;

import mot.common.technology.Technology;
import mot.common.technology.TechnologyBundle;
import mot.common.technology.Weapons;

public class WeaponTableModel extends TechnologyTableModel {
    private Weapons content;
    private TechnologyBundle[] techBundle;
    private boolean includeCosts;

    public WeaponTableModel(Weapons content, boolean includeCosts) {
        super(new Weapons(content));
        this.content = (Weapons) getContents();
        this.includeCosts = includeCosts;
        this.techBundle = content.getDistinct();
        
        this.content.sortByName();
    }

    public Technology getContentAtIndex(int index) {
        return techBundle[index].getTechnology();
    }

    public int getIndexOfTechnology(Technology tech) {
        for (int i=0; i<techBundle.length; i++) {
            if (techBundle[i].getTechnology() == tech) {
                return i;
            }
        }
        return -1;
    }

    public int getColumnCount() { 
        int qty = 8; 
        if (includeCosts) qty+=2;
        return qty;
    }
    public int getRowCount() { return techBundle.length; }
    public Class getColumnClass(int c) { return (c != 9) ? String.class :  getValueAt(0, c).getClass(); } 
    public boolean isCellEditable(int row, int col) { return (col == 9); }
    public String getColumnName(int column) { 
        switch (column) {
        case 0:
            return "Qty";
        case 1:
            return "Name";
        case 2:
            return "Damage";
        case 3:
            return "Degredation";
        case 4:
            return "Range";
        case 5:
            return "Variance";
        case 6:
            return "Qty Shots";
        case 7:
            return "Salvage";
        case 8:
            return "Cost";
        case 9:
            return "Space";
        case 10:
            return "";
        }
        return "X";
    } 
    public Object getValueAt(int row, int col) {
        String name = techBundle[row].getName();
        switch (col) {
        case 0:
            return ""+techBundle[row].qty; 
        case 1:
            return name; 
        case 2:
            return ""+content.getWeapon(name).getDamage(); 
        case 3:
            return ""+content.getWeapon(name).getDegredation(); 
        case 4:
            return ""+content.getWeapon(name).getRange(); 
        case 5:
            return ""+content.getWeapon(name).getVariance(); 
        case 6:
            return ""+content.getWeapon(name).getQtyShotsAsString(); 
        case 7:
            return ""+content.getWeapon(name).getCostToBuild(); 
        case 8:
            return ""+content.getWeapon(name).getSalvageEffect(); 
        case 9:
            return ""+content.getWeapon(name).getSpace(); 
        }
        return null;
    }
    public void setValueAt(Object value, int row, int col) {
    }
}
