/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.technology;

import mot.common.technology.AsteroidFieldConstruction;
import mot.common.technology.GalacticLore;
import mot.common.technology.MineField;
import mot.common.technology.MiscTechnology;
import mot.common.technology.NewsSystem;
import mot.common.technology.PlanetConstruction;
import mot.common.technology.StationMissileBase;
import mot.common.util.ApplicationError;
import mot.common.util.Formatter;
import mot.common.util.NameValuePair;

public class MiscDetailsGrid extends TechnologyDetailsGrid {

	public MiscDetailsGrid(MiscTechnology v, boolean fullName) throws ApplicationError {
		super(fullName ? v.getFullName() : v.getName(), v.getDescription(), getData(v));
	}

	private static NameValuePair[] getData(MiscTechnology v) throws ApplicationError {
		if (v instanceof StationMissileBase) {
			return getData( (StationMissileBase) v);
		} else if (v instanceof GalacticLore) {
			return getData( (GalacticLore) v);
		} else if (v instanceof PlanetConstruction) {
			return getData( (PlanetConstruction) v);
		} else if (v instanceof AsteroidFieldConstruction) {
			return getData( (AsteroidFieldConstruction) v);
		} else if (v instanceof MineField) {
			return getData( (MineField) v);
		} else if (v instanceof NewsSystem) {
			return getData( (NewsSystem) v);
		} else {
			throw new ApplicationError(""+v);
		}
	}
	
	private static NameValuePair[] getData(StationMissileBase v) {
		NameValuePair[] d = new NameValuePair[3];
		d[0] = new NameValuePair("Quantity of Missiles", Formatter.nnv(v.getQtyMissiles()));
		d[1] = new NameValuePair("Cost to Build", ""+v.getCostToBuild());
		d[2] = new NameValuePair("Cost to Research", ""+v.getCostToResearch());
		return d;
	}

	private static NameValuePair[] getData(GalacticLore v) {
		NameValuePair[] d = new NameValuePair[3];
		d[0] = new NameValuePair("Quantity of Lore", Formatter.nnv(v.getQtyGalacticLore()));
		d[1] = new NameValuePair("Cost to Build", ""+v.getCostToBuild());
		d[2] = new NameValuePair("Cost to Research", ""+v.getCostToResearch());
		return d;
	}

	private static NameValuePair[] getData(PlanetConstruction v) {
		NameValuePair[] d = new NameValuePair[9];
		d[0] = new NameValuePair("New Planet Size", Formatter.nnv(v.getPlanetSize()));
		d[1] = new NameValuePair("New Planet Terraform", ""+v.getPlanetTerraform());
		d[2] = new NameValuePair("New Planet Population", Formatter.nnv(v.getPlanetPopulation()));
		d[3] = new NameValuePair("New Planet Production Bonus", Formatter.changeLabel(v.getPlanetProductionBonus()));
		d[4] = new NameValuePair("New Planet Reproduction Bonus", Formatter.changeLabel(v.getPlanetReproductionBonus()));
		d[5] = new NameValuePair("New Planet Research Bonus", Formatter.changeLabel(v.getPlanetResearchBonus()));
		d[6] = new NameValuePair("New Planet Quantity of Factories", Formatter.nnv(v.getPlanetQtyFactories()));
		d[7] = new NameValuePair("Cost to Build", ""+v.getCostToBuild());
		d[8] = new NameValuePair("Cost to Research", ""+v.getCostToResearch());
		return d;
	}

	private static NameValuePair[] getData(AsteroidFieldConstruction v) {
		NameValuePair[] d = new NameValuePair[2];
		d[0] = new NameValuePair("Cost to Build", ""+v.getCostToBuild());
		d[1] = new NameValuePair("Cost to Research", ""+v.getCostToResearch());
		return d;
	}

	private static NameValuePair[] getData(MineField v) {
		NameValuePair[] d = new NameValuePair[3];
		d[0] = new NameValuePair("Quantity of Mines", Formatter.nnv(v.getQty()));
		d[1] = new NameValuePair("Cost to Build", ""+v.getCostToBuild());
		d[2] = new NameValuePair("Cost to Research", ""+v.getCostToResearch());
		return d;
	}

	private static NameValuePair[] getData(NewsSystem v) {
		NameValuePair[] d = new NameValuePair[3];
		d[0] = new NameValuePair("Quantity of Influence Generated", Formatter.nnv(v.getInfluence()));
		d[1] = new NameValuePair("Cost to Build", ""+v.getCostToBuild());
		d[2] = new NameValuePair("Cost to Research", ""+v.getCostToResearch());
		return d;
	}

	
}
