/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.technology;

import mot.common.technology.Special;
import mot.common.util.Formatter;
import mot.common.util.NameValuePair;

public class SpecialsDetailsGrid extends TechnologyDetailsGrid {

	public SpecialsDetailsGrid(Special v, boolean fullName) {
		super(fullName ? v.getFullName() : v.getName(), v.getDescription(), getData(v));
	}
	
	private static NameValuePair[] getData(Special v) {
		NameValuePair[] d = new NameValuePair[21];
		d[0] = new NameValuePair("Speed Bonus", Formatter.nnv(v.getSpeedBonus()));
		d[1] = new NameValuePair("Battle Speed Bonus", Formatter.nnv(v.getBattleSpeedBonus()));
		d[2] = new NameValuePair("Battle Turning Speed Bonus", Formatter.nnv(v.getBattleTurningBonus()));
		d[3] = new NameValuePair("Defender Modification", Formatter.nnv(v.getDefenderModification()));
		d[4] = new NameValuePair("Attacker Modification", Formatter.nnv(v.getAttackerModification()));
		d[5] = new NameValuePair("Range Modification", Formatter.nnv(v.getRangeModification()));
		d[6] = new NameValuePair("Initiative Bonus", Formatter.nnv(v.getInitiativeBonus()));
		d[7] = new NameValuePair("Maximum Damage Bonus", Formatter.nnv(v.getMaxDamageBonus()));
		d[8] = new NameValuePair("Colonise Rating", Formatter.nnv(v.getCanColoniseRating()));
		d[9] = new NameValuePair("Crew Berths", Formatter.nnv(v.getQtyBerths()));
		d[10] = new NameValuePair("Quantity of Fighter Craft", Formatter.nnv(v.getQtyFighters()));
		d[11] = new NameValuePair("Quantity of Holo Craft", Formatter.nnv(v.getQtyHoloCraft()));
		d[12] = new NameValuePair("Influence", Formatter.nnv(v.getInfluence()));
		d[13] = new NameValuePair("Salvage Effect", Formatter.nnv(v.getSalvageEffect()));
		d[14] = new NameValuePair("Shield Span", Formatter.nnv(v.getShieldSpan()));
//		d[0] = new NameValuePair("Immunity", ""+v.get);
		d[15] = new NameValuePair("Repair Effect", Formatter.nnv(v.getRepairEffect()));
		d[16] = new NameValuePair("Missile Retarget", Formatter.nnv(v.getMissileRetarget()));
		d[17] = new NameValuePair("Space", Formatter.nnv(v.getSpace()));
		d[18] = new NameValuePair("Cost to Build", Formatter.nnv(v.getCostToBuild()));
		d[19] = new NameValuePair("Cost to Research", Formatter.nnv(v.getCostToResearch()));
		d[20] = new NameValuePair("Maintenance Cost", Formatter.nnv(v.getMaintenanceCost()));
		return d;
	}

}
