/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.technology;

import mot.common.technology.Biotechnology;
import mot.common.technology.Computer;
import mot.common.technology.Engine;
import mot.common.technology.Factory;
import mot.common.technology.Hull;
import mot.common.technology.Laboratory;
import mot.common.technology.MiscTechnology;
import mot.common.technology.Module;
import mot.common.technology.Scanner;
import mot.common.technology.Shield;
import mot.common.technology.Special;
import mot.common.technology.Technology;
import mot.common.technology.Theory;
import mot.common.technology.Weapon;
import mot.common.util.ApplicationError;

public class TechnologyGridFactory  {

    public static TechnologyDetailsGrid createTechnologyTable(Technology tech, boolean fullName) throws ApplicationError {
        if (tech == null) { 
            return null;
        } else if (tech instanceof Hull) {
			return new HullDetailsGrid((Hull)tech, fullName);
        } else if (tech instanceof Engine) {
			return new EngineDetailsGrid((Engine)tech, fullName);
        } else if (tech instanceof Computer) {
			return new ComputerDetailsGrid((Computer)tech, fullName);
        } else if (tech instanceof Weapon) {
			return new WeaponsDetailsGrid((Weapon)tech, fullName);
        } else if (tech instanceof Shield) {
			return new ShieldDetailsGrid((Shield)tech, fullName);
        } else if (tech instanceof Scanner) {
			return new ScannerDetailsGrid((Scanner)tech, fullName);
        } else if (tech instanceof Special) {
			return new SpecialsDetailsGrid((Special)tech, fullName);
        } else if (tech instanceof Factory) {
			return new FactoryDetailsGrid((Factory)tech, fullName);
        } else if (tech instanceof Laboratory) {
			return new LaboratoryDetailsGrid((Laboratory)tech, fullName);
        } else if (tech instanceof Biotechnology) {
			return new BiotechnologyDetailsGrid((Biotechnology)tech, fullName);
        } else if (tech instanceof Theory) {
			return new TheoryDetailsGrid((Theory)tech, fullName);
        } else if (tech instanceof Module) {
			return new ModulesDetailsGrid((Module)tech, fullName);
        } else if (tech instanceof MiscTechnology) {
			return new MiscDetailsGrid((MiscTechnology)tech, fullName);
        }
        return null;
    }
}