/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.battle;

import mot.client.swing.buttons.MotButton;
import mot.client.swing.window.battle.actions.MotBattleMapActions;
import mot.client.swing.window.galaxy.actions.ShortcutListener;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public abstract class BattleActionButton extends MotButton implements MotBattleMapActions, ShortcutListener {

	protected BattleWindowListener listener;
	protected BattleWindowState state;
	protected BattleWindowView view;
	
	private Character shortcut;
	
	protected BattleActionButton(BattleWindowListener listener, Character shortcut) {
		this.listener = listener;
		this.state = listener.getState();
		this.view = listener.getView();
		this.shortcut = shortcut;
		
		if (shortcut != null) {
			listener.addShortcutLisneter(this);
		}
		setTip(shortcut);
	}

	public void setTip(Character shortcut) {
		String t = _getToolTipText();
		if (t != null) {			
			if (shortcut != null) {
				setToolTipText("<html>" + t + "<br/>"+L.EXPRESS_KEY_+shortcut+"</html>");
			} else {
				setToolTipText("<html>"+t+"</html>");
			}
		}
	}
	
	/*
	 * Return a string containing the tool tip text for this button.
	 */
	protected abstract String _getToolTipText();

	public boolean keyPressed(char key, int modifiers) {
		if (shortcut != null && shortcut.charValue() == key) {
			actionPerformed(null);
	        return true;
		} else {
			return false;
		}
	}
	
	public Character getShortcutKey() {
		return shortcut;
	}
	
	protected void _doAction() throws ApplicationError, ValidationError {
		if (listener.isShowingAnimations()) {
			throw new ValidationError(L.INVALID_COMMAND_BUSY);
		}
        listener.paused = false;
        state.setUserSelected(false);
        __doAction();
	}
	
	protected abstract void __doAction() throws ApplicationError, ValidationError;

	public Character getShortcut() {
		return shortcut;
	}

}
