/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.battle;

import mot.client.deligates.BattleObjectDelegate;
import mot.client.deligates.ImageObjectDelegate;
import mot.client.proxy.CompletedCallback;
import mot.common.technology.Weapon;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class BattleObjectCommandCallback implements CompletedCallback {

	private BattleWindowListener listener;
	private BattleObjectDelegate selectedObject;
	private ImageObjectDelegate target;
	private boolean updateMouseOverInfo;

	public BattleObjectCommandCallback(BattleWindowListener listener, BattleObjectDelegate selectedObject, ImageObjectDelegate target, boolean updateMouseOverInfo) {
		this.listener = listener;
		this.selectedObject = selectedObject;
		this.target = target;
		this.updateMouseOverInfo = updateMouseOverInfo;
	}
	
	@Override
	public void complete(Object result) throws ApplicationError, ValidationError {
		BattleWindowView view = listener.getView();
		BattleWindowState state = listener.getState();
        Weapon weapon = view.getSelectWeaponPanel().getWeapon();
        int qtyToFire = view.getSelectWeaponPanel().getQty();
		boolean stopped = (result != null) && (result instanceof Boolean) && (Boolean)result;
		listener.moveToNextMode(selectedObject, weapon, target, stopped);
		view.updateWeaponSelect(selectedObject);
		if (updateMouseOverInfo) {
			listener.calculateMouseOverInformation();
		} else {
			state.clearMouseOverInformation();
		}
        view.getMapWindow().repaint();
	}

}
