/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.battle;

import java.awt.Dimension;

import javax.swing.JPanel;

import mot.client.animation.AnimationContainer;
import mot.client.animation.BattleAnimationList;
import mot.client.deligates.BattleDelegate;
import mot.client.deligates.PlayerDelegate;
import mot.client.swing.window.main.MainWindowConfig;
import mot.client.swing.window.main.MainWindowView;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;
import mot.test.TestBase;

public class BattleWindowConfig implements MainWindowConfig, AnimationContainer {

	private static final String NAME = "BattleWindowConfig";
	
	/**
	 * This is the listener of this configuration.
	 */
	private BattleWindowListener listener;
	
	/**
	 * This is the view of this configuration.
	 */
	private BattleWindowView view;
	
    public BattleWindowConfig() throws ApplicationError {
    	listener = new BattleWindowListener();
    	view = new BattleWindowView(listener);
    }
    
    public BattleWindowConfig(TestBase test) throws ApplicationError {
    }
    
    public void setOwner(String owner) {
    	if (listener != null) listener.setOwner(owner);
    }

    public void activate() throws ApplicationError {
    	throw new ApplicationError("USE WITH PARAM BATTLE DELIGATE!");
    }
    
    public void activate(BattleDelegate battle) throws ApplicationError, ValidationError {
    	view.activate();
    	listener.flushScale();
    	listener.setBattle(battle);
    	listener.next();
    }
    
    public void deactivate() throws ApplicationError {
    	view.deactivate();
    }
    
    public void handleTick() throws ApplicationError, ValidationError {
        listener.handleTick();
        view.handleTick();
    }

	public String getName() { return NAME; }

	public BattleWindowListener getListener() {
		return listener;
	}

	public void setListener(BattleWindowListener listener) {
		this.listener = listener;
	}

	public BattleWindowView getBattleView() {
		return view;
	}

	public MainWindowView getView() {
		return view;
	}
	public void setBattleView(BattleWindowView view) {
		this.view = view;
	}

    public JPanel getMainPanel() {
    	return view.getMapWindow();
    }
	
	public Dimension getMainPanelSize() {
		return view.getMapPanelScrollPane().getSize();
	}

	//
	// Animation Container Methods
	//
	
	public BattleAnimationList getAnimations() {
		return listener.getState().getAnimations();
	}

	public boolean isEndBattleRecieved() {
		return listener.isEndBattleRecieved();
	}

	public PlayerDelegate getOwnerOfActiveAnimation() throws ApplicationError {
		return listener.getState().getOwnerOfActiveAnimation();
	}

}
