/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.battle;

import java.awt.Color;
import java.awt.Dimension;

import javax.swing.JButton;
import javax.swing.JProgressBar;
import javax.swing.JToggleButton;
import javax.swing.SwingConstants;

import mot.client.deligates.BattleObjectDelegate;
import mot.client.deligates.ImageObjectDelegate;
import mot.client.swing.common.ComponentTable;
import mot.client.swing.panels.SelectWeaponPanel;
import mot.client.swing.window.battle.actions.ActionCompleteBattle;
import mot.client.swing.window.battle.actions.ActionEndTurn;
import mot.client.swing.window.battle.actions.ActionLaunchFighters;
import mot.client.swing.window.battle.actions.ActionMode;
import mot.client.swing.window.battle.actions.ActionNextCraft;
import mot.client.swing.window.battle.actions.ActionRetreat;
import mot.client.swing.window.battle.actions.ActionWait;
import mot.client.swing.window.battle.actions.MissileDefenceMode;
import mot.client.swing.window.battle.actions.MotBattleMapActions;
import mot.client.swing.window.main.MotListener;
import mot.common.bean.GameConstants;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.PropertyManager;

public class BattleWindowControlPanel extends ComponentTable implements MotBattleMapActions {

    private JButton nextCraftButton;
    private JButton endTurnButton;
    private JButton retreatButton;
    private JButton launchFightersButton;
    private JButton waitButton;
    private JButton completeButton;
    
    private ActionMode expressButton;
    private MissileDefenceMode missileDefence;
    
    private JToggleButton autoButton;

    private SelectWeaponPanel selectWeaponPanel;
    private JProgressBar turnField;

    public BattleWindowControlPanel(MotListener listener) throws ApplicationError {
		super("HVS,HVS", 1, 2, 2, 2, 2);

        nextCraftButton = new ActionNextCraft((BattleWindowListener)listener);
        endTurnButton = new ActionEndTurn((BattleWindowListener)listener);
        retreatButton = new ActionRetreat((BattleWindowListener)listener);
        launchFightersButton = new ActionLaunchFighters((BattleWindowListener)listener);
        waitButton = new ActionWait((BattleWindowListener)listener);
        completeButton = new ActionCompleteBattle((BattleWindowListener)listener);
        expressButton = new ActionMode((BattleWindowListener)listener);
        missileDefence = new MissileDefenceMode((BattleWindowListener)listener);
        
        autoButton = new JToggleButton(AUTO_BUTTON_TEXT);
        
        selectWeaponPanel = new SelectWeaponPanel(null);

		red = PropertyManager.getMandatoryAsColor("window.main.endturn_busy.background");
		normal = launchFightersButton.getBackground();
		
        turnField = new JProgressBar(SwingConstants.HORIZONTAL, 0, GameConstants.MAX_BATTLE_TURNS);
        turnField.setString(L.TURNS);
        turnField.setPreferredSize(new Dimension(40, 20));
        launchFightersButton.setOpaque(true);

        ComponentTable buttonPanel = new ComponentTable("HV,HV,HV,HV,HV", 2, 5, 0, 2, 2);
        buttonPanel.setGridWidths("0.2,0.2,0.2,0.2,0.2");
        buttonPanel.setGridHeights("0.5,0.5");

        buttonPanel.add( nextCraftButton );
        buttonPanel.add( endTurnButton );
        buttonPanel.add( waitButton );
        buttonPanel.add( launchFightersButton );
        buttonPanel.add( retreatButton );

        buttonPanel.add( expressButton );
        buttonPanel.add( autoButton );
        buttonPanel.add( completeButton );
        buttonPanel.add( missileDefence );
        buttonPanel.add(turnField);
        
        setGridWidths("700,300");
        add( buttonPanel );
        add( selectWeaponPanel );
        
        //addKeyListener(listener);
        //endTurnButton.addKeyListener(listener);
        //nextCraftButton.addKeyListener(listener);
        //expressButton.addKeyListener(listener);
        //autoButton.addKeyListener(listener);
        //waitButton.addKeyListener(listener);
        //selectWeaponPanel.addKeyListener(listener);

        //PanelUtils.setTheBloodySize(selectWeaponPanel, 125, 40);
        //PanelUtils.setTheBloodySize(this, 600, 90);
    }

    public void updateWeaponSelect(ImageObjectDelegate io) throws ApplicationError {
        if (io != null && io instanceof BattleObjectDelegate) {
            selectWeaponPanel.update((BattleObjectDelegate)io);
        } else {
            selectWeaponPanel.update((BattleObjectDelegate)null);
        }
    }

    public void setTurn(int v) {
        turnField.setValue(v);
    }

	public JToggleButton getAutoButton() {
		return autoButton;
	}

	public MissileDefenceMode getMissileDefenceButton() {
		return missileDefence;
	}

	public void setAutoButton(JToggleButton autoButton) {
		this.autoButton = autoButton;
	}

	public ActionMode getModeButton() {
		return expressButton;
	}

	public SelectWeaponPanel getSelectWeaponPanel() {
		return selectWeaponPanel;
	}

	public void setSelectWeaponPanel(SelectWeaponPanel selectWeaponPanel) {
		this.selectWeaponPanel = selectWeaponPanel;
	}

	private int counter = 0;
	private Color red;
	private Color normal;
	public void handleTick(boolean selectedCraftHasFightersToLaunch) {
		if (counter%6==0 && selectedCraftHasFightersToLaunch) {
			if ((counter/6)%2 == 0) {
				launchFightersButton.setBackground(red);
			} else {
				launchFightersButton.setBackground(normal);
			}
		} if (!selectedCraftHasFightersToLaunch) {
			if (launchFightersButton.getBackground() != normal) {
				launchFightersButton.setBackground(normal);
			}
		} else {
			counter++;
		}
	}
    
}
