/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.battle;

import java.awt.Color;
import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.Graphics2D;

import javax.swing.JPanel;

import mot.common.util.ApplicationError;
import mot.common.util.PropertyManager;

/**
 * Display a health par showing damage that a selected battle object
 * has sustained. There are several types;
 * 	Physical Damage
 * 	Movement Damage
 * 	Psi Damage
 * 	Crew Damage
 */
public class DamagePanel extends JPanel {
	/**
	 * This is the color of the health bar. Different colors are used to dipict
	 * different types of damage. See AnimationSettings for details.
	 */
	private Color damageColor;
	
	/**
	 * This is a value between 0.0 and 1.0 where 1.0 is 100% damage (maximum).
	 * It represents the total damage on this object of this type!
	 */
	private double damage;
	
	private boolean hasBorder = false;
	
	private String label = null;

	public DamagePanel(Color color, double damage) {
		this.damageColor = color;
		this.damage = damage;
	}

	public DamagePanel(Color color, double damage, boolean hasBorder, String label) throws ApplicationError {
		this.damageColor = color;
		this.damage = damage;
		this.hasBorder = hasBorder;
		this.label = label;
		setBackground(PropertyManager.getMandatoryAsColor("panel.damage.background.color"));
		setForeground(PropertyManager.getMandatoryAsColor("panel.damage.border.color"));
	}

	public Color getDamageColor() {
		return damageColor;
	}

	public void setDamageColor(Color color) {
		this.damageColor = color;
	}

	public double getDamage() {
		return damage;
	}

	public void setDamage(double value) {
		this.damage = value;
		repaint();
	}

	public void paint(Graphics g) {
		//super.paint(g);
		Graphics2D graphics = (Graphics2D) g;
		Dimension size = getSize();
		int height = size.height;
		int width = size.width;
		int left = 0;
		int top = 0;
		if (hasBorder) {
	        graphics.setColor(getForeground());
			graphics.drawRect(left, top, width-1, height-1);
			left++;
			top++;
			width -= 2;
			height -= 2;
		}
		int boundary = (int)(width*damage); 
        graphics.setColor(damageColor);
        graphics.fillRect(left, top, boundary, height);
        graphics.setColor(getBackground());
        graphics.fillRect(left+boundary, top, width-boundary, height);
        if (label != null) {
        	graphics.setColor(Color.WHITE);
        	graphics.drawString(label, 3, height-3);
        }
	}

	public String getLabel() {
		return label;
	}

	public void setLabel(String label) {
		this.label = label;
	}
	
	
	
}
