/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.battle;

import mot.client.deligates.ImageObjectDelegate;
import mot.client.proxy.CompletedCallback;
import mot.common.bean.Location;
import mot.common.bean.LocationAndDirection;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class FetchCraftMoveActualLocationCommandCallback implements CompletedCallback {

	private BattleWindowListener listener;
	private ImageObjectDelegate selection;
	private Location mouseLocation;
	private ImageObjectDelegate mouseOverObject;

	public FetchCraftMoveActualLocationCommandCallback(BattleWindowListener listener, ImageObjectDelegate selection, Location mouseLocation, ImageObjectDelegate mouseOverObject) {
		this.listener = listener;
		this.selection = selection;
		this.mouseLocation = mouseLocation;
		this.mouseOverObject = mouseOverObject;
	}
	
	@Override
	public void complete(Object result) throws ApplicationError, ValidationError {
		LocationAndDirection actualLocation = (LocationAndDirection) result;
		BattleWindowView view = listener.getView();
		BattleWindowState state = listener.getState();
		state.setMouseOverActualDest(actualLocation);
		listener.updateCursor(selection, mouseLocation, mouseOverObject);
	}

}
