/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.battle.actions;

import mot.client.deligates.BattleDelegate;
import mot.client.deligates.BattleObjectDelegate;
import mot.client.deligates.ImageObjectDelegate;
import mot.client.proxy.CompletedCallback;
import mot.client.proxy.ProxyStore;
import mot.client.swing.panels.SelectWeaponPanel;
import mot.client.swing.window.battle.BattleActionButton;
import mot.client.swing.window.battle.BattleWindowListener;
import mot.common.technology.Weapon;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class ActionEndTurn extends BattleActionButton implements CompletedCallback {

	public ActionEndTurn(BattleWindowListener listener) {
		super(listener, 't');
		setText(END_BATTLE_TURN_BUTTON_TEXT);

	}

	protected void __doAction() throws ApplicationError, ValidationError {
		ImageObjectDelegate selected = state.getSelected();
        if (selected != null && selected instanceof BattleObjectDelegate) {
        	BattleDelegate battle = listener.getBattle();
        	BattleObjectDelegate bo = (BattleObjectDelegate)selected;
        	if (listener.isMove()) {
				ProxyStore.getInstance().battleEndTurnCmd(battle, bo, true, false, null, -1, this, this);
        	} else if (listener.isAttack()) {
        		SelectWeaponPanel swp = listener.getView().getControlPanel().getSelectWeaponPanel();
        		Weapon weapon = swp.getWeapon();
        		int qtyWeapons = swp.getQty();
        		ProxyStore.getInstance().battleEndTurnCmd(battle, bo, false, true, weapon, qtyWeapons, this, this);
        	} else {
        		ProxyStore.getInstance().battleEndTurnCmd(battle, bo, true, true, null, -1, this, this);
        	}
        }
	}

	protected String _getToolTipText() {
		return "End the turn of selected object.<br/>If on express mode all movement and weapons are ended and this turn is over for this object.<br/>If mode is move then all movement is complete but weapons are not discharged.<br/>If mode is attack then all weapons are discharged but remaining movement is not effected.<br/>If all movement is finished and all weapons discharged then control moves to the next object in this battle.";
	}

	@Override
	public void complete(Object result) throws ApplicationError, ValidationError {
		ImageObjectDelegate selected = state.getSelected();
        if (selected != null && selected instanceof BattleObjectDelegate) {
	    	if (listener.isCraftWithMoveRemaining(selected) || listener.hasWeaponsToFire((BattleObjectDelegate) selected)) {
	    		view.updateWeaponSelect(selected);
	        	listener.selectModeFor(selected);
	    	} else {
	    		listener.next();
	    	}
	        view.getMapWindow().repaint();
        }
	}

}
