/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.battle.actions;

import mot.client.proxy.CompletedCallback;
import mot.client.proxy.ProxyStore;
import mot.client.swing.window.battle.BattleActionButton;
import mot.client.swing.window.battle.BattleWindowListener;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class ActionNextCraft extends BattleActionButton implements CompletedCallback {

	public ActionNextCraft(BattleWindowListener listener) {
		super(listener, 'n');
		setText(NEXT_CRAFT_BUTTON_TEXT);
	}

	protected void __doAction() throws ApplicationError, ValidationError {
		ProxyStore.getInstance().battleGetNextObject(listener.getBattle(), this, this);
	}

	protected String _getToolTipText() {
		return "Select the next object to move in this battle.<br/>Crafts move in order of their initiative (calculated using the craft's speed and manoeuvrability + bonuses).<br/>You can manually select the next craft and move it providing no un-moved enemy craft has higher initiative than your selection.";
	}

	@Override
	public void complete(Object result) throws ApplicationError, ValidationError {
        listener.next();
        view.getMapWindow().repaint();
	}

}
