/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.battle.actions;

import mot.client.deligates.BattleDelegate;
import mot.client.deligates.BattleObjectDelegate;
import mot.client.deligates.ImageObjectDelegate;
import mot.client.proxy.CompletedCallback;
import mot.client.proxy.ProxyStore;
import mot.client.swing.window.battle.BattleActionButton;
import mot.client.swing.window.battle.BattleWindowListener;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class ActionRetreat extends BattleActionButton implements CompletedCallback {

	public ActionRetreat(BattleWindowListener listener) {
		super(listener, 'r');
		setText(RETREAT_BUTTON_TEXT);
	}

	protected void __doAction() throws ApplicationError, ValidationError {
		ImageObjectDelegate selected = state.getSelected();
        if (selected != null && selected instanceof BattleObjectDelegate) {
            BattleDelegate battle = listener.getBattle();
            ProxyStore.getInstance().battleRetreatCmd(battle, (BattleObjectDelegate)selected, this, this);
        }
	}

	@Override
	public void complete(Object result) throws ApplicationError, ValidationError {
        listener.autoSelectNext();
        view.getMapWindow().repaint();
	}
	
	protected String _getToolTipText() {
		return "Retreat the selected object from this battle (craft will no longer take part in the battle).<br/>Craft that retreat in the last turn of a battle that you have lost are routed (they do not have time to get away).";
	}

}
