/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.battle.actions;

import java.awt.Color;

import mot.client.swing.window.battle.BattleActionButton;
import mot.client.swing.window.battle.BattleWindowListener;
import mot.common.util.ApplicationError;
import mot.common.util.PropertyManager;
import mot.common.util.ValidationError;

public class MissileDefenceMode extends BattleActionButton {

	private static Color colorOn;
	private static Color colorOff;
	
	private boolean on = true;
	
	public MissileDefenceMode(BattleWindowListener listener) {
		super(listener, ' ');
		if (colorOn == null) {
			colorOn = getBackground();
			colorOff = PropertyManager.getMandatoryAsColorNoError("window.background.color.medium");
		}
		update();
	}

	protected void __doAction() throws ApplicationError, ValidationError {
		on = !on;
		update();
	}

	private void update() {
		if (on) {
			setText(MISSILE_DEFENCE_ON);
			if (colorOn != null) setBackground(colorOn);
		} else {
			setText(MISSILE_DEFENCE_OFF);
			if (colorOff != null) setBackground(colorOff);
		} 
		
	}

	protected String _getToolTipText() {
		return "Select Missile Defence Mode - If 'On' the computer will automatically fire missile defence weapons on your behalf";
	}
	public void setTip(Character shortcut) {
		String t = _getToolTipText();
		if (t != null) {			
			setToolTipText("<html>"+t+"</html>");
		}
	}

	public boolean isOn() {
		return on;
	}

}
