/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.common;

import java.awt.Dimension;

import javax.swing.JLabel;
import javax.swing.SwingConstants;
import javax.swing.plaf.basic.BasicInternalFrameUI;

import mot.client.deligates.UserPlayerDelegate;
import mot.client.swing.common.ComponentTable;
import mot.client.swing.common.MotBorder;
import mot.client.swing.common.MotLabel;
import mot.common.lang.L;
import mot.common.util.ApplicationError;

/**
 * Displays a dialog box containing a message.
 * It has no buttons or functionality.
 * It is intended for displaying messages like "Wait....." or "Processing....."
 */
public class MessageWindow extends MotInternalWindow {

	private String message;

    private static final Dimension SIZE = new Dimension(250, 50);

    public MessageWindow(UserPlayerDelegate player, MotInternalWindow parent, String message) throws ApplicationError {
        super(player, parent, L.MESSAGE, SIZE);

    	BasicInternalFrameUI ui = (BasicInternalFrameUI)getUI();
    	ui.setNorthPane(null);
    	setBorder(null);
        
        this.message = message;
        
		if (message != null) {
			JLabel label = new MotLabel(message, 8, null, null, SwingConstants.CENTER, true);
			//PanelUtils.setTheBloodySize(label, new Size(220,40));
			ComponentTable border = new ComponentTable("HV", 1, 1, 3, 0, 0);
			border.add(label);
			getContentPane().add(new MotBorder(border));
		}
		
        show();
    }

}

