/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.common;

import java.awt.AWTEvent;
import java.awt.ActiveEvent;
import java.awt.Component;
import java.awt.MenuComponent;
import java.awt.Toolkit;
import java.awt.event.MouseEvent;

import javax.swing.SwingUtilities;

import mot.common.util.ApplicationError;
import mot.common.util.Logger;

public class MotEventProcessor {

	public static void processNextMessage() {
		try {
			long start1 = Logger.TRACE_ON ? System.currentTimeMillis() : 0;
			AWTEvent event = Toolkit.getDefaultToolkit().getSystemEventQueue().getNextEvent();
			long end1 = Logger.TRACE_ON ? System.currentTimeMillis() : 0;
			long start2 = end1;
			Object source = event.getSource();
			if (event instanceof ActiveEvent) {
				((ActiveEvent)event).dispatch();
			} else if (source instanceof Component) {
				((Component)source).dispatchEvent(event);
			} else if (source instanceof MenuComponent) {
				((MenuComponent)source).dispatchEvent(event);
			} else {
				Logger.logError("Unable to process : "+event.getClass(), new ApplicationError());
			}
			if (Logger.TRACE_ON) {
				long end2 = System.currentTimeMillis();
				Logger.logDebug("Process ["+(end1-start1)+"->"+(end2-start2)+"] : "+event.getClass());
			}
		} catch (InterruptedException e) {
			// Nothing...
		}
	}
	
    public static void processNextMessageModel(MotInternalWindow win) {
        try {
            AWTEvent event = Toolkit.getDefaultToolkit().getSystemEventQueue().getNextEvent();
            Object source = event.getSource();
            boolean dispatch = true;

            if (event instanceof MouseEvent) {
                MouseEvent e = (MouseEvent) event;
                MouseEvent m = SwingUtilities.convertMouseEvent((Component) e.getSource(), e, win);
                if (!win.contains(m.getPoint()) && e.getID() != MouseEvent.MOUSE_DRAGGED) {
                    dispatch = false;
                }
            }

            if (dispatch) {
                if (event instanceof ActiveEvent) {
                    ((ActiveEvent) event).dispatch();
                } else if (source instanceof Component) {
                    ((Component) source).dispatchEvent(event);
                } else if (source instanceof MenuComponent) {
                    ((MenuComponent) source).dispatchEvent(event);
                } else {
                    Logger.logDebug("Unable to dispatch: " + event);
                }
            } else {
                //Logger.logDebug("Ignore " + event);
            }
        } catch (InterruptedException ignored) {
        }

    }
    

}
