/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.common;

import java.awt.BorderLayout;
import java.awt.Dimension;

import javax.swing.JPanel;
import javax.swing.JTextField;

import mot.client.swing.common.ComponentTable;
import mot.client.swing.common.PanelUtils;
import mot.client.swing.config.ImageConfig;
import mot.client.swing.config.ImageConfigFactory;
import mot.client.swing.panels.ImagePanel;
import mot.client.swing.window.common.actions.MotInputDialogOKButton;
import mot.common.bean.Size;
import mot.common.util.ApplicationError;

public class MotInputDialogPopup extends MotInternalWindow {

	private static Dimension INPUT_SIZE = new Dimension(200,20);
	private static Dimension SIZE = new Dimension(600,100);
	
	private JTextField inputField;
	
	protected MotInputDialogPopup(MotInternalWindow parent, String msg, String title, String initialValue) throws ApplicationError {
		super(null, parent, title, SIZE);
		
    	msg = "<HTML>" + msg.replaceAll("\\n", "<br>");
		
    	inputField = new JTextField();
    	inputField.setPreferredSize(INPUT_SIZE);
    	if (initialValue != null) {
    		inputField.setText(initialValue);
    	}
    	
		ImageConfig imageConfig = ImageConfigFactory.getInstance().getImageConfig("InputImage");
		String imageName = (imageConfig == null) ? "input.gif" : imageConfig.getImage();
		Size imageSize = (imageConfig == null) ? new Size(50,50) : imageConfig.getImageSize();
    	ImagePanel imagePanel = new ImagePanel(imageName);
    	PanelUtils.setTheBloodySize(imagePanel, imageSize);
		
    	ComponentTable controlTable = new ComponentTable("HVP,R,-", 1,3, 0,10,0);
    	controlTable.add(new JPanel());
    	controlTable.add(inputField);
    	MotInputDialogOKButton okButton = new MotInputDialogOKButton(this);
		controlTable.add(okButton);
    	ComponentTable contents = new ComponentTable("HV", 2,1, 5,0,2);
    	contents.add(msg, "R");
    	contents.add(controlTable);
    	ComponentTable main = new ComponentTable("-,HVSP", 1,2, 0,5,0);
    	main.add(imagePanel);
    	main.add(contents);
		
		getContentPane().add(main, BorderLayout.CENTER);
		
		show();
		inputField.requestFocus();
		getRootPane().setDefaultButton(okButton);
    	waitUntilClosed();
	}
	
	
	public boolean processKeyEventsGlobally() {
		return false;
	}
	
	public String getText() {
		if (inputField != null) {
			return inputField.getText();
		} else {
			return null;
		}
	}
}
