/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.common;

import java.awt.BorderLayout;
import java.awt.Dimension;

import javax.swing.JComboBox;

import mot.client.swing.common.ComponentTable;
import mot.client.swing.common.PanelUtils;
import mot.client.swing.config.ImageConfig;
import mot.client.swing.config.ImageConfigFactory;
import mot.client.swing.panels.ImagePanel;
import mot.client.swing.window.common.actions.CloseButton;
import mot.common.bean.Size;
import mot.common.lang.L;
import mot.common.util.ApplicationError;

public class MotSelectionDialog extends MotInternalWindow {

	private static Dimension SIZE = new Dimension(600,100);

	public static String show(String msg, String title, String [] values, String defaultValue, MotInternalWindow parent) throws ApplicationError {
		MotSelectionDialog win = new MotSelectionDialog(msg, title, values, defaultValue, parent);
		win.waitUntilClosed();
		String r = win.getSelection();
        return r;
	}
	
	public String getSelection() {
		return (String) combo.getSelectedItem();
	}

	private JComboBox combo;
	
	protected MotSelectionDialog(String msg, String title, String [] values, String defaultValue, MotInternalWindow parent) throws ApplicationError {
		super(null, parent, title, SIZE);
		
    	msg = "<HTML>" + msg.replaceAll("\n", "<br>");

		ImageConfig imageConfig = ImageConfigFactory.getInstance().getImageConfig("QuestionImage");
		String imageName = (imageConfig == null) ? "question.gif" : imageConfig.getImage();
		Size imageSize = (imageConfig == null) ? new Size(50,50) : imageConfig.getImageSize();
    	ImagePanel imagePanel = new ImagePanel(imageName);
    	PanelUtils.setTheBloodySize(imagePanel, imageSize);
		
    	combo = new JComboBox(values);
    	combo.setSelectedItem(defaultValue);
    	
    	ComponentTable controlTable = new ComponentTable("HSP,L", 1,2, 5,5,0);
    	controlTable.add(combo);
    	controlTable.add(new CloseButton(L.CLOSE, this));
    	
    	ComponentTable contents = new ComponentTable("-,HVSP", 2,2, 0,10,1);
		contents.add(imagePanel, "a");
    	contents.add(msg);
    	contents.add(controlTable);
		
		getContentPane().add(contents, BorderLayout.CENTER);
		
		show();
	}
	
}
