/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.common;

import java.awt.BorderLayout;
import java.awt.Dimension;

import mot.client.swing.buttons.MotButton;
import mot.client.swing.common.ComponentTable;
import mot.client.swing.common.PanelUtils;
import mot.client.swing.config.ImageConfig;
import mot.client.swing.config.ImageConfigFactory;
import mot.client.swing.panels.ImagePanel;
import mot.common.bean.Size;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class MotShowMessageDialogPopup extends MotInternalWindow {

	private static Dimension SIZE = new Dimension(600,100);
	
	protected MotShowMessageDialogPopup(MotInternalWindow parent, String msg, String title) throws ApplicationError {
		super(null, parent, title, SIZE);
		
    	msg = "<HTML>" + msg.replaceAll("\n", "<br>");

		ImageConfig imageConfig = ImageConfigFactory.getInstance().getImageConfig("QuestionImage");
		String imageName = (imageConfig == null) ? "input.png" : imageConfig.getImage();
		Size imageSize = (imageConfig == null) ? new Size(50,50) : imageConfig.getImageSize();
    	ImagePanel imagePanel = new ImagePanel(imageName);
    	PanelUtils.setTheBloodySize(imagePanel, imageSize);
		
    	MotConfirmationDialogButtonOK okButton = new MotConfirmationDialogButtonOK(this);
    	ComponentTable contents = new ComponentTable("-,HVSP,-", 1,10, 0,10,5);
		contents.add(imagePanel);
    	contents.add(msg);
    	contents.add(okButton);
		
		getContentPane().add(contents, BorderLayout.CENTER);
		getRootPane().setDefaultButton(okButton);
	}
	
}

class MotConfirmationDialogButtonOK extends MotButton {

	private MotShowMessageDialogPopup window;
	
	public MotConfirmationDialogButtonOK(MotShowMessageDialogPopup window) {
		this.window = window;
		setText("OK");
	}

	protected void _doAction() throws ApplicationError, ValidationError {
		window.hide();
	}

}


