/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.common;

import java.awt.Dimension;
import java.awt.Rectangle;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.ArrayList;
import java.util.Iterator;

import javax.swing.JButton;
import javax.swing.JComboBox;
import javax.swing.JLabel;

import mot.client.deligates.UserPlayerDelegate;
import mot.common.technology.Technologies;
import mot.common.technology.Technology;
import mot.common.technology.TechnologyList;
import mot.common.util.ApplicationError;
import mot.common.util.Comp;
import mot.common.util.Logger;

public class SelectTechByTypeWindow extends MotInternalWindow implements ActionListener {
    private JComboBox typeComboBox = new JComboBox();
    private JComboBox listComboBox = new JComboBox();
    private JButton cancelButton = new JButton();
    private JButton closeButton = new JButton();

    private static final Dimension SIZE = new Dimension(249, 159);
    private static final String title = "Select Technology Window";
    
    /**
     * This is the selection made is any from this dialog box
     */
    public Technology selection;
    private boolean all;

    public SelectTechByTypeWindow(MotInternalWindow parent, ArrayList techTypeList, UserPlayerDelegate player, Technology selection, boolean all) throws ApplicationError {
        super(player, parent, title, SIZE);
        this.all = all;
        setup(techTypeList, selection);
    }
    
    public void setup(ArrayList techTypeList, Technology selection) throws ApplicationError {
        this.selection = selection;

        this.getContentPane().setLayout(null);
        typeComboBox.setBounds(new Rectangle(5, 15, 230, 20));
        JLabel jLabel1 = new JLabel();
        jLabel1.setText("Technology Type");
        jLabel1.setFont(mot.client.swing.common.LocalDefaults.font);
        jLabel1.setBounds(new Rectangle(5, 0, 175, 14));
        JLabel jLabel2 = new JLabel();
        jLabel2.setText("Technolog Names");
        jLabel2.setFont(mot.client.swing.common.LocalDefaults.font);
        jLabel2.setBounds(new Rectangle(5, 45, 175, 15));
        listComboBox.setBounds(new Rectangle(5, 60, 230, 20));
        cancelButton.setText(" Cancel ");
        cancelButton.setFont(mot.client.swing.common.LocalDefaults.font);
        cancelButton.setBounds(new Rectangle(25, 95, 85, 25));
        cancelButton.setActionCommand("Cancel");
        closeButton.setText(" Select ");
        closeButton.setFont(mot.client.swing.common.LocalDefaults.font);
        closeButton.setBounds(new Rectangle(135, 95, 85, 25));
        closeButton.setActionCommand("Close");
        this.getContentPane().add(closeButton, null);
        this.getContentPane().add(cancelButton, null);
        this.getContentPane().add(listComboBox, null);
        this.getContentPane().add(jLabel2, null);
        this.getContentPane().add(jLabel1, null);
        this.getContentPane().add(typeComboBox, null);
        
        if (techTypeList == null) {
            techTypeList = getBuiltOnCraftTechTypeList();
        }
        
        Iterator i = techTypeList.iterator();
        typeComboBox.addItem("");
        while (i.hasNext()) {
            String name = (String) i.next();
            typeComboBox.addItem(name);
        }
        
        if (selection != null) {
            typeComboBox.setSelectedItem(selection.getTechType());
            changeListChange();
        }

        closeButton.addActionListener(this);
        cancelButton.addActionListener(this);
        typeComboBox.addActionListener(this);
    }
    
    public static final ArrayList getBuiltOnCraftTechTypeList() {
        ArrayList techTypeList = new ArrayList();
        techTypeList.add(mot.common.technology.Technologies.TECH_TYPE_HULL);
        techTypeList.add(mot.common.technology.Technologies.TECH_TYPE_COMPUTER);
        techTypeList.add(mot.common.technology.Technologies.TECH_TYPE_WEAPON);
        techTypeList.add(mot.common.technology.Technologies.TECH_TYPE_SHIELD);
        techTypeList.add(mot.common.technology.Technologies.TECH_TYPE_SCANNER);
        techTypeList.add(mot.common.technology.Technologies.TECH_TYPE_SPECIAL);
        techTypeList.add(mot.common.technology.Technologies.TECH_TYPE_ENGINE);
        return techTypeList;
    }

    public static final ArrayList getBuiltOnPlanetTechTypeList() {
        ArrayList techTypeList = new ArrayList();
        techTypeList.add(mot.common.technology.Technologies.TECH_TYPE_FACTORY);
        techTypeList.add(mot.common.technology.Technologies.TECH_TYPE_LABORATORY);
        techTypeList.add(mot.common.technology.Technologies.TECH_TYPE_BIOTECHNOLOGY);
        return techTypeList;
    }

    public static final ArrayList getAllTechTypeList() {
        ArrayList techTypeList = new ArrayList();
        techTypeList.add(mot.common.technology.Technologies.TECH_TYPE_FACTORY);
        techTypeList.add(mot.common.technology.Technologies.TECH_TYPE_LABORATORY);
        techTypeList.add(mot.common.technology.Technologies.TECH_TYPE_BIOTECHNOLOGY);
        techTypeList.add(mot.common.technology.Technologies.TECH_TYPE_HULL);
        techTypeList.add(mot.common.technology.Technologies.TECH_TYPE_COMPUTER);
        techTypeList.add(mot.common.technology.Technologies.TECH_TYPE_WEAPON);
        techTypeList.add(mot.common.technology.Technologies.TECH_TYPE_SHIELD);
        techTypeList.add(mot.common.technology.Technologies.TECH_TYPE_SCANNER);
        techTypeList.add(mot.common.technology.Technologies.TECH_TYPE_SPECIAL);
        techTypeList.add(mot.common.technology.Technologies.TECH_TYPE_ENGINE);
        techTypeList.add(mot.common.technology.Technologies.TECH_TYPE_MISC);
        techTypeList.add(mot.common.technology.Technologies.TECH_TYPE_MODULE);
        techTypeList.add(mot.common.technology.Technologies.TECH_TYPE_HUMANITIES);
        return techTypeList;
    }

    public void actionPerformed(ActionEvent e) {
        if (Logger.isDebug()) {
            Logger.logDebug("SelectTechByTypeWindow.actionPerformed() Action="+e.getActionCommand());
        }
        try {
            doActionPerformed(e);
        } catch (ApplicationError ex) {
            Logger.logError("", ex);
        }
    }
    
    public void doActionPerformed(ActionEvent e) throws ApplicationError {
        if (Comp.same(e.getActionCommand(), "Close")) {
            String techType = (String) typeComboBox.getSelectedItem();
            String techName = (String) listComboBox.getSelectedItem();
            if (Logger.isDebug()) {
                Logger.logDebug("SelectTechByTypeWindow.actionPerformed() Close techType="+techType+" techName="+techName);
            }
            if (techType != null && techName != null) {
                try {
                    selection = mot.common.technology.Technologies.getTechnology(techType, techName);
                } catch (ApplicationError err) {
                    Logger.logError("Failed techType="+techType+" techName="+techName, err);
                }
            }
            this.hide();
        } else if (Comp.same(e.getActionCommand(), "Cancel")) {
            selection = null;
            this.hide();
        } else if (Comp.same(e.getActionCommand(), "comboBoxChanged")) {
            changeListChange();
        }
    }

    /**
     * The tech type list has changed value
     * Set the technology list to be the list of techs discovered by this player
     */
    private void changeListChange() throws ApplicationError {
        String techType = (String) typeComboBox.getSelectedItem();
        if (all) {
        	if (Comp.same(techType, mot.common.technology.Technologies.TECH_TYPE_FACTORY)) {
        		setupList(Technologies.getFactories());
        	} else if (Comp.same(techType, mot.common.technology.Technologies.TECH_TYPE_LABORATORY)) {
        		setupList(Technologies.getLaboratories());
        	} else if (Comp.same(techType, mot.common.technology.Technologies.TECH_TYPE_BIOTECHNOLOGY)) {
        		setupList(Technologies.getBiotechnologies());
        	} else if (Comp.same(techType, mot.common.technology.Technologies.TECH_TYPE_HULL)) {
        		setupList(Technologies.getHulls());
        	} else if (Comp.same(techType, mot.common.technology.Technologies.TECH_TYPE_COMPUTER)) {
        		setupList(Technologies.getComputers());
        	} else if (Comp.same(techType, mot.common.technology.Technologies.TECH_TYPE_WEAPON)) {
        		setupList(Technologies.getWeapons());
        	} else if (Comp.same(techType, mot.common.technology.Technologies.TECH_TYPE_SHIELD)) {
        		setupList(Technologies.getShields());
        	} else if (Comp.same(techType, mot.common.technology.Technologies.TECH_TYPE_SCANNER)) {
        		setupList(Technologies.getScanners());
        	} else if (Comp.same(techType, mot.common.technology.Technologies.TECH_TYPE_SPECIAL)) {
        		setupList(Technologies.getSpecials());
        	} else if (Comp.same(techType, mot.common.technology.Technologies.TECH_TYPE_ENGINE)) {
        		setupList(Technologies.getEngines());
        	} else if (Comp.same(techType, mot.common.technology.Technologies.TECH_TYPE_MODULE)) {
        		setupList(Technologies.getModules());
        	} else if (Comp.same(techType, mot.common.technology.Technologies.TECH_TYPE_MISC)) {
        		setupList(Technologies.getMiscTechnologies());
        	}
        } else {
        	if (Comp.same(techType, mot.common.technology.Technologies.TECH_TYPE_FACTORY)) {
        		setupList(owner.getFactories());
        	} else if (Comp.same(techType, mot.common.technology.Technologies.TECH_TYPE_LABORATORY)) {
        		setupList(owner.getLaboratories());
        	} else if (Comp.same(techType, mot.common.technology.Technologies.TECH_TYPE_BIOTECHNOLOGY)) {
        		setupList(owner.getBiotechnologies());
        	} else if (Comp.same(techType, mot.common.technology.Technologies.TECH_TYPE_HULL)) {
        		setupList(owner.getHulls());
        	} else if (Comp.same(techType, mot.common.technology.Technologies.TECH_TYPE_COMPUTER)) {
        		setupList(owner.getComputers());
        	} else if (Comp.same(techType, mot.common.technology.Technologies.TECH_TYPE_WEAPON)) {
        		setupList(owner.getWeapons());
        	} else if (Comp.same(techType, mot.common.technology.Technologies.TECH_TYPE_SHIELD)) {
        		setupList(owner.getShields());
        	} else if (Comp.same(techType, mot.common.technology.Technologies.TECH_TYPE_SCANNER)) {
        		setupList(owner.getScanners());
        	} else if (Comp.same(techType, mot.common.technology.Technologies.TECH_TYPE_SPECIAL)) {
        		setupList(owner.getSpecials());
        	} else if (Comp.same(techType, mot.common.technology.Technologies.TECH_TYPE_ENGINE)) {
        		setupList(owner.getEngines());
        	} else if (Comp.same(techType, mot.common.technology.Technologies.TECH_TYPE_MODULE)) {
        		setupList(Technologies.getModules());
        	} else if (Comp.same(techType, mot.common.technology.Technologies.TECH_TYPE_MISC)) {
        		setupList(Technologies.getMiscTechnologies());
        	}
        }
    }
    
    private void setupList(TechnologyList list) {
        listComboBox.removeAllItems();
        if (list == null) {
            return;
        }
        setupList(list.getAllAsArray(true));
    }
    
    private void setupList(TechnologyList list, String group) {
        listComboBox.removeAllItems();
        if (list == null || group == null) {
            return;
        }
        setupList(list.getAllWithGroup(group));
    }
    
    private void setupList(Technology[] techs) {
        for (int i=0; i<techs.length; i++) {
            listComboBox.addItem(techs[i].getName());
        }
    }

	public Technology getSelection() {
		return selection;
	}
}