/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.common;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.FlowLayout;

import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.SwingConstants;

import mot.client.swing.buttons.MotClickTechnologyLabelAction;
import mot.client.swing.common.ComponentTable;
import mot.client.swing.common.DefaultButtonListener;
import mot.client.swing.common.MotLabel;
import mot.client.swing.common.PanelUtils;
import mot.client.swing.lists.FakeTechnologyLabelList;
import mot.client.swing.renderers.CellRendererTechnologyLabel;
import mot.client.swing.window.common.actions.CloseButton;
import mot.common.bean.Size;
import mot.common.technology.Technology;
import mot.common.technology.TechnologyList;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class SelectTechnologyWindow extends MotInternalWindow {
	private String message;
    private Technology technology = null;

    private FakeTechnologyLabelList technologyList;
    private JScrollPane technologyListScrolePane;

    private static final Dimension SIZE = new Dimension(250, 400);
    private static final String TITLE = "Select Technology Window";
    
    public SelectTechnologyWindow(MotInternalWindow parent, TechnologyList available, boolean useFullname) throws ApplicationError {
        super(null, parent, TITLE, SIZE);
        MotClickTechnologyLabelAction selectListener = new MotClickTechnologyLabelAction() {
			protected void selectTechnology(Technology t) throws ApplicationError, ValidationError {
				technology = t;
				hide();
			}
        };
        technologyList = new FakeTechnologyLabelList(available, null, new CellRendererTechnologyLabel(false, true, false, new Size(30,30), true, 2, false, null, null, true, selectListener, null, null));
        technologyListScrolePane = new JScrollPane(technologyList, JScrollPane.VERTICAL_SCROLLBAR_ALWAYS, JScrollPane.HORIZONTAL_SCROLLBAR_AS_NEEDED);
        init();
    }

    public void init() {
        JPanel buttonPanel = new JPanel(new FlowLayout(FlowLayout.CENTER));
        CloseButton closeButton = new CloseButton(this);
		buttonPanel.add(closeButton);
		if (message != null) {
			JLabel label = new MotLabel(message, 0, null, null, SwingConstants.CENTER, false);
			PanelUtils.setTheBloodySize(label, new Size(220,40));
			ComponentTable border = new ComponentTable("HV", 1, 1, 3, 0, 0);
			border.add(label);
			getContentPane().add(border, BorderLayout.NORTH);
		}
        getContentPane().add(buttonPanel, BorderLayout.SOUTH);
        getContentPane().add(technologyListScrolePane);
		addKeyListener(	new DefaultButtonListener(closeButton) );
		technologyList.addKeyListener(	new DefaultButtonListener(closeButton) );
		technologyListScrolePane.addKeyListener(	new DefaultButtonListener(closeButton) );

        show();
        waitUntilClosed();
    }

	public Technology getTechnology() {
		return technology;
	}

}