/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.common;

import java.awt.Dimension;
import java.awt.Toolkit;
import java.awt.Window;

import javax.swing.JComponent;
import javax.swing.JInternalFrame;

import mot.client.swing.window.main.MainWindow;
import mot.common.util.ApplicationError;

public class WindowLocator  {

    public static void setCenter(Window frame) {
        Dimension screenSize = Toolkit.getDefaultToolkit().getScreenSize();
        Dimension size = frame.getSize();
        screenSize.height = screenSize.height/2;
        screenSize.width = screenSize.width/2;
        size.height = size.height/2;
        size.width = size.width/2;
        int y = screenSize.height - size.height;
        int x = screenSize.width - size.width;
        frame.setLocation(x, y);
    }

    public static void setCenter(JComponent frame) throws ApplicationError {
        MainWindow mainWindow = MainWindow.getInstance();
//        mainWindow.doLayout();
		Dimension screenSize = mainWindow.getActiveConfiguration().getMainPanelSize();
//        screenSize.width -= (int)(screenSize.width*0.25);
//        screenSize.height -= (int)(screenSize.height*0.1);
        Dimension size = frame.getSize();
//        screenSize.height = screenSize.height/2;
//        screenSize.width = screenSize.width/2;
//        size.height = (int)(size.height/1.5);
//        size.width = size.width/2;
        int y = (screenSize.height - size.height)/2;
        int x = (screenSize.width - size.width)/2;
        frame.setLocation(x, y);
    }

    public static void setDefault(Window frame) {
        Dimension screenSize = Toolkit.getDefaultToolkit().getScreenSize();
        Dimension size = frame.getSize();
        screenSize.height = screenSize.height/4;
        screenSize.width = screenSize.width/4;
        size.height = size.height/2;
        size.width = size.width/2;
        int y = screenSize.height - size.height;
        int x = screenSize.width - size.width;
        if (y < 0) y = 0;
        if (x < 0) x = 0;
        frame.setLocation(x, y);
    }

    public static void setDefault(JInternalFrame frame) throws ApplicationError {
        Dimension screenSize = MainWindow.getInstance().getContentPane().getSize();
        Dimension size = frame.getSize();
        screenSize.height = screenSize.height/4;
        screenSize.width = screenSize.width/4;
        size.height = size.height/2;
        size.width = size.width/2;
        int y = screenSize.height - size.height;
        int x = screenSize.width - size.width;
        if (y < 0) y = 0;
        if (x < 0) x = 0;
        frame.setLocation(x, y);
    }

    public static void setCenterOfParent(Window frame, Window parent) throws ApplicationError {
        if (parent == null) {
        	parent = MainWindow.getInstance().getWindow();
        } else if (parent.getSize().getWidth() < frame.getSize().getWidth()) {
    		parent = MainWindow.getInstance().getWindow();
    	}
        int x = (int) parent.getLocationOnScreen().getX();
        int y = (int) parent.getLocationOnScreen().getY();
        int xpos = x + ((int)parent.getSize().getWidth() - (int)frame.getSize().getWidth())/2;
        int ypos = y + ((int)parent.getSize().getHeight() - (int)frame.getSize().getHeight())/3;
        frame.setLocation(xpos, ypos);
    }
    
    public static void setCenterOfParent(JInternalFrame frame, Window parent) throws ApplicationError {
        if (parent == null) {
        	parent = MainWindow.getInstance().getWindow();
        } else if (parent.getSize().getWidth() < frame.getSize().getWidth()) {
    		parent = MainWindow.getInstance().getWindow();
    	}
        int x = (int) parent.getLocationOnScreen().getX();
        int y = (int) parent.getLocationOnScreen().getY();
        int xpos = x + ((int)parent.getSize().getWidth() - (int)frame.getSize().getWidth())/2;
        int ypos = y + ((int)parent.getSize().getHeight() - (int)frame.getSize().getHeight())/3;
        frame.setLocation(xpos, ypos);
    }
    
    public static void setCenterOfParent(JInternalFrame frame, JInternalFrame parent) throws ApplicationError {
        int x = (int) parent.getLocationOnScreen().getX();
        int y = (int) parent.getLocationOnScreen().getY();
        int xpos = x + ((int)parent.getSize().getWidth() - (int)frame.getSize().getWidth())/2;
        int ypos = y + ((int)parent.getSize().getHeight() - (int)frame.getSize().getHeight())/3;
        frame.setLocation(xpos, ypos);
    }
    
    public static void setToParent(Window frame, Window parent) {
        if (parent == null) {
            setDefault(frame);
        } else {
            int x = (int) parent.getLocationOnScreen().getX();
            int y = (int) parent.getLocationOnScreen().getY();
            //int width = parent.getWidth();
            x += 10;
            y += 10;
            frame.setLocation(x, y);
        }
    }

    public static void setToParent(JInternalFrame frame, Window parent) throws ApplicationError {
        setDefault(frame);
    }

    public static void setToParent(JInternalFrame frame, JInternalFrame parent) throws ApplicationError  {
        if (parent == null) {
            setDefault(frame);
        } else {
            int x = (int) parent.getLocation().getX();
            int y = (int) parent.getLocation().getY();
            //int width = parent.getWidth();
            x += 10;
            y += 10;
            frame.setLocation(x, y);
        }
    }
}