/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.craft;

import java.awt.Color;

import javax.swing.JLabel;

import mot.client.deligates.CraftDelegate;
import mot.client.swing.common.ComponentTable;
import mot.client.swing.common.MotLabel;
import mot.client.swing.panels.DamageBarPanel;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.Formatter;
import mot.common.util.PropertyManager;

public class BuildQualityPanel extends ComponentTable{

	private DamageBarPanel damageBarPanel;
	private MotLabel label;

	public BuildQualityPanel(Color textColour) throws ApplicationError {
		super("HV", 2, 1, 3, 0, 2);
		
		label = new MotLabel("", JLabel.CENTER);
		label.setForeground(textColour);
		damageBarPanel = new DamageBarPanel(0.0, 12, PropertyManager.getMandatoryAsColor("buildqualitybar.color"), Color.GRAY);
		
		add(label);
		add(damageBarPanel);
		
        setToolTipText(L.TT_BUILD_QUALITY);
	}

	public void setContent(CraftDelegate craft) throws ApplicationError {
		double buildQualityAsPercent = craft.getBuildQualityAsPercent();
		setContent(buildQualityAsPercent);
	}

	public void setContent(double buildQualityAsPercent) {
		String text = L.BUILD_QUALITY + ": " + Formatter.whole(buildQualityAsPercent * 100) + "%";
		label.setText(text);
		damageBarPanel.setDamagePercent(1.0-buildQualityAsPercent);
		repaint();
	}
}
