/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.craft;

import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;

import mot.client.swing.buttons.MotAction;
import mot.client.swing.window.main.MotAWTMouseListener;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

/**
 * This class is defined purely to get around the JScrollPane throwing away mouse Clicks inside the JViewPort.
 * This listener is added the the
 * mot.client.swing.window.main.MotAWTMouseListener
 * which listens to the AWT Main Event loop getting ALL mouse events.
 * 
 * Therefore we need to determine which mouse events we are actually interested in by matching them to the component.
 */
public class CraftDesignGlobalMouseListener extends MouseAdapter {

	private TechnologyTypeSelectionListener techTypeListener;
	private CraftDesignWindow craftDesignWindow;

	public CraftDesignGlobalMouseListener(TechnologyTypeSelectionListener techTypeListener, CraftDesignWindow craftDesignWindow) {
		this.techTypeListener = techTypeListener;
		this.craftDesignWindow = craftDesignWindow;
	}

	private MouseEvent me;
	public void mouseClicked(MouseEvent e) {
		if (!craftDesignWindow.isShowing()) {
			removeListener();
			return;
		}
		me = e;
		new MotAction() {
			protected void _doAction() throws ApplicationError, ValidationError {
				CraftDesignPicturePanel picturePanel = craftDesignWindow.getCraftDesignPanel().getPicturePanel();
				picturePanel.handleGlobalMouseClick(me, techTypeListener);
			}
		}.runAction();
	}

	public void removeListener() {
		MotAWTMouseListener.removeListener(this);
	}

}
