/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.craft;

import javax.swing.JScrollPane;

import mot.client.deligates.CraftDelegate;
import mot.client.deligates.PlayerDelegate;
import mot.client.deligates.UserPlayerDelegate;
import mot.client.proxy.ProxyStore;
import mot.client.swing.common.ComponentTable;
import mot.client.swing.labels.TechnologyLabelClickListener;
import mot.client.swing.renderers.ListItemControlPanelListener;
import mot.common.bean.CraftDesignStatistics;
import mot.common.designs.CraftDesign;
import mot.common.technology.TechnologyBundle;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class CraftDesignPanel extends ComponentTable {

	private CraftDesignPicturePanel picturePanel;
	private CraftDesignStatsPanel statsPanel;
    
    public CraftDesignPanel(UserPlayerDelegate owner, PlayerDelegate craftOwner, PlayerDelegate craftOrigin, CraftDesign cd, CraftDesignStatistics cdStats, TechnologyLabelClickListener listener, TechnologyTypeSelectionListener techTypeListener, ListItemControlPanelListener craftDesignerWindow, CraftDelegate craft) throws ApplicationError, ValidationError {
    	super("HV", 2,1, 0,0,0);
    	picturePanel = new CraftDesignPicturePanel(owner, craftOrigin, cd, cdStats, listener, techTypeListener, craftDesignerWindow, craft, true, true, true);
    	statsPanel = new CraftDesignStatsPanel(owner, craftOwner, craftOrigin, cd, cdStats);
    	setGridHeights("100,800");
    	add(statsPanel);
    	add(picturePanel);
        _fetchDesignStats(craftOwner, craftOrigin, cd);
    }
    
	private void _fetchDesignStats(PlayerDelegate craftOwner, PlayerDelegate craftOrigin, CraftDesign cd) throws ApplicationError, ValidationError {
		if (cd != null) {
			CraftDesignStatsFetchComplete callback = new CraftDesignStatsFetchComplete(cd, this, craftOwner, craftOrigin);
	        ProxyStore.getInstance().getCraftDesignStatistics(cd, craftOwner, craftOrigin, callback, null);
		}
	}

    public void updateDesign(CraftDesign cd, CraftDesignStatistics cdStats, PlayerDelegate craftOwner, PlayerDelegate craftOrigin) throws ApplicationError, ValidationError {
    	picturePanel.setDesign(cd, craftOrigin, cdStats);
    	if (cdStats != null) {
    		statsPanel.setDesign(cd, craftOwner, craftOrigin, cdStats);
    	} else {
    		_fetchDesignStats(craftOwner, craftOrigin, cd);
    	}
    }
    
    public void setDesign(CraftDesign cd, CraftDesignStatistics cdStats, PlayerDelegate craftOwner, PlayerDelegate craftOrigin) throws ApplicationError {
    	picturePanel.setDesign(cd, craftOrigin, cdStats);
    	statsPanel.setDesign(cd, craftOwner, craftOrigin, cdStats);
    }

    public void setSalvage(TechnologyBundle[] salvage) throws ApplicationError {
    	picturePanel.setSalvage(salvage);
    }
    
	public CraftDesignPicturePanel getPicturePanel() {
		return picturePanel;
	}

    private JScrollPane scrollPanel;
    public JScrollPane getScrollPane() {
        if (scrollPanel == null) {
            scrollPanel = new JScrollPane(this, JScrollPane.VERTICAL_SCROLLBAR_AS_NEEDED, JScrollPane.HORIZONTAL_SCROLLBAR_AS_NEEDED);
        }
        return scrollPanel;
    }


}