/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.craft;

import java.awt.BorderLayout;
import java.awt.FlowLayout;

import javax.swing.BorderFactory;
import javax.swing.JPanel;
import javax.swing.border.EtchedBorder;

import mot.client.deligates.CraftDelegate;
import mot.client.deligates.UserPlayerDelegate;
import mot.client.swing.window.common.MotInternalWindow;
import mot.client.swing.window.common.actions.CloseButton;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class CraftDetailsWindow extends MotInternalWindow {

    private CraftDelegate craft;


    public CraftDetailsWindow(MotInternalWindow parent, UserPlayerDelegate owner, CraftDelegate craft) throws ApplicationError, ValidationError {
        super(owner, parent, L.TITLE+craft.getName()+" [ "+craft.getOwner()+" ]", null);
        setup(craft);
    }

    public void setup(CraftDelegate craft) throws ApplicationError {
        this.craft = craft;

        try {
            jbInit();
        } catch(Exception e) {
            e.printStackTrace();
        }

        show();
    }

    private void jbInit() throws Exception {
        CraftDesignPanel infoPanel = new CraftDesignPanel(owner, craft.getOwnerDelegate(), craft.getOriginDelegate(), craft.getCraftDesign(), null, null, null, null, craft);
        infoPanel.setBorder(BorderFactory.createEtchedBorder(EtchedBorder.LOWERED));

        JPanel buttonPanel = new JPanel();
        buttonPanel.setLayout(new FlowLayout(FlowLayout.CENTER));
        buttonPanel.add(new CloseButton(this), null);

        getContentPane().add(addTitleBar(infoPanel));
        getContentPane().add(buttonPanel, BorderLayout.SOUTH);
    }

}