/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.craft;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.Image;
import java.awt.Point;

import javax.swing.BoxLayout;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.SwingConstants;

import mot.client.deligates.CraftDelegate;
import mot.client.deligates.MoveableOwnedObjectDelegate;
import mot.client.deligates.UserPlayerDelegate;
import mot.client.swing.window.common.MotDialog;
import mot.client.swing.window.common.MotFrame;
import mot.common.bean.Size;
import mot.common.util.ApplicationError;
import mot.common.util.Logger;

public class CraftImageWindow extends MotDialog  {

    private static CraftImageWindow instance = null;
    
    public static CraftImageWindow getInstance(UserPlayerDelegate owner, MotFrame parent) throws ApplicationError {
        if (instance == null) {
            instance = new CraftImageWindow(owner, parent);
        }
        return instance;
    }

    private static final String EMPTY_LABEL = "--";
    private JLabel infoLabel = new JLabel(EMPTY_LABEL);
    
    private CraftImageWindow(UserPlayerDelegate owner, MotFrame parent) throws ApplicationError {
        super(owner, parent, "");
        setModal(false);
        try {
            jbInit();
        } catch(Exception e) {
            e.printStackTrace();
        }
        
        JPanel infoPanel = new JPanel();
        infoPanel.setLayout(new BoxLayout(infoPanel, BoxLayout.X_AXIS));
        infoPanel.add(infoLabel);
        
        CraftImageWindow.MainContentPane contentWin = new CraftImageWindow.MainContentPane(this);
        contentWin.setOpaque(true);
        getContentPane().add(contentWin, BorderLayout.CENTER);
        getContentPane().add(infoPanel, BorderLayout.SOUTH);
        getContentPane().setBackground(Color.BLACK);
        Point plos = parent.getLocationOnScreen();
        Dimension pdim = parent.getSize();
        setLocation((int)(plos.getX() + pdim.getWidth()/2), (int)plos.getY());
        infoLabel.setHorizontalAlignment(SwingConstants.CENTER);
    }
    
    private void jbInit() throws Exception {
        this.setSize(new Dimension(100, 120));
        this.setResizable(false);
        this.setEnabled(true);
        this.setBackground(Color.BLACK);
    }

    private class MainContentPane extends JPanel {
        private CraftImageWindow win;
        public MainContentPane(CraftImageWindow win) { this.win = win; setBackground(Color.BLACK); }
        public void paint(Graphics g) { super.paint(g); win.painContent(g); }    
    };
    
    private MoveableOwnedObjectDelegate craft = null;
    
    public void setCraft(CraftDelegate c) throws ApplicationError {
        if (c != null) {
            craft = c;
            infoLabel.setText("Craft "+c.getName());
            setTitle(c.getOwner());
            instance.setVisible(true);
            instance.repaint();
        } else {
            craft = null;
            instance.hide();
        }
    }

    public void painContent(Graphics g) {
        if (Logger.isDebug()) {
            Logger.logDebug("CraftImageWindow.painContent() Paint the main window ");
        }
        
        try {
            draw((Graphics2D)g);
        } catch (Exception e) {
            Logger.logError("CraftImageWindow.painContent() Failed due to error ",e);
        }
    }
    
    private void draw(Graphics2D graphics) throws ApplicationError {
        if (craft != null) {
            Dimension d = getContentPane().getSize();
            Size s = craft.getImageSize();
            graphics.setBackground(Color.BLACK);
            Image image = mot.client.swing.common.ImageCache.getImage(getToolkit(), craft.getImage());
            int dx = (int) d.getWidth() - s.getX();
            int dy = (int) d.getHeight() - s.getY();
            graphics.drawImage(image, dx/2, dy/2, s.getX(), s.getY(), this);
        }
    }

}