/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.craft;

import javax.swing.JLabel;
import javax.swing.JPanel;

import mot.client.deligates.MoveableOwnedObjectDelegate;
import mot.client.swing.common.ComponentTable;
import mot.client.swing.common.MotLabel;
import mot.client.swing.common.PadPanel;
import mot.client.swing.panels.MooImagePanel;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.vo.NavigatorVO;

public class CraftListPanel extends ComponentTable {

	private MoveableOwnedObjectDelegate craft;

	public CraftListPanel(MoveableOwnedObjectDelegate craft, CraftListWindow parent) throws ApplicationError {
		super("HV,HVP,HV,HV", 1, 4, 0, 5, 2);
		this.craft = craft;
		
		NavigatorVO navigator = craft.getNavigator();
		
		String name = null;
		if (navigator != null) {
			name = craft.getName() + " " + L.HEADING_TO_ + navigator.getDestination() + " [ETA " + navigator.getEta()+"]";
		} else if (craft.getOrbit() != null){
			name = craft.getName() + L.AT + craft.getOrbit().getName();
		}
		String description = craft.getDescription(1, false, false);
    	JPanel craftIcon = new MooImagePanel(craft, true, null);
		MotLabel nameLabel = new MotLabel(name, 3, JLabel.LEFT, true);
		MotLabel descriptionLabel = new MotLabel(description, 0, JLabel.LEFT, false);
		nameLabel.setOpaque(false);
		descriptionLabel.setOpaque(false);
		
		ComponentTable infoPanel = new ComponentTable("HVP", 4, 1, 0, 0, 2);
		JPanel padPanel1 = new JPanel();
		JPanel padPanel2 = new JPanel();
		padPanel1.setOpaque(false);
		padPanel2.setOpaque(false);
		infoPanel.add(padPanel1, "HVSP");
		infoPanel.add(nameLabel);
		infoPanel.add(descriptionLabel, "HVP");
		infoPanel.add(padPanel2, "HVSP");
		infoPanel.setOpaque(false);
		
		JPanel buttonPanel = parent.createCraftButtonPanel(craft, null);
		
		add(craftIcon);
		add(infoPanel);
		add(buttonPanel);
		add(new PadPanel(3));
	}

	public MoveableOwnedObjectDelegate getCraft() {
		return craft;
	}

}
