/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.craft;

import java.awt.BorderLayout;
import java.awt.Color;

import javax.swing.JPanel;

import mot.client.deligates.FleetDelegate;
import mot.client.deligates.MoveableOwnedObjectDelegate;
import mot.client.deligates.UserPlayerDelegate;
import mot.client.swing.common.ActionClose;
import mot.client.swing.lists.FakePanelList;
import mot.client.swing.lists.FakePanelListClickListener;
import mot.client.swing.window.common.MotInternalWindow;
import mot.client.swing.window.craft.actions.RenameFleetButton;
import mot.client.swing.window.galaxy.GalaxyWindowListener;
import mot.client.swing.window.main.MainWindow;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public abstract class CraftListWindow extends MotInternalWindow implements FakePanelListClickListener {

    private FakePanelList craftsPanel;

    public CraftListWindow(String title, UserPlayerDelegate owner, MoveableOwnedObjectDelegate[] crafts) throws ApplicationError, ValidationError {
        this(title, (MotInternalWindow)null, owner, crafts, null);
    }

    public CraftListWindow(String title, MotInternalWindow parent, UserPlayerDelegate owner, MoveableOwnedObjectDelegate[] crafts, FleetDelegate fleet) throws ApplicationError {
        super(owner, parent, title, null);

        craftsPanel = new FakePanelList(this, true);
        setContent(crafts);

        JPanel buttonPanel = new JPanel();
        buttonPanel.add(new ActionClose(this), null);
        if (fleet != null) {
        	buttonPanel.add(new RenameFleetButton(this, fleet));
        }

    	getContentPane().add(addTitleBar(craftsPanel.getScrollPane()), null);
        getContentPane().add(buttonPanel, BorderLayout.SOUTH);
        
        show();
    }

	public void setContent(MoveableOwnedObjectDelegate[] crafts) throws ApplicationError {
		if (crafts == null) {
			craftsPanel.setContent(null);
		} else {
			CraftListPanel [] panels = new CraftListPanel[crafts.length];
			for (int i = 0; i < panels.length; i++) {
				panels[i] = new CraftListPanel(crafts[i], this);
			}
			craftsPanel.setContent(panels);
		}
	}
    
	
	public void click(JPanel listItem) throws ApplicationError, ValidationError {
		if (listItem instanceof CraftListPanel) {
			MoveableOwnedObjectDelegate moo = ((CraftListPanel)listItem).getCraft();
			GalaxyWindowListener listener = MainWindow.getExestingInstance().getGalaxyMapListener();
			listener.openCraftDetailsWindow(this, moo, false);
		}
	}
    
    protected abstract JPanel createCraftButtonPanel(MoveableOwnedObjectDelegate craft, Color background) throws ApplicationError;

}
