/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.craft;

import java.awt.Color;

import javax.swing.JButton;
import javax.swing.JPanel;

import mot.client.deligates.CraftDelegate;
import mot.client.deligates.FleetDelegate;
import mot.client.deligates.MoveableOwnedObjectDelegate;
import mot.client.deligates.UserPlayerDelegate;
import mot.client.swing.common.ComponentTable;
import mot.client.swing.window.common.MotInternalWindow;
import mot.client.swing.window.craft.actions.CraftActionLeaveFleet;
import mot.client.swing.window.craft.actions.CraftActionOpenCraftDetailsWindow;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class FleetDetailsWindow extends CraftListWindow {

	private static boolean withRemove = true;

    private FleetDelegate fleet;

    public FleetDetailsWindow(UserPlayerDelegate owner, FleetDelegate fleet) throws ApplicationError, ValidationError {
        this((MotInternalWindow)null, owner, fleet);
    }

    public FleetDetailsWindow(MotInternalWindow parent, UserPlayerDelegate owner, FleetDelegate fleet) throws ApplicationError, ValidationError {
        super(getTitle(fleet), parent, owner, fleet.getCrafts(), fleet);
        this.fleet = fleet;
    }
    
    public static String getTitle(FleetDelegate fleet) throws ApplicationError {
    	return L.FLEET_DETAILS+" "+fleet.getName()+" [ "+fleet.getOwner()+" ]";
    }
    
    protected JPanel createCraftButtonPanel(MoveableOwnedObjectDelegate craft, Color background) throws ApplicationError {
        if (!(craft instanceof CraftDelegate)) {
        	return new JPanel();
        }
        
        CraftDelegate c = (CraftDelegate) craft;
    	int qty = 1;
    	
        JButton detailsButton = new CraftActionOpenCraftDetailsWindow(this, c);

        if (!(craft instanceof CraftDelegate)) withRemove = false;
        if (withRemove) {
            qty++;
        }

        ComponentTable buttonPanel = new ComponentTable("HSP", qty,1, 0, 2,2);
        buttonPanel.add(detailsButton);
        
        if (withRemove) {
            JButton leaveButton = new CraftActionLeaveFleet(this, c.getFleetDelegate(), c);
            buttonPanel.add(leaveButton);
        }
        
        if (background != null) {
        	buttonPanel.setBackground(background);
        	buttonPanel.setOpaque(true);
        } else {
        	buttonPanel.setOpaque(false);
        }
        
        return buttonPanel;
    }

}