/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.craft;

import java.awt.FlowLayout;

import javax.swing.JLabel;
import javax.swing.JPanel;

import mot.client.deligates.StellarObjectOrbitalDelegate;
import mot.client.swing.common.ComponentTable;
import mot.client.swing.common.PanelUtils;
import mot.client.swing.panels.StationAnimationPanel;
import mot.client.swing.window.common.MotInternalWindow;
import mot.common.lang.L;
import mot.common.technology.Scanner;
import mot.common.util.ApplicationError;

public class OutpostPanel extends ComponentTable {

	private StationAnimationPanel stationPanel;

	public OutpostPanel(MotInternalWindow container, StellarObjectOrbitalDelegate outpost) throws ApplicationError {
		super("HV",2,1,0,0,0);
        Scanner scanner = outpost.getOrbital().getScannerTech();
        if (scanner != null) {
            add( createTitleLabel(L.OUTPOST_SCAN+scanner.getStrength()) );
        }
        stationPanel = new StationAnimationPanel(container, outpost.getOwner(), outpost.getOrbital());
        PanelUtils.setTheBloodySize(stationPanel, 40, 40);
        add(stationPanel,"CV");
    }

    private JPanel createTitleLabel(String text) {
        JLabel label = PanelUtils.createLabel(text);
        JPanel panel = new JPanel(new FlowLayout(FlowLayout.LEFT,0,0));
        panel.add(label);
        panel.setOpaque(true);
        return panel;
    }
    
	public void handleTick() throws ApplicationError {
		if (stationPanel != null) {
			stationPanel.handleTick();
		}
	}

}