/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.craft;

import java.awt.Color;

import javax.swing.JComponent;
import javax.swing.JPanel;

import mot.client.deligates.CraftDelegate;
import mot.client.deligates.FleetDelegate;
import mot.client.deligates.MoveableOwnedObjectDelegate;
import mot.client.deligates.UserPlayerDelegate;
import mot.client.swing.buttons.MotButton;
import mot.client.swing.common.ComponentTable;
import mot.client.swing.window.common.MotInternalWindow;
import mot.client.swing.window.craft.actions.CraftActionOpenCraftDetailsWindow;
import mot.client.swing.window.craft.actions.CraftActionOpenFleetWindow;
import mot.client.swing.window.galaxy.GalaxyWindowConfig;
import mot.client.swing.window.main.MainWindow;
import mot.common.bean.Rectangle;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;


public class PlayerFleetWindow extends CraftListWindow {

	public PlayerFleetWindow(MotInternalWindow parent, UserPlayerDelegate owner) throws ApplicationError {
        this(parent, owner, MainWindow.getInstance().getGalaxyMapListener().getCrafts(owner, true));
    }

    public PlayerFleetWindow(MotInternalWindow parent, UserPlayerDelegate owner, MoveableOwnedObjectDelegate [] crafts) throws ApplicationError {
        super(L.FLEET_DETAILS+" [ "+owner.getName()+" ]", parent, owner, crafts, null);
    }

    protected JPanel createCraftButtonPanel(MoveableOwnedObjectDelegate craft, Color background) throws ApplicationError {
    	int qty = 2;
    	
        JComponent detailsButton = null;
        if (craft instanceof CraftDelegate) {
        	detailsButton =  new CraftActionOpenCraftDetailsWindow(this, (CraftDelegate)craft);
        } else if (craft instanceof FleetDelegate) {
        	detailsButton =  new CraftActionOpenFleetWindow(this, (FleetDelegate)craft);
        } else {
        	detailsButton =  new JPanel();
        }

        MotButton gotoCraftButton = new GotoCraftButton(craft, this);
        
        ComponentTable buttonPanel = new ComponentTable("HSP", qty,1, 0, 2,2);
        buttonPanel.add(detailsButton);
        buttonPanel.add(gotoCraftButton);
        
        if (background != null) {
        	buttonPanel.setBackground(background);
        	buttonPanel.setOpaque(true);
        } else {
        	buttonPanel.setOpaque(false);
        }
        
        return buttonPanel;
    }

}

class GotoCraftButton extends MotButton {
	private MoveableOwnedObjectDelegate craft;
	private MotInternalWindow parent;

	public GotoCraftButton(MoveableOwnedObjectDelegate craft, MotInternalWindow parent) {
		super(L.GOTO);
		this.craft = craft;
		this.parent = parent;
	}
	
	protected void _doAction() throws ApplicationError, ValidationError {
		MainWindow mainWin = MainWindow.getInstance();
		GalaxyWindowConfig gmc = mainWin.getGalaxyMapConfiguration();
		gmc.getGalaxyView().deactivateDesktopPane();
		Rectangle rect = new Rectangle(craft.getLocation(), 10);
		gmc.getListener().focusOn(craft);
		gmc.getGalaxyView().getMapPanel().setSelection(craft);
	}
};
