/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.craft;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.FlowLayout;

import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.SwingConstants;

import mot.client.deligates.CraftDelegate;
import mot.client.deligates.MoveableOwnedObjectDelegate;
import mot.client.deligates.UserPlayerDelegate;
import mot.client.swing.common.ComponentTable;
import mot.client.swing.common.DefaultButtonListener;
import mot.client.swing.common.MotLabel;
import mot.client.swing.common.PanelUtils;
import mot.client.swing.lists.FakeMooList;
import mot.client.swing.lists.MooListOwner;
import mot.client.swing.window.common.MotInternalWindow;
import mot.client.swing.window.common.actions.CloseButton;
import mot.common.bean.Size;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class SelectCraftWindow extends MotInternalWindow {

	private String message;
    private CraftDelegate[] crafts;
    
    public CraftDelegate craft = null;

    private FakeMooList craftList;
    private JScrollPane craftListScrolePane;

    private static final Dimension SIZE = new Dimension(250, 400);


    /**
     * Displays a dialog box to view and edit Solar Systems
     * @throws ValidationError 
     */
    public SelectCraftWindow(UserPlayerDelegate player, MotInternalWindow parent, CraftDelegate[] crafts, String message) throws ApplicationError, ValidationError {
        super(player, parent, L.SELECT_A_CRAFT_TO_OFFER, SIZE);
        this.crafts = crafts;
        this.message = message;
        
        
        MooListOwner selectAction = new MooListOwner() {
			public void selectMoo(MoveableOwnedObjectDelegate moo) throws ApplicationError, ValidationError {
		        craft = (CraftDelegate) moo;
		        hide();
			}
			public void executeMoo(MoveableOwnedObjectDelegate moo) throws ApplicationError, ValidationError {
		        craft = (CraftDelegate) moo;
		        hide();
			}
			public void removeMoo(MoveableOwnedObjectDelegate moo) throws ApplicationError, ValidationError {
			}
        };
        craftList = new FakeMooList(selectAction);
        craftListScrolePane = new JScrollPane(craftList, JScrollPane.VERTICAL_SCROLLBAR_ALWAYS, JScrollPane.HORIZONTAL_SCROLLBAR_AS_NEEDED);
        
        init();
        setup();
    }

    private void init() {
        JPanel buttonPanel = new JPanel(new FlowLayout(FlowLayout.CENTER));
        CloseButton closeButton = new CloseButton(this);
		buttonPanel.add(closeButton);
		if (message != null) {
			JLabel label = new MotLabel(message, 0, null, null, SwingConstants.CENTER, false);
			PanelUtils.setTheBloodySize(label, new Size(220,40));
			ComponentTable border = new ComponentTable("HV", 1, 1, 3, 0, 0);
			border.add(label);
			getContentPane().add(border, BorderLayout.NORTH);
		}
        getContentPane().add(buttonPanel, BorderLayout.SOUTH);
        getContentPane().add(craftListScrolePane);
		addKeyListener(	new DefaultButtonListener(closeButton) );
		craftList.addKeyListener(	new DefaultButtonListener(closeButton) );
		craftListScrolePane.addKeyListener(	new DefaultButtonListener(closeButton) );
    }

    private void setup() throws ApplicationError, ValidationError {
        craftList.setMoos(crafts, null);
        show();
    }

}

