/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.craft;

import javax.swing.ButtonGroup;
import javax.swing.JLabel;
import javax.swing.JRadioButton;

import mot.client.swing.buttons.MotActionListener;
import mot.client.swing.common.ComponentTable;
import mot.client.swing.common.MotLabel;
import mot.client.swing.common.PanelUtils;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class TechnologyTypeSelectionPanel extends ComponentTable {

	private TechnologyTypeSelectionListener ttl;
	
	JRadioButton hull;
	JRadioButton engine;
	JRadioButton computer;
	JRadioButton scanner;
	JRadioButton weapons;
	JRadioButton shields;
	JRadioButton specials;
	
	public TechnologyTypeSelectionPanel(TechnologyTypeSelectionListener pttl) {
		super("TR", 8, 1, 0, 0, 3);
		this.ttl = pttl;

		MotActionListener selectHull = new MotActionListener() {
			public void _doAction() throws ApplicationError, ValidationError {
				ttl.selectHull();
			}
		};
		MotActionListener selectEngine = new MotActionListener() {
			public void _doAction() throws ApplicationError, ValidationError {
				ttl.selectEngine();
			}
		};
		MotActionListener selectComputer = new MotActionListener() {
			public void _doAction() throws ApplicationError, ValidationError {
				ttl.selectComputer();
			}
		};
		MotActionListener selectScanner = new MotActionListener() {
			public void _doAction() throws ApplicationError, ValidationError {
				ttl.selectScanner();
			}
		};
		MotActionListener selectShields = new MotActionListener() {
			public void _doAction() throws ApplicationError, ValidationError {
				ttl.selectShields();
			}
		};
		MotActionListener selectWeapons = new MotActionListener() {
			public void _doAction() throws ApplicationError, ValidationError {
				ttl.selectWeapons();
			}
		};
		MotActionListener selectSpecials = new MotActionListener() {
			public void _doAction() throws ApplicationError, ValidationError {
				ttl.selectSpecials();
			}
		};
		
		ButtonGroup bg = new ButtonGroup();
		hull = PanelUtils.createRadioButton(L.HULL, selectHull, bg, false);
		engine = PanelUtils.createRadioButton(L.ENGINE, selectEngine, bg, false);
		weapons = PanelUtils.createRadioButton(L.WEAPONS, selectWeapons, bg, false);
		shields = PanelUtils.createRadioButton(L.SHIELDS, selectShields, bg, false);
		scanner = PanelUtils.createRadioButton(L.SCANNER, selectScanner, bg, false);
		computer = PanelUtils.createRadioButton(L.COMPUTER, selectComputer, bg, false);
		specials = PanelUtils.createRadioButton(L.SPECIAL, selectSpecials, bg, false);
		
		hull.setToolTipText(L.TT_CRAFT_DESIGN_HULL);
		engine.setToolTipText(L.TT_CRAFT_DESIGN_ENGINES);
		computer.setToolTipText(L.TT_CRAFT_DESIGN_COMPUTERS);
        scanner.setToolTipText(L.TT_CRAFT_DESIGN_SCANNERS);
        weapons.setToolTipText(L.TT_CRAFT_DESIGN_WEAPONS);
        shields.setToolTipText(L.TT_CRAFT_DESIGN_SHIELDS);
        specials.setToolTipText(L.TT_CRAFT_DESIGN_SPECIALS);
		
		add( new MotLabel(L.EDIT_TYPE, JLabel.LEFT) );
		add( hull );
		add( engine );
		add( weapons );
		add( shields );
		add( scanner );
		add( computer );
		add( specials , "TRSP");
	}

	public void selectHull() throws ApplicationError, ValidationError {
		hull.setSelected(true);
	}
	public void selectEngine() throws ApplicationError, ValidationError {
		engine.setSelected(true);
	}
	public void selectComputer() throws ApplicationError, ValidationError {
		computer.setSelected(true);
	}
	public void selectScanner() throws ApplicationError, ValidationError {
		scanner.setSelected(true);
	}
	public void selectShields() throws ApplicationError, ValidationError {
		shields.setSelected(true);
	}
	public void selectSpecials() throws ApplicationError, ValidationError {
		specials.setSelected(true);
	}
	public void selectWeapons() throws ApplicationError, ValidationError {
		weapons.setSelected(true);
	}

}
