/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.craft.actions;

import java.util.ArrayList;

import mot.client.deligates.PlanetDelegate;
import mot.client.deligates.UserPlayerDelegate;
import mot.client.deligates.cache.DeligateCacheManager;
import mot.client.proxy.CompletedCallback;
import mot.client.proxy.ProxyStore;
import mot.client.swing.buttons.MotButton;
import mot.client.swing.lists.CraftDesignList;
import mot.client.swing.window.craft.CraftDesignsWindow;
import mot.client.swing.window.main.MainWindow;
import mot.common.designs.CraftDesign;
import mot.common.designs.ProjectDesign;
import mot.common.util.ApplicationError;
import mot.common.util.Comp;
import mot.common.util.ValidationError;

public class CloseAndUpdateAllCraftDesignButton extends MotButton implements CompletedCallback  {

	public static final String NAME = "Close Update Planets";

	private CraftDesignsWindow parent;
	private CraftDesignList craftDesignList;

	private CraftDesign design;
	
	public CloseAndUpdateAllCraftDesignButton(CraftDesignsWindow parent) {
		super(NAME);
		this.parent = parent;
		this.craftDesignList = parent.getCraftDesignList();
		
		setToolTipText("Close all windows and updates all planets building a craft with a design of this name");
	}

	protected void _doAction() throws ApplicationError, ValidationError {
		UserPlayerDelegate owner = parent.getOwner();
        design = parent.getSelectedCraftDesign();
        if (design != null) {
        	PlanetDelegate[] myPlanets = DeligateCacheManager.getPlanets(owner);
        	if  (myPlanets != null) {
        		ArrayList<PlanetDelegate> updateProjectList = null;
        		for (int i = 0; i < myPlanets.length; i++) {
					ProjectDesign project = myPlanets[i].getProjectDesign();
					if (project instanceof CraftDesign && Comp.same(((CraftDesign)project).getName(), design.getName())) {
						if (updateProjectList == null) updateProjectList = new ArrayList();
						updateProjectList.add(myPlanets[i]);
					}
				}
        		if (updateProjectList != null) {
        			PlanetDelegate[] pda = updateProjectList.toArray(new PlanetDelegate[updateProjectList.size()]);
        			ProxyStore.getInstance().setProjectCmd(pda, design, 0, false, this, this);						
        		} else {
        			parent.hide();
        		}
        	}
        }
	}
	
	@Override
	public void complete(Object result) throws ApplicationError, ValidationError {
        parent.hide();
        MainWindow.getInstance().getGalaxyMapConfiguration().getView().deactivateDesktopPane();
	}
	


}
