/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.craft.actions;

import mot.client.deligates.CraftDelegate;
import mot.client.deligates.FleetDelegate;
import mot.client.deligates.cache.DeligateCacheManager;
import mot.client.proxy.CompletedCallback;
import mot.client.proxy.ProxyStore;
import mot.client.swing.buttons.MotButton;
import mot.client.swing.window.craft.FleetDetailsWindow;
import mot.client.swing.window.galaxy.GalaxyWindowConfig;
import mot.client.swing.window.main.MainWindow;
import mot.client.swing.window.main.MainWindowConfig;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class CraftActionLeaveFleet extends MotButton implements CompletedCallback {


	private FleetDetailsWindow parent;
	private FleetDelegate fleet;
	private CraftDelegate craft;
	
	public CraftActionLeaveFleet(FleetDetailsWindow parent, FleetDelegate fleet, CraftDelegate craft) throws ApplicationError {
		super(L.LEAVE);
		this.parent = parent;
		this.fleet = fleet;
		this.craft = craft;
	}

	protected void _doAction() throws ApplicationError, ValidationError {
        ProxyStore.getInstance().craftLeaveFleetCmd(craft, this, this);
	}

	@Override
	public void complete(Object result) throws ApplicationError, ValidationError {
		FleetDelegate fd = (FleetDelegate) DeligateCacheManager.getMoo(fleet.getName());
        CraftDelegate[] crafts = (fd == null) ? null : fd.getCrafts();
		parent.setContent(crafts);
        MainWindowConfig config = MainWindow.getInstance().getActiveConfiguration();
        if (config instanceof GalaxyWindowConfig) {
        	GalaxyWindowConfig galaxyConfig = (GalaxyWindowConfig) config;
        	if (fd == null || crafts == null || crafts.length == 0) {
        		// If fleet is empty close fleet window and remove fleet from select moos in galaxy window
    			parent.setVisible(false);
        	} 
        	galaxyConfig.getGalaxyMapPanel().updateMooList(fd);
        }
	}

}
