/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.craft.actions;

import mot.client.deligates.FleetDelegate;
import mot.client.deligates.UserPlayerDelegate;
import mot.client.deligates.cache.DeligateCacheManager;
import mot.client.swing.buttons.MotButton;
import mot.client.swing.window.craft.CraftListWindow;
import mot.client.swing.window.craft.FleetDetailsWindow;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class CraftActionOpenFleetWindow extends MotButton {


	private CraftListWindow parent;
	private FleetDelegate craft;
	
	public CraftActionOpenFleetWindow(CraftListWindow parent, FleetDelegate craft) {
		super(L.DETAILS);
		this.parent = parent;
		this.craft = craft;
	}

	protected void _doAction() throws ApplicationError, ValidationError {
        UserPlayerDelegate owner = parent.getOwner();
        if (!craft.isOwnedBy(owner) && (craft.getOrbit() == null || !DeligateCacheManager.getStellarObject(craft.getOrbit().getStellarObject()).isOwnedBy(owner))) {
            throw new ValidationError(L.THIS_DOES_NOT_BELONG_TO_YOU);
        }
        new FleetDetailsWindow(parent, owner, craft);
	}

}
