/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.craft.actions;

import mot.client.deligates.PlayerDelegate;
import mot.client.deligates.UserPlayerDelegate;
import mot.client.proxy.CompletedCallback;
import mot.client.proxy.ProxyStore;
import mot.client.swing.buttons.MotButton;
import mot.client.swing.window.craft.CraftDesignWindow;
import mot.common.command_results.CraftDesignCR;
import mot.common.designs.CraftDesign;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class CraftDesignButtonAuto extends MotButton implements CompletedCallback {

	private CraftDesignWindow parent;
	private PlayerDelegate origin;
	private String name;
	private CraftDesignButtonHullProvider hullProvider;
	
	public CraftDesignButtonAuto(CraftDesignWindow parent, PlayerDelegate origin) {
		super(L.AUTO);
		this.parent = parent;
		this.origin = origin;
	}

	public CraftDesignButtonAuto(CraftDesignWindow parent, PlayerDelegate origin, CraftDesignButtonHullProvider hullProvider) {
		super(L.AUTO_SAME_HULL);
		this.parent = parent;
		this.origin = origin;
		this.hullProvider = hullProvider;
	}

	protected void _doAction() throws ApplicationError, ValidationError {
		UserPlayerDelegate owner = parent.getOwner();
		CraftDesign design = parent.getDesign();
        name = design.getName();
        String hullName = (hullProvider == null) ? null : hullProvider.getCurrentHullName();
        ProxyStore.getInstance().designMilitaryCraft(hullName, null, this, this);
	}

	@Override
	public void complete(Object result) throws ApplicationError, ValidationError {
		if (result != null && result instanceof CraftDesignCR) {
			CraftDesign design = ((CraftDesignCR) result).getResult();
	        design.setName(name);
	        parent.updateDesign(design);
		}
	}
	
}
