/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.craft.actions;

import java.awt.Container;

import javax.swing.ButtonGroup;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JViewport;

import mot.client.swing.buttons.MotRolloverLabelButton;
import mot.client.swing.buttons.MotToggleButton;
import mot.client.swing.common.ComponentTable;
import mot.client.swing.common.PadPanel;
import mot.client.swing.panels.TechnologyIconPanel;
import mot.client.swing.window.common.MessagePanel;
import mot.client.swing.window.craft.CraftDesignWindow;
import mot.common.bean.Size;
import mot.common.lang.L;
import mot.common.technology.GeneralTechnologyList;
import mot.common.technology.Technology;
import mot.common.technology.TechnologyBundle;
import mot.common.technology.TechnologyList;
import mot.common.technology.Weapon;
import mot.common.technology.Weapons;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class CraftDesignButtonSelectTech extends MotToggleButton {

	public static final String ADD_HULL = L.HULL;
	public static final String ADD_ENGINE = L.ENGINE;
	public static final String ADD_COMPUTER = L.COMPUTER;
	public static final String ADD_SCANNER = L.SCANNER;
	public static final String ADD_WEAPON = L.WEAPON;
	public static final String ADD_SHIELD = L.SHIELD;
	public static final String ADD_SPECIAL = L.SPECIAL;
	public static final String ADD_SALVAGE = L.SALVAGE;

    private CraftDesignWindow parent;
	private Technology [] techs;

	public CraftDesignButtonSelectTech(CraftDesignWindow parent, String text, TechnologyList techs, ButtonGroup group) {
		this(parent, text, (techs == null) ? null : techs.getAllAsArray(), group);
	}
	
	public CraftDesignButtonSelectTech(CraftDesignWindow parent, String text, Technology [] techs, ButtonGroup group) {
		super(text);
        this.parent = parent;
        this.techs = techs;
        
        group.add(this);
        setActionCommand(text);
	}
	
    protected void _doAction() throws ApplicationError, ValidationError {
    	selectTechType(true);
    }

    public void selectTechType(boolean setTechSelection) throws ApplicationError, ValidationError {
    	ComponentTable controlPanel = parent.getControlPanel();
    	controlPanel.removeAll();
   		controlPanel.setQtyRows(11);
   		controlPanel.reset();
   		controlPanel.add(parent.hullsButton);
        String techTypeCommandName = getActionCommand();
		if (techTypeCommandName == parent.hullsButton.getActionCommand()) {
        	controlPanel.add(createTechLabelList(techs));
        	if (setTechSelection) {
        		parent.getCraftDesignPanel().getPicturePanel().selectHullBackground();
        		parent.getCraftDesignPanel().getPicturePanel().getTechTypeSelectionPanel().selectHull();
        	}
        }
   		controlPanel.add(parent.enginesButton);
        if (techTypeCommandName == parent.enginesButton.getActionCommand()) {
        	controlPanel.add(createTechLabelList(techs));
        	if (setTechSelection) {
        		parent.getCraftDesignPanel().getPicturePanel().selectEngineBackground();
        		parent.getCraftDesignPanel().getPicturePanel().getTechTypeSelectionPanel().selectEngine();
        	}
        }
   		controlPanel.add(parent.computersButton);
        if (techTypeCommandName == parent.computersButton.getActionCommand()) {
        	controlPanel.add(createTechLabelList(techs));
        	if (setTechSelection) {
        		parent.getCraftDesignPanel().getPicturePanel().selectComputerBackground();
        		parent.getCraftDesignPanel().getPicturePanel().getTechTypeSelectionPanel().selectComputer();
        	}
        }
   		controlPanel.add(parent.scannersButton);
        if (techTypeCommandName == parent.scannersButton.getActionCommand()) {
        	controlPanel.add(createTechLabelList(techs));
        	if (setTechSelection) {
        		parent.getCraftDesignPanel().getPicturePanel().selectScannerBackground();
        		parent.getCraftDesignPanel().getPicturePanel().getTechTypeSelectionPanel().selectScanner();
        	}
        }
   		controlPanel.add(parent.weaponsButton);
        if (techTypeCommandName == parent.weaponsButton.getActionCommand()) {
        	controlPanel.add(createWeaponLabelList());
        	if (setTechSelection) {
        		parent.getCraftDesignPanel().getPicturePanel().selectWeaponsBackground();
        		parent.getCraftDesignPanel().getPicturePanel().getTechTypeSelectionPanel().selectWeapons();
        	}
        }
   		controlPanel.add(parent.shieldsButton);
        if (techTypeCommandName == parent.shieldsButton.getActionCommand()) {
        	controlPanel.add(createTechLabelList(techs));
        	if (setTechSelection) {
        		parent.getCraftDesignPanel().getPicturePanel().selectShieldsBackground();
        		parent.getCraftDesignPanel().getPicturePanel().getTechTypeSelectionPanel().selectShields();
        	}
        }
   		controlPanel.add(parent.specialsButton);
        if (techTypeCommandName == parent.specialsButton.getActionCommand()) {
        	controlPanel.add(createTechLabelList(techs));
        	if (setTechSelection) {
        		parent.getCraftDesignPanel().getPicturePanel().selectSpecialsBackground();
        		parent.getCraftDesignPanel().getPicturePanel().getTechTypeSelectionPanel().selectSpecials();
        	}
        }
   		controlPanel.add(parent.salvageButton);
        if (techTypeCommandName == parent.salvageButton.getActionCommand()) {
        	controlPanel.add(createTechLabelList(new GeneralTechnologyList(techs).getDistinct()));
        }
        Container container = controlPanel.getParent();
		if (container != null && container instanceof JViewport) {
			JViewport viewport = (JViewport) container;
			viewport.validate();
        }
        controlPanel.add(new JPanel(), "HTS");
        controlPanel.validate();
        controlPanel.repaint();
	}

    private JPanel createTechLabelList(Technology [] ta) throws ApplicationError {
    	if (ta == null) return new JPanel();
    	ComponentTable panel = new ComponentTable("HVSP", ta.length, 1, 0,0,0);
    	for (int i = 0; i < ta.length; i++) {
    		String tip = null;
            if (ta[i].getDescription() != null) {            	
            	tip = MessagePanel.toHtml(ta[i].getDescription(), 100, false);
            }
            TechnologyIconPanel icon = new TechnologyIconPanel(ta[i], new Size(20, 20));
    		MotRolloverLabelButton label = new MotRolloverLabelButton(new PadPanel(icon, 3), new JLabel(ta[i].getName()), tip, ta[i]) {
    			protected void _doAction() throws ApplicationError, ValidationError {
    				Technology tech = (Technology) getSubject();
    				parent.changeListItem(tech, 1);
    			}
            };
            panel.add(label);
		}
    	return panel;
    }

    private JPanel createTechLabelList(TechnologyBundle [] ta) throws ApplicationError {
    	if (ta == null) return new JPanel();
    	ComponentTable panel = new ComponentTable("HVSP", ta.length, 1, 0,0,0);
    	for (int i = 0; i < ta.length; i++) {
            TechnologyIconPanel icon = new TechnologyIconPanel(ta[i].getTechnology(), new Size(20, 20));
    		MotRolloverLabelButton label = new MotRolloverLabelButton(new PadPanel(icon, 3), new JLabel(ta[i].getNameWithQty()), null, ta[i]) {
    			protected void _doAction() throws ApplicationError, ValidationError {
    				TechnologyBundle tech = (TechnologyBundle) getSubject();
    				parent.changeListItem(tech.getTechnology(), 1);
    			}
            };
            panel.add(label);
		}
    	return panel;
    }

    private JPanel createWeaponLabelList() throws ApplicationError {
    	if (techs == null) return new JPanel();
    	Weapons existing = new Weapons(parent.getCraftDesign().getWeapons());
    	Weapons available = new Weapons((Weapon[])techs);
    	Weapon[] content = available.getCraftWeapons(existing);
    	return createTechLabelList(content);
    }

    
}
