/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.craft.actions;

import mot.client.swing.labels.AbstractTechnologyLabelClickListener;
import mot.client.swing.window.craft.CraftDesignWindow;
import mot.common.technology.Technology;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class CraftDesignSelectTechnology extends AbstractTechnologyLabelClickListener {

	private CraftDesignWindow parent;

	public CraftDesignSelectTechnology(CraftDesignWindow parent) {
		this.parent = parent;
	}

    /**
     * Called when a technology label is right clicked on.
     * @param technology The technology this label contained.
     * @throws ApplicationError 
     * @throws ValidationError 
     */
    public void handleRightClick(Technology technology) throws ValidationError, ApplicationError {
        parent.changeListItem(technology, -1);
    }

    /**
     * Called when a technology label is left clicked on.
     * @param technology The technology this label contained.
     * @throws ApplicationError 
     * @throws ValidationError 
     */
    public void handleLeftClick(Technology technology) throws ValidationError, ApplicationError {
      	parent.changeListItem(technology, 1);
    }
 	
}
