/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.craft.actions;

import mot.client.deligates.PlayerDelegate;
import mot.client.deligates.UserPlayerDelegate;
import mot.client.proxy.CompletedCallback;
import mot.client.proxy.ProxyStore;
import mot.client.swing.buttons.MotButton;
import mot.client.swing.window.common.MotInputDialog;
import mot.client.swing.window.craft.CraftDesignWindow;
import mot.client.swing.window.craft.CraftDesignsWindow;
import mot.common.designs.CraftDesign;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class NewCraftDesignButton extends MotButton implements CompletedCallback {


	public static final String NAME = L.NEW;

	private PlayerDelegate origin;
	private CraftDesignsWindow parent;

	private CraftDesign design;
	
	public NewCraftDesignButton(CraftDesignsWindow parent, PlayerDelegate origin) {
		super(NAME);
		this.parent = parent;
		this.origin = origin;
		
		setToolTipText(L.TT_CRAFT_DESIGN_NEW);
	}

	protected void _doAction() throws ApplicationError, ValidationError {
        String name = MotInputDialog.showInPopup(parent, L.PLEASE_ENTER_A_NAME, "Player Selection");
        if (name == null || name.length() == 0) {
            return;
        }
        if (name.length() > 15) {
            throw new ValidationError(L.CRAFT_NAME_MUST_BE_A_MAXIMUM_OF_15_CHARACTERS);
        }
        UserPlayerDelegate owner = parent.getOwner();
        if (owner.getCraftDesigns() != null && owner.getCraftDesigns().get(name) != null) {
            throw new ValidationError(L.YOU_ALREADY_HAVE_A_CRAFT_DESIGN_USING_THIS_NAME);
        }
        CraftDesign lastDesign = owner.getLastCraftDesigned();
        if (lastDesign != null) {
            design = new CraftDesign(lastDesign);
        } else {
            design = new CraftDesign();
            design.setHull(owner.getHulls().getBiggestCraftHull());
            design.setEngine(owner.getEngines().getFastestEngine());
        }
        design.setName(name);
        design = new CraftDesignWindow(parent, design, owner, origin).getCraftDesign();
        if (design != null) {
	        ProxyStore.getInstance().addCraftDesign(design, this, this);
        }
	}

	@Override
	public void complete(Object result) throws ApplicationError, ValidationError {
		design = parent.getOwner().getCraftDesigns().get(design.getName());
        parent.changeDesignsSelection(design);
	}
	
}
