/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.craft.actions;

import mot.client.deligates.CraftDelegate;
import mot.client.deligates.FleetDelegate;
import mot.client.proxy.CompletedCallback;
import mot.client.proxy.ProxyStore;
import mot.client.swing.buttons.MotButton;
import mot.client.swing.window.common.MotInputDialog;
import mot.client.swing.window.craft.CraftListWindow;
import mot.client.swing.window.craft.FleetDetailsWindow;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.Comp;
import mot.common.util.ValidationError;

public class RenameFleetButton extends MotButton implements CompletedCallback {


	private CraftListWindow parent;
	private FleetDelegate fleet;
	
	public RenameFleetButton(CraftListWindow parent, FleetDelegate fleet) {
		super(L.RENAME);
		this.parent = parent;
		this.fleet = fleet;
	}

	protected void _doAction() throws ApplicationError, ValidationError {
        String name = fleet.getName();
        String newName = MotInputDialog.showInPopup(parent, L.THIS_FLEET_WILL_BE_CALLED, L.RENAME, name);
        if (newName != null && !Comp.same(name, newName)) {
        	ProxyStore.getInstance().renameMoo(fleet, newName, this, this);
        }
	}

	@Override
	public void complete(Object result) throws ApplicationError, ValidationError {
        CraftDelegate[] crafts = fleet.getCrafts();
		//parent.setContent(crafts);
        parent.setTitle(FleetDetailsWindow.getTitle(fleet));
//    	galaxyConfig.getGalaxyMapPanel().rebuildContent();
//    	GalaxyWindowListener.validateGalaxyCraftList();
	}

}
