/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.craft.actions;

import mot.client.deligates.PlayerDelegate;
import mot.client.deligates.UserPlayerDelegate;
import mot.client.proxy.CompletedCallback;
import mot.client.proxy.ProxyStore;
import mot.client.swing.buttons.MotButton;
import mot.client.swing.lists.CraftDesignList;
import mot.client.swing.window.craft.CraftDesignWindow;
import mot.client.swing.window.craft.CraftDesignsWindow;
import mot.common.designs.CraftDesign;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class UpdateCraftDesignButton extends MotButton implements CompletedCallback  {

	public static final String NAME = "Update";

	private PlayerDelegate origin;
	private CraftDesignsWindow parent;
	private CraftDesignList craftDesignList;

	private CraftDesign design;
	
	public UpdateCraftDesignButton(CraftDesignsWindow parent, PlayerDelegate origin) {
		super(NAME);
		this.parent = parent;
		this.craftDesignList = parent.getCraftDesignList();
		this.origin = origin;
		
		setToolTipText(L.TT_CRAFT_DESIGN_UPDATE);
	}

	protected void _doAction() throws ApplicationError, ValidationError {
		UserPlayerDelegate owner = parent.getOwner();
        design = parent.getSelectedCraftDesign();
        if (design != null) {
            CraftDesign ncd = new CraftDesign(design);
			CraftDesign newDesign = new CraftDesignWindow(parent, ncd, owner, origin).getCraftDesign();
            if (newDesign != null) {
            	design.update(newDesign);
            	ProxyStore.getInstance().addCraftDesign(design, this, this);
            }
        }
	}
	
	@Override
	public void complete(Object result) throws ApplicationError, ValidationError {
		design = parent.getOwner().getCraftDesigns().get(design.getName());
        parent.changeDesignsSelection(design);
	}
	


}
