/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.empire;

import javax.swing.JLabel;
import javax.swing.JPanel;

import mot.client.deligates.PlayerDelegate;
import mot.client.deligates.UserPlayerDelegate;
import mot.client.proxy.CompletedCallback;
import mot.client.proxy.ProxyStore;
import mot.client.swing.buttons.MotButton;
import mot.client.swing.common.ComponentTable;
import mot.client.swing.common.PadPanel;
import mot.client.swing.window.common.MotInternalWindow;
import mot.client.swing.window.common.actions.UpdatablePlayerContainer;
import mot.client.swing.window.main.MainWindow;
import mot.common.lang.L;
import mot.common.technology.Technology;
import mot.common.util.ApplicationError;
import mot.common.util.Formatter;
import mot.common.util.ValidationError;

public class EspionagePanel extends ComponentTable {

	private MotInternalWindow win;
	private UpdatablePlayerContainer container;
	
    private JLabel spiesDefLabel = new JLabel();
    private JLabel spiesEspLabel = new JLabel();
    private JLabel spiesSabLabel = new JLabel();
    
    private JLabel chanceDefLabel = new JLabel();
    private JLabel chanceEspLabel = new JLabel();
    private JLabel chanceSabLabel = new JLabel();
    
    private JLabel targetDefLabel = new JLabel();
    private JLabel targetEspLabel = new JLabel();
    private JLabel targetSabLabel = new JLabel();
    
    private IconPanelSpyDefender spiesDefPanel = new IconPanelSpyDefender(0);
    private IconPanelSpyEspionage spiesEspPanel = new IconPanelSpyEspionage(0);
    private IconPanelSpySabatour spiesSabPanel = new IconPanelSpySabatour(0);
    
    private class UpdateCallback implements CompletedCallback {
		public void complete(Object result) throws ApplicationError, ValidationError {
			container.updatePlayerContainer(false);
		}
    };
    
    private UpdateCallback updateCallback = new UpdateCallback();
    
    public EspionagePanel(UpdatablePlayerContainer pContainer, MotInternalWindow owner) {
        super("HVSP,H-", 1, 1, 0, 0, 0);
        this.container = pContainer;
        this.win = owner;

        JPanel modifyEspPanel = new JPanel();
        modifyEspPanel.add(new MotButton("+") {
        	{ setToolTipText(L.TT_ESPIONAGE_PLUS); }
			protected void _doAction() throws ApplicationError, ValidationError {
				PlayerDelegate player = container.getSelectedPlayer();
                ProxyStore.getInstance().addSpyEspionage(player, updateCallback, this);
			}        	
        });
        modifyEspPanel.add(new MotButton("-") {
        	{ setToolTipText(L.TT_ESPIONAGE_MINUS); }
			protected void _doAction() throws ApplicationError, ValidationError {
				PlayerDelegate player = container.getSelectedPlayer();
                ProxyStore.getInstance().removeSpyEspionage(player, updateCallback, this);
			}        	
        });

        JPanel modifySabPanel = new JPanel();
        modifySabPanel.add(new MotButton("+") {
        	{ setToolTipText(L.TT_SABOTAGE_PLUS); }
			protected void _doAction() throws ApplicationError, ValidationError {
				PlayerDelegate player = container.getSelectedPlayer();
                ProxyStore.getInstance().addSpySabotage(player, updateCallback, this);
			}        	
        });
        modifySabPanel.add(new MotButton("-") {
        	{ setToolTipText(L.TT_SABOTAGE_MINUS); }
			protected void _doAction() throws ApplicationError, ValidationError {
				PlayerDelegate player = container.getSelectedPlayer();
                ProxyStore.getInstance().removeSpySabotage(player, updateCallback, this);
			}        	
        });
        
        ComponentTable panel = new ComponentTable("-,-,-,-,HVP,-", 3, 6, 0, 4, 0);
        panel.setGridHeights("100,100,100");
        panel.add(new PadPanel(new JPanel(),5));
        panel.add(new JLabel(L.DEFEND+" : "));
        panel.add(chanceDefLabel);
        panel.add(spiesDefLabel);
        panel.add(spiesDefPanel);
        panel.add(targetDefLabel);

        panel.add(modifyEspPanel);
        panel.add(new JLabel(L.ESPIONAGE+" : "));
        panel.add(chanceEspLabel);
        panel.add(spiesEspLabel);
        panel.add(spiesEspPanel);
        panel.add(targetEspLabel);

        panel.add(modifySabPanel);
        panel.add(new JLabel(L.SABOTAGE+" : "));
        panel.add(chanceSabLabel);
        panel.add(spiesSabLabel);
        panel.add(spiesSabPanel);
        panel.add(targetSabLabel);

        add(panel);
    }

    public void update(PlayerDelegate player) throws ApplicationError {
		UserPlayerDelegate owner = MainWindow.getOwner();
        spiesDefLabel.setText(""+owner.getQtySpiesDefending());
        spiesEspLabel.setText(""+owner.getQtySpiesEspionage(player));
        spiesSabLabel.setText(""+owner.getQtySpiesSabotage(player));
        spiesDefPanel.update(owner.getQtySpiesDefending());
        spiesEspPanel.update(owner.getQtySpiesEspionage(player));
        spiesSabPanel.update(owner.getQtySpiesSabotage(player));
		chanceEspLabel.setText(formatChance(owner.getEspionageSuccessChance(player.getName())));
    	chanceSabLabel.setText(formatChance(owner.getSabotageSuccessChance(player.getName())));
    	Technology espionageTarget = owner.getEspionageTarget(player.getName());
		if (espionageTarget == null) {
    		targetEspLabel.setText("");
    	} else {
    		targetEspLabel.setText(espionageTarget.getName());
    	}
    	//chanceSabLabel.setText(owner.getEspionageTarget(player.getName()));
    }

    private String formatChance(int v) {
    	if (v == 0) {
    		return "";
    	} else {
    		return Formatter.percentLabelNoSign(1.0/v);
    	}
    }
}