/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.empire;

import java.awt.Color;
import java.awt.Graphics;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.JPanel;
import javax.swing.JScrollPane;

import mot.client.deligates.cache.DeligateCacheManager;
import mot.client.proxy.CompletedCallback;
import mot.client.proxy.ProxyStore;
import mot.common.bean.stats.Graph;
import mot.common.bean.stats.GraphPlayerState;
import mot.common.bean.stats.GraphState;
import mot.common.bean.stats.Line;
import mot.common.bean.stats.Statistic;
import mot.common.util.ApplicationError;
import mot.common.util.Comp;
import mot.common.util.Logger;
import mot.common.util.ValidationError;

public class GraphPanel extends JPanel implements ActionListener {
	
    private GraphState graph;
    private String selection = mot.client.deligates.GraphDelegate.POPULATION;
    private JScrollPane scrollPanel;
    
    public GraphPanel() throws ApplicationError, ValidationError {
        setBackground(Color.BLACK);
        CompletedCallback callback = new CompletedCallback() {
			public void complete(Object result) {
				graph = (GraphState) result;
				repaint();
			}
		};
    	ProxyStore.getInstance().getGraph(callback, null);
    }
    
    public void paintComponent(Graphics g) { 
        super.paintComponent(g);
        if (graph == null) return;
        GraphPlayerState[] state = graph.getGraphPlayerState();
        if (state == null || state.length == 0) return;
        int max = graph.getMaximumValue(selection);
        max= (int)(((float)max)*1.2);
        for (int i=0; i<state.length; i++) {
            Graph playerGraph = state[i].getGraph();
            if (playerGraph != null) {
                try {
					g.setColor(DeligateCacheManager.getPlayer(state[i].getPlayerName()).getColor().getColor());
				} catch (Exception e) {
					Logger.logError("Colour Error "+state[i], e);
					
				}
                paintGraph(g, playerGraph, max);
            }
        }
    }
    
    public void paintGraph(Graphics g, Graph graph, int max) { 
        int start = (int) graph.getMinimumDate();
        start -= 10;
        Line [] lines = graph.getGraphLines();
        if (lines == null) return;
        
        int bottom = getHeight();
        for (int i=0; i<lines.length; i++) {
            if (!Comp.same(lines[i].getName(), selection)) {
                continue;
            }
            Statistic [] stats = lines[i].getStatsData();
            Statistic prev = null;
            for (int j=0; stats != null && j<stats.length; j++) {
                int d = (int)stats[j].getDate();
                if (prev == null) {
                    g.drawLine(0, bottom, d - start, toY((int)stats[j].getValue(), max));
                } else {
                    int p = (int)prev.getDate();
                    g.drawLine(p - start, toY((int)prev.getValue(), max), d - start, toY((int)stats[j].getValue(), max));
                }
                prev = stats[j];
            }
        }
    }
    
    private int toY(float v, float max) {
        float bottom = getHeight();
        return (int)( bottom - v/max * bottom );        
    }

    public JScrollPane getScrollPane() {
        if (scrollPanel == null) {
            scrollPanel = new JScrollPane(this, JScrollPane.VERTICAL_SCROLLBAR_AS_NEEDED, JScrollPane.HORIZONTAL_SCROLLBAR_AS_NEEDED);
        }
        return scrollPanel;
    }

    public void actionPerformed(ActionEvent e) {
        if (Comp.same(e.getActionCommand(), mot.client.deligates.GraphDelegate.POPULATION)) {
            selection = mot.client.deligates.GraphDelegate.POPULATION;
        } else if (Comp.same(e.getActionCommand(), mot.client.deligates.GraphDelegate.FLEET)) {
            selection = mot.client.deligates.GraphDelegate.FLEET;
        } else if (Comp.same(e.getActionCommand(), mot.client.deligates.GraphDelegate.RESEARCH)) {
            selection = mot.client.deligates.GraphDelegate.RESEARCH;
        }
        repaint();
    }
}