/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.empire;

import mot.client.swing.panels.PicturePanel;
import mot.common.leaders.GovenorDetails;
import mot.common.leaders.GovenorLeader;
import mot.common.util.ApplicationError;
import mot.common.util.PropertyManager;

/**
 * This is a picture panel that displays the image of a a govenor leader.
 * Note picture panel are fixed size panel - they do not resize with the container.
 */
public class LeaderGovenorPanel extends PicturePanel {

    private static final String IMAGE = PropertyManager.getMandatoryNoError("image.govenor.none");

    public LeaderGovenorPanel(GovenorLeader leader) throws ApplicationError {
        super(leader == null ? IMAGE : leader.getDetails().getPicture());
        if (leader != null) {
            GovenorDetails details = leader.getDetails();
            setToolTipText(details.getDescription());
        }
    }

    public void update(GovenorLeader leader) throws ApplicationError {
        setImage(leader == null ? IMAGE : leader.getDetails().getPicture());
        if (leader != null) {
            GovenorDetails details = leader.getDetails();
            setToolTipText(details.getDescription());
        }
    }

}
