/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.empire;

import java.awt.Color;

import javax.swing.SwingConstants;

import mot.client.swing.config.ImageConfigFactory;
import mot.client.swing.panels.PlainTextBackgroundImagePanel;
import mot.common.bean.Size;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.Logger;

/**
 * Display a message saying the player does not have diplomatic relations with another
 * player in from of an appropriate background!
 */
public class NoRelationsPanel extends PlainTextBackgroundImagePanel {

	public NoRelationsPanel() {
		super(L.NO_DIPLOMATIC_RELATIONS, Color.RED, 10, true, 0.75, 0.1, 0.1, 0.8, SwingConstants.CENTER, SwingConstants.CENTER);
		setFixedSizeAtCenter(new Size(300, 300));
	}

    protected String getImage() {
    	try {
			return ImageConfigFactory.getInstance().getRaceImageConfig("NoRelations").getImage();
		} catch (ApplicationError e) {
			Logger.logWarning("No Image for NoRelations");
			return null;
		}
    }

}