/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.empire;

import javax.swing.JLabel;

import mot.client.actions.MotTask;
import mot.client.deligates.PlayerDelegate;
import mot.client.deligates.UserPlayerDelegate;
import mot.client.proxy.CompletedCallback;
import mot.client.proxy.ProxyStore;
import mot.client.swing.common.ComponentTable;
import mot.client.swing.common.MotLabel;
import mot.client.swing.common.MotTextField;
import mot.client.swing.window.common.MotInternalWindow;
import mot.client.swing.window.common.actions.UpdatablePlayerContainer;
import mot.client.swing.window.main.MainWindow;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.Formatter;
import mot.common.util.Logger;
import mot.common.util.ValidationError;

public class RecruitePanel extends ComponentTable {

	private MotInternalWindow win;
	private UpdatablePlayerContainer container;
	
    private JLabel recruiteChanceLabel = new JLabel();
    private JLabel recruiteAccumulatedTotalLabel = new JLabel();
    private MotTextField recruiteField;
    
	private CompletedCallback fetchComplete;

    public RecruitePanel(UpdatablePlayerContainer pContainer, MotInternalWindow owner) {
        super("HT,HT", 3, 2, 10, 10, 10);
        this.container = pContainer;
        this.win = owner;

        fetchComplete = new CompletedCallback() {
			public void complete(Object result) throws ApplicationError, ValidationError {
				update(MainWindow.getOwner());
			}
		};

        MotTask changeRecruitEffort = new MotTask() {
			public void run() throws ApplicationError, ValidationError {
		        if (Logger.isDebug()) {
		            Logger.logDebug("EspionagePanel.changeRecruiteEffort()");
		        }
		        int v = recruiteField.getTextAsInt();
                ProxyStore.getInstance().setRecruiteSpyEffortCmd(v, fetchComplete, null);
			}
		};
		 
		recruiteChanceLabel.setToolTipText(L.TT_RECRUIT_SPIES);
		recruiteAccumulatedTotalLabel.setToolTipText(L.TT_RECRUIT_SPIES);
        recruiteField = new MotTextField(6, changeRecruitEffort);
        recruiteField.setToolTipText(L.TT_RECRUIT_SPIES);
        
        add(new MotLabel(L.CHANGE_TO_RECRUIT, L.TT_RECRUIT_SPIES));
        add(recruiteChanceLabel);
        add(new MotLabel(L.ACCUMULATED_EFFORT, L.TT_RECRUIT_SPIES));
        add(recruiteAccumulatedTotalLabel);
        add(new MotLabel(L.MONEY_PER_TURN, L.TT_RECRUIT_SPIES));
        add(recruiteField);

        //add(new PadPanel(new EspionagePlayerButton(container), 4));
    }

    public void update(PlayerDelegate player) throws ApplicationError, ValidationError {
		UserPlayerDelegate owner = MainWindow.getOwner();			
		recruiteChanceLabel.setText(Formatter.percentLabelNoSign(owner.getSpyRecruitChance()));
		recruiteField.setText(""+owner.getSpyRecruitCosts());
		recruiteAccumulatedTotalLabel.setText(""+owner.getSpyRecruitTotal());
		MainWindow.getInstance().getGalaxyMapConfiguration().getGalaxyView().updateStatus(owner);
    }

	public MotTextField getRecruiteField() {
		return recruiteField;
	}

}