/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.empire;

import java.awt.Color;

import javax.swing.JLabel;
import javax.swing.JPanel;

import mot.client.deligates.CraftDelegate;
import mot.client.deligates.PlanetDelegate;
import mot.client.deligates.PlayerDelegate;
import mot.client.deligates.UserPlayerDelegate;
import mot.client.deligates.cache.DeligateCacheManager;
import mot.client.proxy.CompletedCallback;
import mot.client.proxy.ProxyStore;
import mot.client.swing.buttons.MotButton;
import mot.client.swing.common.ComponentTable;
import mot.client.swing.common.MotLabel;
import mot.client.swing.common.PadPanel;
import mot.client.swing.window.common.MotInputDialog;
import mot.client.swing.window.common.SelectTechnologyWindow;
import mot.client.swing.window.common.actions.UpdatablePlayerContainer;
import mot.client.swing.window.craft.SelectCraftWindow;
import mot.client.swing.window.main.MainWindow;
import mot.client.swing.window.solarsystem.SelectPlanetWindow;
import mot.common.bean.DiplomaticProposal;
import mot.common.bean.NameList;
import mot.common.command_results.TechnologyListCR;
import mot.common.lang.L;
import mot.common.technology.Technology;
import mot.common.technology.TechnologyList;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class TradePanel extends ComponentTable {

	
	private RelationsWindow parent;
	private UpdatablePlayerContainer container;
	private DiplomaticProposal proposal;
	private Color backgroundColour;
	
    public TradePanel(RelationsWindow pParent, UpdatablePlayerContainer pContainer, DiplomaticProposal pProposal, Color backgroundColour) throws ApplicationError {
    	super("-,-,-,-,-,-,-", 4,7, 3, 5,3);
        this.parent = pParent;
        this.container = pContainer;
        this.proposal = pProposal;
		this.backgroundColour = backgroundColour;

        setOpaque(true);
        setBackground(backgroundColour);

        setOpaque(true);
        setBackground(backgroundColour);
        add(new MotLabel(L.OFFER, 6, JLabel.LEFT, true), "Rx"); 
        add(new PadPanel(10,10));
        add(new MotButton(L.MONEY) {
        	{ setToolTipText(L.TT_RELATIONS_OFFER_MONEY); }
			protected void _doAction() throws ApplicationError, ValidationError {
				if (proposal.isExecuted()) proposal.clear();
				PlayerDelegate player = container.getSelectedPlayer();
				UserPlayerDelegate owner = MainWindow.getOwner();
                addMoney(owner, true);
                //container.update();
				parent.selectedTab().updateProposalText();
			}        	
        }); 
        add(new MotButton(L.TECHNOLOGY) {
        	{ setToolTipText(L.TT_RELATIONS_OFFER_TECH); }
			protected void _doAction() throws ApplicationError, ValidationError {
				if (proposal.isExecuted()) proposal.clear();
				PlayerDelegate player = container.getSelectedPlayer();
				UserPlayerDelegate owner = MainWindow.getOwner();
				TechnologyList exclude = proposal.getOfferedTechnologList();
                addTechnology(player, owner, exclude, true);
				parent.selectedTab().updateProposalText();
			}        	
        }); 
        add(new MotButton(L.PLANET) {
        	{ setToolTipText(L.TT_RELATIONS_OFFER_PLANET); }
			protected void _doAction() throws ApplicationError, ValidationError {
				if (proposal.isExecuted()) proposal.clear();
				PlayerDelegate player = container.getSelectedPlayer();
				UserPlayerDelegate owner = MainWindow.getOwner();
                addPlanet(owner, true);
				parent.selectedTab().updateProposalText();
			}        	
        });
        add(new MotButton(L.CRAFT) {
        	{ setToolTipText(L.TT_RELATIONS_OFFER_CRAFT); }
			protected void _doAction() throws ApplicationError, ValidationError {
				if (proposal.isExecuted()) proposal.clear();
				PlayerDelegate player = container.getSelectedPlayer();
				UserPlayerDelegate owner = MainWindow.getOwner();
                addCraft(owner, proposal.getOfferedCraftNames(), true);
				parent.selectedTab().updateProposalText();
			}        	
        });
        add(new MotButton(L.NOTHING) {
        	{ setToolTipText(L.TT_RELATIONS_OFFER_NOTHING); }
			protected void _doAction() throws ApplicationError, ValidationError {
				if (proposal.isExecuted()) proposal.clear();
				PlayerDelegate player = container.getSelectedPlayer();
				proposal.setOffered(null);
				parent.selectedTab().updateProposalText();
			}        	
        });
        add(new JPanel(),"H");

        //buttonPanel.newLine();

        add(new MotLabel(L.REQUEST, 6, JLabel.LEFT, true), "Rx"); 
        add(new PadPanel(10,10));
        add(new MotButton(L.MONEY) {
        	{ setToolTipText(L.TT_RELATIONS_WANT_MONEY); }
			protected void _doAction() throws ApplicationError, ValidationError {
				if (proposal.isExecuted()) proposal.clear();
				PlayerDelegate player = container.getSelectedPlayer();
				UserPlayerDelegate owner = MainWindow.getOwner();
                addMoney(player, false);
				parent.selectedTab().updateProposalText();
			}        	
        });
        add(new MotButton(L.TECHNOLOGY) {
        	{ setToolTipText(L.TT_RELATIONS_WANT_TECH); }
			protected void _doAction() throws ApplicationError, ValidationError {
				if (proposal.isExecuted()) proposal.clear();
				PlayerDelegate player = container.getSelectedPlayer();
				UserPlayerDelegate owner = MainWindow.getOwner();
				TechnologyList exclude = proposal.getWantedTechnologList();
                addTechnology(owner, player, exclude, false);
				parent.selectedTab().updateProposalText();
			}        	
        }); 
        add(new MotButton(L.PLANET) {
        	{ setToolTipText(L.TT_RELATIONS_WANT_PLANET); }
			protected void _doAction() throws ApplicationError, ValidationError {
				if (proposal.isExecuted()) proposal.clear();
				PlayerDelegate player = container.getSelectedPlayer();
				UserPlayerDelegate owner = MainWindow.getOwner();
	            addPlanet(player, false);
				parent.selectedTab().updateProposalText();
			}        	
        });
        add(new MotButton(L.CRAFT) {
        	{ setToolTipText(L.TT_RELATIONS_WANT_CRAFT); }
			protected void _doAction() throws ApplicationError, ValidationError {
				if (proposal.isExecuted()) proposal.clear();
				PlayerDelegate player = container.getSelectedPlayer();
				UserPlayerDelegate owner = MainWindow.getOwner();
	            addCraft(player, proposal.getWanted().getCraftNames(), false);
				parent.selectedTab().updateProposalText();
			}        	
        });
        add(new MotButton(L.NOTHING) {
        	{ setToolTipText(L.TT_RELATIONS_WANT_NOTHING); }
			protected void _doAction() throws ApplicationError, ValidationError {
				if (proposal.isExecuted()) proposal.clear();
				PlayerDelegate player = container.getSelectedPlayer();
	            proposal.setWanted(null);
				parent.selectedTab().updateProposalText();
			}        	
        });
        add(new JPanel(),"H");
    }

    public void update(PlayerDelegate player) throws ApplicationError {
    }

    private void addMoney(PlayerDelegate player, boolean offered) throws ApplicationError, ValidationError {
        int amount = 0;
        try {
            String str = MotInputDialog.showInPopup(parent, L.ENTER_THE_AMOUNT, L.INPUT);
            amount = Integer.parseInt(str);
        } catch (NumberFormatException ex) {
            throw new ValidationError(L.INVALID_MONEY_MUST_BE_A_VALID_WHOLE_NUMBER_NO_LETTERS_OR_SPACES);
        }
        if (amount != 0) {
            if (offered) {
                proposal.addOfferedMoney(amount);
            } else {
            	proposal.addWantedMoney(amount);
            }
	        container.updatePlayerContainer(true);
        }
    }
    
    private void addTechnology(PlayerDelegate to, PlayerDelegate from, TechnologyList exclude, boolean offered) throws ApplicationError, ValidationError {
    	CompletedCallback callback = new CompletedCallback() {
        	boolean offered;
        	TechnologyList excludeList;
        	public CompletedCallback init(boolean v, TechnologyList exclude) { offered = v; excludeList = exclude; return this; }
			public void complete(Object result) throws ValidationError, ApplicationError {
		        TechnologyListCR cr = (TechnologyListCR)result;
		        TechnologyList list =  (cr != null) ? cr.getResultAsList() : null;
		        if (list != null && excludeList != null) {
		        	list.remove(excludeList);
		        }
		        if (list == null || list.getQuantity() == 0) {
		        	if (offered) {		        		
		        		throw new ValidationError(L.YOU_DO_NOT_HAVE_ANY_TECHS_TO_GIVE_AWAY);
		        	} else {
		        		throw new ValidationError(L.NO_TECHS_OFFERED_TO_TRADE);
		        	}
		        }
		        Technology tech = null;
		        if (list.getQuantity() == 1) {
		        	tech = list.getTechnologyAtIndex(0);
		        } else {
		        	tech = new SelectTechnologyWindow(parent, list, true).getTechnology();
		        }
		        if (tech != null) {
		            if (offered) {
		            	proposal.addOfferedTechnology(tech);
		            } else {
		            	proposal.addWantedTechnology(tech);
		            }
		        }
		        container.updatePlayerContainer(true);
			}
		}.init(offered, exclude);
        ProxyStore.getInstance().fetchStealableTechnology(from, to, exclude, callback, null);
    }
    
    private void addPlanet(PlayerDelegate player, boolean offered) throws ApplicationError, ValidationError {
        PlanetDelegate [] list = DeligateCacheManager.getPlanets(player);
        if (list == null || list.length < 1) {
            throw new ValidationError(L.YOU_DO_NOT_HAVE_ANY_PLANETS_TO_GIVE_AWAY);
        }
		UserPlayerDelegate owner = MainWindow.getOwner();
        SelectPlanetWindow spw = new SelectPlanetWindow(owner, parent, list, L.SELECT_A_PLANET_TO_OFFER);
        spw.waitUntilClosed();
		PlanetDelegate planet = spw.getSelectedPlanet();
        if (planet != null && planet.getName() != null) {
            if (offered) {
            	proposal.addOfferedPlanet(planet.getName());
            } else {
            	proposal.addWantedPlanet(planet.getName());
            }
	        container.updatePlayerContainer(true);
        }
    }

    private void addCraft(PlayerDelegate player, NameList existing, boolean offered) throws ApplicationError, ValidationError {
        CraftDelegate [] list = DeligateCacheManager.getCrafts(player, existing);
        if (list == null || list.length < 1) {
            throw new ValidationError(L.YOU_DO_NOT_HAVE_ANY_CRAFTS_TO_GIVE_AWAY);
        }
		UserPlayerDelegate owner = MainWindow.getOwner();
		SelectCraftWindow scw = new SelectCraftWindow(owner, parent, list, L.SELECT_A_CRAFT_TO_OFFER);
        scw.waitUntilClosed();
		CraftDelegate craft = scw.craft;
        if (craft != null && craft.getName() != null) {
            if (offered) {
            	proposal.addOfferedCraft(craft.getName());
            } else {
            	proposal.addWantedCraft(craft.getName());
            }
	        container.updatePlayerContainer(true);
        }
    }

}

