/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.empire;

import java.awt.Color;

import javax.swing.BoxLayout;
import javax.swing.JLabel;
import javax.swing.JPanel;

import mot.client.deligates.PlayerDelegate;
import mot.client.deligates.RelationDelegate;
import mot.client.deligates.UserPlayerDelegate;
import mot.client.swing.buttons.MotButton;
import mot.client.swing.common.ComponentTable;
import mot.client.swing.common.MotLabel;
import mot.client.swing.common.PadPanel;
import mot.client.swing.common.SpringPanel;
import mot.client.swing.window.common.actions.UpdatablePlayerContainer;
import mot.client.swing.window.main.MainWindow;
import mot.common.bean.DiplomaticProposal;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class TreatyPanel extends ComponentTable {

	private RelationsWindow parent;
	private UpdatablePlayerContainer container;
	
    private SpringPanel treatyButtonPanel = null;
	private DiplomaticProposal proposal;
	private Color backgroundColour;
	
    public TreatyPanel(RelationsWindow pParent, PlayerDelegate player, UpdatablePlayerContainer pContainer, DiplomaticProposal proposal, Color backgroundColour) throws ApplicationError {
    	super("HV,HVSP", 1, 2, 0,0,0);
        this.parent = pParent;
        this.container = pContainer;
		this.proposal = proposal;
		this.backgroundColour = backgroundColour;


        setLayout(new BoxLayout(this, BoxLayout.Y_AXIS));
        add(new MotLabel(L.REQUEST_TREATIES, 6, JLabel.LEFT, true));
        add(createOrUpdate(player));
        setOpaque(true);
        setBackground(backgroundColour);
    }

    private JPanel createOrUpdate(PlayerDelegate player) throws ApplicationError {
		UserPlayerDelegate owner = MainWindow.getOwner();
        RelationDelegate rel = owner.getRelation(player);
        if (treatyButtonPanel == null) {
            treatyButtonPanel = new SpringPanel(3);
        } else {
            treatyButtonPanel.removeAll();
        }
        int count = 0;
        treatyButtonPanel.add(new PadPanel(15,10));
        if (rel != null && rel.canHaveAllianceTreaty() && proposal.canAddAllianceTreaty()) {
            treatyButtonPanel.add(new MotButton(L.ALLIANCE) {
    			protected void _doAction() throws ApplicationError, ValidationError {
    				if (proposal.isExecuted()) proposal.clear();
    				proposal.removeTreaies();
    				proposal.setAlliance(true);
    				//parent.selectedTab().updateProposalText();
    				container.updatePlayerContainer(true);
    			}        	
            });
            count++;
        }
        if (rel != null && rel.canHaveNonAgressionTreaty() && proposal.canAddNonAgressionTreaty()) {
            treatyButtonPanel.add(new MotButton(L.NON_AGRESSION) {
    			protected void _doAction() throws ApplicationError, ValidationError {
    				if (proposal.isExecuted()) proposal.clear();
    				proposal.removeTreaies();
    				proposal.setNonAggression(true);
    				//parent.selectedTab().updateProposalText();
    				container.updatePlayerContainer(true);
    			}        	
            });
            count++;
        }
        if (rel != null && rel.canHavePeaceTreaty() && proposal.canAddPeaceTreaty()) {
            treatyButtonPanel.add(new MotButton(L.REQUEST_PEACE) {
    			protected void _doAction() throws ApplicationError, ValidationError {
    				if (proposal.isExecuted()) proposal.clear();
    				proposal.removeTreaies();
    				proposal.setPeace(true);
    				//parent.selectedTab().updateProposalText();
    				container.updatePlayerContainer(true);
    			}        	
            });
            count++;
        }
        if (count > 4) { count = 0; treatyButtonPanel.newLine(); }
        if (rel != null && rel.canHaveResearchTreaty() && proposal.canAddResearchTreaty()) {
            treatyButtonPanel.add(new MotButton(L.RESEARCH) {
    			protected void _doAction() throws ApplicationError, ValidationError {
    				if (proposal.isExecuted()) proposal.clear();
    				proposal.removeTreaies();
    				proposal.setResearch(true);
    				//parent.selectedTab().updateProposalText();
    				container.updatePlayerContainer(true);
    			}        	
            });
            count++;
        }
        if (count > 4) { count = 0; treatyButtonPanel.newLine(); }
        if (rel != null && rel.canHaveTradeTreaty() && proposal.canAddTradeTreaty()) {
            treatyButtonPanel.add(new MotButton(L.TRADE) {
    			protected void _doAction() throws ApplicationError, ValidationError {
    				if (proposal.isExecuted()) proposal.clear();
    				PlayerDelegate player = container.getSelectedPlayer();
    				proposal.removeTreaies();
    				proposal.setTrade(true);
    				//parent.selectedTab().updateProposalText();
    				container.updatePlayerContainer(true);
    			}        	
            });
            count++;
        }
        if (count > 4) { count = 0; treatyButtonPanel.newLine(); }
        if (rel != null && rel.canHaveWarTreaty() && proposal.canAddWarTreaty()) {
            treatyButtonPanel.add(new MotButton(L.WAR) {
    			protected void _doAction() throws ApplicationError, ValidationError {
    				if (proposal.isExecuted()) proposal.clear();
    				proposal.removeTreaies();
    				proposal.setWar(true);
    				//parent.selectedTab().updateProposalText();
    				container.updatePlayerContainer(true);
    			}        	
            });
            count++;
        }
        if (count > 4) { count = 0; treatyButtonPanel.newLine(); }
        if (proposal.hasTreaty()) {
            treatyButtonPanel.add(new MotButton(L.NOTHING) {
    			protected void _doAction() throws ApplicationError, ValidationError {
    				if (proposal.isExecuted()) proposal.clear();
    				proposal.removeTreaies();
    				//parent.selectedTab().updateProposalText();
    				container.updatePlayerContainer(true);
    			}        	
            });
            count++;
        }
        treatyButtonPanel.setBottom();
        treatyButtonPanel.setOpaque(true);
        treatyButtonPanel.setBackground(backgroundColour);
        return treatyButtonPanel;
    }
    
    public void update(PlayerDelegate player) throws ApplicationError {
		UserPlayerDelegate owner = MainWindow.getOwner();
        createOrUpdate(player);
    }
}