/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.empire.actions;

import java.util.HashMap;
import java.util.Iterator;

import mot.client.deligates.UserPlayerDelegate;
import mot.client.proxy.CompletedCallback;
import mot.client.proxy.ProxyStore;
import mot.client.swing.common.MotTextField;
import mot.client.swing.window.common.actions.CloseButton;
import mot.client.swing.window.empire.RaceRelationPanel;
import mot.client.swing.window.empire.RecruitePanel;
import mot.client.swing.window.empire.RelationsWindow;
import mot.client.swing.window.main.MainWindow;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class CloseRelationsWindow extends CloseButton implements CompletedCallback {

	private RelationsWindow owner;

	public CloseRelationsWindow(RelationsWindow owner) {
		super(L.CLOSE, owner);
		this.owner = owner;
	}
	/**
	 * When the relations window closes it acts as clicking the no button on any treaty requests that are open.
	 */
	protected void _doAction() throws ApplicationError, ValidationError {
		RaceRelationPanel selectedTab = owner.selectedTab();
		if (selectedTab != null && selectedTab.getRecruiteTab() != null) {
			RecruitePanel recruiteTab = selectedTab.getRecruiteTab();
			MotTextField recruiteField = recruiteTab.getRecruiteField();
			UserPlayerDelegate owner = MainWindow.getOwner();			
			int oldRecruitCost = owner.getSpyRecruitCosts();
			int newRecruitCost = recruiteField.getTextAsInt();
			if (newRecruitCost !=  oldRecruitCost) {
				ProxyStore.getInstance().setRecruiteSpyEffortCmd(newRecruitCost, this, null);
				return;
			}
		}
		complete(null);
	}

	public void complete(Object result) throws ApplicationError, ValidationError {
        super._doAction();
        final HashMap nameToTabMap = owner.getNameToTabMap();
        if (nameToTabMap != null && !nameToTabMap.isEmpty()) {
            for (Iterator i = nameToTabMap.values().iterator(); i.hasNext();) {
    			RaceRelationPanel racePanel = (RaceRelationPanel) i.next();
    			if (racePanel != null && racePanel.getNoButton() != null && racePanel.getNoButton().hasAction()) {
    				racePanel.getNoButton().actionPerformed(null);
    			}
    		}
        }
	}

}
