/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.empire.actions;

import mot.client.deligates.PlayerDelegate;
import mot.client.deligates.UserPlayerDelegate;
import mot.client.swing.buttons.MotButton;
import mot.client.swing.window.empire.EspionageReportWindow;
import mot.client.swing.window.empire.RaceRelationPanel;
import mot.client.swing.window.main.MainWindow;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class OpenEspionageReportWindowButton extends MotButton {

	private RaceRelationPanel parent;
	
	public OpenEspionageReportWindowButton(RaceRelationPanel parent) {
		super(L.VIEW_REPORT);
		this.parent = parent;
	}

	protected void _doAction() throws ApplicationError, ValidationError {
		UserPlayerDelegate owner = MainWindow.getOwner();
        PlayerDelegate player = parent.getSelectedPlayer();
        if (!owner.canViewDetails(player)) {
            throw new ValidationError(L.YOU_CANNOT_VIEW_THE_ESPIONAGE_REPORT_FOR_THIS_PLAYER_BECUASE_YOU_HAVE_NOT_ALLOCATED_ANY_SPIES_TO_THIS_PLAYER);
        }
        new EspionageReportWindow(parent.getParentWindow(), parent, owner, player);
	}

}
