/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.empire.actions;

import mot.client.proxy.CompletedCallback;
import mot.client.proxy.ProxyStore;
import mot.client.proxy.ServerProxy;
import mot.client.swing.buttons.MotButton;
import mot.client.swing.window.empire.EmpireWindow;
import mot.client.swing.window.main.MainWindow;
import mot.common.bean.SalvageList;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class SellAllSalvageButton extends MotButton implements CompletedCallback {

	private EmpireWindow parent;

	public SellAllSalvageButton(EmpireWindow parent) {
		super(L.SELL_ALL_SALVAGE);
		this.parent = parent;
		setToolTipText(L.TT_SELL_SALVAGE_SS);
	}
	
	protected void _doAction() throws ApplicationError, ValidationError {
		ServerProxy serverProxy = ProxyStore.getInstance();
		SalvageList salvage = MainWindow.getOwner().getSalvage();
		serverProxy.sellSavlage(salvage, this, null);
	}

	public void complete(Object result) throws ApplicationError, ValidationError {
		parent.update();
		MainWindow.getInstance().getGalaxyMapConfiguration().getGalaxyView().getStatusPanel().updateStatus(MainWindow.getOwner());
	}        	

}
