/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.empire.actions;

import mot.client.deligates.PlayerDelegate;
import mot.client.proxy.CompletedCallback;
import mot.client.proxy.ProxyStore;
import mot.client.swing.buttons.MotButton;
import mot.client.swing.window.empire.RaceRelationPanel;
import mot.client.swing.window.main.MainWindow;
import mot.common.bean.DiplomaticProposal;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class SendButton extends MotButton {

	private RaceRelationPanel parent;

	public SendButton(RaceRelationPanel parent) {
		super(L.SEND);
		this.parent = parent;
		setToolTipText(L.TT_RELATIONS_SEND);
	}
	
	protected void _doAction() throws ApplicationError, ValidationError {
		DiplomaticProposal proposal = parent.getProposal();
		if (proposal == null || !proposal.containsProposal()) {
			throw new ValidationError("You have not made a proposal to send (use treaty buttons above)");
		}
		if (proposal.isExecuted()) {
			throw new ValidationError("This proposal is complete");
		}
		
        send(proposal, null);
	}

	public void send(DiplomaticProposal proposal, String customMessage) throws ApplicationError, ValidationError {
		CompletedCallback callback = new CompletedCallback() {
			public void complete(Object result) throws ApplicationError, ValidationError {
				parent.updatePlayerContainer(true);
			}
		};
		PlayerDelegate player = parent.getSelectedPlayer();
		MainWindow.getInstance().showMessageGalaxy(proposal.getOneLineProposalText(player.getName()), false);
        ProxyStore.getInstance().sendDiplomaticRequest(player, proposal, customMessage, callback, null);
	}

}
