/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.etc;

import java.awt.Dimension;

import javax.swing.JLabel;
import javax.swing.JScrollPane;

import mot.client.swing.common.ComponentTable;
import mot.client.swing.common.MotLabel;
import mot.client.swing.config.ImageConfigFactory;
import mot.client.swing.panels.BackgroundImagePanel;
import mot.client.swing.panels.IconPanel;
import mot.client.swing.panels.IconPanelCraftQuantity;
import mot.client.swing.panels.IconPanelPopulation;
import mot.client.swing.panels.IconPanelResearch;
import mot.common.bean.stats.GameScore;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.Formatter;

public class EndGamePanel extends BackgroundImagePanel {

	private String image;
	
	private ComponentTable iconTable;
	private JLabel messageLabel;

	private JScrollPane iconTableScrollPane;

	public EndGamePanel(String message, GameScore gameScore) throws ApplicationError {
		image = ImageConfigFactory.getImageForConfig("EndGame");

		messageLabel = new MotLabel(message, 24, JLabel.CENTER, true);
		
        int population = gameScore.getQtyPopulation();
        int technology = gameScore.getQtyTechnology();
        int qtyCraftsBuilt = gameScore.getScoreDataNotNull().getTotalQtyCraftsBuilt();
        int qtyCraftsDestroyed = gameScore.getScoreDataNotNull().getTotalQtyCraftsDestroyed();
        int qtyCraftsInvaded = gameScore.getScoreDataNotNull().getTotalQtyCraftsInvaded();
        
        double total = gameScore.getCraftsBuiltScore() + gameScore.getTechnologyScore() + gameScore.getCraftsBuiltScore() + gameScore.getCraftsDestroyedScore() + gameScore.getCraftsInvadedScore();
        
		IconPanel popPanel = new IconPanelPopulation(population);
        IconPanel resPanel = new IconPanelResearch(technology, 0);
        IconPanelCraftQuantity builtPanel = new IconPanelCraftQuantity(gameScore.getScoreDataNotNull().getCraftBuilt());
        IconPanelCraftQuantity destroyedPanel = new IconPanelCraftQuantity(gameScore.getScoreDataNotNull().getCraftDestroyed());
        IconPanelCraftQuantity invadedPanel = new IconPanelCraftQuantity(gameScore.getScoreDataNotNull().getCraftInvaded());
        
        popPanel.setOpaque(false);
        resPanel.setOpaque(false);
        builtPanel.setOpaque(false);
        destroyedPanel.setOpaque(false);
        invadedPanel.setOpaque(false);
        
		iconTable = new ComponentTable("TH,T,THV",6,3, 6, 3,3);
        Dimension min = new Dimension(250, 25);
        iconTable.add(new MotLabel(L.POPULATION1, 0, min, null, JLabel.LEFT, false, null));
        iconTable.add(new MotLabel(Formatter.wholeNoUnits(gameScore.getCraftsBuiltScore()), null));
        iconTable.add(popPanel);
        iconTable.add(new MotLabel(L.RESEARCH, 0, min, null, JLabel.LEFT, false, null));
        iconTable.add(new MotLabel(Formatter.wholeNoUnits(gameScore.getTechnologyScore()), null));
        iconTable.add(resPanel);
        iconTable.add(new MotLabel(L.CRAFTS_BUILT, 0, min, null, JLabel.LEFT, false, null));
        iconTable.add(new MotLabel(Formatter.wholeNoUnits(gameScore.getCraftsBuiltScore()), null));
        iconTable.add(builtPanel);
        iconTable.add(new MotLabel(L.CRAFTS_DESTROYED, 0, min, null, JLabel.LEFT, false, null));
        iconTable.add(new MotLabel(Formatter.wholeNoUnits(gameScore.getCraftsDestroyedScore()), null));
        iconTable.add(destroyedPanel);
        iconTable.add(new MotLabel(L.CRAFTS_INVADED, 0, min, null, JLabel.LEFT, false, null));
        iconTable.add(new MotLabel(Formatter.wholeNoUnits(gameScore.getCraftsInvadedScore()), null));
        iconTable.add(invadedPanel);
        iconTable.add(new MotLabel(L.TOTAL, 6, min, null, JLabel.LEFT, false, null));
        iconTable.add(new MotLabel(Formatter.wholeNoUnits(total), 6, min, null, JLabel.LEFT, false, null), "HT2");
        //JPanel padding = new JPanel();
        //padding.setOpaque(false);
		//iconTable.add(padding);
        
        iconTableScrollPane = new JScrollPane(iconTable, JScrollPane.VERTICAL_SCROLLBAR_AS_NEEDED, JScrollPane.HORIZONTAL_SCROLLBAR_AS_NEEDED);
        iconTableScrollPane.setOpaque(false);
        iconTableScrollPane.getViewport().setOpaque(false);
        iconTable.setOpaque(false);
		
        add(messageLabel);
        add(iconTableScrollPane);
	}

	protected void drawSizeRelativeObjects() {
        setPosition(iconTableScrollPane, 0.68, 0.25, 0.03, 0.94);
        iconTableScrollPane.doLayout();
        
        setPosition(messageLabel, 0.1, 0.1, 0.05, 0.9);
        messageLabel.doLayout();
	}

	protected String getImage() {
		return image;
	}

}
