/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.etc;

import java.awt.BorderLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import mot.client.deligates.UserPlayerDelegate;
import mot.client.swing.common.MotButtonPanel;
import mot.client.swing.window.common.MotInternalWindow;
import mot.client.swing.window.common.actions.CloseButton;
import mot.common.bean.stats.GameScore;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.Logger;
import mot.common.util.ValidationError;

public class EndGameWindow extends MotInternalWindow implements ActionListener {

    //private static final Dimension SIZE = new Dimension(400, 300);
    
    private EndGamePanel panel;
    
	private String image;

    public EndGameWindow(MotInternalWindow parent, UserPlayerDelegate user, String message, GameScore gameScore)throws ApplicationError, ValidationError {
        super(user, parent, L.END_GAME, null);

        panel = new EndGamePanel(message, gameScore);
        getContentPane().add(panel, BorderLayout.CENTER);

        MotButtonPanel buttonPanel = new MotButtonPanel(new CloseButton(L.CLOSE, this));
        getContentPane().add(buttonPanel, BorderLayout.SOUTH);
        
        show();
        waitUntilClosed();
    }

    public void actionPerformed(ActionEvent e) {
        hide();
        try {
			new StartupWindow().show();
		} catch (ApplicationError e1) {
			Logger.logError("EndGameWindow.actionPerformed()", e1);
		}
    }   
}