/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.etc;

import java.awt.Color;

import javax.swing.BoxLayout;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.SwingConstants;

import mot.client.swing.common.ComponentTable;
import mot.client.swing.common.PanelUtils;
import mot.client.swing.panels.RacePicturePanel;
import mot.client.swing.window.empire.FlagPicturePanel;
import mot.common.bean.PlayerSummary;
import mot.common.bean.Size;
import mot.common.util.ApplicationError;

/**
 * This is a panel that is used to display details about a planet. It contains a picture of
 * the planet on the left with population, production, research and money output on the right.
 * This panel is used on the Empire Details window.
 */
public class GalaxyPlayerSummaryPanel extends JPanel {
	
    public GalaxyPlayerSummaryPanel() {
    	setLayout(new BoxLayout(this, BoxLayout.Y_AXIS));
    }

    public void update(PlayerSummary [] players) throws ApplicationError {
    	removeAll();
    	ComponentTable main = new ComponentTable("HV,P,HV", players.length,3, 4,4,4);
    	for (int i = 0; i < players.length; i++) {
    		boolean last = (i == players.length - 1);
    		addPlayerPanel(main, players[i], last ? "ST" : "");
		}
    	add(main);
    	validate();
    	repaint();
    }

    private void addPlayerPanel(ComponentTable main, PlayerSummary player, String fmt) throws ApplicationError {
    	String description = player.getName() + " [" + player.getType() + "]";
    	RacePicturePanel racePicturePanel = new RacePicturePanel(player.getName(), false);
    	FlagPicturePanel flagPicturePanel = new FlagPicturePanel(player.getPlayerColor());
    	JLabel infoLabel = PanelUtils.createLabel(description, 10, SwingConstants.CENTER);
    	PanelUtils.setTheBloodySize(racePicturePanel, new Size(50,50));
    	PanelUtils.setTheBloodySize(flagPicturePanel, new Size(50,50));
    	infoLabel.setBackground(Color.BLACK);
		main.add(racePicturePanel, "H"+fmt);
		main.add(infoLabel, "P"+fmt);
		main.add(flagPicturePanel, "H"+fmt);
    }
 
    private JScrollPane scrollPane;
    public JScrollPane getScrollPane() {
    	if (scrollPane == null) {
        	scrollPane = new JScrollPane(this, JScrollPane.VERTICAL_SCROLLBAR_ALWAYS, JScrollPane.HORIZONTAL_SCROLLBAR_AS_NEEDED);
    	}
    	return scrollPane;
    }
}
