/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.etc;

import java.awt.Color;

import mot.client.deligates.StellarObjectDelegate;
import mot.client.swing.window.galaxy.GalaxyWindowRadarPanel;
import mot.common.bean.GalaxyDetails;
import mot.common.bean.PlayerSummary;
import mot.common.bean.SectorOwnerGrid;
import mot.common.util.ApplicationError;
import mot.common.util.Comp;

/**
 * Displays the galaxy radar map for a saved game as a pre-view before
 * loading it.
 */
public class GalaxyWindowPreviewPanel extends GalaxyWindowRadarPanel {
	
	private PlayerSummary[] playerDetails;
	private SectorOwnerGrid sog;
	private StellarObjectDelegate[] stellarObjects;
	private GalaxyDetails galaxyDetails;

	public GalaxyWindowPreviewPanel() throws ApplicationError {
		super(false, false, 200);
	}
	
	public void update(PlayerSummary [] playerDetails, SectorOwnerGrid sog, StellarObjectDelegate[] stellarObjects, GalaxyDetails galaxyDetails) {
		this.playerDetails = playerDetails;
		this.sog = sog;
		this.stellarObjects = stellarObjects;
		this.galaxyDetails = galaxyDetails;
		repaint();
	}

	protected SectorOwnerGrid getSectorOwnerGrid() {
		return sog;
	}

	protected Color getPlayerColour(String playerName) throws ApplicationError {
		if (playerDetails == null) return null;
		for (int i = 0; i < playerDetails.length; i++) {
			if (Comp.same(playerDetails[i].getName(), playerName)) {
				return playerDetails[i].getPlayerColor().getSectorColor();
			}
		}
		return null;
	}

	public GalaxyDetails getGalaxyDetails() {
		return galaxyDetails;
	}

	public StellarObjectDelegate[] getStellarObjects() {
		return stellarObjects;
	}

	protected boolean readyForPainting() throws ApplicationError {
        return true;
	}

	
}
