/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.etc;

import javax.swing.JDialog;
import javax.swing.JFrame;
import javax.swing.JProgressBar;
import javax.swing.SwingUtilities;

import mot.client.sounds.SoundConfigFactory;
import mot.client.swing.config.AnimationConfigFactory;
import mot.client.swing.config.ImageConfigFactory;
import mot.client.swing.window.common.MotFrame;
import mot.client.swing.window.common.WindowLocator;
import mot.common.bean.Settings;
import mot.common.factory.GraphicsFactory;
import mot.common.factory.PlanetGraphicsFactory;
import mot.common.lang.L;
import mot.common.leaders.GeneralDetailsList;
import mot.common.leaders.GovenorDetailsList;
import mot.common.morals.MoralChoices;
import mot.common.setup.OptionsFactory;
import mot.common.technology.Technologies;
import mot.common.util.Logger;

/**
 * Window containing a progress bar that load all the technologies into the game.
 * This window does not have to be displayed or used, but does cause less delay on 
 * later windows if displayed at startup.
 */
public class LoadProgressWindow extends JDialog {

	public static final int QTY_STAGES = 22;
    private JProgressBar progress;
    
    public LoadProgressWindow(MotFrame parent) {
        super((JFrame)null, L.LOADING, true);

        WindowLocator.setCenter(this);
        setSize(250, 50);

        //JPanel picturePanel = new BackgroundImagePanel(5,5) {
        //    protected String getImage() { return StartupWindow.GAME_BACKGROUND_IMAGE; }
        //    protected void drawSizeRelativeObjects() { }
        //};
        //picturePanel.setMaximumSize(new Dimension(5,5));

        progress = new JProgressBar(0, QTY_STAGES);
        progress.setValue(0);
        progress.setFocusable(false);
        progress.setEnabled(false);

        //JPanel main = new JPanel();
        //main.setLayout(new BoxLayout(main, BoxLayout.X_AXIS));
        //main.add(progress);
        //main.add(picturePanel);
        
        getContentPane().add(progress);        
        
        new LoadProgressWorker(this).start();

        setVisible(true);
    }

    public void update(int stage) {
        progress.setValue(stage);
        if (stage >= QTY_STAGES) {
        	setVisible(false);
        }
    }
    
}

class LoadProgressWorker extends Thread {

    private LoadProgressWindow win;
    private int stage = 0;
    
    public LoadProgressWorker(LoadProgressWindow win) {
        this.win = win;
    }

    public void run() {
        //try { Thread.currentThread().sleep(3000); } catch (Exception ex) { }
        try {
        	Settings.getInstance();
        	AnimationConfigFactory.getInstance();
        	ImageConfigFactory.getInstance();
            stage++;
            update();
            OptionsFactory.getGeneralOptions();
            stage++;
            update();
            Technologies.getBiotechnologies();
            stage++;
            update();
            Technologies.getComputers();
            stage++;
            update();
            Technologies.getEngines();
            stage++;
            update();
            Technologies.getFactories();
            stage++;
            update();
            Technologies.getHulls();
            stage++;
            update();
            Technologies.getLaboratories();
            stage++;
            update();
            Technologies.getScanners();
            stage++;
            update();
            Technologies.getShields();
            stage++;
            update();
            Technologies.getSpecials();
            stage++;
            update();
            Technologies.getTheories();
            stage++;
            update();
            Technologies.getWeapons();
            stage++;
            update();
            Technologies.getModules();
            stage++;
            update();
            Technologies.getMiscTechnologies();
            stage++;
            update();
            MoralChoices.getMoralChoices();
            stage++;
            update();
            GeneralDetailsList.getInstance().getGenerals();
            stage++;
            update();
            GovenorDetailsList.getInstance().getGovenors();
            stage++;
            update();
            PlanetGraphicsFactory.getPlanetGraphicsConfig();
            stage++;
            update();
            GraphicsFactory.getRaceGraphicsList();
            stage++;
            update();
            GraphicsFactory.getGalaxyGraphicsList();
            stage++;
            update();
            SoundConfigFactory.getInstance();
            stage++;
            update();
            if (stage != LoadProgressWindow.QTY_STAGES) {
                Logger.logError("", new Exception("Incorrect quantity of stages "+stage));
            }
        } catch (Exception ex) {
            Logger.logError("LoadProgressWindow.run() Failed due on error ",ex);
            Logger.flushLog();
            System.out.println("LoadProgressWindow.run() Failed due on error "+ex.toString());
            System.exit(0);
        }
    }
    
    private void update() {
        Runnable updater = new Runnable() {
            public void run() {
            	try {
                    win.update(stage);
            	} catch (Exception ex) {
            		Logger.logError("", ex);
            	}
            }
        };
        try {
            SwingUtilities.invokeAndWait(updater);
        } catch (Exception ex) { 
        	Logger.logError("", ex);
        }
    }
    
}


