/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.etc;

import java.awt.BorderLayout;
import java.awt.Dimension;

import javax.swing.ButtonGroup;
import javax.swing.JRadioButton;

import mot.client.swing.common.ComponentTable;
import mot.client.swing.common.MotButtonPanel;
import mot.client.swing.window.common.MotInternalWindow;
import mot.client.swing.window.common.actions.CloseButton;
import mot.common.bean.PlayerAiSettings;
import mot.common.util.ApplicationError;

public class SetupComputerPlayerAISettingsWindow extends MotInternalWindow {

    private static final Dimension SIZE = new Dimension(250, 400);
    
	private JRadioButton foreignPolicyIsolationist;
	private JRadioButton foreignPolicyNormal;
	private JRadioButton foreignPolicyExpansionist;

	private JRadioButton diplomaticTradeEager;
	private JRadioButton diplomaticTradeNormal;
	private JRadioButton diplomaticTradeReluctant;

	private JRadioButton playerPersonalityOn;
	private JRadioButton playerPersonalityOff;

	private NewGameWindow newGameWindow;
    
	private static int random = 0;
	
    public SetupComputerPlayerAISettingsWindow(NewGameWindow parent, SetupComputerPlayerPanel playerPanel, PlayerAiSettings aiSettings) throws ApplicationError {
        super(null, parent, "Computer Player AI Settings", SIZE);
		newGameWindow = parent;
        
        ComponentTable optionsPanel = new ComponentTable("HV,HVSP", 11, 2, 1, 1, 1);

        {
        	optionsPanel.add("Foreign Policy", "HVSP2");
	        ButtonGroup bg = new ButtonGroup();
	        foreignPolicyIsolationist = new JRadioButton("Isolationist");
	        foreignPolicyNormal = new JRadioButton("Normal");
	        foreignPolicyExpansionist = new JRadioButton("Expansionist");
	        bg.add(foreignPolicyIsolationist);
	        bg.add(foreignPolicyNormal);
	        bg.add(foreignPolicyExpansionist);
	        optionsPanel.add("  ");
	        optionsPanel.add(foreignPolicyIsolationist);
	        optionsPanel.add("  ");
	        optionsPanel.add(foreignPolicyNormal);
	        optionsPanel.add("  ");
	        optionsPanel.add(foreignPolicyExpansionist);
        }
        		
        {
        	optionsPanel.add("Diplomatic Trade", "HVSP2");
	        ButtonGroup bg = new ButtonGroup();
	        diplomaticTradeEager = new JRadioButton("Eager");
	        diplomaticTradeNormal = new JRadioButton("Normal");
	        diplomaticTradeReluctant = new JRadioButton("Reluctant");
	        bg.add(diplomaticTradeEager);
	        bg.add(diplomaticTradeNormal);
	        bg.add(diplomaticTradeReluctant);
	        optionsPanel.add("  ");
	        optionsPanel.add(diplomaticTradeEager);
	        optionsPanel.add("  ");
	        optionsPanel.add(diplomaticTradeNormal);
	        optionsPanel.add("  ");
	        optionsPanel.add(diplomaticTradeReluctant);
        }		
		
		{
			optionsPanel.add("Player Personality", "HVSP2");
		    ButtonGroup bg = new ButtonGroup();
		    playerPersonalityOn = new JRadioButton("On");
		    playerPersonalityOff = new JRadioButton("Off");
		    bg.add(playerPersonalityOn);
		    bg.add(playerPersonalityOff);
		    optionsPanel.add("  ");
		    optionsPanel.add(playerPersonalityOn);
		    optionsPanel.add("  ");
		    optionsPanel.add(playerPersonalityOff);
		}
		
		if (aiSettings != null) {
			int foreignPolicy = aiSettings.getForeignPolicy();
			if (foreignPolicy == 0) foreignPolicyNormal.setSelected(true);
			if (foreignPolicy < 0) foreignPolicyIsolationist.setSelected(true);
			if (foreignPolicy > 0) foreignPolicyExpansionist.setSelected(true);
			int diplomaticTrade = aiSettings.getDiplomaticTrade();
			if (diplomaticTrade == 0) diplomaticTradeNormal.setSelected(true);
			if (diplomaticTrade < 0) diplomaticTradeReluctant.setSelected(true);
			if (diplomaticTrade > 0) diplomaticTradeEager.setSelected(true);
			int playerPersonality = aiSettings.getPlayerPersonality();
			if (playerPersonality > 0) playerPersonalityOn.setSelected(true);
			if (playerPersonality <= 0) playerPersonalityOff.setSelected(true);
		} else {
			if (newGameWindow.isHardLevel()) {
				if (random%2==0) {
					foreignPolicyIsolationist.setSelected(true);
				} else {
					foreignPolicyNormal.setSelected(true);
				}
				random++;
			} else {
				foreignPolicyNormal.setSelected(true);
			}
			diplomaticTradeNormal.setSelected(true);
			playerPersonalityOn.setSelected(true);
		}
		
        MotButtonPanel buttonPanel = new MotButtonPanel();
        buttonPanel.add(new CloseButton(this));
        
        getContentPane().add(optionsPanel.getScrollPane());
        getContentPane().add(buttonPanel, BorderLayout.SOUTH);
        
        show();
        waitUntilClosed();
    }

    public int getForeignPolicy() {
    	if (foreignPolicyNormal.isSelected()) return 0;
    	if (foreignPolicyExpansionist.isSelected()) return 1;
    	if (foreignPolicyIsolationist.isSelected()) return -1;
    	return 0;

    }

    public int getDiplomaticTrade() {
    	if (diplomaticTradeNormal.isSelected()) return 0;
    	if (diplomaticTradeEager.isSelected()) return 1;
    	if (diplomaticTradeReluctant.isSelected()) return -1;
    	return 0;

    }

    public int getPlayerPersonality() {
    	if (playerPersonalityOff.isSelected()) return 0;
    	if (playerPersonalityOn.isSelected()) return -1;
    	return 1;

    }

	public PlayerAiSettings getPlayerAiSettings() {
		return new PlayerAiSettings(getForeignPolicy(), getDiplomaticTrade(), getPlayerPersonality());
	}
}