/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.etc;

import java.awt.Color;
import java.awt.Dimension;

import javax.swing.JLabel;

import mot.client.swing.buttons.MotActionClickListener;
import mot.client.swing.combos.DescriptionProvider;
import mot.client.swing.combos.LevelCombo;
import mot.client.swing.combos.RaceCombo;
import mot.client.swing.common.ComponentTable;
import mot.client.swing.common.MotLabel;
import mot.client.swing.common.PadPanel;
import mot.client.swing.config.ImageConfig;
import mot.client.swing.labels.HtmlLabel;
import mot.common.bean.PlayerAiSettings;
import mot.common.bean.Size;
import mot.common.factory.GraphicsFactory;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.Comp;
import mot.common.util.PropertyManager;
import mot.common.util.ValidationError;

public class SetupComputerPlayerPanel extends ComponentTable {

	private NewGameWindow parent;

	private RaceCombo raceComboBox;
	private LevelCombo levelComboBox;
    private JLabel descriptionLabel = new HtmlLabel(JLabel.CENTER, 2, false);
    private boolean constructed = false;

	private PlayerAiSettings aiSettings;

	public SetupComputerPlayerPanel(NewGameWindow p) throws ApplicationError {
		super("HV,HV,HV,HVSP", 1, 4, 4, 4, 10);
		
		this.parent = p;
		
		MotActionClickListener customiseAi = new MotActionClickListener() {
			protected void _doAction() throws ApplicationError, ValidationError {
				aiSettings = new SetupComputerPlayerAISettingsWindow(parent, getSetupComputerPlayerPanel(), aiSettings).getPlayerAiSettings();
			}
		};
		descriptionLabel.addMouseListener(customiseAi);
		
		DescriptionProvider dp = new DescriptionProvider() {
			public String getDescription() {
				if (constructed) {
					String customise = ". <u>To customise AI settings click here</u>";
					String r = "<html><body>"+_getDescription()+customise+"</body><html>";
					//Logger.logDebug("r="+r);
					return r;
				} else {
					return "";
				}
			}
		};
		
        raceComboBox = new RaceCombo(GraphicsFactory.getRaceGraphicsList(), descriptionLabel, true, new Size(100,100), false, true, dp);
        levelComboBox = new LevelCombo(null, descriptionLabel, new Size(100,100), false, dp);
        
        ComponentTable descriptions = new ComponentTable("HV", 4, 1, 0, 0, 1);
        descriptions.setOpaque(false);
        descriptions.add(new PadPanel(1), "HVSP");
        descriptions.add(new MotLabel("Computer Player", 5, null, null, JLabel.LEFT, true, null, null));
        descriptions.add(descriptionLabel);
        descriptions.add(new PadPanel(1), "HVSP");
		
		add(raceComboBox);
		add(levelComboBox);
		add(descriptions);
		add(new PadPanel(1));
		
		raceComboBox.updateDescription();
		
        Color raceBackground = PropertyManager.getMandatoryAsColor("window.setup.color.background.race");
        setBackground(raceBackground);
        
		setMinimumSize(new Dimension(500,70));
		constructed = true;
	}

	public SetupComputerPlayerPanel(NewGameWindow parent, Integer computerRaceIndex, Integer computerLevelIndex) throws ApplicationError {
		this(parent);
		if (computerRaceIndex != null) {
			raceComboBox.setSelectedIndex(computerRaceIndex);
        	if (raceComboBox.hasSelectedRandomPlayer()) {
        		raceComboBox.updateDescription();
        	}
		} else {
			raceComboBox.selectRandomPlayer();
		}
		levelComboBox.setSelectedIndex(computerLevelIndex);
	}

	public SetupComputerPlayerPanel getSetupComputerPlayerPanel() {
		return null;
	}
	
	public RaceCombo getRaceComboBox() {
		return raceComboBox;
	}

	public LevelCombo getLevelComboBox() {
		return levelComboBox;
	}

	public String _getDescription() {
		if (raceComboBox == null || levelComboBox == null) {
			return "";
		}
		String r = raceComboBox.hasSelectedRandomPlayer() ? "of a random race" : "of race "+raceComboBox.getRace();
		ImageConfig config = levelComboBox.getLevelImageConfig();
		if (Comp.same(config.getName(), L.LEVEL_0)) {
			return r+" with production and research handicaps";
		} else if (Comp.same(config.getName(), L.LEVEL_1)) {
			return r+" with production and research handicaps";
		} else if (Comp.same(config.getName(), L.LEVEL_2)) {
			return r+" with production and research output identical to a human player";
		} else if (Comp.same(config.getName(), L.LEVEL_3)) {
			return r+" with production and research bonuses";
		} else if (Comp.same(config.getName(), L.LEVEL_4)) {
			return r+" with significant production and research bonuses";
		}
		return r;
	}

	public PlayerAiSettings getPlayerAiSettings() {
		return aiSettings;
	}
}
