/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.etc;

import java.awt.Color;
import java.util.ArrayList;

import javax.swing.JPanel;
import javax.swing.JScrollPane;

import mot.client.swing.common.ComponentTable;
import mot.client.swing.common.MotBorder;
import mot.common.bean.NewGameDataComputerPlayerDetails;
import mot.common.bean.NewGameDataUserPlayerDetails;
import mot.common.bean.NewGameUserPlayerData;
import mot.common.bean.PlayerAiSettings;
import mot.common.bean.Settings;
import mot.common.util.ApplicationError;
import mot.common.util.Comp;
import mot.common.util.PropertyManager;

public class SetupWindowOtherPlayerList extends ComponentTable {
	
	class UserPlayerTupple {
		public String clientId;
		public NewGameDataUserPlayerDetails userData;
		public UserPlayerTupple(String clientId, NewGameDataUserPlayerDetails userData) {
			this.clientId = clientId;
			this.userData = userData;
		}
	}

	private ArrayList<UserPlayerTupple> userPlayerData = new ArrayList();
	private SetupComputerPlayerPanel[] computerPlayerPanels;
	private NewGameWindow newGameWindow;
	
	public SetupWindowOtherPlayerList(NewGameWindow newGameWindow, Color background) throws ApplicationError {
		super("HST", 1,1, 2,0,2);
		this.newGameWindow = newGameWindow;
		
		if (background != null) {
			setBackground(background);
		} else {
			setOpaque(false);
		}
	}
	
    private void updateOtherPlayerList() throws ApplicationError {
        Color raceBackground = PropertyManager.getMandatoryAsColor("window.setup.color.background.race");
        NewGameDataUserPlayerDetails[] upda = getUserPlayerDetails();
    	int qty = 0;
    	if (upda != null) qty += upda.length;
    	if (computerPlayerPanels != null) qty += computerPlayerPanels.length;
		JPanel[] panels = new JPanel[qty];
		int j = 0;
    	if (upda != null) {
    		for (int i = 0; i < upda.length; i++) {
    			panels[j++] = new MotBorder(new SetupUserPlayerPanel(upda[i]), null, raceBackground);
			}
    	}
    	if (computerPlayerPanels != null) {
    		for (int i = 0; i < computerPlayerPanels.length; i++) {
    			panels[j++] = new MotBorder(computerPlayerPanels[i], null, raceBackground);
			}
    	}
		setContent(panels);
    }

	private void setContent(JPanel[] panels) {
		if (panels != null) {
			removeAll();
			setQtyRows(panels.length);
			for (int i=0; i < panels.length; i++ ) {
				if (i == panels.length-1) {
	                add(panels[i], "HST");
				} else {
	                add(panels[i], "HV");
				}
			}
			getScrollPane().validate();
			validate();
		}
		getScrollPane().repaint();
		repaint();
	}

	private JScrollPane scrollPane;
    public JScrollPane getScrollPane() {
    	if (scrollPane == null) {
        	scrollPane =  new JScrollPane(this, 
					  JScrollPane.VERTICAL_SCROLLBAR_AS_NEEDED,
					  JScrollPane.HORIZONTAL_SCROLLBAR_AS_NEEDED );
    	}
    	return scrollPane;
    }
    
	public NewGameDataUserPlayerDetails[] getUserPlayerDetails() {
		if (userPlayerData == null || userPlayerData.size() == 0) {
			return null;
		}
		NewGameDataUserPlayerDetails[] r = new NewGameDataUserPlayerDetails[userPlayerData.size()];
		for (int i = 0; i < r.length; i++) {
			r[i] = userPlayerData.get(i).userData;
		}
		return r;
	}

	private UserPlayerTupple getNewGameDataUserPlayerDetails(String clientId) {
		if (userPlayerData == null || userPlayerData.size() == 0) {
			return null;
		}
		int size = userPlayerData.size();
		for (int i = 0; i < size; i++) {
			UserPlayerTupple userPlayerTupple = userPlayerData.get(i);
			if (Comp.same(userPlayerTupple.clientId, clientId)) {
				return userPlayerTupple;
			}
		}
		return null;
	}

	public NewGameDataComputerPlayerDetails[] getComputerPlayerDetails() {
    	if (computerPlayerPanels != null) {
    		NewGameDataComputerPlayerDetails[] r = new NewGameDataComputerPlayerDetails[computerPlayerPanels.length];
    		for (int i = 0; i < computerPlayerPanels.length; i++) {
    			String race = computerPlayerPanels[i].getRaceComboBox().getRace();
    			Double level = computerPlayerPanels[i].getLevelComboBox().getLevel();
    			PlayerAiSettings playerAiSettings = computerPlayerPanels[i].getPlayerAiSettings();
    			r[i] = new NewGameDataComputerPlayerDetails(race, level, playerAiSettings);
			}
    		return r;
    	} else {
    		return null;
    	}
	}

	public void changeQtyComputerPlayers(int qtyComputerPlayers) throws ApplicationError {
		int originalQty = computerPlayerPanels == null ? 0 : computerPlayerPanels.length;
		if (qtyComputerPlayers > originalQty) {
			SetupComputerPlayerPanel[] old = computerPlayerPanels;
			computerPlayerPanels = new SetupComputerPlayerPanel[qtyComputerPlayers];
			for (int i = 0; i < originalQty; i++) {
				computerPlayerPanels[i] = old[i];
			}
			for (int i = originalQty; i < qtyComputerPlayers; i++) {
				computerPlayerPanels[i] = new SetupComputerPlayerPanel(newGameWindow);
			}
		} else {
			SetupComputerPlayerPanel[] old = computerPlayerPanels;
			computerPlayerPanels = new SetupComputerPlayerPanel[qtyComputerPlayers];
			for (int i = 0; i < qtyComputerPlayers; i++) {
				computerPlayerPanels[i] = old[i];
			}
		}
		updateOtherPlayerList();
	}

	public void loadFromSettings(Settings settings, int qty) throws ApplicationError {
		if (qty > 0) {
			computerPlayerPanels = new SetupComputerPlayerPanel[qty];
	    	for (int i = 0; i < qty; i++) {
	            Integer computerRaceIndex = settings.getGenericSettingInt("setupwin-computerplayer"+i+"-race");
	            Integer computerLevelIndex = settings.getGenericSettingInt("setupwin-computerplayer"+i+"-level");
	            if (computerRaceIndex != null && computerLevelIndex != null) {
	            	computerPlayerPanels[i] = new SetupComputerPlayerPanel(newGameWindow, computerRaceIndex, computerLevelIndex);
	            } else {
	            	computerPlayerPanels[i] = new SetupComputerPlayerPanel(newGameWindow);
	            }
			}
		} else {
			computerPlayerPanels = null;
		}
    	updateOtherPlayerList();
	}

	public void saveToSettings(Settings settings) {
		if (computerPlayerPanels == null) return;
		for (int i = 0; i < computerPlayerPanels.length; i++) {
			SetupComputerPlayerPanel cpp = (SetupComputerPlayerPanel) computerPlayerPanels[i];
			settings.addGenericSetting("setupwin-computerplayer"+i+"-race", ""+cpp.getRaceComboBox().getSelectedIndex());
			settings.addGenericSetting("setupwin-computerplayer"+i+"-level", ""+cpp.getLevelComboBox().getSelectedIndex());
		}
	}

	public void addUserPlayer(String clientId, NewGameUserPlayerData userData) throws ApplicationError {
		UserPlayerTupple up = getNewGameDataUserPlayerDetails(clientId);
		if (up == null) {
			userPlayerData.add(new UserPlayerTupple(clientId, new NewGameDataUserPlayerDetails(userData.getRaceName(), userData.getAlignment())));
		} else {
			up.userData.setAlignment( userData.getAlignment() );
			up.userData.setRaceName( userData.getRaceName() );
		}
		updateOtherPlayerList();
	}


}
