/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.etc.actions;

import mot.client.proxy.CompletedCallback;
import mot.client.proxy.ProxyStore;
import mot.client.proxy.ServerProxy;
import mot.client.swing.common.MotTextField;
import mot.client.swing.window.etc.MultiPlayerConnectWindow;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class ConnectJoinWaitButton extends ConnectButton {
	
	private MotTextField serverIP;
	private MultiPlayerConnectWindow parent;
	
	public ConnectJoinWaitButton(MotTextField serverIP, MultiPlayerConnectWindow parent) {
		super(L.CONNECT);
		this.serverIP = serverIP;
		this.parent = parent;
	}

	protected void _doAction() throws ApplicationError, ValidationError {
		if (parent.getStatus().isInit()) {
			ServerProxy serverProxy = ProxyStore.getInstance();
			if (!serverProxy.isConnected()) {
				String ip = serverIP.getText();
				if (ip == null || ip.length() < 4) {
					throw new ValidationError(L.INVALID_IP_ADDRESS);
				}
				serverProxy.connect(ip);
			}
			parent.getStatus().moveToConnected();
			setText(L.JOIN);
		} else if (parent.getStatus().isConnected() || parent.getStatus().isWaiting()) {
			CompletedCallback registerNewPlayerCallback = new CompletedCallback() {
				public void complete(Object result) throws ApplicationError, ValidationError {
					parent.getStatus().moveToWaiting();
					setText(L.WAITING);
					parent.setEditable(false);
					parent.saveSelection();
				}
			};
			parent.registerNewPlayerOnServer(registerNewPlayerCallback);
		}
	}
	
	@Override
	public void notifyDetailsChanged() {
		if (parent.getStatus().isWaiting()) {
			setText(L.UPDATE);
		}
	}

}
