/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.etc.actions;

import mot.client.proxy.ProxyStore;
import mot.client.proxy.RemoteConnectionServerProxy;
import mot.client.proxy.ServerProxy;
import mot.client.swing.buttons.MotButton;
import mot.client.swing.window.etc.NewGameWindow;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class ServerSocketThreadStatusButton extends MotButton {
	
	private NewGameWindow parent;
	
	public ServerSocketThreadStatusButton(NewGameWindow parent) {
		super(L.SWITCH_ON_MP);
		this.parent = parent;
	}

	protected void _doAction() throws ApplicationError, ValidationError {
		ServerProxy sp = ProxyStore.getInstance();
		RemoteConnectionServerProxy multiPlayerProxy = sp.getRemoteConnectionServerProxy();
		if (multiPlayerProxy == null) {
			throw new ValidationError(L.INVALID_MP_NOT_AVAILABLE);
		}
		if (multiPlayerProxy.isListeningForConnections()) {
			multiPlayerProxy.stopListingForConnections();
			setText(L.SWITCH_ON_MP);
		} else {
			multiPlayerProxy.startListingForConnections();
			setText(L.SWITCH_OFF_MP);
		}
	}

	

}
