/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.galaxy;

import mot.client.actions.ActiveRectangle;
import mot.client.deligates.MoveableOwnedObjectDelegate;
import mot.client.deligates.NamedObjectDelegate;
import mot.client.swing.window.galaxy.actions.GalaxyMapButtonCraftSleep;
import mot.client.swing.window.main.MainWindow;
import mot.client.swing.window.main.MainWindowConfig;
import mot.client.swing.window.main.MainWindowListener;
import mot.common.bean.Size;
import mot.common.util.ApplicationError;
import mot.common.util.Comp;
import mot.common.util.ValidationError;

public class GalaxyMapMooListItem extends ActiveRectangle {

	/**
	 * The size of each slot used to paint a MOO in.
	 */
	private int imageSize;
	
    /**
     * The moo that owns this Active Rectangle (each moo has its own ActiveRectangle).
     */
    private MoveableOwnedObjectDelegate moo;

    /**
     * The list containing this MOO List Item
     */
	private GalaxyMapMooList list;
    
	public GalaxyMapMooListItem(GalaxyMapMooList list, MoveableOwnedObjectDelegate moo, int x, int y, int panelWidth, int panelHeight) throws ApplicationError {
		super(x, y, panelWidth, panelHeight, true);
		this.list = list;
		this.moo = moo;
		
		Size imageSize = moo.getImageSize();

		this.imageSize = (int)(panelWidth * ((double)imageSize.getX() / (double)panelWidth));
	}

	public void click() throws ApplicationError, ValidationError {
//    	if (TutorialSystem.isActive()) {
//    		TutorialSystem.validateClick(this);
//    	}
		MainWindowConfig config = MainWindow.getInstance().getActiveConfiguration();
		MainWindowListener listener = config.getListener();
		listener.click(moo);
		if (moo.isSleeping()) {
			GalaxyMapButtonCraftSleep.unsleep(moo);
		}
	}

	public void mouseClicked(int x, int y) throws ApplicationError, ValidationError { 
		click();
	}

	public void doubleClick() throws ApplicationError, ValidationError {
		GalaxyWindowListener listener = MainWindow.getExestingInstance().getGalaxyMapListener();
		listener.openCraftDetailsWindow(null, moo, false);
	}

	public boolean contains(NamedObjectDelegate o) {
		return Comp.same(o.getName(), moo.getName());
	}

	public boolean contains(String name) {
		return Comp.same(name, moo.getName());
	}

	public NamedObjectDelegate getContents() {
		return moo;
	}
	
	public MoveableOwnedObjectDelegate getMoo() {
		return moo;
	}

	public String getPicture() throws ApplicationError {
		return moo.getImage();
	}
	
	public void update() throws ApplicationError {
	}

	public int getImageSize() {
		return imageSize;
	}

}
