/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.galaxy;

import mot.client.actions.ActiveRectangle;
import mot.client.deligates.MoveableOwnedObjectDelegate;
import mot.client.deligates.NamedObjectDelegate;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

/**
 * This is the bright white draggable part of the scroll bas next to the list 
 * of MOOs at a location.
 * 
 * @author Paul Davis
 *
 */
public class GalaxyMapMooScrollBar extends ActiveRectangle {

	/** 
	 * The height of the total scroll bar including space to scroll into.
	 */
	private int barTop;

	/** 
	 * The height of the scroll bar being displayed on the screen (not including space to scroll into).
	 */
	private int barHeight;

	/**
	 * The list that owns this scroll bar.
	 */
	private GalaxyMapMooList mooList;

	public GalaxyMapMooScrollBar(int x, int y, int sbHeight, int sbBarHeight, int width, MoveableOwnedObjectDelegate[] moos, GalaxyMapMooList mooList) throws ApplicationError {
		super(x, y, width, sbHeight, true);
		this.barTop = y;
		this.barHeight = sbBarHeight;
		this.mooList = mooList;
	}

	public void mouseClicked(int x, int y) throws ApplicationError { 
		if (y >= barTop && y <= barTop + barHeight) {
			// Might be about to scroll the bar - do nothing!
		} else if (y < barTop) {
			// up
			mouseDragged(0, barHeight);
		} else {
			// down
			mouseDragged(0, -barHeight);
		}
	}

	public void click() throws ApplicationError, ValidationError {
	}

	public void doubleClick() throws ApplicationError, ValidationError {
	}

	public boolean contains(NamedObjectDelegate o) {
		return false;
	}

	public boolean contains(String name) {
		return false;
	}

	public NamedObjectDelegate getContents() {
		return null;
	}
	
	public void update() throws ApplicationError {
	}

	public void mouseDragged(int dx, int dy) throws ApplicationError { 
		int top = getTop();
		int height = getHeight();
		int newBarTop = barTop - dy;
		int maxTop = top + height - barHeight;
		if (newBarTop > maxTop) newBarTop =  maxTop;
		if (newBarTop < top) newBarTop = top;
		if (barTop != newBarTop) {
			barTop = newBarTop;
			mooList.setContentToScrollBar();
		}
	}

	public void setScrollPercent(double scrollPercent) {
		int top = getTop();
		int height = getHeight();
		int newBarTop = top + (int) (height * scrollPercent);
		int maxTop = top + height - barHeight;
		if (newBarTop > maxTop) newBarTop =  maxTop;
		if (barTop != newBarTop) {
			barTop = newBarTop;
		}
	}

	public boolean isDraggable() { return true; }

	public double getPercentScroll() {
		int top = getTop();
		double topPercent = ((double)(barTop - top)) / ((double)getHeight());
		return topPercent;
	}

	public int getBarTop() {
		return barTop;
	}

	public int getBarHeight() {
		return barHeight;
	}
	
}
