/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.galaxy;

import java.util.ArrayList;

import mot.common.util.ApplicationError;

/**
 * Maintains a list of GalaxyWindowMenuButton that constitute a menu.
 * Only one menu (of buttons) is displayable at a time.
 */
public class GalaxyWindowButtonMenu extends GalaxyWindowMenuButton {

	/**
	 * This is the list of buttons on this menu
	 */
	private ArrayList<GalaxyWindowMenuButton> buttons = new ArrayList();

	/**
	 * The panel into which we place the menu
	 */
	private GalaxyWindowContextPanel contextPanel;
	
	public GalaxyWindowButtonMenu(GalaxyWindowListener listener, GalaxyWindowContextPanel contextPanel, String name, String tooltip) throws ApplicationError {
		super(listener, name, null);
		this.contextPanel = contextPanel;
		if (tooltip != null) {
			setToolTipText(tooltip);
		}
	}

	public void add(GalaxyWindowMenuButton button) {
		buttons.add(button);
	}
	
	public void activate() { _doAction(); }
	
	protected void _doAction() {
		contextPanel.showMenu(buttons);
	}

	public ArrayList<GalaxyWindowMenuButton> getButtons() {
		return buttons;
	}

	
}
