/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.galaxy;

import java.util.Arrays;
import java.util.Comparator;

import javax.swing.JPanel;

import mot.client.deligates.CraftDelegate;
import mot.client.swing.common.ComponentTable;
import mot.client.swing.common.MotBorder;
import mot.client.swing.common.MotLabel;
import mot.client.swing.common.PanelUtils;
import mot.client.swing.panels.TechnologyPicturePanel;
import mot.common.bean.Size;
import mot.common.designs.CraftDesign;
import mot.common.technology.Engine;
import mot.common.technology.Special;
import mot.common.technology.Specials;
import mot.common.technology.Technology;
import mot.common.technology.TechnologyBundle;
import mot.common.technology.Weapon;
import mot.common.technology.Weapons;
import mot.common.util.ApplicationError;

public class GalaxyWindowContextCraftDetailsPanel extends ComponentTable {
	
	class FrequencyComparator implements Comparator<TechnologyBundle> {
		public int compare(TechnologyBundle o1, TechnologyBundle o2) {
			if (o1.getQty() > o2.getQty()) {
				return -1;
			}
			if (o1.getQty() < o2.getQty()) {
				return 1;
			}
			return 0;
		}
		
	}

    public GalaxyWindowContextCraftDetailsPanel(CraftDelegate craft, int maxDetailsRows) throws ApplicationError {
		super("HV", maxDetailsRows+1, 1, 0, 0, 0);
		
        int qty = 0;
        
        CraftDesign craftDesign = craft.getCraftDesign();
        Specials specials = craftDesign.getSpecialTechs();
        
        if (specials != null) {
        	Technology[] colonisers = specials.getAllWithGroup(Special.GROUP_COLONISER);
        	if (colonisers != null && colonisers.length > 0 && colonisers[0] instanceof Special) {
        		Special tech = (Special) colonisers[0];
        		TechnologyPicturePanel imagePanel = new TechnologyPicturePanel(null, false, false, 2, true, false, null);
                PanelUtils.setTheBloodySize(imagePanel, new Size(100, 100));
                imagePanel.update(tech, 1, false);
        		ComponentTable panel = new ComponentTable("HV,HV", 2, 2, 1, 5, 0);
        		panel.add(imagePanel, "HV2F");
        		panel.add("Colonise Rating");
        		panel.add( new MotLabel(""+tech.getCanColoniseRating()));
        		add(new MotBorder(panel, "Coloniser"));
        		qty++;
        	}
        }

        if (qty < maxDetailsRows && specials != null) {
        	Technology[] fighters = specials.getAllWithGroup(Special.GROUP_FIGHTER_BAYS);
        	if (fighters != null && fighters.length > 0 && fighters[0] instanceof Special) {
        		Special tech = (Special) fighters[0];
        		TechnologyPicturePanel imagePanel = new TechnologyPicturePanel(null, false, false, 2, true, false, null);
                PanelUtils.setTheBloodySize(imagePanel, new Size(100, 100));
                imagePanel.update(tech, fighters.length * tech.getQtyFighters(), false);
        		ComponentTable panel = new ComponentTable("HV,HV", 2, 2, 1, 5, 0);
        		panel.add(imagePanel, "HV2F");
        		panel.add("Qty Fighters");
        		panel.add( new MotLabel(""+tech.getQtyFighters()));
        		add(new MotBorder(panel, "Carrier"));
        		qty++;
        	}
        }

		Weapons weaponTechs = craftDesign.getWeaponTechs();
		TechnologyBundle[] weapons = null;
		if (qty < maxDetailsRows && weaponTechs != null) {			
			weapons = weaponTechs.getDistinct();
			if (weapons != null && weapons.length > 0) {
				Arrays.sort(weapons, new FrequencyComparator());
				for (int i = 0; i < weapons.length; i++) {
					if (qty < maxDetailsRows) {			
						TechnologyBundle tech = (TechnologyBundle) weapons[i];
		        		TechnologyPicturePanel imagePanel = new TechnologyPicturePanel(null, false, false, 2, true, false, null);
		                PanelUtils.setTheBloodySize(imagePanel, new Size(100, 100));
		                imagePanel.update(tech.technology, tech.qty, false);
		        		ComponentTable panel = new ComponentTable("HV,HV", 2, 2, 1, 5, 0);
		        		panel.add(imagePanel, "HV2F");
		        		panel.add("Damage");
		        		panel.add( new MotLabel(""+((Weapon)tech.technology).getDamage()));
		        		add(new MotBorder(panel, "Weapon"));
		        		qty++;
					}					
				}
			}
		}

		Engine engine = craftDesign.getEngineTech();
        if (qty < maxDetailsRows && engine != null) {
        	if (engine != null) {
        		TechnologyPicturePanel imagePanel = new TechnologyPicturePanel(null, false, false, 2, true, false, null);
                PanelUtils.setTheBloodySize(imagePanel, new Size(100, 100));
                imagePanel.update(engine, false);
        		ComponentTable panel = new ComponentTable("HV,HV", 3, 2, 1, 5, 0);
        		panel.add(imagePanel, "HV2F");
        		panel.add("Range");
        		panel.add( new MotLabel(" "+engine.getMaxTravelDistance()));
        		panel.add("Speed");
        		panel.add( new MotLabel(" "+engine.getImpulseSpeed()));
        		add(new MotBorder(panel, "Engine"));
        		qty++;
        	}
        }

        add(new JPanel());

//        if (qty < maxDetailsRows && specials != null) {
//			Technology[] fighters = specials.getAllWithGroup(Special.GROUP_FIGHTER_BAYS);
//        	if (fighters != null && fighters.length > 0) {
//        		r.add(new TechnologyBundle(fighters[0], fighters.length));
//        	}
//        }
//
//        if (r.size() < maxDetailsRows && specials != null) {
//        	Technology[] commandCenters = specials.getAllWithGroup(Special.GROUP_COMMAND_CENTER);
//        	if (commandCenters != null && commandCenters.length > 0) {
//        		r.add(new TechnologyBundle(commandCenters[0], commandCenters.length));
//        	}
//        }
//
//        if (r.size() < maxDetailsRows) {
//        	Engine engine = craftDesign.getEngineTech();
//        	if (engine != null) {
//        		r.add(new TechnologyBundle(engine, 1));
//        	}
//        }
//
//        if (r.size() < maxDetailsRows && specials != null) {
//        	TechnologyBundle[] stl = specials.getDistinct();
//        	if (stl != null && stl.length > 0) {
//        		for (int i = 0; i < stl.length && r.size() < maxDetailsRows; i++) {	
//        			if (!Comp.same(stl[i].getTechnology().getGroup(), Special.GROUP_FIGHTER_BAYS) &&
//        				!Comp.same(stl[i].getTechnology().getGroup(), Special.GROUP_COLONISER) &&	
//        				!Comp.same(stl[i].getTechnology().getGroup(), Special.GROUP_COMMAND_CENTER) ) {        				
//        				r.add(stl[i]);
//        			}
//				}
//        	}
//        }
//        
//        if (r.size() < maxDetailsRows) {
//        	Shields shieldTechs = craftDesign.getShieldTechs();
//        	if (shieldTechs != null) {
//				TechnologyBundle[] shields = shieldTechs.getDistinct();
//	        	if (shields != null && shields.length > 0) {
//	        		for (int i = 0; i < shields.length && r.size() < maxDetailsRows; i++) {					
//	        			r.add(shields[i]);
//					}
//	        	}
//        	}
//        }
//        
//        if (r.size() < maxDetailsRows) {
//        	Scanners scannerTechs = craftDesign.getScannerTechs();
//        	if (scannerTechs != null) {        		
//        		TechnologyBundle[] scanners = scannerTechs.getDistinct();
//        		if (scanners != null && scanners.length > 0) {
//        			for (int i = 0; i < scanners.length && r.size() < maxDetailsRows; i++) {					
//        				r.add(scanners[i]);
//        			}
//        		}
//        	}
//        }
//        
//    	setContent(r.toArray(), null);
		
		while (qty < maxDetailsRows) {
			add(new JPanel());
			qty++;
		}
    	
    }
}