/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.galaxy;

import mot.client.deligates.CraftDelegate;
import mot.client.deligates.PlayerDelegate;
import mot.client.deligates.RelationDelegate;
import mot.client.deligates.UserPlayerDelegate;
import mot.client.swing.common.ComponentTable;
import mot.client.swing.common.MotLabel;
import mot.client.swing.common.PadPanel;
import mot.client.swing.common.PanelUtils;
import mot.client.swing.panels.RacePicturePanelWithFlag;
import mot.client.swing.window.empire.RaceRelationBar;
import mot.client.swing.window.main.MainWindow;
import mot.common.util.ApplicationError;

public class GalaxyWindowContextCraftOwnerPanel extends ComponentTable {
	
    public GalaxyWindowContextCraftOwnerPanel(CraftDelegate craft) throws ApplicationError {
        super("HV", 9, 1, 0, 0, 0);

        UserPlayerDelegate owner = MainWindow.getOwner();
        PlayerDelegate craftOwner = craft.getOwnerDelegate();
        
        RelationDelegate rel = owner.getRelation(craftOwner);

		RacePicturePanelWithFlag playerPanel = new RacePicturePanelWithFlag(craftOwner, 0, 20, 20);
		PanelUtils.setTheBloodySize(playerPanel, 150,150);
        RaceRelationBar relBar = new RaceRelationBar(rel == null ? 0 : rel.getValue());

        String[] treaties = owner.getTreatyNames(craftOwner);
        ComponentTable treatiesPanel = new ComponentTable("HV,HVSP", treaties == null ? 0 : treaties.length, 2, 0, 0, 0);
        if (treaties != null) {        	
        	for (int i = 0; i < treaties.length; i++) {
        		treatiesPanel.add(new PadPanel(10));
        		treatiesPanel.add(new MotLabel(treaties[i]));
        	}
        }
        
		add(new MotLabel("Owner:", 2, true));
		add(playerPanel);
        add(new PadPanel(5));
		add(new MotLabel("Relationship:", 2, true));
		add(relBar);
        add(new PadPanel(5));
		add(new MotLabel("Treaties:", 2, true));
		add(treatiesPanel);
	    add(new PadPanel(5), "HVSP");
    	
    }
}