/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.galaxy;

import java.util.ArrayList;

import mot.client.actions.CraftAction;
import mot.client.bean.CraftDelegateBundle;
import mot.client.deligates.CraftDelegate;
import mot.client.deligates.FleetDelegate;
import mot.client.swing.lists.FakeList;
import mot.client.swing.renderers.CellRendererCraft;
import mot.client.swing.window.main.MainWindow;
import mot.common.bean.Size;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class GalaxyWindowContextFleetContent extends FakeList {

	private static CraftAction _craftAction = new CraftAction() {
		public void click(CraftDelegate craft) throws ApplicationError, ValidationError {
			MainWindow.getExestingInstance().getGalaxyMapListener().openCraftDetailsWindow(null, craft, true);
		}
	};
	
    public GalaxyWindowContextFleetContent() throws ApplicationError {
        super(new CellRendererCraft(new Size(100, 100), true, 0, false, null, _craftAction, true));
    }
    
    public void setContent(FleetDelegate fleet) throws ApplicationError {
        CraftDelegate[] crafts = fleet.getCrafts();
        ArrayList<CraftDelegateBundle> r = null;
        
        if (crafts != null && crafts.length > 0) {
        	for (int i = 0; i < crafts.length; i++) {
        		CraftDelegateBundle cb = get(r, crafts[i]);
				if (cb == null) {
					cb = new CraftDelegateBundle(crafts[i]);
					if (r == null) r = new ArrayList<CraftDelegateBundle>();
					r.add(cb);
				} else {
					cb.add(crafts[i]);
				}
			}
        }
    	
        if (r != null) {
        	setContent(r.toArray(), null);
        } else {
        	setContent(null, null);
        }

		revalidate();
	}
    
	private CraftDelegateBundle get(ArrayList<CraftDelegateBundle> r, CraftDelegate craftDelegate) throws ApplicationError {
		if (r != null) {
			for (CraftDelegateBundle cb : r) {
				if (cb.firstCraftIsSameDesign(craftDelegate)) {
					return cb;
				}
			}
		}
		return null;
	}

}
