/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.galaxy;

import javax.swing.BoxLayout;

import mot.client.deligates.FleetDelegate;
import mot.client.swing.common.BoxPanel;
import mot.client.swing.common.ComponentTable;
import mot.client.swing.common.MotBorder;
import mot.client.swing.common.PadPanel;
import mot.common.util.ApplicationError;

public class GalaxyWindowContextFleetPanel extends ComponentTable implements GalaxyWindowStateHoldingPanel {

	private GalaxyWindowListener listener;
	
	//private GalaxyWindowContextButtonPanel buttonPanel;
	private BoxPanel headerPanel;
	private GalaxyWindowContextFleetContent fleetContentPanel;

	private FleetDelegate selection;

	public GalaxyWindowContextFleetPanel(GalaxyWindowListener listener) throws ApplicationError {
		super("HV", 5, 1, 0, 0, 0);
		
        this.listener = listener;
        
        //buttonPanel = new GalaxyWindowContextButtonPanel(listener);
		headerPanel = new BoxPanel(BoxLayout.Y_AXIS);
		fleetContentPanel = new GalaxyWindowContextFleetContent();
		
		//add(new MotBorder(buttonPanel, L.COMMANDS));
        add(new PadPanel(5));
        add(headerPanel);
        add(new PadPanel(5));
        add(new MotBorder(fleetContentPanel.getScrollPane(), "Fleet Contents"), "HVPS");
        
        //setBackground(menuBackgroundColor);
	}

    public FleetDelegate getSelection() {
    	return selection;
    }

    public void setSelection(FleetDelegate fleet) throws ApplicationError {
		
    	this.selection = fleet;
    	
    	//buttonPanel.setContent(fleet);
    	GalaxyWindowContextCraftPanel.updateHeaderPanel(headerPanel, fleet);
    	fleetContentPanel.setContent(fleet);
		
    }
    
	@Override
	public void clearState() throws ApplicationError {
	}

	@Override
	public void handleTick() throws ApplicationError {
	}

	@Override
	public void updateSelection() throws ApplicationError {
		setSelection(selection);
	}

}

