/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.galaxy;

import mot.client.deligates.PlanetDelegate;
import mot.client.deligates.TransportDelegate;
import mot.client.deligates.cache.DeligateCacheManager;
import mot.client.swing.common.BoxPanel;
import mot.client.swing.common.ComponentTable;
import mot.client.swing.common.MotBorder;
import mot.client.swing.common.MotLabel;
import mot.client.swing.common.PadPanel;
import mot.client.swing.common.PanelUtils;
import mot.client.swing.lists.TransportList;
import mot.client.swing.panels.ImagePanel;
import mot.client.swing.panels.TransportCargoPanel;
import mot.client.swing.panels.TransportPlanetPopPanel;
import mot.client.swing.window.main.MainWindow;
import mot.common.bean.Size;
import mot.common.designs.TransportDesign;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.vo.NavigatorVO;

public class GalaxyWindowContextTransportPanel extends ComponentTable implements GalaxyWindowStateHoldingPanel {

	private GalaxyWindowListener listener;
	
	private MotBorder transportBorder;
	private ImagePanel hullImagePanel;
	private MotLabel imageLabelLeft, imageLabelRight;
	//private GalaxyWindowContextButtonPanel buttonPanel;
    private TransportCargoPanel cargoPanel;
    private TransportList transportsPanel;
	private BoxPanel detailsPanel;
	private TransportPlanetPopPanel planetPopPanel;

	private TransportDelegate selection;

	public GalaxyWindowContextTransportPanel(GalaxyWindowListener listener) throws ApplicationError {
		super("HV", 9, 1, 0, 0, 0);
		
        this.listener = listener;
        
        hullImagePanel = new ImagePanel();
        PanelUtils.setTheBloodySize(hullImagePanel, new Size(100, 100));
		imageLabelLeft = new MotLabel();
		imageLabelRight = new MotLabel();
		ComponentTable transportPanel = new ComponentTable("HV,HVP", 2, 2, 1, 5, 0);
		transportPanel.add(hullImagePanel, "HV2F");
		transportPanel.add(imageLabelLeft);
		transportPanel.add(imageLabelRight);

        transportsPanel = new TransportList();
		detailsPanel = new BoxPanel();
		planetPopPanel = new TransportPlanetPopPanel();
		
		cargoPanel = new TransportCargoPanel();
				
        transportBorder = new MotBorder(transportPanel, L.HULL);
        
		add(transportBorder);
        add(new PadPanel(5));
        add(new MotBorder(cargoPanel, L.CARGO));
        add(new PadPanel(5));
        add(new MotBorder(planetPopPanel, L.PLANET_POP));
        add(new PadPanel(5));
        add(new MotBorder(transportsPanel, L.TRANSPORTS_IN_ORBIT));
        add(new PadPanel(5));
        add(detailsPanel, "HVPS");
        
        //setBackground(menuBackgroundColor);
	}

    public TransportDelegate getSelection() {
    	return selection;
    }

    public void setSelection(TransportDelegate transport) throws ApplicationError {
		
    	this.selection = transport;
    	
    	hullImagePanel.setImage(TransportDesign.getProjectImage());
    	transportBorder.setPanelName(transport.getName());

		String text = transport.getTaskDescription();
		NavigatorVO navigator = transport.getNavigator();
		if (navigator != null) {
			imageLabelLeft.setText("Turns to Arrive");
			imageLabelRight.setText(""+navigator.getEta());
		} else {
			imageLabelLeft.setText("Capacity");
			imageLabelRight.setText(""+transport.getMaxQty());
		}
		//messagePanel.setHTMLText(text);
		
		cargoPanel.setSelection(transport);
		planetPopPanel.setSelection(transport);

		detailsPanel.removeAll();
    	
    	if (transport.getOrbit() != null && transport.getOrbit().getPlanet() != null) {
    		PlanetDelegate planet = DeligateCacheManager.getPlanet(transport.getOrbit().getPlanet());
    		TransportDelegate[] transports = DeligateCacheManager.getTransportsAt(MainWindow.getOwner(), planet);
    		transportsPanel.setContent(transports);
    	} else {
    		transportsPanel.setContent(null);
    	}
		
		revalidate();
    }

	@Override
	public void clearState() throws ApplicationError {
	}

	@Override
	public void handleTick() throws ApplicationError {
	}


	@Override
	public void updateSelection() throws ApplicationError {
		setSelection(selection);
	}

}
