/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.galaxy;

import mot.client.swing.config.ImageConfigFactory;
import mot.client.swing.window.common.MotInternalWindow;
import mot.client.swing.window.common.MotInternalWindowListener;
import mot.common.bean.Location;
import mot.common.util.ApplicationError;

/**
 * This is an animations displayed on the radar panel representing 
 * the location of the current object the user has selected.
 */
public class GalaxyWindowRadarCarrot {
	
	/**
	 * This is the center location for the animation.
	 */
	private Location location;
	
	/**
	 * This is the time that this carrot animation will expire.
	 * A value of -1 implies that this does not expire!
	 * A value of 0 implies that this has EXPIRED!
	 */
	private long expires;
	
	/**
	 * This carrot will expire when the window passed in is closed.
	 */
	public GalaxyWindowRadarCarrot(Location location, MotInternalWindow window) {
		this.location = location;
		this.expires = -1;
		window.addListener(new WindowTerminator());
	}

	/**
	 * This carrot will expire after qtySecs seconds.
	 */
	public GalaxyWindowRadarCarrot(Location location, int qtySecs) {
		this.location = location;
		this.expires = System.currentTimeMillis() + qtySecs * 1000;
	}

	/**
	 * This carrot does not expire.
	 */
	public GalaxyWindowRadarCarrot(Location location) {
		this.location = location;
		this.expires = -1;
	}
	
	public boolean hasExpired() {
		if (expires == 0) {
			return true;
		} else if (expires == -1) {
			return false;
		} else {
			return System.currentTimeMillis() > expires;
		}
	}

//	public ImageAnimationConfig getAnimationConfig() throws ApplicationError {
//		return AnimationConfigFactory.getInstance().getImageAnimationConfig("Carrot");
//	}
//
//	public String getImage() throws ApplicationError {
//		return getAnimationConfig().getActualImage();
//	}
	
	public String getCarrotImage() throws ApplicationError {
		return ImageConfigFactory.getImageForConfig("Carrot");
	}

	public Location getLocation() {
		return location;
	}

	public void setLocation(Location location) {
		this.location = location;
	}
	
	public void expire() {
		expires = 0;
	}

	class WindowTerminator implements GalaxyWindowRadarCarrotTerminator, MotInternalWindowListener {
		public void hide() { expire(); }
	}

}
