/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.galaxy;

import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;
import java.awt.event.MouseMotionListener;

import javax.swing.JPanel;

import mot.client.swing.common.ZoneProvider;
import mot.client.swing.window.common.MotInternalWindow;
import mot.client.swing.window.main.MainWindow;
import mot.common.bean.Location;
import mot.common.util.ApplicationError;

/**
 * This is an animations displayed on the radar panel representing 
 * the location of the current object the user has selected.
 */
public class GalaxyWindowRadarCarrotFactory implements GalaxyWindowRadarCarrotTerminator, MouseListener, MouseMotionListener {
	
	
	public static void create(Location location, JPanel panel) throws ApplicationError {
		GalaxyWindowConfig galaxyConfig = MainWindow.getInstance().getGalaxyMapConfiguration();
		GalaxyWindowRadarPanel radarPanel = galaxyConfig.getGalaxyView().getRadarPanel();
		GalaxyWindowRadarCarrotFactory carrotFactory = new GalaxyWindowRadarCarrotFactory(location, radarPanel);
		panel.addMouseListener(carrotFactory);
	}

	public static void create(Location location, JPanel panel, ZoneProvider hotZone) throws ApplicationError {
		GalaxyWindowConfig galaxyConfig = MainWindow.getInstance().getGalaxyMapConfiguration();
		GalaxyWindowRadarPanel radarPanel = galaxyConfig.getGalaxyView().getRadarPanel();
		GalaxyWindowRadarCarrotFactory carrotFactory = new GalaxyWindowRadarCarrotFactory(location, radarPanel, hotZone);
		panel.addMouseListener(carrotFactory);
		panel.addMouseMotionListener(carrotFactory);
	}

	public static void create(Location location, MotInternalWindow window) throws ApplicationError {
		GalaxyWindowConfig galaxyConfig = MainWindow.getInstance().getGalaxyMapConfiguration();
		GalaxyWindowRadarPanel radarPanel = galaxyConfig.getGalaxyView().getRadarPanel();
		GalaxyWindowRadarCarrot carrot = new GalaxyWindowRadarCarrot(location, window);
		radarPanel.setCarrot(carrot);
	}

	public static void create(Location location, int qtySecs) throws ApplicationError {
		GalaxyWindowConfig galaxyConfig = MainWindow.getInstance().getGalaxyMapConfiguration();
		GalaxyWindowRadarPanel radarPanel = galaxyConfig.getGalaxyView().getRadarPanel();
		GalaxyWindowRadarCarrot carrot = new GalaxyWindowRadarCarrot(location, qtySecs);
		radarPanel.setCarrot(carrot);
	}
	
	
	
	/**
	 * If this is not null, the carrot should only be displayed when the mouse is in this area.
	 */
	private ZoneProvider zone;
	
	/**
	 * Creates a new carrot every time the mouse enters this panel that
	 * expires when the mouse leaves this panel.
	 */
	private GalaxyWindowRadarPanel radarPanel;
	
	/**
	 * The carrot that will be displayed in the radar panel.
	 */
	private GalaxyWindowRadarCarrot carrot;
	
	/**
	 * This carrot will expire when the mouse leaves the panel passes in.
	 */
	private GalaxyWindowRadarCarrotFactory(Location location, GalaxyWindowRadarPanel radarPanel) {
		this.radarPanel = radarPanel;
		this.carrot = new GalaxyWindowRadarCarrot(location);
	}

	private GalaxyWindowRadarCarrotFactory(Location location, GalaxyWindowRadarPanel radarPanel, ZoneProvider zone) {
		this(location, radarPanel);
		this.zone = zone;
	}

	public void mouseClicked(MouseEvent e) { }
	public void mouseEntered(MouseEvent e) { 
		radarPanel.setCarrot(carrot); 
	}
	public void mouseExited(MouseEvent e) { 
		GalaxyWindowRadarCarrot carrot = radarPanel.getCarrot();
		if (carrot != null) {
			radarPanel.setCarrot(null);
		}
	}
	public void mousePressed(MouseEvent e) { }
	public void mouseReleased(MouseEvent e) { }

	
	
	public void mouseDragged(MouseEvent e) {
	}
	public void mouseMoved(MouseEvent e) {
		if (zone == null) return;
		Location mouseLoc = new Location(e.getX(), e.getY());
		if (zone.contains(mouseLoc)) {
			if (radarPanel.getCarrot() != carrot) {
				radarPanel.setCarrot(carrot);
			}
		} else {
			if (radarPanel.getCarrot() == carrot) {
				radarPanel.setCarrot(null);
			}
		}
	}

}
