/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.galaxy;

import javax.swing.BorderFactory;
import javax.swing.JLabel;
import javax.swing.border.EtchedBorder;

import mot.client.actions.MotAction;
import mot.client.deligates.UserPlayerDelegate;
import mot.client.deligates.cache.DeligateCacheManager;
import mot.client.swing.common.ComponentTable;
import mot.client.swing.common.MotLabel;
import mot.client.swing.common.PanelUtils;
import mot.client.swing.config.ImageConfigFactory;
import mot.client.swing.panels.ImagePanel;
import mot.client.swing.panels.ResearchProgressBar;
import mot.client.swing.window.galaxy.actions.EndTurnButton;
import mot.client.swing.window.main.MainWindow;
import mot.client.swing.window.main.MotListener;
import mot.common.bean.Size;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.Formatter;
import mot.common.util.ValidationError;

/**
 * This is the panel containing a status information such as the date,
 * money in the bank and the quantity of free transports of the player.
 */
public class GalaxyWindowStatusPanel extends ComponentTable {

	private EndTurnButton endTurnButton;
	private MotLabel transportField = new MotLabel();
    private MotLabel fundsField = new MotLabel();
    private MotLabel yearField = new MotLabel();// (null, 0, JLabel.CENTER, true);
	private ResearchProgressBar researchProgressBar;
    private MotLabel spyField = new MotLabel();
    
	public GalaxyWindowStatusPanel(MotListener listener) throws ApplicationError {
		super("L,HV,L,HV", 4, 4, 0, 3, 3);
		setGridWidths("0.0f,0.5f,0.0f,0.5f");

		setBorder(BorderFactory.createEtchedBorder(EtchedBorder.RAISED));

		MotAction openResearchWindowAction = new MotAction() {
			public void doubleClick() throws ApplicationError, ValidationError { }
			public void click() throws ApplicationError, ValidationError {  MainWindow.getInstance().getGalaxyMapConfiguration().getListener().playActionSound(); MainWindow.getInstance().getGalaxyMapConfiguration().getListener().openResearchWindow(MainWindow.getOwner(), false, false);	}
		};
		
        researchProgressBar = new ResearchProgressBar(true, openResearchWindowAction);

        endTurnButton = new EndTurnButton();
        endTurnButton.addMouseWheelListener(listener);
        
        ImagePanel transportIcon = new ImagePanel(ImageConfigFactory.getImageForConfig("TransportIcon"), new Size(15,20));
        ImagePanel fundsIcon = new ImagePanel(ImageConfigFactory.getImageForConfig("Gold"), new Size(15,20));
        ImagePanel dateIcon = new ImagePanel(ImageConfigFactory.getImageForConfig("HourGlass"), new Size(15,20));
        ImagePanel spyIcon = new ImagePanel(ImageConfigFactory.getImageForConfig("SpyIcon"), new Size(15,20));
        JLabel dateLabel = PanelUtils.createLabel(L.YEAR);
        
        add( researchProgressBar, "FHVPS" );
		add( fundsIcon );
        add( fundsField );
		add( transportIcon );
        add( transportField );
		add( dateIcon );
        add( yearField );
		add( spyIcon );
        add( spyField );
        add( endTurnButton, "FHVPS" );
        
        transportIcon.setToolTipText(L.TT_STATUS_TRANSPORTS);
        transportField.setToolTipText(L.TT_STATUS_TRANSPORTS);
        
        fundsIcon.setToolTipText(L.TT_STATUS_FUNDS);
        fundsField.setToolTipText(L.TT_STATUS_FUNDS);
        
        dateLabel.setToolTipText(L.TT_STATUS_DATE);
        yearField.setToolTipText(L.TT_STATUS_DATE);
        
        spyIcon.setToolTipText(L.TT_STATUS_SPY);
        spyField.setToolTipText(L.TT_STATUS_SPY);
        
        setOpaque(true);
        addMouseWheelListener(listener);
	}

    public void updateStatus(UserPlayerDelegate owner) throws ApplicationError, ValidationError {
    	if (owner != null) {
	        int qtyFreeTransport = owner.getQtyFreeTransport();
			transportField.setText(""+qtyFreeTransport);
	        int funds = owner.getFunds();
			int netIncome = owner.getNetIncome();
			fundsField.setText(Formatter.whole(funds)+Formatter.wholeWithSign(netIncome));
	        yearField.setText(""+DeligateCacheManager.getDate());
	        spyField.setText(""+owner.getQtySpiesDefending());
	        researchProgressBar.updateStatus(owner);
    	}
    }

	public EndTurnButton getEndTurnButton() {
		return endTurnButton;
	}

}
