/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.galaxy;

import javax.swing.JSlider;

import mot.client.swing.common.PanelUtils;
import mot.client.swing.window.galaxy.actions.ActionChangeZoom;
import mot.common.util.ApplicationError;

public class GalaxyZoomSlider extends JSlider {
	
	public static final int MAX_ZOOM = 100;
	public static int MIN_ZOOM = 1;
	public static final float SCALE_FACTOR = 1.5f;
	public static final int DEFAULT_ZOOM = 30;
	
    /**
     * When the zoom scale is being moved it will mode the scroll bars, but this 
     * move should not be considered as a move by the user of the scroll bars. 
     */
    public boolean _ignoreScrollBarChange = false;
    
    private ActionChangeZoom listener;

	public ActionChangeZoom getListener() {
		return listener;
	}

	public GalaxyZoomSlider(GalaxyView view) throws ApplicationError {
		super(JSlider.HORIZONTAL, MIN_ZOOM, MAX_ZOOM, DEFAULT_ZOOM);
		
    	listener = new ActionChangeZoom(this, view);
		addChangeListener(listener);
    	view.getMapPanelScrollPane().getHorizontalScrollBar().addAdjustmentListener(listener);
    	view.getMapPanelScrollPane().getVerticalScrollBar().addAdjustmentListener(listener);
    	
        PanelUtils.setTheBloodySize(this, 150, 20);
    	//setPreferredSize(new Dimension(100, 20));
    	//setMaximumSize(new Dimension(110, 20));
    	//setMaximumSize(new Dimension(100, 25));
	}

}
