/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.galaxy;

import java.awt.BorderLayout;
import java.awt.Font;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import mot.client.deligates.UserPlayerDelegate;
import mot.client.sounds.SoundEffect;
import mot.client.sounds.Sounds;
import mot.client.swing.common.ComponentTable;
import mot.client.swing.common.MotBorder;
import mot.client.swing.common.PanelUtils;
import mot.client.swing.window.common.MessagePanel;
import mot.client.swing.window.common.MotInternalWindow;
import mot.common.event.PrizeGiftEvent;
import mot.common.lang.L;
import mot.common.util.ApplicationError;

public class PrizeGiftGraphicWindow extends MotInternalWindow implements ActionListener {

    private PrizePicturePanel imagePanel;
    private PrizeGiftEvent event;
	

    public PrizeGiftGraphicWindow(MotInternalWindow parent, PrizeGiftEvent prizeEvent, UserPlayerDelegate user)throws ApplicationError {
        super(user, parent, prizeEvent.isPrize() ? L.DISCOVER_PRIZE : L.GIFT_NOTIFICATION, null);
        this.event = prizeEvent;

        String description = event.getDescription();
        ComponentTable mainPanel = new ComponentTable("HV", 2, 1, 25, 5, 0);
        imagePanel = new PrizePicturePanel(event.getImageConfigName(), event.getTechFullName(), user);
        //imagePanel.setMaximumSize(new Dimension(200, 200));
        PanelUtils.setTheBloodySize(imagePanel, 200, 200);
        ComponentTable innerPanel = new ComponentTable("C", 1, 1, 0, 0, 0);
        innerPanel.add(new MotBorder(imagePanel));
		mainPanel.add(innerPanel,"HVPS");
        Font font = new Font(Font.SERIF, Font.BOLD, 18);
		mainPanel.add(new MessagePanel(description, 80, font, null),"HV");
        
        getContentPane().add(mainPanel, BorderLayout.CENTER);
        
        ComponentTable buttonPanel = new ComponentTable("HVPS", 1, 1, 0, 0, 0);
        buttonPanel.add(PanelUtils.createButton(L.CLOSE, this), "C");
        getContentPane().add(buttonPanel, BorderLayout.SOUTH);
  
        SoundEffect sound = Sounds.getSound("DiscoverPrize");
		if (sound != null) {
			sound.play();
		}        
        show();
        waitUntilClosed();
    }
    
    

    public void actionPerformed(ActionEvent e) {
        hide();
    }
 
}