/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.galaxy;

import mot.client.deligates.UserPlayerDelegate;
import mot.client.swing.config.ImageConfig;
import mot.client.swing.config.ImageConfigFactory;
import mot.client.swing.panels.BackgroundImagePanel;
import mot.client.swing.panels.RacePicturePanel;
import mot.client.swing.panels.TechnologyPicturePanel;
import mot.common.technology.Technologies;
import mot.common.technology.Technology;
import mot.common.util.ApplicationError;
import mot.common.util.Logger;

public class PrizePicturePanel extends BackgroundImagePanel {
	
	private String imageConfigName;
	private String techFullName;
	private UserPlayerDelegate owner;

	PrizePicturePanel(String imageConfigName, String techFullName, UserPlayerDelegate owner) {
		this.imageConfigName = imageConfigName;
		this.techFullName = techFullName;
		this.owner = owner;
		
	}
	
	protected String getImage() {
	    if (imageConfigName != null) {
			ImageConfig imageConfig = ImageConfigFactory.getImageConfigNoError(imageConfigName);
	        if (imageConfig != null) {
	        	return imageConfig.getImage();
	        }
	    }
		if (techFullName != null) {
	    	Technology tech;
			try {
				tech = Technologies.getTechnology(techFullName);
	        	if (tech != null) {
	        		return TechnologyPicturePanel.getImage(tech);
	        	} else {
	        		Logger.logWarning("PrizeGraphicWindow.init() No tech for "+techFullName);
	        	}
			} catch (ApplicationError e) {
				Logger.logError("PrizeGraphicWindow.init()", e);
			}
	    }
	    try {
			return RacePicturePanel.getImageForRace(owner);
		} catch (ApplicationError e) {
			Logger.logError("PrizeGraphicWindow.init()", e);
		}
	    return null;
	}

	protected void drawSizeRelativeObjects() {
	}
}   

