/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.galaxy;

import java.awt.AlphaComposite;
import java.awt.Color;
import java.awt.Composite;
import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.Image;
import java.awt.Transparency;
import java.awt.image.BufferedImage;
import java.util.ArrayList;
import java.util.Iterator;

import javax.swing.ImageIcon;

import mot.common.bean.Location;

public class RangeImage {
	
	private int width;
	private int height; 

	private ArrayList locations = new ArrayList();
	
	private ImageIcon icon;

	public RangeImage(int width, int height) {
		this.width = width;
		this.height = height;
	}
	
	public void addRangeLocation(Location location) {	
		locations.add(location);
	}
    
    private static final Color rangeColour = new Color(30, 30, 30);
    
	public void calculateImage(int range) {	
		BufferedImage normalImage = new BufferedImage(width, height,  BufferedImage.TYPE_INT_RGB);
		Graphics g1 =  normalImage.getGraphics();
		g1.setColor(rangeColour);
		for (Iterator i = locations.iterator(); i.hasNext();) {
			Location l = (Location) i.next();			
			g1.fillOval(l.getX() - range, l.getY() - range, range*2, range*2);
		}
		g1.dispose();
		
		BufferedImage image = new BufferedImage(width, height, Transparency.TRANSLUCENT);
		Graphics2D g2 = (Graphics2D) image.getGraphics();
		Composite alpha = AlphaComposite.getInstance(AlphaComposite.SRC_OVER, 0.25f);
		g2.setComposite(alpha);
		g2.drawImage(normalImage, 0, 0, null);
        g2.dispose();
		
		icon = new ImageIcon( image );
	}
    
	public Image getImage() {
		if (icon == null) {
			return null;
		} else {
			return icon.getImage();
		}
	}

	public int getWidth() {
		return width;
	}

	public int getHeight() {
		return height;
	}

}
