/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.galaxy;

import java.awt.Container;
import java.awt.Graphics2D;

import mot.client.actions.ActiveRectangle;
import mot.client.animation.GalaxyAnimation;
import mot.client.swing.animation.strokes.WarpTrailStroke;
import mot.client.swing.config.ImageStrokeAnimationConfig;
import mot.common.bean.Location;
import mot.common.util.ApplicationError;

public class TrailAnimation extends GalaxyAnimation {

	private ActiveRectangle source;
	private ActiveRectangle destination;
	private Container container;
	private WarpTrailStroke stroke;

	public TrailAnimation(ActiveRectangle source, ActiveRectangle destination, Container container, ImageStrokeAnimationConfig config) {
		super(config.getLife(), config.getInterval());
		this.source = source;
		this.destination = destination;
		this.container = container;
		this.stroke = new WarpTrailStroke(config);
	}

	public void paint(Graphics2D graphics) throws ApplicationError {
		Location s = source.getCenterLocation();
		Location d = destination.getCenterLocation();
		double direction = s.getAccurateDirectionFor(d);
		s.shiftInDirectionWithDouble(direction, source.getWidth()/2);
		stroke.paint(container, graphics, getStage(), s, d);
	}

	public ActiveRectangle getSource() {
		return source;
	}

	public ActiveRectangle getDestination() {
		return destination;
	}

}
