/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.galaxy;

import java.awt.Container;
import java.awt.Graphics2D;

import mot.client.actions.ActiveRectangle;
import mot.client.animation.GalaxyAnimation;
import mot.client.swing.animation.scroll.ImageScroll;
import mot.client.swing.config.AnimationConfigFactory;
import mot.client.swing.config.ImageScrollAnimationConfig;
import mot.common.bean.Location;
import mot.common.util.ApplicationError;
import mot.common.util.Utils;

public class TrailAnimationResourceMine extends GalaxyAnimation {

	private static final String CONFIG1 = "ResourceMineTrail1";
	private static final String CONFIG2 = "ResourceMineTrail2";
	private static final String CONFIG3 = "ResourceMineTrail3";

	private GalaxyMapPlanet minePlanet;
	private GalaxyMapPlanet colonyPlanet;
	private Container container;
	private int speed;
	private ImageScroll scroll;

	public TrailAnimationResourceMine(GalaxyMapPlanet minePlanet, GalaxyMapPlanet colonyPlanet, Container container) throws ApplicationError {
		super(0,0, minePlanet.getName()+colonyPlanet.getName());
		
		// This output includes output from the mine
		int gdp = colonyPlanet.getPlanet().getTotalOutput();
		ImageScrollAnimationConfig config = null;
		if (gdp < 400) {
			config = AnimationConfigFactory.getInstance().getImageScrollAnimationConfig(CONFIG1);
		} else if (gdp < 800) {
			config = AnimationConfigFactory.getInstance().getImageScrollAnimationConfig(CONFIG2);
		} else {			
			config = AnimationConfigFactory.getInstance().getImageScrollAnimationConfig(CONFIG3);
		}

		setLife(config.getLife());
		setInterval(config.getInterval());
		if (getStage() == 0) {
			setStage(Utils.random(config.getSize().getY()));
		}

		this.minePlanet = minePlanet;
		this.colonyPlanet = colonyPlanet;
		this.container = container;
		this.speed = config.getSpeed();
		this.scroll = new ImageScroll(config);
	}        

    public boolean isComplete() {
    	return false;
    }

	public void paint(Graphics2D graphics) throws ApplicationError {
		Location d = minePlanet.getCenterLocation();
		Location s = colonyPlanet.getCenterLocation();
		scroll.paint(container, graphics, getStage()*speed, s, d);
	}

	public ActiveRectangle getSource() {
		return minePlanet;
	}

	public ActiveRectangle getDestination() {
		return colonyPlanet;
	}

}
