/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.galaxy;

import java.awt.Container;
import java.awt.Graphics2D;

import mot.client.actions.ActiveRectangle;
import mot.client.animation.GalaxyAnimation;
import mot.client.deligates.TradeRouteDelegate;
import mot.client.swing.animation.scroll.ImageScroll;
import mot.client.swing.config.AnimationConfigFactory;
import mot.client.swing.config.ImageScrollAnimationConfig;
import mot.common.bean.Location;
import mot.common.util.ApplicationError;
import mot.common.util.Utils;

public class TrailAnimationTradeRoute extends GalaxyAnimation {

	private static final String TRADE_ROUTE1_ANIMATION = "TradeRoute1Animation";
	private static final String TRADE_ROUTE2_ANIMATION = "TradeRoute2Animation";
	private static final String TRADE_ROUTE3_ANIMATION = "TradeRoute3Animation";
	
	private GalaxyMapStellarObject source;
	private GalaxyMapStellarObject destination;
	private Container container;
	private int speed;
	private ImageScroll scroll;

	public TrailAnimationTradeRoute(TradeRouteDelegate tradeRoute, GalaxyMapStellarObject source, GalaxyMapStellarObject destination, Container container) throws ApplicationError {
		super(0,0, source.getName()+destination.getName());
		
		ImageScrollAnimationConfig config = null;
		int gdp = tradeRoute.getTotalIndustryOutput();
		if (gdp < 600) {
			config = AnimationConfigFactory.getInstance().getImageScrollAnimationConfig(TRADE_ROUTE1_ANIMATION);
		} else if (gdp < 1200) {
			config = AnimationConfigFactory.getInstance().getImageScrollAnimationConfig(TRADE_ROUTE2_ANIMATION);
		} else {			
			config = AnimationConfigFactory.getInstance().getImageScrollAnimationConfig(TRADE_ROUTE3_ANIMATION);
		}
			 
		setLife(config.getLife());
		setInterval(config.getInterval());
		if (getStage() == 0) {
			setStage(Utils.random(config.getSize().getY()));
		}
		
		this.source = source;
		this.destination = destination;
		this.container = container;
		this.speed = config.getSpeed();
		this.scroll = new ImageScroll(config);
	}        

    public boolean isComplete() {
    	return false;
    }

	public void paint(Graphics2D graphics) throws ApplicationError {
		Location s = source.getCenterLocation();
		Location d = destination.getCenterLocation();
		int stage = getStage();
		scroll.paint(container, graphics, stage*speed, s, d);
	}

	public ActiveRectangle getSource() {
		return source;
	}

	public ActiveRectangle getDestination() {
		return destination;
	}

}
