/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.galaxy;

import java.awt.Container;
import java.awt.Graphics2D;

import mot.client.actions.ActiveRectangle;
import mot.client.animation.GalaxyAnimation;
import mot.client.swing.animation.scroll.ImageScroll;
import mot.client.swing.config.AnimationConfigFactory;
import mot.client.swing.config.ImageScrollAnimationConfig;
import mot.common.bean.Location;
import mot.common.util.ApplicationError;

public class TrailAnimationWarp extends GalaxyAnimation {

	private static final String WARP_ANIMATION = "WarpTrailAnimation";
	
	private ActiveRectangle source;
	private ActiveRectangle destination;
	private Container container;
	private int speed;
	private ImageScroll scroll;

	public TrailAnimationWarp(ActiveRectangle source, ActiveRectangle destination, Container container) throws ApplicationError {
		super(0,0);
		
		ImageScrollAnimationConfig config = AnimationConfigFactory.getInstance().getImageScrollAnimationConfig(WARP_ANIMATION);
			 
		setLife(config.getLife());
		setInterval(config.getInterval());

		this.source = source;
		this.destination = destination;
		this.container = container;
		this.speed = config.getSpeed();
		this.scroll = new ImageScroll(config);
	}        

    public boolean isComplete() {
    	return false;
    }

	public void paint(Graphics2D graphics) throws ApplicationError {
		Location d = source.getCenterLocation();
		Location s = destination.getCenterLocation();
		int stage = getStage();
		//Logger.logDebug("source "+source+" stage "+stage);
		scroll.paint(container, graphics, stage*speed, s, d);
	}

	public ActiveRectangle getSource() {
		return source;
	}

	public ActiveRectangle getDestination() {
		return destination;
	}

}
