/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.galaxy.actions;

import mot.client.deligates.CraftDelegate;
import mot.client.deligates.FleetDelegate;
import mot.client.deligates.MoveableOwnedObjectDelegate;
import mot.client.deligates.TransportDelegate;
import mot.client.proxy.CompletedCallback;
import mot.client.proxy.ProxyStore;
import mot.client.swing.window.galaxy.GalaxyWindowListener;
import mot.client.swing.window.galaxy.GalaxyWindowMenuButton;
import mot.client.swing.window.galaxy.MotGalaxyMapActions;
import mot.client.swing.window.main.MainWindow;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class ActionButtonCraftDelete extends GalaxyWindowMenuButton implements MotGalaxyMapActions, CompletedCallback {


	public ActionButtonCraftDelete(GalaxyWindowListener listener) throws ApplicationError {
		super(listener, MENU_CRAFT_DELETE, new Character('x'));
		setTip(L.DELEET_THE_CURRENTLY_SELECTED_CRAFT);
	}

	
	private MoveableOwnedObjectDelegate selection;
	
	protected void _doAction() throws ApplicationError, ValidationError {
    	MainWindow mainWindow = MainWindow.getInstance();
    	selection = listener.getSelectedMoo();
        if (selection != null && (selection instanceof CraftDelegate || selection instanceof FleetDelegate || selection instanceof TransportDelegate)) {
            ProxyStore.getInstance().mooDeleteCmd(selection, this, this);
        } else {
            throw new ValidationError(L.INVALID_COMMAND_PLEASE_SELECT_A_CRAFT_FIRST);
        }                
	}

	@Override
	public void complete(Object result) throws ApplicationError, ValidationError {
        if (selection != null) {
        	//OrbitVO orbit = selection.getOrbit();
        	//boolean hasNavigator = selection.hasNavigator();
            //listener.setDescription((MoveableOwnedObjectDelegate)null);
        	//view.getContextPanel().updateSelectionAt(orbit, hasNavigator);
        	view.getMapPanel().updateMooList(null);
        }
        view.getStatusPanel().updateStatus(getOwner());
        view.getMapPanel().rebuildContent();
	}
	
}
