/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.galaxy.actions;

import mot.client.deligates.MoveableOwnedObjectDelegate;
import mot.client.deligates.PlanetDelegate;
import mot.client.deligates.StellarObjectDelegate;
import mot.client.deligates.UserPlayerDelegate;
import mot.client.deligates.cache.DeligateCacheManager;
import mot.client.proxy.CompletedCallback;
import mot.client.proxy.ProxyStore;
import mot.client.swing.window.galaxy.GalaxyWindowListener;
import mot.client.swing.window.galaxy.GalaxyWindowMenuButton;
import mot.client.swing.window.galaxy.MotGalaxyMapActions;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;
import mot.common.vo.OrbitVO;

public class ActionButtonCraftDeploy extends GalaxyWindowMenuButton implements MotGalaxyMapActions, CompletedCallback {


	public ActionButtonCraftDeploy(GalaxyWindowListener listener) throws ApplicationError {
		super(listener, MENU_CRAFT_DEPLOY, null);
		setTip(L.DEPLOY_THE_CURRENTLY_SELECTED_MOO);
	}

	protected void _doAction() throws ApplicationError, ValidationError {
    	UserPlayerDelegate owner = getOwner();
        MoveableOwnedObjectDelegate moo = listener.getSelectedMooInOrbit();
        OrbitVO orbit = moo.getOrbit();
        StellarObjectDelegate sod = DeligateCacheManager.getStellarObject(orbit);
        PlanetDelegate pd = DeligateCacheManager.getPlanet(orbit);
        ProxyStore.getInstance().mooDeploy(moo, sod, pd, this, this);
	}

	@Override
	public void complete(Object result) throws ApplicationError, ValidationError {
    	view.getMapPanel().updateMooList(null);
	}

}
