/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.galaxy.actions;

import mot.client.deligates.MoveableOwnedObjectDelegate;
import mot.client.deligates.PlanetDelegate;
import mot.client.deligates.SolarSystemDelegate;
import mot.client.deligates.StellarObjectDelegate;
import mot.client.deligates.TransportDelegate;
import mot.client.deligates.UserPlayerDelegate;
import mot.client.deligates.cache.DeligateCacheManager;
import mot.client.proxy.ProxyStore;
import mot.client.swing.window.galaxy.GalaxyWindowListener;
import mot.client.swing.window.galaxy.GalaxyWindowMenuButton;
import mot.client.swing.window.galaxy.MotGalaxyMapActions;
import mot.client.swing.window.main.MainWindow;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class ActionButtonCraftInvade extends GalaxyWindowMenuButton implements MotGalaxyMapActions {

	public ActionButtonCraftInvade(GalaxyWindowListener listener) throws ApplicationError {
		super(listener, MENU_CRAFT_INVADE, new Character('i'));
		setTip(L.INVADE_AN_ENEMY_PLANET);
	}

	protected void _doAction() throws ApplicationError, ValidationError {
    	MainWindow mainWindow = MainWindow.getInstance();
    	UserPlayerDelegate owner = getOwner();
        MoveableOwnedObjectDelegate moo = listener.getSelectedMooInOrbit();
        if (moo == null) {
            throw new ValidationError(L.INVALID_COMMAND_PLEASE_SELECT_A_CRAFT_FIRST);
        }
        StellarObjectDelegate so = DeligateCacheManager.getStellarObject(moo.getOrbit().getStellarObject());
        if (!so.hasOwner() || !owner.isEnemy(so.getOwners())) {
            throw new ValidationError(L.INVALID_COMMAND_YOU_DO_NOT_HAVE_AN_ENEMY_AT_THIS_LOCATION);
        }
        if (!(so instanceof SolarSystemDelegate)) {
            throw new ValidationError(L.INVALID_COMMAND_CANNOT_ATTACK_THIS_TYPE_OF_STELLAR_OBJECT);
        }
        if (!(moo instanceof TransportDelegate)) {
            throw new ValidationError(L.INVALID_COMMAND_ONLY_TRANSPORTS_WITH_TROOPS_CAN_INVADE);
        }
        TransportDelegate transport = (TransportDelegate) moo;
        PlanetDelegate colony = listener.getColonyToAttack(moo.getOrbit(), false, false);
        if (colony != null) {
            ProxyStore.getInstance().invadePlanet(transport, colony, this);
        }
	}

}
