/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.galaxy.actions;

import mot.client.animation.GalaxyAnimationRegister;
import mot.client.deligates.UserPlayerDelegate;
import mot.client.proxy.CompletedCallback;
import mot.client.proxy.ProxyStore;
import mot.client.swing.window.etc.LoadWindow;
import mot.client.swing.window.galaxy.GalaxyWindowListener;
import mot.client.swing.window.galaxy.GalaxyWindowMenuButton;
import mot.client.swing.window.galaxy.GalaxyWindowView;
import mot.client.swing.window.galaxy.MotGalaxyMapActions;
import mot.client.swing.window.main.MainWindow;
import mot.common.command_results.StringCR;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class ActionButtonLoad extends GalaxyWindowMenuButton implements MotGalaxyMapActions {


	public ActionButtonLoad(GalaxyWindowListener listener) throws ApplicationError {
		super(listener, MENU_GALAXY_LOAD, new Character('l'));
		setTip(L.LOAD_AN_OLD_GAME_THAT_YOU_HAVE_PREVIOUSLY_SAVED);
	}

	protected void _doAction() throws ApplicationError, ValidationError {
		CompletedCallback callback = new CompletedCallback() {
			public void complete(Object result) throws ApplicationError, ValidationError {
		        String ownerName = ((StringCR)result).getValue();
		        if (ownerName != null) {
		        	MainWindow mainWindow = MainWindow.getInstance();
		        	listener.clearSelection();
		            CompletedCallback registerCallback = new CompletedCallback() {
		    			public void complete(Object result) throws ApplicationError, ValidationError {
		    				UserPlayerDelegate owner = (UserPlayerDelegate) result;
				            // Get the Owner Delegate
				        	MainWindow mainWindow = MainWindow.getInstance();
				            mainWindow.setWindowOwner(owner.getName());
				            // Rebuild content is important here otherwise focus pn home SS causes a 
				            // repaint and the delegate cache will get filled with obsolete delegates.
				    		GalaxyAnimationRegister.clean();
				            view.getMapPanel().rebuildContent();
				    		view.getRadarPanel().repaint();
				            listener.setMapWindowSize();
				            listener.focusOnHomeSolarSystem();
				            GalaxyWindowView galaxyView = mainWindow.getGalaxyMapConfiguration().getGalaxyView();
							galaxyView.updateStatus(owner);
							galaxyView.getMessageList().removeAllMessages();
							mainWindow.toGalaxyWindow();
		    			}
		            };
		            ProxyStore.getInstance().register(ownerName, false, registerCallback, null);
		        }
			}
		};
		new LoadWindow(null, null, callback, false);
        //LoadGameButton.load(null, null, callback, this);		
	}

}
