/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.galaxy.actions;

import mot.client.deligates.MoveableOwnedObjectDelegate;
import mot.client.deligates.PlanetDelegate;
import mot.client.deligates.SolarSystemDelegate;
import mot.client.deligates.StellarObjectDelegate;
import mot.client.deligates.cache.DeligateCacheManager;
import mot.client.proxy.CompletedCallback;
import mot.client.proxy.ProxyStore;
import mot.client.swing.window.galaxy.GalaxyMapPanel;
import mot.client.swing.window.galaxy.GalaxyWindowListener;
import mot.client.swing.window.galaxy.MotGalaxyMapActions;
import mot.client.swing.window.main.MainWindow;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class GalaxyMapButtonCraftAttack extends GalaxyMapButton implements MotGalaxyMapActions, CompletedCallback {

	private MoveableOwnedObjectDelegate craft;

	public GalaxyMapButtonCraftAttack(GalaxyWindowListener listener, int x, int y) throws ApplicationError {
		super(listener, MENU_CRAFT_ATTACK, new Character('a'), x, y);
		setTip(L.ATTACK_AN_ENEMY_PLANET_CRAFT_OR_FLEET);
	}

	protected void _doAction() throws ApplicationError, ValidationError {
        craft = listener.getSelectedMooInOrbit();
        if (craft == null) {
            throw new ValidationError(L.INVALID_COMMAND_PLEASE_SELECT_A_CRAFT_FIRST);
        }
        
        StellarObjectDelegate so = DeligateCacheManager.getStellarObject(craft.getOrbit().getStellarObject());
        if (so instanceof SolarSystemDelegate) {
	        PlanetDelegate planet = listener.getColonyToAttack(craft.getOrbit(), true, true);
	        ProxyStore.getInstance().craftAttackCmd( craft, planet, this, this );
        } else {
	        ProxyStore.getInstance().craftAttackCmd( craft, null, this, this );
        }
        
        MainWindow.getInstance().showTemporaryMessage(L.BATTLES_OCCUR_AT_END_OF_TURN, true, null, 0);
	}

	public void doubleClick() throws ApplicationError, ValidationError {
	}

	@Override
	public void complete(Object result) throws ApplicationError, ValidationError {
        GalaxyMapPanel mapPanel = listener.getView().getMapPanel();
        if (craft != null) mapPanel.updateMooList(craft);
	}

}
