/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.galaxy.actions;

import mot.client.deligates.CraftDelegate;
import mot.client.deligates.FleetDelegate;
import mot.client.deligates.MoveableOwnedObjectDelegate;
import mot.client.deligates.SolarSystemDelegate;
import mot.client.deligates.StellarObjectDelegate;
import mot.client.deligates.cache.DeligateCacheManager;
import mot.client.swing.window.galaxy.GalaxyWindowListener;
import mot.client.swing.window.galaxy.MotGalaxyMapActions;
import mot.client.swing.window.main.MainWindow;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;
import mot.common.vo.OrbitVO;

public class GalaxyMapButtonCraftColonise extends GalaxyMapButton implements MotGalaxyMapActions {

	public GalaxyMapButtonCraftColonise(GalaxyWindowListener listener, int x, int y) throws ApplicationError {
		super(listener, MENU_CRAFT_COLONISE, new Character('c'), x, y);
		setTip(L.COLONISE_AN_UNINHABITED_PLANET);
	}

	protected void _doAction() throws ApplicationError, ValidationError {
    	MainWindow mainWindow = MainWindow.getInstance();
        MoveableOwnedObjectDelegate moo = listener.getSelectedMooInOrbit();
        OrbitVO so = moo.getOrbit();
        StellarObjectDelegate sod = DeligateCacheManager.getStellarObject(so);
        if (sod == null || !(sod instanceof SolarSystemDelegate)) {
            throw new ValidationError(L.INVALID_COMMAND_CRAFT_MUST_BE_IN_ORBIT_OF_A_SOLAR_SYSTEM);
        }
		SolarSystemDelegate ss = (SolarSystemDelegate)sod;
        CraftDelegate craft = null;
        if (moo instanceof CraftDelegate) {
        	craft = (CraftDelegate) moo;
        } else if (moo instanceof FleetDelegate) {
        	craft = ((FleetDelegate)moo).getBestColonyCraft();        	
        }
        if (craft == null) {
            throw new ValidationError(L.INVALID_COMMAND_PLEASE_SELECT_A_CRAFT_FIRST);
        }
        listener.openSelectPlanetForColonisation(ss, craft, true);
	}

	public void doubleClick() throws ApplicationError, ValidationError {
	}

}
