/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.galaxy.actions;

import mot.client.deligates.CraftDelegate;
import mot.client.deligates.FleetDelegate;
import mot.client.deligates.MoveableOwnedObjectDelegate;
import mot.client.deligates.TransportDelegate;
import mot.client.deligates.UserPlayerDelegate;
import mot.client.deligates.cache.DeligateCacheManager;
import mot.client.proxy.CompletedCallback;
import mot.client.proxy.ProxyStore;
import mot.client.swing.window.galaxy.GalaxyWindowListener;
import mot.client.swing.window.galaxy.GalaxyWindowView;
import mot.client.swing.window.galaxy.MotGalaxyMapActions;
import mot.client.swing.window.main.MainWindow;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;
import mot.common.vo.OrbitVO;

public class GalaxyMapButtonCraftDelete extends GalaxyMapButton implements MotGalaxyMapActions, CompletedCallback {

	private MoveableOwnedObjectDelegate selection;
	private OrbitVO selectionOrbit;

	public GalaxyMapButtonCraftDelete(GalaxyWindowListener listener, int x, int y) throws ApplicationError {
		super(listener, MENU_CRAFT_DELETE, new Character('x'), x, y);
		setTip(L.DELEET_THE_CURRENTLY_SELECTED_CRAFT);
	}

	protected void _doAction() throws ApplicationError, ValidationError {
    	selection = listener.getSelectedMoo();
        if (selection != null && (selection instanceof CraftDelegate || selection instanceof FleetDelegate || selection instanceof TransportDelegate)) {
        	selectionOrbit = selection.getOrbit();
            ProxyStore.getInstance().mooDeleteCmd(selection, this, this);
        } else {
            throw new ValidationError(L.INVALID_COMMAND_PLEASE_SELECT_A_CRAFT_FIRST);
        }                
	}

	@Override
	public void complete(Object result) throws ApplicationError, ValidationError {
		GalaxyWindowView view = listener.getView();
		UserPlayerDelegate owner = MainWindow.getOwner();
        if (selection != null) {
        	if (selectionOrbit != null) {
        		MoveableOwnedObjectDelegate moo = DeligateCacheManager.getMostVisibleMooInOrbitAtOwnedBy(selectionOrbit, owner);
        		if (moo == null) {
        			listener.clearSelection();
        		} else {
        			view.refresh();
        			listener.setSelection(moo);
        		}
        	} else {
        		listener.clearSelection();
        	}
        }
        view.getStatusPanel().updateStatus(owner);
        view.getMapPanel().rebuildContent();
	}

	public void doubleClick() throws ApplicationError, ValidationError {
	}

}
