/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.galaxy.actions;

import mot.client.deligates.CraftDelegate;
import mot.client.deligates.FleetDelegate;
import mot.client.deligates.MoveableOwnedObjectDelegate;
import mot.client.proxy.CompletedCallback;
import mot.client.proxy.ProxyStore;
import mot.client.swing.window.galaxy.GalaxyWindowListener;
import mot.client.swing.window.galaxy.MotGalaxyMapActions;
import mot.client.swing.window.main.MainWindow;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class GalaxyMapButtonCraftJoinFleet extends GalaxyMapButton implements MotGalaxyMapActions, CompletedCallback {

	private MoveableOwnedObjectDelegate craft;

	public GalaxyMapButtonCraftJoinFleet(GalaxyWindowListener listener, int x, int y) throws ApplicationError {
		super(listener, MENU_CRAFT_JOIN_FLEET, new Character('j'), x, y);
		setTip(L.MAKE_THE_CURRENTLY_SELECTED_CRAFT_JOIN_A_FLEET_AT_ITS_LOCATION);
	}

	protected void _doAction() throws ApplicationError, ValidationError {
    	MainWindow mainWindow = MainWindow.getInstance();
        craft = listener.getSelectedCraftBaseInOrbit();
        if (craft == null) {
            throw new ValidationError(L.INVALID_COMMAND_PLEASE_SELECT_A_CRAFT_FIRST);
        }
        ProxyStore.getInstance().joinFleetCmd(craft, this, this);
	}
	
	@Override
	public void complete(Object result) throws ApplicationError, ValidationError {
        if (craft != null) {
        	FleetDelegate fleet = (craft instanceof CraftDelegate) ? ((CraftDelegate)craft).getFleetDelegate() : null; 
        	listener.getView().getMapPanel().updateMooList(fleet);
        }
	}

	public void doubleClick() throws ApplicationError, ValidationError {
	}

}
