/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.galaxy.actions;

import mot.client.deligates.CraftDelegate;
import mot.client.deligates.FleetDelegate;
import mot.client.deligates.NamedObjectDelegate;
import mot.client.proxy.CompletedCallback;
import mot.client.proxy.ProxyStore;
import mot.client.swing.window.galaxy.GalaxyWindowListener;
import mot.client.swing.window.galaxy.GalaxyWindowView;
import mot.client.swing.window.galaxy.MotGalaxyMapActions;
import mot.client.swing.window.main.MainWindow;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class GalaxyMapButtonCraftLeaveFleet extends GalaxyMapButton implements MotGalaxyMapActions, CompletedCallback {

	private CraftDelegate craft;

	public GalaxyMapButtonCraftLeaveFleet(GalaxyWindowListener listener, int x, int y) throws ApplicationError {
		super(listener, MENU_CRAFT_LEAVE_FLEET, null, x, y);
		setTip(L.INSTRUCT_SELECTED_CRAFT_LEAVE_A_FLEET);
	}

	protected void _doAction() throws ApplicationError, ValidationError {
		craft = listener.getSelectedCraftInOrbit();
        if (craft == null) {
            throw new ValidationError(L.INVALID_COMMAND_PLEASE_SELECT_A_CRAFT_FIRST);
        }
        
    	MainWindow mainWindow = MainWindow.getInstance();
        ProxyStore.getInstance().craftLeaveFleetCmd(craft, this, this);
	}

	
	@Override
	public void complete(Object result) throws ApplicationError, ValidationError {
        if (craft != null) {
        	FleetDelegate fleet = ((CraftDelegate)craft).getFleetDelegate(); 
        	if (fleet != null) {
	           	GalaxyWindowView view = listener.getView();
	        	view.getMapPanel().updateMooList(fleet);
        	}
        }
	}

	public void doubleClick() throws ApplicationError, ValidationError {
	}

	public void update() throws ApplicationError {
	}

	public boolean contains(NamedObjectDelegate o) {
		return false;
	}

	public boolean contains(String name) {
		return false;
	}

	public NamedObjectDelegate getContents() {
		return null;
	}

}
