/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.galaxy.actions;

import mot.client.deligates.MoveableOwnedObjectDelegate;
import mot.client.proxy.CompletedCallback;
import mot.client.proxy.ProxyStore;
import mot.client.swing.window.galaxy.GalaxyWindowListener;
import mot.client.swing.window.galaxy.MotGalaxyMapActions;
import mot.client.swing.window.main.MainWindow;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.Logger;
import mot.common.util.ValidationError;

public class GalaxyMapButtonCraftSleep extends GalaxyMapButton implements MotGalaxyMapActions, CompletedCallback {

	public GalaxyMapButtonCraftSleep(GalaxyWindowListener listener, int x, int y) throws ApplicationError {
		super(listener, MENU_CRAFT_SLEEP, null, x, y);
		setTip(L.SLEEP_THE_CURRENTLY_SELECTED_MOO);
		setShortcut('z'); // Must not use constructor because do not want to register listener
	}

	public GalaxyMapButtonCraftSleep() throws ApplicationError {
		super(MainWindow.getExestingInstance().getGalaxyMapListener(), null, null, 0, 0);
		setShortcut('z'); // Must not use constructor because do not want to register listener
	}

	protected void _doAction() throws ApplicationError, ValidationError {
        MoveableOwnedObjectDelegate moo = listener.getSelectedMooIfInOrbit();
        _doAction(moo);
	}
	
	protected void _doAction(MoveableOwnedObjectDelegate moo) throws ApplicationError, ValidationError {
        //OrbitVO orbit = moo.getOrbit();
        ProxyStore.getInstance().mooSleep(moo, this, this);
	}

	@Override
	public void complete(Object result) throws ApplicationError, ValidationError {
    	listener.getView().getMapPanel().updateMooList(null);
	}

	public void doubleClick() throws ApplicationError, ValidationError {
	}
	
	public static void unsleep(MoveableOwnedObjectDelegate moo) {
		try {
			new GalaxyMapButtonCraftSleep()._doAction(moo);
		} catch (ApplicationError e) {
			Logger.logError("Unsleep Failed", e);
		} catch (ValidationError e) {
			MainWindow.getExestingInstance().reportValidationError(e);
		}
	}

	public static ShortcutListener getShortcutListener(GalaxyWindowListener listener) throws ApplicationError {
		return new GalaxyMapButtonCraftSleep(listener, 0,0);
	}

}
