/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.galaxy.actions;

import mot.client.deligates.MoveableOwnedObjectDelegate;
import mot.client.deligates.StellarObjectDelegate;
import mot.client.deligates.cache.DeligateCacheManager;
import mot.client.proxy.CompletedCallback;
import mot.client.proxy.ProxyStore;
import mot.client.swing.window.galaxy.GalaxyWindowListener;
import mot.client.swing.window.galaxy.GalaxyWindowView;
import mot.client.swing.window.galaxy.MotGalaxyMapActions;
import mot.client.swing.window.main.MainWindow;
import mot.common.command_results.NameListCR;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;
import mot.common.vo.OrbitVO;

public class GalaxyMapButtonCreateTradeRoute extends GalaxyMapButton implements MotGalaxyMapActions, CompletedCallback {

	private StellarObjectDelegate solarSystem;

	public GalaxyMapButtonCreateTradeRoute(StellarObjectDelegate ss, GalaxyWindowListener listener, int x, int y) throws ApplicationError {
		super(listener, MENU_CREATE_TRADE_ROUTE, null, x, y);
		this.solarSystem = ss;
		setTip(L.CREATE_TRADE_ROUTE);
	}

	protected void _doAction() throws ApplicationError, ValidationError {
		ProxyStore.getInstance().loadTransportCmd(new OrbitVO(solarSystem.getName(), null), null, 0, 2, this, this);
	}
	
	@Override
	public void complete(Object result) throws ApplicationError, ValidationError {
        GalaxyWindowView view = listener.getView();
		view.getMapPanel().refresh();
        if (result != null && result instanceof NameListCR) {
        	String [] transportNames = ((NameListCR) result).getNames();
        	if (transportNames != null && transportNames.length > 0) {        		
        		MoveableOwnedObjectDelegate transport = DeligateCacheManager.getMoo(transportNames[0]);
        		listener.setSelection(transport);
        	}
            view.getStatusPanel().updateStatus(MainWindow.getOwner());
        }
	}

	public void doubleClick() throws ApplicationError, ValidationError {
	}

}
