/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.galaxy.actions;

import mot.client.deligates.NamedObjectDelegate;
import mot.client.deligates.PlanetDelegate;
import mot.client.deligates.StellarObjectDelegate;
import mot.client.proxy.CompletedCallback;
import mot.client.proxy.ProxyStore;
import mot.client.swing.window.galaxy.GalaxyMapPanel;
import mot.client.swing.window.galaxy.GalaxyWindowContextPanel;
import mot.client.swing.window.galaxy.GalaxyWindowListener;
import mot.client.swing.window.galaxy.MotGalaxyMapActions;
import mot.client.swing.window.main.MainWindow;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;
import mot.common.vo.OrbitVO;

public class GalaxyMapButtonSetWaypoint extends GalaxyMapButton implements MotGalaxyMapActions, CompletedCallback {

	public GalaxyMapButtonSetWaypoint(GalaxyWindowListener listener, int x, int y) throws ApplicationError {
		super(listener, MENU_SET_WAYPOINT, null, x, y);
		setTip(L.SET_WAYPOINT);
	}

	protected void _doAction() throws ApplicationError, ValidationError {
    	MainWindow mainWindow = MainWindow.getInstance();
        NamedObjectDelegate selection = listener.getSelection();
        if (selection == null) {
        	throw new ValidationError(L.INVALID_COMMAND_PLEASE_SELECT_A_OBJECT_FIRST);
        }
        if (selection instanceof StellarObjectDelegate) {
        	OrbitVO orbit = ((StellarObjectDelegate)selection).getOrbit();
        	ProxyStore.getInstance().setFleetWayPoint(orbit, this, this);
        	return;
        }
        if (selection instanceof PlanetDelegate) {
        	OrbitVO orbit = ((PlanetDelegate)selection).getOrbit();
        	ProxyStore.getInstance().setFleetWayPoint(orbit, this, this);
        	return;
        }
        throw new ValidationError(L.INVALID_COMMAND_PLEASE_SELECT_A_OBJECT_FIRST);
	}
	
	@Override
	public void complete(Object result) throws ApplicationError, ValidationError {
    	GalaxyMapPanel mapPanel = listener.getView().getMapPanel();
    	mapPanel.updateSelection();
    	mapPanel.rebuildContent();
    	GalaxyWindowContextPanel contextPanel = listener.getView().getContextPanel();
    	if (contextPanel != null) {
    		contextPanel.updateSelection();
    	}
	}

	public void doubleClick() throws ApplicationError, ValidationError {
	}

}
