/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.main;

import java.awt.Color;

import javax.swing.JComponent;
import javax.swing.JLabel;

import mot.client.swing.common.ComponentTable;
import mot.client.swing.common.MotBorder;
import mot.client.swing.common.MotLabel;
import mot.client.swing.common.PadPanel;
import mot.client.swing.panels.TechnologyIconPanel;
import mot.common.bean.Size;
import mot.common.lang.L;
import mot.common.technology.Technology;
import mot.common.util.ApplicationError;

public class MainWindowMessageDiscoveredTech extends MainWindowMessageCustom {

	private static final Color [] COLOURS_DEFAULT = {
		new Color(0,0,0),
		new Color(29,34,52)
	};

	public MainWindowMessageDiscoveredTech(Technology tech) throws ApplicationError {
		super(getComponentMessage(tech), MainWindowMessageList.TIME_FOR_TEMP_MSGS_TO_EXPIRE, 8, 10, null);
		setColours(COLOURS_DEFAULT);
	}

	private static JComponent getComponentMessage(Technology tech) throws ApplicationError {
		ComponentTable component = new ComponentTable("-,-,HVSP", 1, 3, 0, 0, 0);
		TechnologyIconPanel imagePanel = new TechnologyIconPanel(tech, new Size(40, 40));
		component.add(new MotBorder(imagePanel));
		component.add(new PadPanel(25));
		component.add(new MotLabel("<html>"+L.DISCOVERED_+tech.getName()+"<br/>"+tech.getDescription()+"</html>", 2, JLabel.LEFT, false));
		return component;

	}
	
}
