/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.main;

import java.awt.AWTEvent;
import java.awt.event.AWTEventListener;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;
import java.util.ArrayList;

/**
 * Listens to all mouse events in the entire game for every window everywhere.
 * @author Paul Davis
 */
public class MotAWTMouseListener implements AWTEventListener {
	
	private static ArrayList<MouseListener> listeners = new ArrayList();
	
    public void eventDispatched(AWTEvent e) {
    	// THIS WILL BE CALLED FOR EVERY MOUSE CLICK IN THE ENTIRE GAME - EVERYWHERE
    	// JScrollPane loses mouse click events.
    	if (listeners == null) return;
    	MouseListener[] la = listeners.toArray(new MouseListener[listeners.size()]);
    	if (e instanceof MouseEvent && e.getID() == MouseEvent.MOUSE_CLICKED) {
    		MouseEvent me = (MouseEvent) e;
    		for (int i = 0; i < la.length; i++) {
    			la[i].mouseClicked(me);
    		}
    	}
    }

    public static void addListener(MouseListener ml) {
    	if (ml != null) listeners.add(ml);
    }
    
    public static void removeListener(MouseListener ml) {
    	if (ml != null) listeners.remove(ml);
    }
    
}
