/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.main;

import mot.client.animation.AnimationContainer;
import mot.client.deligates.BattleDelegate;
import mot.client.swing.window.battle.BattleWindowConfig;
import mot.client.swing.window.galaxy.GalaxyWindowConfig;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;
import mot.test.TestAnimationContainer;

public class TestMainWindow extends MainWindow {

	TestAnimationContainer animationContainer;
	
	protected TestMainWindow(MainWindowConfig config) throws ApplicationError {
		super(config);
		
		if (isBattleMapConfigurationActive()) {
			animationContainer = new TestAnimationContainer(getBattleWinConfig().getListener().getState().getAnimations());
		}
	}

	
	public AnimationContainer getAnimationContainer() {
		return animationContainer;
	}

    public void toGalaxyWindow() throws ApplicationError, ValidationError {
    	GalaxyWindowConfig gwc = getGalaxyMapConfiguration();
    	if (gwc == null) {
    		_setActiveConfiguration(new TestGalaxyWindowConfig());
    	} else {
    		_setActiveConfiguration(gwc);
    	}
    }
    
    public void toBattleWindow(BattleDelegate battle) throws ApplicationError {
    }

	public BattleWindowConfig getBattleWinConfig() {
		MainWindowConfig activeConfiguration = getActiveConfiguration();
		if (activeConfiguration instanceof BattleWindowConfig) {
			return (BattleWindowConfig) activeConfiguration;
		} else {
			return null;
		}
	}
    
}
