/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.solarsystem;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Font;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.MouseEvent;

import javax.swing.JPanel;

import mot.client.deligates.PlanetDelegate;
import mot.client.deligates.UserPlayerDelegate;
import mot.client.proxy.ProxyStore;
import mot.client.swing.common.PanelUtils;
import mot.client.swing.config.AnimationConfigFactory;
import mot.client.swing.config.ImageAnimationConfig;
import mot.client.swing.panels.AnimationPanel;
import mot.client.swing.window.common.MotInputDialog;
import mot.client.swing.window.common.MotInternalWindow;
import mot.client.swing.window.common.MotMessageDialog;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.Comp;
import mot.common.util.Logger;
import mot.common.util.ValidationError;

public class ColoniseGraphicWindow extends MotInternalWindow implements ActionListener {


    private static String IMAGE_TYPE = null;
    private static String IMAGE_NAME = null;
    private static String [] STAGES = null;

    private AnimationPanel animationPanel;
    
    private PlanetDelegate planet;

    public ColoniseGraphicWindow(MotInternalWindow parent, PlanetDelegate planet, UserPlayerDelegate user, String message)throws ApplicationError, ValidationError {
        super(user, parent, L.PLANET_COLONISED, null);
        this.planet = planet;
        if (IMAGE_NAME == null) {
        	ImageAnimationConfig config = AnimationConfigFactory.getInstance().getImageAnimationConfig("Colonise");
			IMAGE_NAME = config.getImage(); 
        	STAGES = config.getStagesMandatoryAsSplit();
        	IMAGE_TYPE = config.getImageType();
        }
        
        animationPanel = new AnimationPanel(this, message, IMAGE_NAME, STAGES, IMAGE_TYPE, "Colonise") {
            protected void animationFinished() {
                showRename();
            }
        	public void motMouseClicked(MouseEvent e) {
        		actionPerformed(null);
        	}
        };
        Font font = new Font(Font.SERIF, Font.BOLD, 24);
        animationPanel.changeFont(font, Color.BLACK);
        
        getContentPane().add(animationPanel, BorderLayout.CENTER);
        
        JPanel buttonPanel = new JPanel();
        buttonPanel.add(PanelUtils.createButton(L.CLOSE, this));

        getContentPane().add(animationPanel, BorderLayout.CENTER);
        //getContentPane().add(buttonPanel, BorderLayout.SOUTH);
        
        show();
        waitUntilClosed();
    }

    public void actionPerformed(ActionEvent e) {
        animationPanel.stop();
        hide();
    }
    
    protected void showRename() {
    	if (isShowing()) {    		
    		try {
    			PlanetDelegate [] colonies = planet.getSolarSystem().getColonies();
    			if (colonies != null && colonies.length == 1) {
    				String name = planet.getSolarSystem().getName();
    				String newName = MotInputDialog.showInPopup(this, L.THIS_SOLAR_SYSTEM_WILL_BE_CALLED, L.RENAME_NEW_COLONY, name);
    				if (newName != null && !Comp.same(name, newName)) {
    					ProxyStore.getInstance().renameStellarObject(planet.getSolarSystem(), newName, null, null);
    				}
    			}
    		} catch (ValidationError ex) {
    			MotMessageDialog.showError(this, ex);
    		} catch (Exception ex) {
    			Logger.logError("MainWindow.actionPerformed() Failed due to error ",ex);
    		}
    		hide();
    	}
    }
    
    public void handleTick() throws ApplicationError {
    	if (animationPanel != null) {
    		animationPanel.handleTick();
    	}
    }

}