/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.solarsystem;

import mot.client.deligates.PlanetDelegate;
import mot.client.swing.config.ImageConfigFactory;
import mot.client.swing.panels.AnimationPanel;
import mot.client.swing.window.common.MotInternalWindow;
import mot.common.bean.RaceGraphicsForColony;
import mot.common.bean.RaceGraphicsList;
import mot.common.factory.GraphicsFactory;
import mot.common.util.ApplicationError;

/**
 * Displays an animated image of a colony - maybe industry working!
 * The image is race specific and comes from race_graphics.xml unless
 * there is no colony then NoColonyImage is used from image_config.xml
 * 
 * THIS IS FOR USE IN THE SOLAR SYSTEM WINDOW
 */
public class ColonyImagePanel extends AnimationPanel {
	
	private static final String IMAGE_NAME = "NoColonyImage";

	private String image; 
	
	public ColonyImagePanel(MotInternalWindow container) throws ApplicationError {
		super(container, null, ImageConfigFactory.getInstance().getImageConfig(IMAGE_NAME).getImage(),null,"");
	}
	
	public void update(PlanetDelegate planet) throws ApplicationError {
		if (planet != null) {
			String race = planet.getOriginName();
			RaceGraphicsList raceGraphicsList = GraphicsFactory.getRaceGraphicsList();
			RaceGraphicsForColony colonyGraphics = raceGraphicsList.getGraphicsFor(race).getColonyGraphics();
			setName(colonyGraphics.getImageName());
			setFileType(colonyGraphics.getImageType());
			setLife(colonyGraphics.getImagesSuffixesAsArray());
		} else {
			setName(ImageConfigFactory.getInstance().getImageConfig(IMAGE_NAME).getImage());
			setFileType("");
			setLife(null);
		}
	}
	
	protected void drawSizeRelativeObjects() {
	}

	protected boolean infinate() { return true; }
}
