/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.solarsystem;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Font;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.MouseEvent;

import mot.client.deligates.UserPlayerDelegate;
import mot.client.swing.config.AnimationConfigFactory;
import mot.client.swing.config.ImageAnimationConfig;
import mot.client.swing.panels.AnimationPanel;
import mot.client.swing.window.common.MotInternalWindow;
import mot.client.swing.window.common.MotShowMessageDialog;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.Logger;
import mot.common.util.ValidationError;

public class CrisisGraphicWindow extends MotInternalWindow implements ActionListener {


    private static String IMAGE_TYPE = null;
    private static String IMAGE_NAME = null;
    private static String [] STAGES = null;

    private AnimationPanel animationPanel;
    
    private String planet;
	private String message;

    public CrisisGraphicWindow(MotInternalWindow parent, String planet, UserPlayerDelegate user, String message)throws ApplicationError, ValidationError {
        super(user, parent, L.PLANET_BOMBARDED, null);
        this.planet = planet;
		this.message = message;
        if (IMAGE_NAME == null) {
        	ImageAnimationConfig config = AnimationConfigFactory.getInstance().getImageAnimationConfig("Crisis");
			IMAGE_NAME = config.getImage(); 
        	STAGES = config.getStagesMandatoryAsSplit();
        	IMAGE_TYPE = config.getImageType();
        }
        
        animationPanel = new AnimationPanel(this, L.CRISIS+" "+planet, IMAGE_NAME, STAGES, IMAGE_TYPE, "Crisis") {
            protected void animationFinished() {
                showFinish();
            }
        	public void motMouseClicked(MouseEvent e) {
        		actionPerformed(null);
        	}
        };
        Font font = new Font(Font.SERIF, Font.BOLD, 28);
        animationPanel.changeFont(font, Color.BLACK);
        
        getContentPane().add(animationPanel, BorderLayout.CENTER);
        
//        JPanel buttonPanel = new JPanel();
//        buttonPanel.add(PanelUtils.createButton(CLOSE_WINDOW, this));

        show();
        waitUntilClosed();
    }

    public void actionPerformed(ActionEvent e) {
        animationPanel.stop();
        hide();
    }
    
    protected void showFinish() {
    	if (isShowing()) {    		
	        try {
	        	MotShowMessageDialog.showInPopup(this, message, L.CRISIS+" on "+planet);
	        } catch (Exception ex) {
	            Logger.logError("MainWindow.actionPerformed() Failed due to error ",ex);
	        }
	        hide();
    	}
    }
    
    public void handleTick() throws ApplicationError {
    	if (animationPanel != null) {
    		animationPanel.handleTick();
    	}
    }

}