/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.solarsystem;
import java.awt.Graphics2D;

import mot.client.deligates.PlanetDelegate;
import mot.client.swing.common.ImageUtils;
import mot.client.swing.common.PanelUtils;
import mot.client.swing.config.AnimationConfigFactory;
import mot.client.swing.config.ImageAnimationConfig;
import mot.client.swing.panels.AnimationPanel;
import mot.client.swing.window.common.MotInternalWindow;
import mot.common.bean.Size;
import mot.common.factory.PlanetGraphicsFactory;
import mot.common.util.ApplicationError;
import mot.common.util.PropertyManager;

public class PlanetAnimationPanel extends AnimationPanel {

    private PlanetDelegate planet;
    private double scale;
	private ImageAnimationConfig asteroidRingImage;


    public PlanetAnimationPanel(MotInternalWindow owner, PlanetDelegate planet, Size size) throws ApplicationError {
        super(owner, planet.getCrisis() != null ? planet.getCrisis().getName() : null, PropertyManager.getMandatoryAsColorNoError("redtext.color"), 3, true, getImage(planet), getLife(planet), getImageType(planet), null);
        
        this.planet = planet;
        this.scale = PlanetGraphicsFactory.getScale(planet.getSize());
        if (planet.hasAsteroids()) {
        	asteroidRingImage = AnimationConfigFactory.getInstance().getAsteroidRingAnimationConfig();
        }
        PanelUtils.setTheBloodySize(this, size.getX(), size.getY());
    }
    
    public PlanetAnimationPanel(MotInternalWindow owner, PlanetDelegate planet) throws ApplicationError {
        super(owner, planet.getCrisis() != null ? planet.getCrisis().getName() : null, PropertyManager.getMandatoryAsColorNoError("redtext.color"), 3, true, getImage(planet), getLife(planet), getImageType(planet), null);
        
        this.planet = planet;
        this.scale = PlanetGraphicsFactory.getScale(planet.getSize());
        if (planet.hasAsteroids()) {
        	asteroidRingImage = AnimationConfigFactory.getInstance().getAsteroidRingAnimationConfig();
        }
        PanelUtils.setTheBloodySize(this, 100, 100);
    }

    public PlanetAnimationPanel(MotInternalWindow owner) throws ApplicationError {
        super(owner, null, PropertyManager.getMandatoryAsColorNoError("redtext.color"), 3, true, null, null, null, null);
        PanelUtils.setTheBloodySize(this, 100, 100);
    }

    public PlanetAnimationPanel(MotInternalWindow owner, Size size) throws ApplicationError {
        super(owner, null, PropertyManager.getMandatoryAsColorNoError("redtext.color"), 3, true, null, null, null, null);
        PanelUtils.setTheBloodySize(this, size.getX(), size.getY());
    }

    public void setPlanet(PlanetDelegate planet) throws ApplicationError {
    	setText(planet.getCrisis() != null ? planet.getCrisis().getName() : null);
        setName(getImage(planet));
        setLife(getLife(planet));
        setFileType(getImageType(planet));
        
        this.planet = planet;
        this.scale = PlanetGraphicsFactory.getScale(planet.getSize());
        if (planet.hasAsteroids()) {
        	asteroidRingImage = AnimationConfigFactory.getInstance().getAsteroidRingAnimationConfig();
        }
        PanelUtils.setTheBloodySize(this, 100, 100);
    }

	private static String getImage(PlanetDelegate planet) throws ApplicationError {
		return PlanetGraphicsFactory.getPlanetGraphics(planet.getTeraforming()).getImage();
	}

	private static String [] getLife(PlanetDelegate planet) throws ApplicationError {
		return PlanetGraphicsFactory.getPlanetGraphics(planet.getTeraforming()).getStagesAsArray();
	}

	private static String getImageType(PlanetDelegate planet) throws ApplicationError {
		return PlanetGraphicsFactory.getPlanetGraphics(planet.getTeraforming()).getImageType();
	}

    protected boolean infinate() { return true; }
    
    protected double getXScale() { return scale; }
    protected double getYScale() { return scale; }


    @Override
    protected void postPaint(Graphics2D g) { 
        //Logger.logDebug(""+getClass()+" PlanetAnimationPanel.postPaint()");
        if (asteroidRingImage != null) {
            int imageWidth = (int)(width * getXScale());
            int imageHeight = (int)(height * getYScale());
            int left = 0;
            int top = 0;
            if (width > imageWidth) {
                left = (width-imageWidth)/2;
            }
            if (height > imageHeight) {
                top = (height-imageHeight)/2;
            }
            int rotation = getRotation();
            if (rotation == 0) {
                ImageUtils.drawImage(this, g, asteroidRingImage.getActualImage(), left, top, imageWidth, imageHeight);
            } else {
                ImageUtils.drawRotatedImage(this, g, asteroidRingImage.getActualImage(), left, top, imageWidth, imageHeight, null, rotation);
            }
        }
    }

}