/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.solarsystem;

import mot.client.deligates.PlanetDelegate;
import mot.client.deligates.PlayerDelegate;
import mot.client.swing.lists.FakeTechnologyLabelList;
import mot.client.swing.renderers.CellRendererTechnologyLabel;
import mot.common.bean.Size;
import mot.common.designs.Orbital;
import mot.common.technology.GeneralTechnologyList;
import mot.common.technology.Scanners;
import mot.common.technology.Shields;
import mot.common.technology.TechnologyList;
import mot.common.technology.Weapons;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class PlanetDefensePanel extends FakeTechnologyLabelList {

    public PlanetDefensePanel() throws ApplicationError {
        super(new CellRendererTechnologyLabel(false, true, false, new Size(30,30), true, 0, false, null, null, true, null, null, null));
    }

    public void selectPlanet(PlanetDelegate planet, PlayerDelegate owner) throws ApplicationError, ValidationError {
        TechnologyList tl = null;
        boolean viewable = (planet != null) && planet.isViewable();
        boolean isMiningColony = (viewable && planet.isMiningColony());
		if (viewable && !isMiningColony) {
	        Weapons weapons = planet.getWeapons();
	        if (weapons != null && weapons.getQuantity() > 0) {
	        	if (tl == null) tl = new GeneralTechnologyList();
	            tl.add(weapons);
	        }
	        
	        Shields shields = planet.getShields();
	        if (shields != null && shields.getQuantity() > 0) {
	        	if (tl == null) tl = new GeneralTechnologyList();
	            tl.add(shields);
	        }
	        
	        Scanners scanners = planet.getScanners();
	        if (scanners != null && scanners.getQuantity() > 0) {
	        	if (tl == null) tl = new GeneralTechnologyList();
	            tl.add(scanners);
	        }
	
	    	Orbital orbital = planet.getOrbital();
			if (orbital != null) {
	        	if (tl == null) tl = new GeneralTechnologyList();
	            tl.add(orbital.getHullTech());
			}
		}
		
        if (tl != null) {
        	setContent(tl, null);
        } else {
        	clearContent();
        }
        repaint();
    }
}