/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.solarsystem;

import javax.swing.JLabel;

import mot.client.deligates.PlanetDelegate;
import mot.client.deligates.PlayerDelegate;
import mot.client.deligates.SolarSystemDelegate;
import mot.client.deligates.TradeRouteDelegate;
import mot.client.swing.common.ComponentTable;
import mot.client.swing.common.MotLabel;
import mot.client.swing.common.PanelUtils;
import mot.client.swing.panels.IconPanelMoney;
import mot.client.swing.panels.IconPanelProduction;
import mot.client.swing.panels.IconPanelResearch;
import mot.client.swing.window.common.MotInternalWindow;
import mot.common.bean.Size;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.Formatter;
import mot.common.util.ValidationError;

public class PlanetTradeRoutePanel extends ComponentTable {

	private JLabel titleLabel = new MotLabel("", 5, JLabel.CENTER, true);
    
    private JLabel moneyLabel = PanelUtils.createLabel(null);
    private JLabel productionLabel = PanelUtils.createLabel(null);
    private JLabel researchLabel = PanelUtils.createLabel(null);

    private IconPanelMoney moneyIconPanel = new IconPanelMoney(0,0);
    private IconPanelProduction productionIconPanel = new IconPanelProduction(0);
    private IconPanelResearch researchIconPanel = new IconPanelResearch(0,0);

    private StellarObjectAnimationPanel stellarObjectPicturePanel;

    public PlanetTradeRoutePanel(MotInternalWindow parent) throws ApplicationError {
        super("-", 1,2, 5,3,3);
       
        ComponentTable leftPanel = new ComponentTable("HV", 4,1, 0, 3,3);

        ComponentTable prodPanel = new ComponentTable("RT,T,HV", 1,3, 0, 3,3);
        prodPanel.add(L.PRODUCTION);
        prodPanel.add(productionLabel);
        prodPanel.add(productionIconPanel);
        leftPanel.add(prodPanel);
       
        ComponentTable resPanel = new ComponentTable("RT,T,HV", 1,3, 0, 3,3);
        resPanel.add(L.RESEARCH);
        resPanel.add(researchLabel);
        resPanel.add(researchIconPanel);
        leftPanel.add(resPanel);
       
        ComponentTable moneyPanel = new ComponentTable("RT,T,HV", 1,3, 0, 3,3);
        moneyPanel.add(L.MONEY);
        moneyPanel.add(moneyLabel);
        moneyPanel.add(moneyIconPanel);
        leftPanel.add(moneyPanel);
        
        ComponentTable rightPanel = new ComponentTable("HV", 2,1, 0, 3,3);
        stellarObjectPicturePanel = new StellarObjectAnimationPanel(parent, new Size(100,100));
        rightPanel.add(titleLabel, "TF");
        rightPanel.add(stellarObjectPicturePanel,"HVSP");

        add(rightPanel,"HV");
		add(leftPanel, "HVSP");
    }


    public void selectTradeRoute(PlanetDelegate planet1, SolarSystemDelegate otherSolarSystem, TradeRouteDelegate tradeRoute, PlayerDelegate owner) throws ApplicationError, ValidationError {
        if (tradeRoute != null) {
            titleLabel.setText(otherSolarSystem.getName());
            int money = (int) (tradeRoute.getIndustryOutput(planet1.getName()) * planet1.getPercentMoney());
            int production = (int) (tradeRoute.getIndustryOutput(planet1.getName()) * planet1.getPercentProduction());
            int research = (int) (tradeRoute.getResearchOutput(planet1.getName()) * planet1.getPercentResearch());
            selectTradeRoute(otherSolarSystem, production, research, money);
        } else {
            titleLabel.setText(L.UNKNOWN);
            moneyLabel.setText( "-" );
            moneyIconPanel.update(0,0);
            productionLabel.setText( "-" );
            productionIconPanel.update(0, 0);
            researchLabel.setText( "-" );
            researchIconPanel.update(0, 0);
			//planetPicturePanel.setStellarObject(null);
        }
    }

    public void selectTradeRoute(SolarSystemDelegate solarSystem, int production, int research, int money) throws ApplicationError, ValidationError {
        moneyLabel.setText( Formatter.whole(money) );
        moneyIconPanel.update(money,0);
        productionLabel.setText( Formatter.whole(production) );
        productionIconPanel.update(production, 0);
        researchLabel.setText( Formatter.whole(research) );
        researchIconPanel.update(research, 0);
		stellarObjectPicturePanel.setStellarObject(solarSystem);
    }


	public void handleTick() throws ApplicationError {
    }
}
