/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.solarsystem;

import javax.swing.JScrollPane;
import javax.swing.JTabbedPane;

import mot.client.swing.panels.PlainTextBackgroundImagePanel;
import mot.client.swing.tables.GeneralTechnologyTable;
import mot.common.lang.L;
import mot.common.technology.Module;
import mot.common.util.ApplicationError;

public class ProjectModulePanel  extends JTabbedPane {

	private ProjectModuleOverviewPanel overview;
    private GeneralTechnologyTable details;

    public ProjectModulePanel(Module project) throws ApplicationError {
        overview = new ProjectModuleOverviewPanel(project);
        addTab(L.MODULE_DESIGN, null, new JScrollPane(overview),  L.MODULE_INFORMATION);
        details = new GeneralTechnologyTable(project);
        //details = ModuleTable.createWithHeader(project);
        addTab(L.MODULE_DETAILS, null, new JScrollPane(details),  L.DETAILED_MODULE_INFORMATION);
    }
}

class ProjectModuleOverviewPanel extends PlainTextBackgroundImagePanel {
    
	private Module project;
	
    public ProjectModuleOverviewPanel(Module project) {
        super(project.getDescription());
    	this.project = project;
    }

    private static final String IMAGE = "images/backgrounds/technology_module.jpg";

    protected String getImage() {
    	if (project != null && project.getImage() != null) {
    		return project.getImage();
    	} else {
    		return IMAGE;
    	}
    }

    
}