/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.solarsystem;

import javax.swing.JScrollPane;
import javax.swing.JTabbedPane;

import mot.client.swing.panels.PlainTextBackgroundImagePanel;
import mot.client.swing.tables.GeneralTechnologyTable;
import mot.common.lang.L;
import mot.common.technology.Scanner;
import mot.common.util.ApplicationError;

public class ProjectScannerPanel  extends JTabbedPane {

	private ProjectScannerOverviewPanel overview;
    private GeneralTechnologyTable details;

    public ProjectScannerPanel(Scanner project) throws ApplicationError {
        overview = new ProjectScannerOverviewPanel(project);
        addTab(L.SCANNER, null, new JScrollPane(overview),  L.SCANNER_INFORMATION);
        details = new GeneralTechnologyTable(project);
        //details = ScannerTable.createWithHeader(project);
        addTab(L.SCANNER_DETAILS, null, new JScrollPane(details),  L.DETAILED_SCANNER_INFORMATION);
    }
}

class ProjectScannerOverviewPanel extends PlainTextBackgroundImagePanel {

	private Scanner project;
	
    public ProjectScannerOverviewPanel(Scanner project) {
        super(project.getDescription());
    	this.project = project;
    }

    private static final String IMAGE = "images/backgrounds/project_scanner.jpg";

    protected String getImage() {
    	if (project != null && project.getImage() != null) {
    		return project.getImage();
    	} else {
    		return IMAGE;
    	}
    }
    
}