/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.solarsystem;

import javax.swing.JScrollPane;
import javax.swing.JTabbedPane;

import mot.client.swing.panels.PlainTextBackgroundImagePanel;
import mot.client.swing.tables.GeneralTechnologyTable;
import mot.common.lang.L;
import mot.common.technology.Shield;
import mot.common.util.ApplicationError;

public class ProjectShieldPanel  extends JTabbedPane {

	private ProjectShieldOverviewPanel overview;
    private GeneralTechnologyTable details;

    public ProjectShieldPanel(Shield project) throws ApplicationError {
        overview = new ProjectShieldOverviewPanel(project);
        addTab(L.SHIELD, null, new JScrollPane(overview),  L.SHIELD_INFORMATION);
        details = new GeneralTechnologyTable(project);
        //details = ShieldTable.createWithHeader(project);
        addTab(L.SHIELD_DETAILS, null, new JScrollPane(details),  L.DETAILED_SHIELD_INFORMATION);
    }
}

class ProjectShieldOverviewPanel extends PlainTextBackgroundImagePanel {

	private Shield project;
	
    public ProjectShieldOverviewPanel(Shield project) {
        super(project.getDescription());
    	this.project = project;
    }

    private static final String IMAGE = "images/backgrounds/project_shield.jpg";

    protected String getImage() {
    	if (project != null && project.getImage() != null) {
    		return project.getImage();
    	} else {
    		return IMAGE;
    	}
    }
    
}
