/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.solarsystem;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.FlowLayout;

import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.SwingConstants;

import mot.client.deligates.PlanetDelegate;
import mot.client.deligates.UserPlayerDelegate;
import mot.client.swing.buttons.MotButton;
import mot.client.swing.buttons.PlanetSelectionListener;
import mot.client.swing.common.BackgroundImageWindow;
import mot.client.swing.common.ComponentTable;
import mot.client.swing.common.DefaultButtonListener;
import mot.client.swing.common.MotLabel;
import mot.client.swing.common.PanelUtils;
import mot.client.swing.lists.PlanetList;
import mot.client.swing.window.common.MotInternalWindow;
import mot.client.swing.window.common.actions.CloseButton;
import mot.common.bean.Size;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class SelectPlanetWindow extends MotInternalWindow {

	private String message;
    private PlanetDelegate[] planets;
    
    private PlanetDelegate planet = null;

    private PlanetList planetList;
    private JScrollPane planetListScrolePane;

    private static final Dimension SIZE = new Dimension(250, 400);

    public static void openWithBackground(UserPlayerDelegate player, PlanetDelegate[] planets, String message) {
    	BackgroundImageWindow background;
    }
    
    /**
     * Displays a dialog box to select a planet from a list
     * @throws ValidationError 
     */
    public SelectPlanetWindow(UserPlayerDelegate player, MotInternalWindow parent, PlanetDelegate[] planets, String message) throws ApplicationError, ValidationError {
        super(player, parent, L.SELECT_PLANET, SIZE);
        this.planets = planets;
        this.message = message;
        
        
        PlanetSelectionListener selectPlanetListener = new PlanetSelectionListener() {
			public void select(PlanetDelegate planet) throws ApplicationError, ValidationError {
				setSelectedPlanet(planet);
		        hide();
			}
        };
        planetList = new PlanetList(this, planets, selectPlanetListener);
        planetListScrolePane = new JScrollPane(planetList, JScrollPane.VERTICAL_SCROLLBAR_ALWAYS, JScrollPane.HORIZONTAL_SCROLLBAR_AS_NEEDED);
        
        init();
        
		if (parent instanceof SolarSystemWindow) {
			SolarSystemWindow ssw = (SolarSystemWindow) parent;
			ssw.selectPlanet(planets[0]);
		}
		
        show();
    }

    private void init() {
        JPanel buttonPanel = new JPanel(new FlowLayout(FlowLayout.CENTER));
        CloseButton closeButton = new CloseButton(L.CANCEL, this);
        MotButton selectButton = new MotButton(L.SELECT) {
			protected void _doAction() throws ApplicationError, ValidationError {
				PlanetDelegate planet = (PlanetDelegate) planetList.getSelectedPlanet();
				if (planet == null) {
					throw new ValidationError(L.SELECT_A_PLANET_TO_COLONISE);
				}
				setSelectedPlanet(planet);
				closeSelectPlanetDlg();
			}
		};
		buttonPanel.add(selectButton);
		buttonPanel.add(closeButton);
		if (message != null) {
			JLabel label = new MotLabel(message, 0, null, null, SwingConstants.CENTER, false);
			PanelUtils.setTheBloodySize(label, new Size(220,40));
			ComponentTable border = new ComponentTable("HV", 1, 1, 3, 0, 0);
			border.add(label);
			getContentPane().add(border, BorderLayout.NORTH);
		}
        getContentPane().add(buttonPanel, BorderLayout.SOUTH);
        getContentPane().add(planetListScrolePane);
		addKeyListener(	new DefaultButtonListener(closeButton) );
		planetList.addKeyListener(	new DefaultButtonListener(closeButton) );
		planetListScrolePane.addKeyListener(	new DefaultButtonListener(closeButton) );
    }

    public void handleTick() throws ApplicationError {
    	planetList.handleTick();
    }

	public PlanetDelegate getSelectedPlanet() {
		return planet;
	}
	
	public void setSelectedPlanet(PlanetDelegate planet) {
		this.planet = planet;
	}

	public void closeSelectPlanetDlg() {
		hide();
	}


}

