/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.solarsystem;

import javax.swing.JScrollPane;

import mot.client.deligates.SolarSystemDelegate;
import mot.client.swing.common.ComponentTable;
import mot.client.swing.lists.PlanetList;
import mot.client.swing.window.common.MotInternalWindow;
import mot.client.swing.window.craft.OutpostPanel;
import mot.common.util.ApplicationError;

/**
 * This panel displays the contents of a solar system.
 * It is a vertical panel containing an outpost panel (if present)
 * followed by a (selectable) list of planets.
 */
public class SolarSystemPanel extends ComponentTable {

    private OutpostPanel outpostPanel;

	public SolarSystemPanel(MotInternalWindow owner, SolarSystemDelegate solarSystem, PlanetList planetList) throws ApplicationError {
        super("HV", 2, 1, 0,0,0);
        
        if (solarSystem.getStellarObjectOrbital() != null) {
            outpostPanel = new OutpostPanel(owner, solarSystem.getStellarObjectOrbital());
			add(outpostPanel);
        }
        add(planetList.getInScrollPane(), "HVSP");
    }
    
    public JScrollPane getScrollPane() {
        return new JScrollPane(this, JScrollPane.VERTICAL_SCROLLBAR_ALWAYS, JScrollPane.HORIZONTAL_SCROLLBAR_AS_NEEDED);
    }
    
	public void handleTick() throws ApplicationError {
		if (outpostPanel != null) {
			outpostPanel.handleTick();
		}
	}

}