/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.solarsystem;
import mot.client.deligates.StellarObjectDelegate;
import mot.client.swing.common.PanelUtils;
import mot.client.swing.panels.AnimationPanel;
import mot.client.swing.window.common.MotInternalWindow;
import mot.common.bean.Size;
import mot.common.bean.StellarObjectGraphics;
import mot.common.util.ApplicationError;
import mot.common.util.PropertyManager;

public class StellarObjectAnimationPanel extends AnimationPanel {

    private StellarObjectDelegate stellarObject;

    public StellarObjectAnimationPanel(MotInternalWindow owner, StellarObjectDelegate stellarObject) throws ApplicationError {
        super(owner, null, getImage(stellarObject), getLife(stellarObject), getImageType(stellarObject));
        
        this.stellarObject = stellarObject;
        PanelUtils.setTheBloodySize(this, 100, 100);
    }

    public StellarObjectAnimationPanel(MotInternalWindow owner, StellarObjectDelegate stellarObject, Size size) throws ApplicationError {
        super(owner, null, getImage(stellarObject), getLife(stellarObject), getImageType(stellarObject));
        
        this.stellarObject = stellarObject;
        PanelUtils.setTheBloodySize(this, size.getX(), size.getY());
    }

    public StellarObjectAnimationPanel(MotInternalWindow owner, Size size) throws ApplicationError {
        super(owner, null, PropertyManager.getMandatoryAsColorNoError("redtext.color"), 3, true, null, null, null, null);
       
        PanelUtils.setTheBloodySize(this, size.getX(), size.getY());
    }

	private static String getImage(StellarObjectDelegate stellarObject) throws ApplicationError {
		StellarObjectGraphics starGraphics = stellarObject.getGraphics(true);
		return starGraphics.getPicture();
	}

	private static String [] getLife(StellarObjectDelegate stellarObject) throws ApplicationError {
		StellarObjectGraphics starGraphics = stellarObject.getGraphics(true);
		return starGraphics.getStagesAsArray();
	}

	private static String getImageType(StellarObjectDelegate stellarObject) throws ApplicationError {
		StellarObjectGraphics starGraphics = stellarObject.getGraphics(true);
		return starGraphics.getPictureType();
	}

    public void setStellarObject(StellarObjectDelegate stellarObject) throws ApplicationError {
    	//setText(stellarObject.getCrisis() != null ? stellarObject.getCrisis().getName() : null);
    	if (stellarObject != null) {
	        setName(getImage(stellarObject));
	        setLife(getLife(stellarObject));
	        setFileType(getImageType(stellarObject));
    	} else {
    		setName(null);
	        setLife(null);
	        setFileType(null);
    	}
        this.stellarObject = stellarObject;
    }

    protected boolean infinate() { return true; }
    
}