/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.solarsystem.actions;

import javax.swing.JLabel;

import mot.client.swing.buttons.MotRolloverLabelButton;
import mot.client.swing.common.MotLabel;
import mot.client.swing.common.PadPanel;
import mot.client.swing.panels.ImagePanel;
import mot.client.swing.panels.TechnologyIconPanel;
import mot.common.bean.Size;
import mot.common.designs.TransportDesign;
import mot.common.technology.Technology;
import mot.common.util.ApplicationError;

/**
 * Sets the selection of technology type. So if type if craft design then
 * the list contains a list of all the crafts designs.
 */
public abstract class SelectProjectBase extends MotRolloverLabelButton {
	
	protected static Size ICON_SIZE = new Size(20,20);
	
	public SelectProjectBase(String imageName, String text, String tipText) throws ApplicationError {
		super(new PadPanel(new ImagePanel(TransportDesign.getProjectImage(), ICON_SIZE), 3), new MotLabel(text, 2, JLabel.LEFT, false), tipText, null);
	}

	public SelectProjectBase(Technology tech, String text, String tipText) throws ApplicationError {
		super(new PadPanel(new TechnologyIconPanel(tech, ICON_SIZE), 3), new MotLabel(text, 2, JLabel.LEFT, false), tipText, null);
	}

}
