/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.solarsystem.actions;

import mot.common.bean.MotComparable;
import mot.common.designs.CraftDesign;
import mot.common.util.ApplicationError;
import mot.common.util.Comp;
import mot.common.util.Logger;
import mot.common.util.ValidationError;

/**
 * Sets the selection of technology type. So if type if craft design then
 * the list contains a list of all the crafts designs.
 */
public class SelectProjectCraft extends SelectProjectBase implements MotComparable {
	
	private CraftDesign cd;
	private ProjectChangeListener model;
	
	public SelectProjectCraft(ProjectChangeListener model, CraftDesign cd) throws ApplicationError {
		super(cd.getHullTech(), cd.getName(), null);
		this.model = model;
		this.cd = cd;
	}

	protected final void _doAction() throws ApplicationError, ValidationError {
        if (Logger.isDebug()) {
            Logger.logDebug("SelectProjectWindow.setProject() select Build Craft "+cd.getName());
        }
        model.changeDesignsSelection(cd);
	}

	public boolean same(MotComparable other) {
		if (other != null && other instanceof CraftDesign) {
			CraftDesign ocd = (CraftDesign)other;
			return Comp.same(ocd, cd);
		}
		return false;
	}

}
