/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.solarsystem.actions;

import mot.client.swing.window.solarsystem.SelectProjectWindow;
import mot.common.designs.AsteroidDesign;
import mot.common.designs.ConstructPlanetDesign;
import mot.common.technology.AsteroidFieldConstruction;
import mot.common.technology.MiscTechnology;
import mot.common.technology.PlanetConstruction;
import mot.common.util.ApplicationError;
import mot.common.util.Logger;
import mot.common.util.ValidationError;

/**
 * Sets the selection of technology type. So if type if craft design then
 * the list contains a list of all the crafts designs.
 */
public class SelectProjectOther extends SelectProjectBase {
	
    private MiscTechnology tech;
	private SelectProjectWindow model;

	public SelectProjectOther(SelectProjectWindow model, MiscTechnology tech) throws ApplicationError {
		super(tech , tech.getName(), tech.getDescription());
		this.model = model;
		this.tech = tech;
	}

	protected final void _doAction() throws ApplicationError, ValidationError {
        if (Logger.isDebug()) {
            Logger.logDebug("SelectProjectWindow.setProject() select module "+tech);
        }
        if (tech instanceof PlanetConstruction) {
	        model.setProject(new ConstructPlanetDesign((PlanetConstruction)tech, model.getPlanet().getSolarSystem().getName()));
	        model.updateProjectDisplay();
        } else  if (tech instanceof AsteroidFieldConstruction) {
	        model.setProject(new AsteroidDesign((AsteroidFieldConstruction)tech));
	        model.updateProjectDisplay();
        }
	}

}
