/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.solarsystem.actions;

import mot.client.swing.window.solarsystem.SelectProjectWindow;
import mot.common.designs.DesignFactory;
import mot.common.designs.ProjectDesign;
import mot.common.technology.Hull;
import mot.common.util.ApplicationError;
import mot.common.util.Logger;
import mot.common.util.ValidationError;

/**
 * Sets the selection of technology type. So if type if craft design then
 * the list contains a list of all the crafts designs.
 */
public class SelectProjectStation extends SelectProjectBase {
	
    private Hull station;
	private SelectProjectWindow model;

	public SelectProjectStation(SelectProjectWindow model, Hull station) throws ApplicationError {
		super(station, station.getName(), station.getDescription());
		this.model = model;
		this.station = station;
	}

	protected final void _doAction() throws ApplicationError, ValidationError {
        if (Logger.isDebug()) {
            Logger.logDebug("SelectProjectWindow.setProject() select station "+station);
        }
        DesignFactory designFactory = new DesignFactory(model);
        ProjectDesign project = designFactory.createStationProjectDesign(model.getPlanet(), station);
		model.setProject(project);
        model.updateProjectDisplay();
	}

}
