/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.solarsystem.actions;

import mot.client.deligates.UserPlayerDelegate;
import mot.client.swing.window.main.MainWindow;
import mot.client.swing.window.solarsystem.SelectProjectWindow;
import mot.common.designs.DesignFactory;
import mot.common.technology.Weapon;
import mot.common.util.ApplicationError;
import mot.common.util.Logger;
import mot.common.util.ValidationError;

/**
 * Sets the selection of technology type. So if type if craft design then
 * the list contains a list of all the crafts designs.
 */
public class SelectProjectWeapon extends SelectProjectBase {
	
    private Weapon weapon;
	private SelectProjectWindow model;

	public SelectProjectWeapon(SelectProjectWindow model, Weapon weapon) throws ApplicationError {
		super(weapon,  weapon.getName(), weapon.getDescription());
		this.model = model;
		this.weapon = weapon;
	}

	protected final void _doAction() throws ApplicationError, ValidationError {
        if (Logger.isDebug()) {
            Logger.logDebug("SelectProjectWindow.setProject() select Weapon "+weapon);
        }
        UserPlayerDelegate owner = MainWindow.getOwner();
        DesignFactory designFactory = new DesignFactory(model);
        model.setProject(designFactory.createWeaponProjectDesign(owner, model.getPlanet(), weapon));
        model.updateProjectDisplay();
	}

}
