/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.solarsystem.actions;

import mot.client.deligates.PlanetDelegate;
import mot.client.proxy.CompletedCallback;
import mot.client.proxy.ProxyStore;
import mot.client.swing.buttons.MotButton;
import mot.client.swing.window.main.MainWindow;
import mot.client.swing.window.solarsystem.PlanetOtherPanel;
import mot.client.swing.window.solarsystem.SolarSystemWindow;
import mot.client.swing.window.solarsystem.SolarSystemWindowState;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class SolarSystemActionButtonAbandon extends MotButton implements CompletedCallback {


	private PlanetOtherPanel panel;
	private SolarSystemWindow parent;
	private SolarSystemWindowState state;
	
	private PlanetDelegate currentPlanet;
	
	public SolarSystemActionButtonAbandon(SolarSystemWindow parent, PlanetOtherPanel panel, SolarSystemWindowState state) {
		super(L.ABANDON);
		this.panel = panel;
		this.parent = parent;
		this.state = state;
		setToolTipText(L.TT_BUTTON_ABANDON);
	}

	protected void _doAction() throws ApplicationError, ValidationError {
		if (MainWindow.getExestingInstance().getGalaxyMapConfiguration().getGalaxyView().isEndTurnInProgress()) {
			throw new ValidationError(L.END_TURN_IN_PROGRESS);
		}
        currentPlanet = state.getCurrentPlanet();
        if (currentPlanet == null) {
            return;
        }
        ProxyStore.getInstance().abandonCmd(currentPlanet, this, this);
	}

	@Override
	public void complete(Object result) throws ApplicationError, ValidationError {
        parent.selectPlanet(currentPlanet);
	}
}
