/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.solarsystem.actions;

import mot.client.deligates.PlanetDelegate;
import mot.client.deligates.SolarSystemDelegate;
import mot.client.proxy.CompletedCallback;
import mot.client.proxy.ProxyStore;
import mot.client.swing.buttons.MotButton;
import mot.client.swing.window.common.MotInputDialog;
import mot.client.swing.window.main.MainWindow;
import mot.client.swing.window.solarsystem.PlanetOtherPanel;
import mot.client.swing.window.solarsystem.SolarSystemWindow;
import mot.client.swing.window.solarsystem.SolarSystemWindowState;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.Comp;
import mot.common.util.ValidationError;

public class SolarSystemActionButtonRename extends MotButton implements CompletedCallback {


	private PlanetOtherPanel panel;
	private SolarSystemWindow parent;
	private SolarSystemWindowState state;
	
	public SolarSystemActionButtonRename(SolarSystemWindow parent, PlanetOtherPanel panel, SolarSystemWindowState state) {
		super(L.RENAME);
		this.panel = panel;
		this.parent = parent;
		this.state = state;
		
		setToolTipText(L.TT_BUTTON_RENAME);
	}

	protected void _doAction() throws ApplicationError, ValidationError {
		if (MainWindow.getExestingInstance().getGalaxyMapConfiguration().getGalaxyView().isEndTurnInProgress()) {
			throw new ValidationError(L.END_TURN_IN_PROGRESS);
		}
        SolarSystemDelegate solarSystem = state.getSolarSystem();
        PlanetDelegate currentPlanet = state.getCurrentPlanet();
		String name = solarSystem.getName();
        String newName = MotInputDialog.showInPopup(parent, "What do you want the new name to be?", "Rename Solar System", name);
        if (newName == null || newName.length() > 10) {
            throw new ValidationError("Name must be a maximum of 10 characters");
        }
        if (!Comp.same(name, newName)) {
            ProxyStore.getInstance().renameStellarObject(solarSystem, newName, this, this);
        }
	}

	@Override
	public void complete(Object result) throws ApplicationError, ValidationError {
        SolarSystemDelegate solarSystem = state.getSolarSystem();
        PlanetDelegate currentPlanet = state.getCurrentPlanet();
        panel.solarSystemNameLabel.setText(solarSystem.getName());
        if (currentPlanet != null) {
        	panel.planetNameLabel.setText(currentPlanet.getName());
        }
        parent.setTitle();
	}
}
