/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.solarsystem.actions;

import mot.client.deligates.PlanetDelegate;
import mot.client.proxy.CompletedCallback;
import mot.client.proxy.ProxyStore;
import mot.client.swing.buttons.MotButton;
import mot.client.swing.window.main.MainWindow;
import mot.client.swing.window.solarsystem.PlanetOtherPanel;
import mot.client.swing.window.solarsystem.SolarSystemWindow;
import mot.client.swing.window.solarsystem.SolarSystemWindowState;
import mot.common.bean.Settings;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class SolarSystemActionButtonTransfer extends MotButton implements CompletedCallback  {


	private PlanetOtherPanel panel;
	private SolarSystemWindow parent;
	private SolarSystemWindowState state;
	private boolean isTroops;
	
	public SolarSystemActionButtonTransfer(String label, SolarSystemWindow parent, PlanetOtherPanel panel, SolarSystemWindowState state, boolean isTroops) {
		super(label);
		this.panel = panel;
		this.parent = parent;
		this.state = state;
		this.isTroops = isTroops;
		if (isTroops) {
			setToolTipText(L.TT_BUTTON_TRANSFER_TROOPS);
		} else {
			setToolTipText(L.TT_BUTTON_TRANSFER_COLONISTS);
		}
	}

	protected void _doAction() throws ApplicationError, ValidationError {
        PlanetDelegate currentPlanet = state.getCurrentPlanet();
        if (currentPlanet == null) {
            return;
        }
        int qty = Settings.getInstance().getQtyColonistsToLoadPerShuttle();
        ProxyStore.getInstance().loadTransportCmd(currentPlanet, null, qty, isTroops ? 1 : 0, this, this);
	}

	public boolean isTroops() {
		return isTroops;
	}

	@Override
	public void complete(Object result) throws ApplicationError, ValidationError {
        PlanetDelegate currentPlanet = state.getCurrentPlanet();
        if (currentPlanet == null) {
            return;
        }
        parent.selectPlanet(currentPlanet);
        MainWindow mainWindow = MainWindow.getInstance();
		mainWindow.getGalaxyMapConfiguration().getGalaxyView().updateStatus(mainWindow.getWindowOwner());
	}

}
