/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.solarsystem.actions;

import mot.client.deligates.PlanetDelegate;
import mot.client.proxy.CompletedCallback;
import mot.client.proxy.ProxyStore;
import mot.client.swing.buttons.MotButton;
import mot.client.swing.window.common.MotConfirmationDialog;
import mot.client.swing.window.solarsystem.SolarSystemWindow;
import mot.client.swing.window.solarsystem.SolarSystemWindowState;
import mot.common.designs.ProjectDesign;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class SolarSystemActionBuyProject extends MotButton implements CompletedCallback  {

	private SolarSystemWindow parent;
	private SolarSystemWindowState state;
	
	private PlanetDelegate currentPlanet;
	
	public SolarSystemActionBuyProject(SolarSystemWindow parent, SolarSystemWindowState state) {
		super(L.BUY);
		this.parent = parent;
		this.state = state;
		
		setToolTipText(L.TT_BUTTON_BUY);
	}

	protected void _doAction() throws ApplicationError, ValidationError {
        currentPlanet = state.getCurrentPlanet();
        if (currentPlanet != null && currentPlanet.getProjectDesign() != null) {
            if (currentPlanet.isOwnedBy(parent.getOwner())) {
                ProjectDesign p = currentPlanet.getProjectDesign();
                int remainingProd = currentPlanet.getCostToBuild() - currentPlanet.getProduction();
                long cost = currentPlanet.getCostToPurchaseProject();
                String msg = L.BUY+" "+p.getName()+" : "+L.PRODUCTION+" "+remainingProd+L._AT_COST_+cost+"?";
                if (MotConfirmationDialog.showInPopup(parent, msg, L.CONFIRM)) {
                    ProxyStore.getInstance().purchaseProjectCmd(currentPlanet, this, this);
                }
            }
        }
	}

	@Override
	public void complete(Object result) throws ApplicationError, ValidationError {
        parent.selectPlanet(currentPlanet);
	}

}
