/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.solarsystem.actions;

import mot.client.deligates.PlanetDelegate;
import mot.client.swing.buttons.MotButton;
import mot.client.swing.window.common.MotMessageDialog;
import mot.client.swing.window.solarsystem.SelectProjectWindow;
import mot.client.swing.window.solarsystem.SolarSystemWindow;
import mot.client.swing.window.solarsystem.SolarSystemWindowState;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.Logger;
import mot.common.util.ValidationError;

public class SolarSystemActionChangeProject extends MotButton {


	private SolarSystemWindow parent;
	private SolarSystemWindowState state;
	
	public SolarSystemActionChangeProject(SolarSystemWindow parent, SolarSystemWindowState state) {
		super(L.CHANGE);
		this.parent = parent;
		this.state = state;
		
		setToolTipText(L.TT_BUTTON_CHANGE);
	}

	protected void _doAction() throws ApplicationError, ValidationError {
        PlanetDelegate currentPlanet = state.getCurrentPlanet();
        if (currentPlanet != null) {
            if (currentPlanet.isOwnedBy(parent.getOwner()) && !currentPlanet.isMiningColony()) {
                try {
                    new SelectProjectWindow(parent, currentPlanet);
                } catch (ApplicationError e2) {
                    Logger.logError("SolarSystemWindow.actionPerformed() Failed "+e2, e2);
                    MotMessageDialog.showError(parent, e2);
                }
                parent.getPlanetOutput().updateProject(currentPlanet);
            }
        }
	}

}
