/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.solarsystem.actions;

import mot.client.deligates.PlanetDelegate;
import mot.client.proxy.CompletedCallback;
import mot.client.proxy.ProxyStore;
import mot.client.swing.buttons.MotButton;
import mot.client.swing.window.solarsystem.PlanetOtherPanel;
import mot.client.swing.window.solarsystem.SolarSystemWindow;
import mot.client.swing.window.solarsystem.SolarSystemWindowState;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class SolarSystemActionRemoveWaypoint extends MotButton implements CompletedCallback  {


	private PlanetOtherPanel panel;
	private SolarSystemWindow parent;
	private SolarSystemWindowState state;
	
	public SolarSystemActionRemoveWaypoint(SolarSystemWindow parent, PlanetOtherPanel panel, SolarSystemWindowState state) {
		super(L.REMOVE_WAYPOINT);
		this.panel = panel;
		this.parent = parent;
		this.state = state;
		setToolTipText(L.TT_FLEET_WAY_POINT);
	}

	protected void _doAction() throws ApplicationError, ValidationError {
		ProxyStore.getInstance().setFleetWayPoint(null, this, this);
	}

	@Override
	public void complete(Object result) throws ApplicationError, ValidationError {
        PlanetDelegate currentPlanet = state.getCurrentPlanet();
        if (currentPlanet != null) {
            parent.selectPlanet(currentPlanet);
        } else {
        	parent.selectPlanet(null);
        }
	}

}
