/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.solarsystem.actions;

import mot.client.deligates.PlanetDelegate;
import mot.client.deligates.SolarSystemDelegate;
import mot.client.proxy.CompletedCallback;
import mot.client.proxy.ProxyStore;
import mot.client.swing.buttons.MotButton;
import mot.client.swing.window.solarsystem.PlanetOtherPanel;
import mot.client.swing.window.solarsystem.SolarSystemWindow;
import mot.client.swing.window.solarsystem.SolarSystemWindowState;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;
import mot.common.vo.OrbitVO;

public class SolarSystemActionSetWaypoint extends MotButton implements CompletedCallback  {


	private PlanetOtherPanel panel;
	private SolarSystemWindow parent;
	private SolarSystemWindowState state;
	private boolean useSun;
	
	private PlanetDelegate currentPlanet;
	
	public SolarSystemActionSetWaypoint(SolarSystemWindow parent, PlanetOtherPanel panel, SolarSystemWindowState state, boolean useSun) {
		super(useSun ? L.SET_SUN_WAYPOINT : L.SET_PLANET_WAYPOINT);
		this.panel = panel;
		this.parent = parent;
		this.state = state;
		this.useSun = useSun;
		setToolTipText(L.TT_FLEET_WAY_POINT);
	}

	protected void _doAction() throws ApplicationError, ValidationError {
        SolarSystemDelegate currentSolarSystem = state.getSolarSystem();
		if (currentSolarSystem == null) {
        	return;
        }
        currentPlanet = state.getCurrentPlanet();
        if (currentPlanet == null) {
            ProxyStore.getInstance().setFleetWayPoint( new OrbitVO(state.getSolarSystem().getName(), null), this, this );
        } else {
        	if (useSun) {
        		ProxyStore.getInstance().setFleetWayPoint( new OrbitVO(currentSolarSystem.getName(), null), this, this );
        	} else {        		
        		ProxyStore.getInstance().setFleetWayPoint( new OrbitVO(currentPlanet.getSolarSystem().getName(), currentPlanet.getName()), this, this );
        	}
        }
	}

	@Override
	public void complete(Object result) throws ApplicationError, ValidationError {
		parent.selectPlanet(currentPlanet);
	}

}
