/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.tech;

import java.awt.BorderLayout;

import javax.swing.JLabel;

import mot.client.deligates.UserPlayerDelegate;
import mot.client.swing.buttons.MotAction;
import mot.client.swing.common.ComponentTable;
import mot.client.swing.common.MotButtonGeneric;
import mot.client.swing.common.MotButtonPanel;
import mot.client.swing.common.MotLabel;
import mot.client.swing.window.common.MotInternalWindow;
import mot.client.swing.window.common.actions.CloseButton;
import mot.common.lang.L;
import mot.common.technology.Technology;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class DiscoverTechWindow extends MotInternalWindow {

	public TechnologyDiscoveredPanel researchPanel;
	
	private MotButtonGeneric yesButton;
	private MotButtonGeneric noButton;

	private MotButtonPanel buttonPanel;

    public DiscoverTechWindow(MotInternalWindow parent, UserPlayerDelegate player, Technology discoveredTech, MotAction yesAction, MotAction noAction, String question, boolean fromSalvage) throws ApplicationError, ValidationError {
        super(player, parent, L.TECHNOLOGY_WINDOW, null);
        
        researchPanel = new TechnologyDiscoveredPanel(owner, discoveredTech, fromSalvage);

        if (question != null) {
        	ComponentTable content = new ComponentTable("HV", 2, 1, 0, 0, 0);
        	content.add(addTitleBar(researchPanel), "HVSP");
        	content.add(new MotLabel(question, 4, null, null, JLabel.CENTER, true));
        	getContentPane().add(content);        	
        } else {
        	getContentPane().add(addTitleBar(researchPanel));        	
        }
        
        buttonPanel = new MotButtonPanel();
        if (question != null && yesAction != null) {
        	yesButton = new MotButtonGeneric(L.YES, yesAction);
        	buttonPanel.add(yesButton);
        }
        if (question != null && noAction != null) {
        	noButton = new MotButtonGeneric(L.YES, noAction);
        	buttonPanel.add(noButton);
        }
		if (yesButton != null && noButton == null) {
			CloseButton button = new CloseButton(this);
			button.setText(L.NO);
        	buttonPanel.add(button);
        } else if (yesButton == null && noButton == null) {
        	buttonPanel.add(new CloseButton(this));
        }
        
        getContentPane().add(buttonPanel, BorderLayout.SOUTH);
    }
    
    public void showAndWait() {
    	show();
    	waitUntilClosed();
    }


    
}