/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.tech;
import javax.swing.JLabel;
import javax.swing.JScrollPane;
import javax.swing.JTabbedPane;
import javax.swing.JTable;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;

import mot.client.deligates.UserPlayerDelegate;
import mot.client.swing.buttons.MotClickTechnologyLabelAction;
import mot.client.swing.combos.TechnologyTypeCombo;
import mot.client.swing.common.ComponentTable;
import mot.client.swing.common.PadPanel;
import mot.client.swing.common.PanelUtils;
import mot.client.swing.lists.FakeTechnologyLabelList;
import mot.client.swing.panels.TechnologyPicturePanel;
import mot.client.swing.renderers.CellRendererTechnologyLabel;
import mot.client.swing.tables.GeneralTechnologyTable;
import mot.common.bean.Size;
import mot.common.lang.L;
import mot.common.technology.Technology;
import mot.common.util.ApplicationError;
import mot.common.util.Logger;
import mot.common.util.ValidationError;

public class ResearchDiscoveredPanel extends ComponentTable {

    private FakeTechnologyLabelList discoveredList = new FakeTechnologyLabelList();
    private TechnologyTypeCombo typeComboBox;
    private JScrollPane availableScrollPane = new JScrollPane(discoveredList, JScrollPane.VERTICAL_SCROLLBAR_AS_NEEDED, JScrollPane.HORIZONTAL_SCROLLBAR_AS_NEEDED);

    private TechnologyPicturePanel technologyPanel;
    private JScrollPane detailsScrollPane = new JScrollPane();
    
    private UserPlayerDelegate owner;
    
    /**
     * The research project the user has selected
     */
    public Technology selection;

    public ResearchDiscoveredPanel(UserPlayerDelegate owner) throws ApplicationError {
        super("V,HPV", 1, 2, 0, 0, 0);

        MotClickTechnologyLabelAction selectionListener = new MotClickTechnologyLabelAction() {
    		protected void selectTechnology(Technology technology) throws ApplicationError, ValidationError {
    			discoveredList.setSelection(technology);
	            setSelection(technology);            
			}
		};
        discoveredList.setRenderer( new CellRendererTechnologyLabel(false, true, false, new Size(20,20), true, 2, false, null, null, false, selectionListener, null, null) );
		ChangeListener changeTechTypeListener = new ChangeListener() {
			public void stateChanged(ChangeEvent e) {
				Technology selection = (Technology) discoveredList.getSelection();
				try {
					setSelection(selection);
				} catch (ApplicationError e1) {
					Logger.logError("", e1);
				}
			}
		};
        
        this.owner = owner;
        this.typeComboBox = new TechnologyTypeCombo(discoveredList, owner, changeTechTypeListener);
        this.technologyPanel = new TechnologyPicturePanel(owner, false, true, true, false, null);
    
        ComponentTable listPanel = new ComponentTable("HV", 5, 1, 0, 0, 0);
        listPanel.add(PanelUtils.createLabel(L.TYPE), "R");
        listPanel.add(typeComboBox);
        listPanel.add(new PadPanel(new JLabel(), 100,3));
        listPanel.add(PanelUtils.createLabel(L.DISCOVERED), "R");
        listPanel.add(availableScrollPane);
        
        JTabbedPane tabs = new JTabbedPane();
        tabs.addTab(L.OVERVIEW, technologyPanel);
        tabs.addTab(L.DETAILS, detailsScrollPane);
        
        add(listPanel);
        add(tabs);
        
        //changeDiscoveredList();
        Technology selection = (Technology) discoveredList.getSelection();
        setSelection(selection);            

    }
	
    public void setSelection(Technology selection) throws ApplicationError {
        technologyPanel.update(selection);
        detailsScrollPane.getViewport().removeAll();
        if (selection != null) {
            if (Logger.isDebug()) {
                Logger.logDebug("ResearchWindow.valueChanged() Close selection="+selection.getFullName());
            }
            JTable table = new GeneralTechnologyTable(selection);
            detailsScrollPane.getViewport().add(table);
        }
        detailsScrollPane.doLayout();
        doLayout();
        repaint();
    }


    private JScrollPane scrollPanel;
    public JScrollPane getScrollPane() {
        if (scrollPanel == null) {
            scrollPanel = new JScrollPane(this, JScrollPane.VERTICAL_SCROLLBAR_AS_NEEDED, JScrollPane.HORIZONTAL_SCROLLBAR_AS_NEEDED);
        }
        return scrollPanel;
    }


}