/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.tech;

import javax.swing.JTabbedPane;

import mot.client.deligates.ResearchProjectDelegate;
import mot.client.deligates.UserPlayerDelegate;
import mot.common.bean.SalvageList;
import mot.common.lang.L;
import mot.common.technology.Technology;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class ResearchPanel extends JTabbedPane {

	private SelectableTechnologyPanel available;
    private ResearchDiscoveredPanel discovered;
    private SelectableTechnologyPanel missed;
    private TechnologyDictionaryPanel all;

    public ResearchPanel(UserPlayerDelegate owner, ResearchProjectDelegate currentResearchProject, Technology [] availableTechs, SalvageList availableSalvage, Technology [] missedTechs, Technology [] recentMissedTechs) throws ApplicationError, ValidationError {
        // Must be able to open tech window when all research is complete!
        //if (availableTechs == null || availableTechs.length == 0) throw new ValidationError(L.NO_TECHNOLOGY_AVAILABLE_FOR_RESEARCH);
        
        available = new SelectableTechnologyPanel(owner, true, availableTechs, availableSalvage, currentResearchProject, recentMissedTechs);
        addTab(L.TECHNOLOGIES_AVAILABLE_FOR_RESEARCH, null, available,  L.TECHNOLOGIES_YOUR_SCIENTISTS_ARE_CAPABLE_OF_RESEARCHING_NOW);
        
        discovered = new ResearchDiscoveredPanel(owner);
        addTab(L.TECHNOLOGIES_ALREADY_DISCOVERED, null, discovered,  L.TECHNOLOGIES_YOUR_SCIENTISTS_HAVE_ALREADY_DISCOVERED);

        missed = new SelectableTechnologyPanel(owner, false, missedTechs, null, null, null);
        addTab(L.MISSED_TECHNOLOGIES, null, missed,  L.TECHNOLOGIES_YOUR_SCIENTISTS_ARE_HAVING_TROUBLE_UNDERSTANDING);
        
        all = new TechnologyDictionaryPanel(owner);
        addTab(L.TECHNOLOGIES_ALL, null, all,  L.TECHNOLOGIES_COMPLETE_LIST);
    }
    
    public Technology getProjectSelection() {
        return available.getSelection();
    }

	public void displayDiscoveredTech(Technology discoveredTech) throws ApplicationError {
		setSelectedComponent(discovered);
		discovered.setSelection(discoveredTech);
	}
}