/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.tech;

import javax.swing.JLabel;
import javax.swing.JProgressBar;

import mot.client.deligates.ResearchProjectDelegate;
import mot.client.swing.common.ComponentTable;
import mot.client.swing.common.PanelUtils;
import mot.common.lang.L;
import mot.common.technology.Technology;
import mot.common.util.ApplicationError;

/**
 * Displays details of the research project.
 * It displays, Research Project Description above a progress bar indicating progress achieved.
 */
public class ResearchProjectPanel extends ComponentTable {

	private JLabel description;
    private JProgressBar progress;

    public ResearchProjectPanel(ResearchProjectDelegate project) throws ApplicationError {
        super("H", 2, 1, 4, 0, 2);
        
        if (project == null) {
            description = PanelUtils.createLabel(L.NONE);
            progress = new JProgressBar(0, 100);
            progress.setValue(0);
        } else {
            description = PanelUtils.createLabel(getProjectDescription(project.getTechnology(), project.getWork()));
            progress = new JProgressBar(0, project.getTechnology().getCostToResearch());
            progress.setValue(project.getWork());
        }
        
        add(description, "R");
        add(progress, "H");
    }
    
    public void update(ResearchProjectDelegate project) throws ApplicationError {
        description.setText(project.getProjectDescription());
        progress.setMaximum(project.getTechnology().getCostToResearch());
        progress.setValue(project.getWork());
    }

    private String getProjectDescription(Technology technology, int work) {
    	if (technology == null) {
    		return L.RESEARCHING_NOTHING;
    	} else {
    		return L.RESEARCHING_A_+technology.getTechType()+L._CALLED_+technology.getName()+" [ "+work+" of "+technology.getCostToResearch()+" ]";
    	}
    }
}