/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.tech;

import java.awt.BorderLayout;

import javax.swing.JLabel;
import javax.swing.JPanel;

import mot.client.deligates.ResearchProjectDelegate;
import mot.client.deligates.UserPlayerDelegate;
import mot.client.swing.common.ComponentTable;
import mot.client.swing.common.PanelUtils;
import mot.client.swing.window.common.MotInternalWindow;
import mot.client.swing.window.tech.actions.ResearchWindowAutoButton;
import mot.client.swing.window.tech.actions.ResearchWindowCancelButton;
import mot.client.swing.window.tech.actions.ResearchWindowSelectTopicButton;
import mot.common.bean.SalvageList;
import mot.common.lang.L;
import mot.common.technology.Technology;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class ResearchWindow extends MotInternalWindow {
    public ResearchPanel researchPanel;
    private ResearchProjectPanel researchProjectPanel;
    private JLabel jLabel3 = new JLabel();

    
    /**
     * This is the selection made is any from this dialog box
     */
    public ResearchProjectDelegate project;

    public ResearchWindow(MotInternalWindow parent, UserPlayerDelegate player, ResearchProjectDelegate project, Technology [] availableTechs, SalvageList availableSalvage, Technology [] missedTechs, Technology [] recentMissedTechs, boolean stopEndTurnUntilWinClosed) throws ApplicationError, ValidationError {
        super(player, parent, L.RESEARCH_PROJECT_WINDOW, null);
        setup(project, availableTechs, availableSalvage, missedTechs, recentMissedTechs);
    	setStopEndTurnButton(stopEndTurnUntilWinClosed);
    	show();
    	waitUntilClosed();
    }
    
    public void setup(ResearchProjectDelegate currentResearchProject, Technology [] availableTechs, SalvageList availableSalvage, Technology [] missedTechs, Technology [] recentMissedTechs) throws ApplicationError, ValidationError {
        this.project = currentResearchProject;

        researchPanel = new ResearchPanel(owner, currentResearchProject, availableTechs, availableSalvage, missedTechs, recentMissedTechs);
        researchProjectPanel = new ResearchProjectPanel(currentResearchProject);

        ComponentTable content = new ComponentTable("HV", 2, 1, 0, 0, 0);
        content.add(researchPanel, "HVS");
        content.add(researchProjectPanel);
        getContentPane().add(addTitleBar(content));

        JPanel buttonPanel = new JPanel();
        buttonPanel.add(new ResearchWindowSelectTopicButton(this));
        buttonPanel.add(PanelUtils.createFiller(25,5));
        buttonPanel.add(new ResearchWindowCancelButton(this));
        buttonPanel.add(PanelUtils.createFiller(25,5));
        buttonPanel.add(new ResearchWindowAutoButton(this));
        getContentPane().add(buttonPanel, BorderLayout.SOUTH);
    }
    
}