/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.tech;

import java.awt.Font;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.JPanel;

import mot.client.deligates.UserPlayerDelegate;
import mot.client.swing.common.ComponentTable;
import mot.client.swing.common.MotBorder;
import mot.client.swing.common.PanelUtils;
import mot.client.swing.panels.RacePicturePanel;
import mot.client.swing.panels.TechnologyPicturePanel;
import mot.client.swing.window.common.MessagePanel;
import mot.client.swing.window.common.MotInternalWindow;
import mot.common.event.TechnologyStolenEvent;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class StealTechnologyWindow extends MotInternalWindow implements ActionListener {

    
	private TechnologyStolenEvent event;

    public StealTechnologyWindow(MotInternalWindow parent, UserPlayerDelegate player, TechnologyStolenEvent event) throws ApplicationError, ValidationError {
        super(player, parent, L.STEAL_TECHNOLOGY_WINDOW, null);
		this.event = event;

		RacePicturePanel racePicturePanel = new RacePicturePanel(event.getGiver(), L.WHAT_HAVE_WE_EVER_DONE_TO_YOU_BR_WE_ARE_MOST_UPSET_WITH_YOUR_CONDUCT, null, 5, false);
		TechnologyPicturePanel technologyPicturePanel = new TechnologyPicturePanel(player, false, true, true, false, event.getTechnology(), null);
        ComponentTable imageRow = new ComponentTable("HV,HV", 1, 2, 25, 5, 0);
        imageRow.setGridWidths("500,500");
        imageRow.add(new MotBorder(racePicturePanel, L.RACE+": "+event.getGiver()));
        imageRow.add(new MotBorder(technologyPicturePanel,L.TECHNOLOGY+": "+event.getTechnology().getFullNameSpaceSeperated()));
        
        String message = L.YOU_HAVE_STOLEN+event.getTechnology().getFullNameSpaceSeperated()+L.FROM+event.getGiver();
        Font font = new Font(Font.SERIF, Font.BOLD, 28);
		MessagePanel messagePanel = new MessagePanel(L.TECHNOLOGY+": "+message, 50, font, null);
        
        JPanel buttonPanel = new JPanel();
        buttonPanel.add(PanelUtils.createButton(L.CLOSE, this));

        ComponentTable content = new ComponentTable("HV", 3, 1, 0, 0, 0);
        content.add(imageRow,"HVSP");
        content.add(messagePanel);
        content.add(buttonPanel);
        getContentPane().add(addTitleBar(content));
		
		
        show();
    	waitUntilClosed();
    }
 
    public void actionPerformed(ActionEvent e) {
        hide();
    }

}