/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.tech;

import javax.swing.JScrollPane;
import javax.swing.JTabbedPane;

import mot.client.deligates.PlayerDelegate;
import mot.client.swing.common.ComponentTable;
import mot.client.swing.panels.TechnologyPicturePanel;
import mot.client.swing.tables.GeneralTechnologyTable;
import mot.common.lang.L;
import mot.common.technology.Technology;
import mot.common.util.ApplicationError;

public class TechnologyDiscoveredPanel extends ComponentTable {

	private TechnologyPicturePanel technologyPanel;
    private JScrollPane detailsScrollPane = new JScrollPane();
    
    private PlayerDelegate owner;
    
    public TechnologyDiscoveredPanel(PlayerDelegate owner, Technology discoveredTech, boolean fromSalvage) throws ApplicationError {
        super("HPV", 1, 1, 0, 0, 0);

        this.owner = owner;
        this.technologyPanel = new TechnologyPicturePanel(owner, false, true, false, false, discoveredTech, fromSalvage ? L.DISCOVERED_FROM_SALVAGE : null);
        this.detailsScrollPane = new JScrollPane(new GeneralTechnologyTable(discoveredTech));
        
        JTabbedPane tabs = new JTabbedPane();
        tabs.addTab(L.OVERVIEW, technologyPanel);
        tabs.addTab(L.DETAILS, detailsScrollPane);
        
        add(tabs);
        
    }

}
