/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.tech.actions;

import mot.client.deligates.cache.DeligateCacheManager;
import mot.client.proxy.CompletedCallback;
import mot.client.proxy.ProxyStore;
import mot.client.swing.buttons.MotButton;
import mot.client.swing.window.main.MainWindow;
import mot.client.swing.window.tech.ResearchWindow;
import mot.common.lang.L;
import mot.common.technology.GeneralTechnologyList;
import mot.common.technology.Technology;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class ResearchWindowAutoButton extends MotButton {

	private ResearchWindow parent;
	
	public ResearchWindowAutoButton(ResearchWindow parent) {
		super(L.AUTO);
		this.parent = parent;
	}

	protected void _doAction() throws ApplicationError, ValidationError {
		parent.hide();
		//Technology selection = parent.researchPanel.getProjectSelection();
		ProxyStore.getInstance().setResearchProjectAuto(true);
		setNextResearchProject();
	}
	
	public static void setNextResearchProject() throws ApplicationError, ValidationError {
        Technology [] availableTechs = DeligateCacheManager.getTechsAvailableForResearch();
        if (availableTechs != null) {
        	Technology selection = new GeneralTechnologyList(availableTechs).getCheapestToResearch();
        	if (selection != null) {
    			CompletedCallback callback = new CompletedCallback() {
    				public void complete(Object result) throws ApplicationError, ValidationError {
    					MainWindow.getExestingInstance().getGalaxyMapConfiguration().getGalaxyView().updateStatus(MainWindow.getOwner());
    				}
    			};
    			ProxyStore.getInstance().setResearchProjectCmd(selection, callback , null);
        	}
        }
	}

}
