/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.swing.window.tech.actions;

import mot.client.deligates.UserPlayerDelegate;
import mot.client.proxy.CompletedCallback;
import mot.client.proxy.ProxyStore;
import mot.client.swing.buttons.MotButton;
import mot.client.swing.window.common.MotConfirmationDialog;
import mot.client.swing.window.main.MainWindow;
import mot.client.swing.window.tech.ResearchWindow;
import mot.common.lang.L;
import mot.common.technology.Technology;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class ResearchWindowSelectTopicButton extends MotButton {

	private ResearchWindow parent;
	
	public ResearchWindowSelectTopicButton(ResearchWindow parent) {
		super(L.SELECT);
		this.parent = parent;
	}

	protected void _doAction() throws ApplicationError, ValidationError {
		ProxyStore.getInstance().setResearchProjectAuto(false);
		Technology selection = parent.researchPanel.getProjectSelection();
        if (selection != null && parent.project != null && selection != parent.project.getTechnology()) {
            boolean r = MotConfirmationDialog.showInPopup(parent, "You were researching "+parent.project.getTechnology().getName()+", Cancel this research project and start a new one?", "Warning");
            if (!r) {
				return;
            }
        }
		parent.hide();
        if (selection != null) {
        	UserPlayerDelegate owner = parent.getOwner();
            if (owner.getResearchProject() == null || owner.getResearchProject().getTechnology() != selection) {
                CompletedCallback callback = new CompletedCallback() {
					public void complete(Object result) throws ApplicationError, ValidationError {
						MainWindow.getExestingInstance().getGalaxyMapConfiguration().getGalaxyView().updateStatus(MainWindow.getOwner());
					}
				};
				ProxyStore.getInstance().setResearchProjectCmd(selection, callback , null);
            }
        }
	}

}
