/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.telemetry;

import mot.common.util.Logger;
import mot.common.util.PropertyManager;

public class Telemetry {
	
	private static final long INTERVAL_DURATION = 1000;

	public static boolean ON = false;
	
	public static int qtyDrawGalaxyMap;
	public static int qtyDrawGalaxyLabels;
	public static int qtyDrawGalaxyMoo;

	public static int qtyDrawImage;
	public static int qtyDrawRotatedImage;

	public static int qtyTick;

	public static int qtyPaintDialog;
	public static int qtyPaintLebel;
	
	
	private static long lastIntervalStart = 0;
	private static TelemetryStore store;
	
	public static void checkIntervalComplete() {
		long now = System.currentTimeMillis();
		if (now > lastIntervalStart + INTERVAL_DURATION) {
			lastIntervalStart = now;
			TelemetryStoreItem si = new TelemetryStoreItem();
			si.qtyDrawGalaxyMap = qtyDrawGalaxyMap;
			si.qtyDrawGalaxyLabels = qtyDrawGalaxyLabels;
			si.qtyDrawGalaxyMoo = qtyDrawGalaxyMoo;
			
			si.qtyDrawImage = qtyDrawImage;
			si.qtyDrawRotatedImage = qtyDrawRotatedImage;
			
			si.qtyTick = qtyTick;
			
			si.qtyPaintDialog = qtyPaintDialog;
			si.qtyPaintLebel = qtyPaintLebel;
			
			qtyDrawGalaxyMap = 0;
			qtyDrawGalaxyLabels = 0;
			qtyDrawGalaxyMoo = 0;
			
			qtyDrawImage = 0;
			qtyDrawRotatedImage = 0;
			
			qtyTick = 0;
			
			qtyPaintDialog = 0;
			qtyPaintLebel = 0;
			
			if (store == null) store = new TelemetryStore();
			store.add(si);
		}
	}

	public static void save() {
		if (store != null) {
			String file = PropertyManager.get("telemetry.file");
			if (file != null) {
				try {
					store.save(file);
				} catch (Exception e) {
					Logger.logError("Unable to save telemetry", e);
				}
			}
		}
	}

	public static void clear() {
		store = null;
	}

}
