/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.telemetry;

import java.io.BufferedWriter;
import java.io.FileWriter;
import java.io.IOException;
import java.io.PrintWriter;

import mot.common.util.Formatter;

public class TelemetryStore {

	private static final int VALUE_SIZE = 6;
	private TelemetryStoreItem [] content  = new TelemetryStoreItem[3600];
	private int start = 0;
	
	public void add(TelemetryStoreItem si) {
		content[start] = si;
		start++;
		if (start == content.length) {
			compact();
		}
	}

	private void compact() {
		start = 0;
		int i = content.length/2 + 2; 
		while (i < content.length) {
			content[start] = content[i];
			start++;
			i++;
		}
	}

	public void save(String fileName) throws IOException {
		PrintWriter out = new PrintWriter(new BufferedWriter(new FileWriter(fileName, false)));
		out.print("cticks,");
		out.print("galfps,");
		out.print("galmoo,");
		out.print("gallab,");
		out.print("totimg,");
		out.print("totrmg,");
		out.print("dlgfps,");
		out.print("dlglab,");
		out.println(' ');
		for (int i = 0; i < content.length; i++) {
			if (content[i] != null) {				
				out.print(Formatter.fixedSizeCardinal(content[i].qtyTick, VALUE_SIZE, ' ') );
				out.print(',');
				out.print(Formatter.fixedSizeCardinal(content[i].qtyDrawGalaxyMap, VALUE_SIZE, ' ') );
				out.print(',');
				out.print(Formatter.fixedSizeCardinal(content[i].qtyDrawGalaxyMoo, VALUE_SIZE, ' ') );
				out.print(',');
				out.print(Formatter.fixedSizeCardinal(content[i].qtyDrawGalaxyLabels, VALUE_SIZE, ' ') );
				out.print(',');
				out.print(Formatter.fixedSizeCardinal(content[i].qtyDrawImage, VALUE_SIZE, ' ') );
				out.print(',');
				out.print(Formatter.fixedSizeCardinal(content[i].qtyDrawRotatedImage, VALUE_SIZE, ' ') );
				out.print(',');
				out.print(Formatter.fixedSizeCardinal(content[i].qtyPaintDialog, VALUE_SIZE, ' ') );
				out.print(',');
				out.print(Formatter.fixedSizeCardinal(content[i].qtyPaintLebel, VALUE_SIZE, ' ') );
				out.print(',');
				out.println(' ');
			}
		}
		out.flush();
		out.close();		
	}

}
