/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.test;

	import java.awt.Image;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import java.net.MalformedURLException;

import javax.swing.JFrame;

import mot.client.swing.panels.AnimationPanel;
import mot.common.bean.PlanetGraphics;
import mot.common.factory.PlanetGraphicsFactory;
import mot.common.util.ApplicationError;
	 
	public class AnimationTest extends JFrame { 
	 
	    // this line is needed to avoid serialization warnings  
	    private static final long serialVersionUID = 1L;
	 
	 
	    Image screenImage; // downloaded image  
	    int w, h; // Display height and width 
	 
	 
	    // Program entry 
	    public static void main(String[] args) throws Exception {
	    	int index = 4;
	    	PlanetGraphics[] planetGraphics = PlanetGraphicsFactory.getPlanetGraphicsConfig().getPlanetGraphics();
            String[] stages = planetGraphics[index].getStagesAsArray();
			new AnimationTest(planetGraphics[index].getImage(), stages, planetGraphics[index].getImageType()); 
	    } 
	 
	    // Class constructor  
	    AnimationTest(String image, String [] stages, String imageType) throws MalformedURLException, ApplicationError { 
	    	
	    	AnimationPanel panel = new AnimationPanel(null, "Test", image, stages, imageType) {
	            protected void animationFinished() {
	            }
	        };
	        
	    	getContentPane().add(panel);
	    	
	        // Exiting program on window close 
	        addWindowListener(new WindowAdapter() { 
	            public void windowClosing(WindowEvent e) { 
	                System.exit(0);
	            } 
	        });
	 
	        // Exiti program on mouse click 
	        addMouseListener(new MouseListener() { 
	            public void mouseClicked(MouseEvent e) { System.exit(0); } 
	            public void mousePressed(MouseEvent e) {} 
	            public void mouseReleased(MouseEvent e) {} 
	            public void mouseEntered(MouseEvent e) {} 
	            public void mouseExited(MouseEvent e) {} 
	        } 
	        );
	        
	        // remove window frame  
	        //this.setUndecorated(true);
	 
	        // window should be visible 
	        this.setSize(500, 500);
	        this.setVisible(true);
	        
	        // switching to fullscreen mode 
	        //GraphicsEnvironment.getLocalGraphicsEnvironment().
	        //getDefaultScreenDevice().setFullScreenWindow(this);
	 

	    } 
	 
}
