/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.tutorials;

import mot.client.swing.buttons.MotButton;
import mot.client.swing.window.common.MotInternalWindow;
import mot.client.swing.window.main.MainWindow;
import mot.client.swing.window.solarsystem.SelectProjectWindow;
import mot.client.swing.window.solarsystem.SolarSystemWindow;
import mot.common.designs.CraftDesign;
import mot.common.designs.ProjectDesign;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.Comp;
import mot.common.util.Logger;
import mot.common.util.ValidationError;

public class A3aSetProjectTip extends TextTutorialTip {

	public A3aSetProjectTip() throws ApplicationError {
		super();
	}

	protected int getId() throws ApplicationError {
		return 0;
	}

	protected String getTutorialText() throws ApplicationError {
		return L.TT_SET_PROJECT2;
	}

	public void notifyWindowClose(MotInternalWindow win) throws ApplicationError {
		if (Logger.isDebug()) {
			Logger.logDebug("A3aSetProjectTip.notifyWindowOpen() win="+win.getClass().getName()); 
		}
		if (win instanceof SolarSystemWindow) {
			next();
		}
	}
	
	public void validateCommand(MotButton command)throws ApplicationError, ValidationError {
		MotInternalWindow win = MainWindow.getInstance().getGalaxyMapConfiguration().getGalaxyView().getTopWindow();
		if (win != null && win instanceof SelectProjectWindow && Comp.same(L.BUILD, command.getText())) {
			SelectProjectWindow spw = (SelectProjectWindow) win;
			ProjectDesign project = spw.getProject();
			if (project != null && project instanceof CraftDesign && ((CraftDesign)project).getName().startsWith("Colonise")) {
				return;
			}
			throw new ValidationError(L.YOU_ARE_IN_A_TUTORIAL_FOLLOW_THE_INSTRUCTIONS_OR_CLOSE_THE_TUTORIAL);
		}
	}
	
	public void next() throws ApplicationError {
		TutorialSystem.closeTip();
		new A3bClearPlanetSelectionTip().display();
	}
}
