/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.tutorials;

import mot.client.actions.ActiveRectangle;
import mot.client.deligates.CraftDelegate;
import mot.client.deligates.MoveableOwnedObjectDelegate;
import mot.client.deligates.PlanetDelegate;
import mot.client.deligates.StellarObjectDelegate;
import mot.client.deligates.cache.DeligateCacheManager;
import mot.client.swing.window.galaxy.GalaxyMapMoo;
import mot.client.swing.window.galaxy.GalaxyMapPlanet;
import mot.client.swing.window.main.MainWindow;
import mot.common.bean.GameConstants;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.Comp;
import mot.common.util.ValidationError;

public class A5MoveColonyCraftTip extends TextTutorialTip {

	public A5MoveColonyCraftTip() throws ApplicationError {
		super();
	}

	protected int getId() throws ApplicationError {
		return 10;
	}

	protected String getTutorialText() throws ApplicationError {
		return L.TT_MOVE_COLONY_CRAFT;
	}

	protected int getQtyFlashes() {
		return 12;
	}
	
	public void notifyInstructMoo(MoveableOwnedObjectDelegate selection, StellarObjectDelegate so, PlanetDelegate planet) throws ApplicationError {
		next();
	}

	public void validateClick(ActiveRectangle ar) throws ApplicationError, ValidationError {
		MoveableOwnedObjectDelegate selection = MainWindow.getInstance().getGalaxyMapConfiguration().getListener().getSelectedMoo();
		if (ar instanceof GalaxyMapMoo) {
			GalaxyMapMoo moo = (GalaxyMapMoo) ar;
			if (moo.getMostVisibleMoo() instanceof CraftDelegate) {
				CraftDelegate craft = (CraftDelegate) moo.getMostVisibleMoo();
				if (craft.getName().startsWith("Coloniser")) {
					return;
				}
			}
		} else if (ar instanceof GalaxyMapPlanet) {
			if (selection != null && selection.getName().startsWith("Coloniser")) {
				GalaxyMapPlanet p = (GalaxyMapPlanet) ar;
				PlanetDelegate firstNewColony = DeligateCacheManager.getPlanet(GameConstants.TUTORIAL_FIRST_COLONY_NAME+"-A");
				if (firstNewColony != null) {
					if (Comp.same(firstNewColony, p.getPlanet())) {
						return;
					}
				}
			}
		}
		throw new ValidationError(L.YOU_ARE_IN_A_TUTORIAL_FOLLOW_THE_INSTRUCTIONS_OR_CLOSE_THE_TUTORIAL);
	}

	public void next() throws ApplicationError {
		TutorialSystem.closeTip();
		new A6EndTurnTip().display();
	}
}
