/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.tutorials;

import mot.client.swing.buttons.MotButton;
import mot.client.swing.window.galaxy.actions.EndTurnButton;
import mot.common.event.EndTurnEvent;
import mot.common.event.StartTurnEvent;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.Logger;
import mot.common.util.ValidationError;

public class A6EndTurnTip extends TextTutorialTip {

	public A6EndTurnTip() throws ApplicationError {
		super();
	}

	protected int getId() throws ApplicationError {
		return 0;
	}

	protected String getTutorialText() throws ApplicationError {
		return L.TT_END_TURN;
	}

	public void notifyEndTurn() throws ApplicationError {
		if (Logger.isDebug()) {
			Logger.logDebug("A6MoveScoutCraftTip.notifyEndTurn()"); 
		}
		next();
	}

	public void validateCommand(MotButton command)throws ApplicationError, ValidationError {
		if (command instanceof EndTurnButton) {
			return;
		}
		super.validateCommand(command);
	}

	public void next() throws ApplicationError {
		TutorialSystem.closeTip();
		new A7MoveScoutCraftTip().display();
	}

	private static Class [] eventsToProcess = { EndTurnEvent.class, StartTurnEvent.class };
	public Class [] getEventToProcess() {
		return eventsToProcess;
	}
}
