/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.tutorials;

import mot.client.deligates.PlanetDelegate;
import mot.client.swing.buttons.MotButton;
import mot.client.swing.panels.BackgroundImagePanel;
import mot.client.swing.window.main.MainWindow;
import mot.client.swing.window.main.MainWindowView;
import mot.client.swing.window.solarsystem.SelectPlanetWindow;
import mot.common.event.EndTurnEvent;
import mot.common.event.PlanetColonisedEvent;
import mot.common.event.StartTurnEvent;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class B0ColoniserArrivedTip extends TextTutorialTip {

	private SelectPlanetWindow win;

	public B0ColoniserArrivedTip(SelectPlanetWindow win) throws ApplicationError {
		super();
		this.win = win;
		MainWindowView view = MainWindow.getInstance().getGalaxyMapConfiguration().getView();
		if (view.isDesktopPaneActive()) {
			view.deactivateDesktopPane();
		}
	}

	protected int getId() throws ApplicationError {
		return 0;
	}

	protected String getTutorialText() throws ApplicationError {
		return L.TT_COLONISER_ARRIVED;
	}

	public void validateCommand(MotButton command) throws ApplicationError, ValidationError {
		if (L.SELECT.equalsIgnoreCase(command.getText())) {
			// User has selected the planet to colonise by clicking on select button.
			next();
		} else {
			super.validateCommand(command);
		}
	}
	
	public void validateBackgroundImageClicked(BackgroundImagePanel parent) throws ValidationError, ApplicationError {
		// User has selected the planet to colonise by clicking on planet image.
		next();
	}
	
	public void next() throws ApplicationError {
		TutorialSystem.closeTip();
		PlanetDelegate newColony = win.getSelectedPlanet();
		new B1FirstNewColonyTip(newColony).display();
	}
	
	private static Class [] eventsToProcess = { EndTurnEvent.class, StartTurnEvent.class, PlanetColonisedEvent.class };
	public Class [] getEventToProcess() {
		return eventsToProcess;
	}
}
