/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.tutorials;

import mot.client.deligates.PlanetDelegate;
import mot.client.swing.buttons.MotButton;
import mot.client.swing.window.main.MainWindow;
import mot.client.swing.window.main.MainWindowView;
import mot.common.event.EndTurnEvent;
import mot.common.event.PlanetColonisedEvent;
import mot.common.event.StartTurnEvent;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class B1FirstNewColonyTip extends TextTutorialTip {

	private PlanetDelegate newColony;

	public B1FirstNewColonyTip(PlanetDelegate newColony) throws ApplicationError {
		super();
		this.newColony = newColony;
		MainWindowView view = MainWindow.getInstance().getGalaxyMapConfiguration().getView();
		if (view.isDesktopPaneActive()) {
			view.deactivateDesktopPane();
		}
	}

	protected int getId() throws ApplicationError {
		return 0;
	}

	protected String getTutorialText() throws ApplicationError {
		return L.TT_FIRST_COLONY;
	}

	public void validateCommand(MotButton command) throws ApplicationError, ValidationError {
		if (L.OK.equalsIgnoreCase(command.getText())) {
			// User has pressed OK button on rename planet window.
			next();
		} else {
			super.validateCommand(command);
		}
	}
	
//	public void validateBackgroundImageClicked(BackgroundImagePanel parent) throws ValidationError, ApplicationError {
//		next();
//	}
	
	public void next() throws ApplicationError {
		TutorialSystem.closeTip();
		new B2ViewNewColonyTip(newColony).display();
	}
	
	private static Class [] eventsToProcess = { EndTurnEvent.class, StartTurnEvent.class, PlanetColonisedEvent.class };
	public Class [] getEventToProcess() {
		return eventsToProcess;
	}
}
