/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.tutorials;

import mot.client.deligates.PlanetDelegate;
import mot.client.swing.buttons.MotButton;
import mot.client.swing.window.common.MotInternalWindow;
import mot.client.swing.window.main.MainWindow;
import mot.client.swing.window.solarsystem.SelectProjectWindow;
import mot.common.designs.ProjectDesign;
import mot.common.designs.TransportDesign;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.Comp;
import mot.common.util.Logger;
import mot.common.util.ValidationError;

public class B3SetTransportProjectTip extends TextTutorialTip {

	private PlanetDelegate newColony;

	public B3SetTransportProjectTip(PlanetDelegate newColony) throws ApplicationError {
		super();
		this.newColony = newColony;
	}

	protected int getId() throws ApplicationError {
		return 0;
	}

	protected String getTutorialText() throws ApplicationError {
		return L.TT_FIRST_COLONY_SETPROJECT;
	}

	public void notifyWindowClose(MotInternalWindow win) throws ApplicationError {
		if (Logger.isDebug()) {
			Logger.logDebug("B3SetTransportProjectTip.notifyWindowOpen() win="+win.getClass().getName()); 
		}
		if (win instanceof SelectProjectWindow) {
			next();
		}
	}
	
	public void validateCommand(MotButton command)throws ApplicationError, ValidationError {
		MotInternalWindow win = MainWindow.getInstance().getGalaxyMapConfiguration().getGalaxyView().getTopWindow();
		if (win != null && win instanceof SelectProjectWindow && Comp.same(L.BUILD, command.getText())) {
			SelectProjectWindow spw = (SelectProjectWindow) win;
			ProjectDesign project = spw.getProject();
			if (project != null && project instanceof TransportDesign) {
				return;
			}
		}
		super.validateCommand(command);
	}
	
	public void next() throws ApplicationError {
		TutorialSystem.closeTip();
		new B4PurchaseProjectTip(newColony).display();
	}
}
