/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.tutorials;

import mot.client.deligates.PlanetDelegate;
import mot.client.swing.buttons.MotButton;
import mot.client.swing.window.galaxy.actions.EndTurnButton;
import mot.client.swing.window.main.MainWindow;
import mot.common.event.EndTurnEvent;
import mot.common.event.NoProjectEvent;
import mot.common.event.StartTurnEvent;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class B5EndTurnTip extends TextTutorialTip {

	private PlanetDelegate newColony;

	public B5EndTurnTip(PlanetDelegate newColony) throws ApplicationError {
		super();
		this.newColony = newColony;
	}

	protected int getId() throws ApplicationError {
		return 0;
	}

	protected String getTutorialText() throws ApplicationError {
		return L.TT_FIRST_COLONY_ENDTURN;
	}

	public void validateCommand(MotButton command)throws ApplicationError, ValidationError {
		if (command instanceof EndTurnButton) {
			if (MainWindow.getInstance().getGalaxyMapConfiguration().getGalaxyView().isDesktopPaneActive()) {
				throw new ValidationError("Close the window before pressing End Turn");
			}
			next();
		} else if (command != null && command.getText().equalsIgnoreCase(L.CLOSE)) {
			// Closing the Solar System Window
		} else {
			super.validateCommand(command);
		}
	}	
	
	public void next() throws ApplicationError {
		TutorialSystem.closeTip();
		new B5NoProject(newColony).display();
	}

	private static Class [] eventsToProcess = { EndTurnEvent.class, StartTurnEvent.class,  NoProjectEvent.class };
	public Class [] getEventToProcess() {
		return eventsToProcess;
	}
}
