/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.tutorials;

import mot.client.actions.ActiveRectangle;
import mot.client.deligates.CraftDelegate;
import mot.client.deligates.FleetDelegate;
import mot.client.deligates.StellarObjectDelegate;
import mot.client.swing.window.galaxy.GalaxyMapMoo;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class C1MonstersAboutTip extends TextTutorialTip {

	private StellarObjectDelegate so;

	public C1MonstersAboutTip(StellarObjectDelegate so) throws ApplicationError {
		super();
		this.so = so;
	}

	protected int getId() throws ApplicationError {
		return 0;
	}

	protected String getTutorialText() throws ApplicationError {
		return L.TT_MONSTER_INSTRUCTMOO;
	}

	public void validateClick(ActiveRectangle ar) throws ApplicationError, ValidationError {
		if (ar instanceof GalaxyMapMoo) {
			GalaxyMapMoo moo = (GalaxyMapMoo) ar;
			if (moo.getMostVisibleMoo() instanceof CraftDelegate) {
				CraftDelegate craft = (CraftDelegate) moo.getMooHeadingTo(so);
				if (craft != null) {
					return;
				}
			} else if (moo.getMostVisibleMoo() instanceof FleetDelegate) {
				FleetDelegate fleet = (FleetDelegate) moo.getMooHeadingTo(so);
				if (fleet != null) {
					return;
				}
			}
		}
		throw new ValidationError(L.YOU_ARE_IN_A_TUTORIAL_FOLLOW_THE_INSTRUCTIONS_OR_CLOSE_THE_TUTORIAL);
	}
	
	public void validateDoubleClick(ActiveRectangle ar) throws ApplicationError, ValidationError {
		if (ar instanceof GalaxyMapMoo) {
			GalaxyMapMoo moo = (GalaxyMapMoo) ar;
			if (moo.getMostVisibleMoo() instanceof CraftDelegate) {
				CraftDelegate craft = (CraftDelegate) moo.getMooHeadingTo(so);
				if (craft != null) {
					next();
					return;
				}
			} else if (moo.getMostVisibleMoo() instanceof FleetDelegate) {
				FleetDelegate fleet = (FleetDelegate) moo.getMooHeadingTo(so);
				if (fleet != null) {
					next();
					return;
				}
			}
		}
		throw new ValidationError(L.YOU_ARE_IN_A_TUTORIAL_FOLLOW_THE_INSTRUCTIONS_OR_CLOSE_THE_TUTORIAL);
	}	
	
	public void next() throws ApplicationError {
		TutorialSystem.closeTip();
		new C2MonstersCraftDesignTip(so).display();
	}
}
