/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.tutorials;

import javax.swing.JComponent;
import javax.swing.JLabel;

import mot.client.swing.buttons.MotButton;
import mot.client.swing.common.ComponentTable;
import mot.client.swing.common.MotLabel;
import mot.client.swing.common.PadPanel;
import mot.client.swing.common.PanelUtils;
import mot.client.swing.config.ImageConfigFactory;
import mot.client.swing.panels.ImagePanel;
import mot.client.swing.window.main.MainWindow;
import mot.common.bean.Size;
import mot.common.util.ApplicationError;

public abstract class TextTutorialTip extends Tutorial {

	private String icon; 
	
	public TextTutorialTip() throws ApplicationError {
		icon = ImageConfigFactory.getImageForConfig("TutorialImage");
	}
	
	protected abstract String getTutorialText() throws ApplicationError;

	protected JComponent getContent() throws ApplicationError {
		String text = getTutorialText();
		MotButton stopAction = new TutorialButtonStop();
		MotButton skipAction = new TutorialButtonSkip();
		double width = MainWindow.getInstance().getSize().getWidth();
		int fontSize = 2;
		boolean useIcon = true;
		if (width < 1100) {
			fontSize = 0;
			useIcon = false;
		} else if (width < 1300) {
			fontSize = 0;
			useIcon = false;
		}

		ComponentTable buttonPanel = new ComponentTable("HVSP", 1, 1, 0, 0, 0);
		buttonPanel.add(stopAction);
		//buttonPanel.add(skipAction);
		
		ComponentTable component = null;
		if (useIcon) {
			component = new ComponentTable("HV,-,-,-,HVSP", 1, 6, 2, 0, 0);
		} else {
			component = new ComponentTable("-,-,HVSP", 1, 4, 5, 0, 0);
		}
		if (useIcon) {
			ImagePanel imagePanel = new ImagePanel(icon);
			PanelUtils.setTheBloodySize(imagePanel, new Size(45, 45));
			component.add(imagePanel);
			component.add(new PadPanel(25));
		}
		component.add(buttonPanel);
		component.add(new PadPanel(25));
		component.add(new MotLabel(text, fontSize, JLabel.LEFT, false));
		return component;
	}

	
}
