/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.tutorials;

import java.awt.Component;

import javax.swing.JComponent;
import javax.swing.Popup;
import javax.swing.PopupFactory;

import mot.client.actions.ActiveRectangle;
import mot.client.deligates.CraftDelegate;
import mot.client.deligates.MoveableOwnedObjectDelegate;
import mot.client.deligates.PlanetDelegate;
import mot.client.deligates.StellarObjectDelegate;
import mot.client.deligates.UserPlayerDelegate;
import mot.client.deligates.cache.DeligateCacheManager;
import mot.client.swing.buttons.MotButton;
import mot.client.swing.buttons.MotImageButton;
import mot.client.swing.buttons.MotToggleButton;
import mot.client.swing.panels.BackgroundImagePanel;
import mot.client.swing.panels.ProgressBarPanel;
import mot.client.swing.window.common.MotInternalWindow;
import mot.client.swing.window.main.MainWindow;
import mot.client.swing.window.main.MainWindowMessageList;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.Comp;
import mot.common.util.ValidationError;

public abstract class Tutorial {
	
	private static final String YOU_ARE_IN_A_TUTORIAL_FOLLOW_THE_INSTRUCTIONS_OR_CLOSE_THE_TUTORIAL = "You are in a tutorial - Follow the instructions or stop the tutorial";
	protected Popup popup;
	
	protected abstract JComponent getContent() throws ApplicationError;
	protected abstract int getId() throws ApplicationError;
	public abstract void next() throws ApplicationError;

	public static CraftDelegate getColonyCraft() throws ApplicationError {
		UserPlayerDelegate user = MainWindow.getOwner();
		CraftDelegate[] crafts = DeligateCacheManager.getCrafts(user);
		return (CraftDelegate) Comp.getNameStartingWith("Coloniser", crafts);
	}
	
	public static CraftDelegate getScoutCraft() throws ApplicationError {
		UserPlayerDelegate user = MainWindow.getOwner();
		CraftDelegate[] crafts = DeligateCacheManager.getCrafts(user);
		return (CraftDelegate) Comp.getNameStartingWith("Scout", crafts);
	}
	
	protected boolean ready() throws ApplicationError {
		return true;
	}
	
	protected void display() throws ApplicationError {
		JComponent contents = getContent();
		MainWindowMessageTutorial mwm = new MainWindowMessageTutorial(contents, this);
		MainWindowMessageList ml = MainWindow.getInstance().getGalaxyMapConfiguration().getGalaxyView().getMessageList();
		ml.showTipMessage(mwm);
	}
	
	protected void display(Component container, int x, int y) throws ApplicationError, ValidationError {
		TutorialSystem.setDateOfLastTip(DeligateCacheManager.getDate());
		JComponent message = getContent();
		popup = PopupFactory.getSharedInstance().getPopup(container, message, x, y);
		popup.show();
	}
	
	public void notifyEndTurn() throws ApplicationError {
	}
	
	public void notifyClearSelection() throws ApplicationError {
	}
	
	public void notifyWindowOpen(MotInternalWindow win) throws ApplicationError {
	}
	
	public void notifyWindowClose(MotInternalWindow win) throws ApplicationError {
	}
	
	public void notifyInstructMoo(MoveableOwnedObjectDelegate selection, StellarObjectDelegate so, PlanetDelegate planet) throws ApplicationError {
	}
	
	public void validateClick(ActiveRectangle ar) throws ApplicationError, ValidationError {
		throw new ValidationError(L.YOU_ARE_IN_A_TUTORIAL_FOLLOW_THE_INSTRUCTIONS_OR_CLOSE_THE_TUTORIAL);
	}
	
	public void validateDoubleClick(ActiveRectangle ar)throws ApplicationError, ValidationError {
		throw new ValidationError(L.YOU_ARE_IN_A_TUTORIAL_FOLLOW_THE_INSTRUCTIONS_OR_CLOSE_THE_TUTORIAL);
	}
	
	public void validateCommand(MotButton command)throws ApplicationError, ValidationError {
		throw new ValidationError(L.YOU_ARE_IN_A_TUTORIAL_FOLLOW_THE_INSTRUCTIONS_OR_CLOSE_THE_TUTORIAL);
	}
	
	public void validateCommand(MotImageButton command)throws ApplicationError, ValidationError {
		throw new ValidationError(L.YOU_ARE_IN_A_TUTORIAL_FOLLOW_THE_INSTRUCTIONS_OR_CLOSE_THE_TUTORIAL);
	}

	public void validateCommand(MotToggleButton command) throws ApplicationError, ValidationError {
		throw new ValidationError(L.YOU_ARE_IN_A_TUTORIAL_FOLLOW_THE_INSTRUCTIONS_OR_CLOSE_THE_TUTORIAL);
	}
	
	public void validateBackgroundImageClicked(BackgroundImagePanel parent) throws ValidationError, ApplicationError {
		throw new ValidationError(L.YOU_ARE_IN_A_TUTORIAL_FOLLOW_THE_INSTRUCTIONS_OR_CLOSE_THE_TUTORIAL);
	}
	
	public void validateProgressBarClicked(ProgressBarPanel parent) throws ValidationError, ApplicationError {
		throw new ValidationError(L.YOU_ARE_IN_A_TUTORIAL_FOLLOW_THE_INSTRUCTIONS_OR_CLOSE_THE_TUTORIAL);
	}
	
	public Class [] getEventToProcess() {
		return null;
	}
	
	
}
