/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.validators;

import java.io.File;

import mot.common.util.Comp;
import mot.common.util.ValidationError;

public class FileValidator implements MotValidator {
	
	private String fieldName;
	private String[] validExtensions;
	
	public FileValidator(String fieldName, String [] validExtensions) {
		this.fieldName = fieldName;
		this.validExtensions = validExtensions;
}
	
	public File validate(String text) throws ValidationError {
		if (text == null || text.length() < 2) {
    		throw new ValidationError("Invalid file type");
		}
		int i = text.indexOf('.');
		if (i < 0) {
    		throw new ValidationError("Invalid file type");
		}
		String extension = text.substring(i+1);
		if (!Comp.in(extension, validExtensions)) {
    		throw new ValidationError("Invalid file type");
		}
    	File file = new File(text);
    	if (!file.exists()) {
    		throw new ValidationError("File does not exist");
    	}
    	return file;
	}
}
