/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.client.validators;

import mot.common.lang.L;
import mot.common.util.ValidationError;

public class IntegerValidator implements MotValidator {
	
	private String fieldName;
	private Integer min;
	private Integer max;
	
	public IntegerValidator(String fieldName, Integer min, Integer max) {
		this.fieldName = fieldName;
		this.min = min;
		this.max = max;
	}
	
	public Integer validate(String text) throws ValidationError {
		int v = 0;
		if (text != null && text.length() > 0) {
			try {			
				v = Integer.parseInt(text);
			} catch (NumberFormatException ex) {
				throw new ValidationError(L.INVALID_+fieldName+" "+text);
			}
			if (min != null && v < min) {
				throw new ValidationError(L.INVALID_+fieldName+" "+text);
			}
			if (max != null && v > max) {
				throw new ValidationError(L.INVALID_+fieldName+" "+text);
			}
		}
		return v;
	}
}
