/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.bean;

import java.io.Serializable;

import mot.common.util.ApplicationError;
import mot.common.xml.XMLBean;
import mot.common.xml.XMLWriter;

/**
 * Represents an area of a map.
 */
public class Circle extends XMLBean implements Serializable  {

	private Location location;
	private int diameter;

	public Circle() {
	}
	
	public Circle(Location center, int diameter) {
		this.location = center;
		this.diameter = diameter;
	}	
	
	public boolean contains(Location l) {
		if (l == null || location == null) return false;
		if (l.getDistanceTo(location) < (diameter/2)) {
			return true;
		} else {
			return false;
		}
	}

	public boolean intersects(Circle c) {
		if (c == null || location == null) return false;
		int td = (c.getDiameter() + diameter)/2;
		if (c.getLocation().getDistanceTo(location) < td) {
			return true;
		} else {
			return false;
		}
	}

	public Location getLocation() {
		return location;
	}

	public void setLocation(Location center) {
		this.location = center;
	}

	public int getDiameter() {
		return diameter;
	}

	public void setDiameter(int diameter) {
		this.diameter = diameter;
	}

	protected String getElementName() { return "circle"; }
    
	protected void encode(XMLWriter writer) throws ApplicationError {
		if (location != null) location.toXML(writer);
		writer.addElement("diameter", diameter);		
	}

    public String toString() { return "Circle ["+location+","+diameter+"]"; }

}