/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.bean;

import java.io.Serializable;


/**
 * This is a Bean that contains the details of a craft's damage. 
 * It is used by the Damage Event and the Weapon Fire Event.
 */
public class Damage implements Serializable {
	
	/**
	 * description of the damage.
	 */
	private String targetDescription;
	
    /**
     * The damage inflicted on the targets hull. DO NOT USE THIS TO DISPLAY DAMAGE - USE DESCRIPTION.
     * This is used by some weapons such as girator to skip certain parts of the animation of no damage was actually inflicted.
     */
    private double damage;

    /**
     * The damage inflicted on the targets shields. DO NOT USE THIS TO DISPLAY DAMAGE - USE DESCRIPTION.
     * This is used to determine if shields should be animated during the hit.
     */
    private double shieldBlockedDamage;

    /**
     * True is this craft has been destroyed at the point of this animation
     */
    private boolean destroyed;

    /**
     * This is the target location to which to draw the weapons fire to.
     * This is usually null, in which case the weapon fire is drawn to the target
     * battle object.
     */
    private Location targetLocation;

    /**
     * The target craft state before this animations is taking place.
     */
    private CraftState oldTargetState;

    /**
     * The target craft state while this animations is taking place.
     */
    private CraftState newTargetState;

    public Damage(String targetDescription, double damage, double shieldBlockedDamage, boolean destroyed, Location targetLocation, CraftState oldTargetState, CraftState newTargetState) {
    	this.targetDescription = targetDescription;
        this.damage = damage;
        this.shieldBlockedDamage = shieldBlockedDamage;
        this.destroyed = destroyed;
        this.targetLocation = targetLocation;
        this.oldTargetState = oldTargetState;
        this.newTargetState = newTargetState;
	}

    public Damage(String targetDescription, double damage, double shieldBlockedDamage, boolean destroyed, CraftState oldTargetState, CraftState newTargetState) {
    	this.targetDescription = targetDescription;
        this.damage = damage;
        this.shieldBlockedDamage = shieldBlockedDamage;
        this.destroyed = destroyed;
        this.oldTargetState = oldTargetState;
        this.newTargetState = newTargetState;
	}
    
	public String toString() {
		return "Damage [dam="+targetDescription+" destyd="+destroyed+" loc="+targetLocation+"]";
	}

	public double getDamage() {
		return damage;
	}

	public void setDamage(double damage) {
		this.damage = damage;
	}

	public double getShieldBlockedDamage() {
		return shieldBlockedDamage;
	}

	public void setShieldBlockedDamage(double shieldBlockedDamage) {
		this.shieldBlockedDamage = shieldBlockedDamage;
	}

	public boolean isDestroyed() {
		return destroyed;
	}

	public boolean getDestroyed() {
		return destroyed;
	}

	public void setDestroyed(boolean destroyed) {
		this.destroyed = destroyed;
	}

	public CraftState getNewTargetState() {
		return newTargetState;
	}

	public void setNewTargetState(CraftState newTargetState) {
		this.newTargetState = newTargetState;
	}

	public CraftState getOldTargetState() {
		return oldTargetState;
	}

	public void setOldTargetState(CraftState oldTargetState) {
		this.oldTargetState = oldTargetState;
	}

	public Location getTargetLocation() {
		return targetLocation;
	}

	public void setTargetLocation(Location targetLocation) {
		this.targetLocation = targetLocation;
	}

	public String getTargetDescription() {
		return targetDescription;
	}

	public void setTargetDescription(String targetDescription) {
		this.targetDescription = targetDescription;
	}

}
