/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.bean;

import java.io.Serializable;

import mot.client.swing.config.ImageAnimationConfig;
import mot.common.util.ApplicationError;

/**
 */
public interface Decorator extends Serializable {
	
	/**
	 * @return The unique name of this decorator
	 */
	String getName();
	
	/**
	 * @return The details of the images that are used to animate this decorator.
	 * @throws ApplicationError 
	 */
	ImageAnimationConfig getImageConfig() throws ApplicationError;
	
	/**
	 * @return True if this decorator should be shown to all the players in a battle
	 * and false if this decorator should only be shown to if the decorator owner is
	 * the window owner.
	 */
	boolean visibleToAll();
	
	/**
	 * Some decorates flash. This enables a decorator to determine when it should 
	 * be on and when it should be off.
	 * @param tickNo A number than increases by one every frame.
	 * @return True if this decorator should be drawn on the window in this animation frame.
	 */
	boolean isOn(int tickNo);

	/**
	 * @return 0 if nothing or a value associated with the decorator
	 */
	int getQty();

}
