/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.bean;
import java.io.Serializable;
import java.util.ArrayList;
import java.util.Iterator;

import mot.client.swing.config.ImageAnimationConfig;
import mot.common.util.ApplicationError;
import mot.common.util.Logger;

/**
 * A decorator is an image that is to be displayed on top of a craft to notify the 
 * owner of its status. Note that they are only displayed to the owner of the craft!
 * They are used to notify the owner
 *  - A ship is a hologram
 */
public class DecoratorList implements Serializable {

    private ArrayList list;
    
    private transient Decorator [] decorators;
    private transient ImageAnimationConfig  [] images;

    public DecoratorList() {
    }
    
    public DecoratorList(DecoratorList other) {
    	if (other != null) {
    		ArrayList l = other.getList();
    		if (l != null) {
    			for (Object o : l) {
    		        if (list == null) list = new ArrayList();
    				list.add(o);
    			}
    		}
    	}
	}

	public void removeAll() {
    	list.clear();
        decorators = null;
        images = null;
    }
    
    public void add(Decorator decorator) {
        if (list == null) list = new ArrayList();
        list.add(decorator);
        decorators = null;
        images = null;
    }
    
    public Decorator [] getDecorators() {
        if (list == null || list.size() == 0) return null;
        if (decorators == null) {
            decorators = new Decorator[list.size()];
            int j = 0;
            for (Iterator i = list.iterator(); i.hasNext();) {
            	decorators[j++] = (Decorator) i.next();
			}
        }
        return decorators;
    }
    
    public ImageAnimationConfig [] getDecoratorImages() throws ApplicationError {
        if (list == null) return null;
        if (images == null) {
        	images = new ImageAnimationConfig[list.size()];
            int j = 0;
            for (Iterator i = list.iterator(); i.hasNext();) {
				Decorator d = (Decorator) i.next();
				ImageAnimationConfig imageConfig = d.getImageConfig();
				if (imageConfig == null) {
					Logger.logWarning("DecoratorList.getDecoratorImages() Unable to find Image Config "+d.getName());
				}
				images[j++] = imageConfig;
			}
        }
        return images;
    }


    public void setList(ArrayList list) {
        this.list = list;
        decorators = null;
        images = null;
    }


    public ArrayList getList() {
        return list;
    }
    
}