/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.bean;

import mot.client.swing.config.AnimationConfigFactory;
import mot.client.swing.config.ImageAnimationConfig;
import mot.common.util.ApplicationError;

/**
 * This decorator is used to indicate the object being drawn is NOT real.
 * It is just a hologram to trick an enemy into waiting shots at it.
 * 
 * This is implemented using the flyweight pattern to reduce the memory 
 * footprint. @see mot.commom.bean.DecoratorStore.
 */
public class DecoratorPlague implements Decorator {
	
	protected static final String NAME = "PlagueDecorator";
	
	private static ImageAnimationConfig imageConfig = null;

	private int qty;
	
	protected DecoratorPlague() {
	}

	protected DecoratorPlague(int qty) {
		this.qty = qty;
	}

	public ImageAnimationConfig getImageConfig() throws ApplicationError {
		if (imageConfig  == null) {
			imageConfig = AnimationConfigFactory.getInstance().getImageAnimationConfig("decorator-plague");
		}
		return imageConfig;
	}

	public String getName() {
		return NAME;
	}

	public boolean visibleToAll() {
		return true;
	}

	public boolean isOn(int tickNo) {
		return true;
	}

	public int getQty() {
		return qty;
	}

	public void setQty(int qty) {
		this.qty = qty;
	}

	public static DecoratorPlague getInstance(int qty) {
		return new DecoratorPlague(qty);
	}

}
