/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.bean;

import mot.client.swing.config.AnimationConfigFactory;
import mot.client.swing.config.ImageAnimationConfig;
import mot.common.util.ApplicationError;

/**
 * This decorator is used to indicate the object being drawn is sleeping (missing turns).
 * 
 * This is implemented using the fly weight pattern to reduce the memory 
 * footprint. @see mot.commom.bean.DecoratorStore.
 */
public class DecoratorSleep implements Decorator {
	
	protected static final String NAME = "SleepDecorator";
	
	private static ImageAnimationConfig imageConfig = null;
	
	public DecoratorSleep() {
	}

	public ImageAnimationConfig getImageConfig() throws ApplicationError {
		if (imageConfig  == null) {
			imageConfig = AnimationConfigFactory.getInstance().getImageAnimationConfig("decorator-sleep");
		}
		return imageConfig;
	}

	public String getName() {
		return NAME;
	}

	public boolean visibleToAll() {
		return true;
	}

	public boolean isOn(int tickNo) {
		return true;
	}

	public static DecoratorSleep decoratorSleep = new DecoratorSleep();
	public static DecoratorSleep getInstance() {
		return decoratorSleep;
	}

	public int getQty() { return 0; }

}
