/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.bean;

/**
 * Defines the list of names for diplomatic statements used in this game.
 * Diplomatic statements are sentences used to communicate things like:
 *  - I declare war on you
 *  - Will you agree to peace with me?
 * Much of these are defined in a players character - this gives us the
 * opportunity to make each player use different language.
 */
public class DiplomaticStatements  {

    public static final String DECLARE_WAR = "WAR";
    public static final String DECLARE_WAR_AFTER_REJECT_DEMAND = "WAR_DEMAND";
    public static final String DECLARE_WAR_AFTER_SABOTAGE = "WAR_SABOTAGE";
    public static final String DECLARE_WAR_SUPRISE_ATTACK = "WAR_SUPRISE_ATTACK";
    
    public static final String ACCEPT_WAR_DECLARATION_LIKE = "ACCEPT_WAR_DECLARATION_LIKE";
    public static final String ACCEPT_WAR_DECLARATION_DISLIKE = "ACCEPT_WAR_DECLARATION_DISLIKE";

    public static final String GIFT_THANKYOU_NO_VALUE = "GIFT_THANKYOU_NO_VALUE";
    public static final String GIFT_THANKYOU_NO_REPEATED_VALUE = "GIFT_THANKYOU_NO_REPEATED_VALUE";
    public static final String GIFT_THANKYOU_SMALL_HATE = "GIFT_THANKYOU_SMALL_HATE";
    public static final String GIFT_THANKYOU_SMALL = "GIFT_THANKYOU_SMALL";
    public static final String GIFT_THANKYOU_LARGE = "GIFT_THANKYOU_LARGE";
    
    public static final String DEMAND_REQUEST = "DEMAND_REQUEST";
    
    public static final String DEMAND_RESPONSE_LIKE_ACCEPTED = "DEMAND_RESPONSE_LIKE_ACCEPTED";
    public static final String DEMAND_RESPONSE_LIKE_REJECTED = "DEMAND_RESPONSE_LIKE_REJECTED";
    public static final String DEMAND_RESPONSE_DISLIKE_ACCEPTED = "DEMAND_RESPONSE_DISLIKE_ACCEPTED";
    public static final String DEMAND_RESPONSE_DISLIKE_REJECTED = "DEMAND_RESPONSE_DISLIKE_REJECTED";
    public static final String DEMAND_RESPONSE_REPEATED_DEMAND = "DEMAND_RESPONSE_REPEATED_DEMAND";

    public static final String SWAP_RESPONSE_ACCEPT_LIKE_GOOD_SWAP = "SWAP_RESPONSE_ACCEPT_LIKE_GOOD_SWAP";
    public static final String SWAP_RESPONSE_ACCEPT_LIKE_OK_SWAP = "SWAP_RESPONSE_ACCEPT_LIKE_OK_SWAP";
    public static final String SWAP_RESPONSE_ACCEPT_NEUTRAL_GOOD_SWAP = "SWAP_RESPONSE_ACCEPT_NEUTRAL_GOOD_SWAP";
    public static final String SWAP_RESPONSE_ACCEPT_NEUTRAL_OK_SWAP = "SWAP_RESPONSE_ACCEPT_NEUTRAL_OK_SWAP";
    public static final String SWAP_RESPONSE_ACCEPT_DISLIKE_EXCELENT_SWAP = "SWAP_RESPONSE_ACCEPT_DISLIKE_EXCELENT_SWAP";
    public static final String SWAP_RESPONSE_REJECT_REPEATED = "SWAP_RESPONSE_REJECT_REPEATED";
    public static final String SWAP_RESPONSE_REJECT_OFFERD_OLD_TECHS = "SWAP_RESPONSE_REJECT_OFFERD_OLD_TECHS";
    public static final String SWAP_RESPONSE_REJECT_DISLIKE_GOOD_SWAP = "SWAP_RESPONSE_REJECT_DISLIKE_GOOD_SWAP";
    public static final String SWAP_RESPONSE_REJECT_LIKE_GOOD_SWAP = "SWAP_RESPONSE_REJECT_LIKE_GOOD_SWAP";
    public static final String SWAP_RESPONSE_REJECT_BAD_SWAP = "SWAP_RESPONSE_REJECT_BAD_SWAP";
    public static final String SWAP_RESPONSE_REJECT_WAR = "SWAP_RESPONSE_REJECT_WAR";

    public static final String REQUEST_PEACE_NOT_MOST_HATED = "REQUEST_PEACE_NOT_MOST_HATED"; 
    
    public static final String REQUEST_PEACE_REJECT_JUST_DECLARED_WAR = "REQUEST_PEACE_REJECT_JUST_DECLARED_WAR";
    public static final String REQUEST_PEACE_REJECT_REPEATED_REQUEST = "REQUEST_PEACE_REJECT_REPEATED_REQUEST";
    public static final String REQUEST_PEACE_ACCEPT_TOO_MANY_WARS = "REQUEST_PEACE_ACCEPT_TOO_MANY_WARS";
    public static final String REQUEST_PEACE_ACCEPT_LIKE_AND_TWO_WARS = "REQUEST_PEACE_ACCEPT_LIKE_AND_TWO_WARS";
    public static final String REQUEST_PEACE_REJECT_LIKE = "REQUEST_PEACE_REJECT_LIKE";
    public static final String REQUEST_PEACE_ACCEPT_NEUTRAL = "REQUEST_PEACE_ACCEPT_NEUTRAL";
    public static final String REQUEST_PEACE_REJECT_DISLIKE = "REQUEST_PEACE_REJECT_DISLIKE";
    public static final String REQUEST_PEACE_REJECT_HATE = "REQUEST_PEACE_REJECT_HATE";
    
    public static final String REQUEST_ALLIANCE = "REQUEST_ALLIANCE"; 
    
    public static final String REQUEST_ALLIANCE_REJECT_REPEATED_REQUEST = "REQUEST_ALLIANCE_REJECT_REPEATED_REQUEST";
    public static final String REQUEST_ALLIANCE_ACCEPT = "REQUEST_ALLIANCE_ACCEPT";
    public static final String REQUEST_ALLIANCE_REJECT = "REQUEST_ALLIANCE_REJECT";

    public static final String REQUEST_NONAGRESSION = "REQUEST_NONAGRESSION"; 

    public static final String REQUEST_NONAGRESSION_REJECT_REPEATED_REQUEST = "REQUEST_NONAGRESSION_REJECT_REPEATED_REQUEST";
    public static final String REQUEST_NONAGRESSION_ACCEPT = "REQUEST_NONAGRESSION_ACCEPT";
    public static final String REQUEST_NONAGRESSION_ACCEPT_TOO_MANY_WARS = "REQUEST_NONAGRESSION_ACCEPT_TOO_MANY_WARS";
    public static final String REQUEST_NONAGRESSION_REJECT_LIKE = "REQUEST_NONAGRESSION_REJECT_LIKE";
    public static final String REQUEST_NONAGRESSION_REJECT_DISLIKE = "REQUEST_NONAGRESSION_REJECT_DISLIKE";

    public static final String REQUEST_TRADE = "REQUEST_TRADE"; 

    public static final String REQUEST_TRADE_REJECT_REPEATED_REQUEST = "REQUEST_TRADE_REJECT_REPEATED_REQUEST";
    public static final String REQUEST_TRADE_ACCEPT_LIKE = "REQUEST_TRADE_ACCEPT_LIKE";
    public static final String REQUEST_TRADE_REJECT_DISLIKE = "REQUEST_TRADE_REJECT_DISLIKE";
    public static final String REQUEST_TRADE_ACCEPT = "REQUEST_TRADE_ACCEPT";
    public static final String REQUEST_TRADE_REJECT = "REQUEST_TRADE_REJECT";

    public static final String REQUEST_RESEARCH = "REQUEST_RESEARCH"; 

    public static final String REQUEST_RESEARCH_REJECT_REPEATED_REQUEST = "REQUEST_RESEARCH_REJECT_REPEATED_REQUEST";
    public static final String REQUEST_RESEARCH_ACCEPT_LIKE = "REQUEST_RESEARCH_ACCEPT_LIKE";
    public static final String REQUEST_RESEARCH_REJECT_DISLIKE = "REQUEST_RESEARCH_REJECT_DISLIKE";
    public static final String REQUEST_RESEARCH_ACCEPT = "REQUEST_RESEARCH_ACCEPT";
    public static final String REQUEST_RESEARCH_REJECT = "REQUEST_RESEARCH_REJECT";
}