/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.bean;

import java.util.ArrayList;

import mot.common.vo.ValueObject;

/**
 * Data container for information about the galaxy
 * The information in this contained DOES NOT CHANGE!
 */
public class GalaxyDetails implements ValueObject {

	private Size size;
	
	private int sectorSize;
	
	private ArrayList<Nebula> nebulae = new ArrayList();
	private transient Nebula [] nebulaeArray;

	public GalaxyDetails(Size size, int sectorSize) {
		this.size = size;
		this.sectorSize = sectorSize;
	}

	public int getSectorSize() {
		return sectorSize;
	}

	public void setSectorSize(int sectorSize) {
		this.sectorSize = sectorSize;
	}

	public Size getSize() {
		return size;
	}

	public void setSize(Size size) {
		this.size = size;
	}

	public Nebula [] getNebulaeAsArray() {
		if (nebulaeArray == null && nebulae != null && nebulae.size() > 0) {
			nebulaeArray = nebulae.toArray(new Nebula [nebulae.size()]);
		}
		return nebulaeArray;
	}

	public void setNebulae(Nebula n) {
		nebulae.add(n);
		this.nebulaeArray = null;
	}

    
	@Override
	public String toString() {
		return "GalaxyDetails";
	}

	public ArrayList<Nebula> getNebulae() {
		return nebulae;
	}

	public void setNebulae(ArrayList<Nebula> nebulae) {
		this.nebulae = nebulae;
	}
}
