/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.bean;

import mot.common.command_results.CommandResult;

/**
 * Contains galaxy summary details including summary details of each player and
 * details required to draw the galaxy may for the galaxy.
 * This is used by save and load windows to fetch summary details of a galaxy that
 * has not been loaded for previewing.
 */
public class GalaxySummary extends CommandResult {

	private PlayerSummary [] players;
	private SectorOwnerGrid sectorOwnerGrid;
	private StellarObjectSummary [] stellarObjects;
	private GalaxyDetails galaxyDetails;
	
	public GalaxySummary() {		
	}

	public GalaxySummary(PlayerSummary[] players, SectorOwnerGrid sectorOwnerGrid, StellarObjectSummary [] stellarObjects, GalaxyDetails galaxyDetails) {
		super();
		this.players = players;
		this.sectorOwnerGrid = sectorOwnerGrid;
		this.stellarObjects = stellarObjects;
		this.galaxyDetails = galaxyDetails;
	}

	public PlayerSummary[] getPlayers() {
		return players;
	}
	
	public void setPlayers(PlayerSummary[] players) {
		this.players = players;
	}

	public SectorOwnerGrid getSectorOwnerGrid() {
		return sectorOwnerGrid;
	}

	public void setSectorOwnerGrid(SectorOwnerGrid sectorOwnerGrid) {
		this.sectorOwnerGrid = sectorOwnerGrid;
	}

	public GalaxyDetails getGalaxyDetails() {
		return galaxyDetails;
	}

	public void setGalaxyDetails(GalaxyDetails galaxyDetails) {
		this.galaxyDetails = galaxyDetails;
	}

	public StellarObjectSummary [] getStellarObjects() {
		return stellarObjects;
	}

	public void setStellarObjects(StellarObjectSummary [] stellarObjects) {
		this.stellarObjects = stellarObjects;
	}
	
	
}
