/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.bean;

import mot.common.util.ApplicationError;

/**
 * This is an object that has a unique name, a location on a map and an
 * image used to display that object on the map.
 */
public abstract class ImageObject extends NamedLocatedObject {
    public ImageObject() {
    }

	public ImageObject(String name, int x, int y) {
		super(name, y, y);
	}

	public ImageObject(String name, Location l) {
		super(name, l);
	}

    /**
     * @return the width of the image to display on the screen.
     */
    public int getWidth() throws ApplicationError {
        Size size = getSize();
        return size.getX();
    }

    /**
     * @return the height of the image to display on the screen.
     */
    public int getHeight() throws ApplicationError {
        Size size = getSize();
        return size.getY();
    }

    /**
     * @return The direction this object is pointing. A value between 0 and 359.
	 * A value of zero implies the craft is pointing North, and then it is measured 
     * in positive degrees.
     */
    public abstract int getDirection();

    /**
     * @return The size this image should be drawn on the screen.
     */
    public abstract Size getSize() throws ApplicationError;
    
    /**
     * @return The name of the image that should be used to draw this image.
     */
    public abstract String getImage() throws ApplicationError;
 
}