/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.bean;
import java.io.Serializable;

import mot.common.technology.Weapon;
import mot.common.util.ApplicationError;
import mot.common.util.Comp;
import mot.common.xml.XMLBean;
import mot.common.xml.XMLWriter;

/**
 * This a class that represents a players immunity to a particular type of attack.
 * If a player is immune to a type of attack then no damage will be inflicted when
 * a weapon causing that damage is used.
 */
abstract public class Immunity extends XMLBean implements Serializable {

    public Immunity() {
    }

    protected void encode(XMLWriter writer) throws ApplicationError {
    }

    protected boolean beanHasBody() {
        return false;
    }
    
    public static Immunity getForName(String name) throws ApplicationError {
        if (name == null || name.length() == 0) {
            return null;
        } else if (Comp.same(name, ImmunityBio.NAME)) {
            return new ImmunityBio();
        } else if (Comp.same(name, ImmunityPsi.NAME)) {
            return new ImmunityPsi();
        } else if (Comp.same(name, ImmunityGravity.NAME)) {
            return new ImmunityGravity();
        } else if (Comp.same(name, ImmunityReplicaBeam.NAME)) {
            return new ImmunityReplicaBeam();
        } else if (Comp.same(name, ImmunityMindControl.NAME)) {
            return new ImmunityMindControl();
        } else if (Comp.same(name, ImmunityTroopTransport.NAME)) {
            return new ImmunityTroopTransport();
        } else {
            throw new ApplicationError("Unknown Immunity type "+name);
        }
    }
    
    public abstract String getName();
    public abstract String getDescription();
	public abstract boolean isImune(Weapon weapon);
}