/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.bean;

import mot.common.technology.Weapon;
import mot.common.util.Comp;

/**
 * Player Characteristic - This player is immune to Psi Attack (Attack from Psi Weapons).
 */
public class ImmunityPsi extends Immunity {

    public static final String NAME = "Psi";
    public static final String DESCRIPTION = "Psi Attack Immunity";

    public ImmunityPsi() {
    }

    protected String getElementName() {
        return "immunity-psi";
    }

	public String getDescription() {
		return DESCRIPTION;
	}

	public String getName() {
		return NAME;	
	}

	public boolean isImune(Weapon weapon) {
		return Comp.same(weapon.getGroup(), Weapon.GROUP_PSI);
	}
}