/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.bean;

import mot.common.util.ApplicationError;
import mot.common.xml.XMLWriter;

/**
 * Based class for all objects that have a name and a location.
 */
public class LocationAndDirection extends Location {

	/**
	 * A direction a value between 0 and 360 where a value of 0 implies north. Null implies no direction.
	 */
	private Integer direction;

	public LocationAndDirection() {
	}

	public LocationAndDirection(int x, int y) {
        super(x,y);
	}

	public LocationAndDirection(int x, int y, int direction) {
        super(x,y);
        this.direction = direction;
	}

	public LocationAndDirection(LocationAndDirection l) {
        super(l.getX(),l.getY());
        this.direction = l.getDirection();
	}

	public LocationAndDirection(Location l) {
        super(l.getX(),l.getY());
        this.direction = null;
	}

	public LocationAndDirection(Location l, int d) {
        super(l.getX(),l.getY());
        this.direction = d;
	}

	public Integer getDirection() {	return direction; }
	public void setDirection(Integer direction) { this.direction = direction;	}
    
	public boolean notEqual(LocationAndDirection o) { return o == null || !equals(o); }
	public boolean equals(LocationAndDirection o) { return o != null && equals(o.getX(), o.getY(), o.getDirection()); }
	public boolean equals(int x, int y, int direction) { return (getX() == x && getY() == y && this.direction == direction); }

	protected void encode(XMLWriter writer) throws ApplicationError {
		super.encode(writer);
		if (direction != null) writer.addElement("direction", direction);
	}

	protected String getElementName() { return "location-and-direction"; }
    
    public String toString() { return "("+getX()+","+getY()+":"+direction+")"; }

}