/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.bean;

import mot.common.util.ApplicationError;
import mot.common.util.BasicNameValueList;
import mot.common.util.NameValuePair;
import mot.common.xml.DomNode;
import mot.common.xml.XMLBean;
import mot.common.xml.XMLWriter;

public class NameIntPair extends XMLBean {
	private String name;
    private int value;

    public NameIntPair() {
    }

    public NameIntPair(String name, int value) {
        this.name = name;
        this.value = value;
    }

    public NameIntPair(DomNode n) {
        this.name = n.getNodeValueByName_String("name");
        this.value = n.getNodeValueByName_Int("value");
	}

	public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public int getValue() {
        return value;
    }

    public void setValue(int value) {
        this.value = value;
    }

    protected void encode(XMLWriter writer) throws ApplicationError {
		// does not have a bean body
	}

    protected BasicNameValueList getAttributes(boolean generateClassAttribute, boolean generateSchemaAttribute) throws ApplicationError {
    	BasicNameValueList params = getAttributesNotNull(generateClassAttribute);
		params.add( new NameValuePair("name", name) );
		params.add( new NameValuePair("value", ""+value) );
		return params;
	}

	protected String getElementName() { return "name-int-pair"; }
    protected boolean beanHasBody() { return false; }

}