/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.bean;

import mot.common.util.ApplicationError;
import mot.common.xml.XMLWriter;

/**
 * Based class for all objects that have a name and a location.
 */
public abstract class NamedLocatedObject extends NamedObject {

	/**
	 * The position on the map.
	 */
	private Location location;

	public Location getLocation() { return location; }
	public Location getLocationClone() { return (location == null) ? null : new Location(location); }
	public void setLocation(Location v) { location = v; }
	public boolean sameLocation(Location v) { return location.equals(v); }
	public int getDistanceTo(Location v) { return location.getDistanceTo(v); }
	public int getDistanceTo(NamedLocatedObject v) { if (v == null) return -1; else  return v.getLocation().getDistanceTo(location); }

	public NamedLocatedObject() {
	}

	public NamedLocatedObject(String name, int x, int y) {
		super(name);
		location = new Location(x, y);
	}

	public NamedLocatedObject(String name, Location l) {
		super(name);
		location = l;
	}
    
    public NamedLocatedObject getClosest(NamedLocatedObject [] list) {
        if (list == null || list.length == 0) return null;
        int min = Integer.MAX_VALUE;
        NamedLocatedObject best = null;
        for (int i=0; i<list.length; i++) {
            int dist = getDistanceTo(list[i].getLocation());
            if (best == null || dist < min) {
                best = list[i];
                min = dist;
            }
        }
        return best;
    }

    public int getClosestDistance(NamedLocatedObject [] list) {
        int min = Integer.MAX_VALUE;
        if (list == null || list.length == 0) return min;
        NamedLocatedObject best = null;
        for (int i=0; i<list.length; i++) {
            int dist = getDistanceTo(list[i].getLocation());
            if (best == null || dist < min) {
                best = list[i];
                min = dist;
            }
        }
        return min;
    }

	protected void encode(XMLWriter writer) throws ApplicationError {
		super.encode(writer);
		if (location != null) {
			location.toXML(writer);
		}
	}
}