/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.bean;

import mot.common.factory.GraphicsFactory;
import mot.common.util.ApplicationError;
import mot.common.xml.XMLWriter;

/**
 * This represents a Nebula on the galaxy map.
 * Shields do not operate inside a nebula so if a nebula passed by a solar system when a 
 * battle is found crafts will not contain shields!
 */
public class Nebula extends Circle {

	private String name;
	private int dateOfLastKaanRelease;

	public Nebula() {
	}

	public Nebula(String name, Location center , int diameter) {
		super(center, diameter);
		this.name = name;
	}
    
	public Nebula(String name, int centerX, int centerY , int diameter) {
		super(new Location(centerX, centerY), diameter);
		this.name = name;
	}
    
	protected String getElementName() { return "nebula"; }
	
	protected void encode(XMLWriter writer) throws ApplicationError {
		writer.addElement("name", name);
		writer.addElement("date-of-last-kaan-release", dateOfLastKaanRelease);
		super.encode(writer);
	}

    public StellarObjectGraphics getNedulaGraphics() throws ApplicationError {
    	return _getNedulaGraphics();
    }
    
    private static transient StellarObjectGraphics nebulaGraphics = null;
    
    public static StellarObjectGraphics _getNedulaGraphics() throws ApplicationError {
        if (nebulaGraphics == null) {
            nebulaGraphics = GraphicsFactory.getGalaxyGraphicsList().getNebulaGraphics();
            if (nebulaGraphics == null) {
                throw new ApplicationError("Nebula._getNebulaGraphics() No image defined for nebula");
            }
        }
        return nebulaGraphics;
    }

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public int getDateOfLastKaanRelease() {
		return dateOfLastKaanRelease;
	}

	public void setDateOfLastKaanRelease(int dateOfLastKaanRelease) {
		this.dateOfLastKaanRelease = dateOfLastKaanRelease;
	}

}