/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.bean;

import mot.common.util.Formatter;

/**
 * Represents the details of an objects turning movement from one direction to another.
 */
public class ObjectTurn implements ObjectMovement {

	/**
	 * The direction the object after the shift.
	 */
    private int to;
	
	/**
	 * The percentage (0.0 to 1.0) of the objects move taken by this shift.
	 */
	private double movePercent;
    
	/**
	 * The state of this craft at the start of this turn.
	 */
	private CraftState state;
	
	public ObjectTurn(int to, double movePercent, CraftState state) {
		this.to = to;
		this.movePercent = movePercent;
		this.state = state;
	}

	public int getTo() {
		return to;
	}

	public void setTo(int to) {
		this.to = to;
	}

	public double getMovePercent() {
		return movePercent;
	}

	public void setMovePercent(double movePercent) {
		this.movePercent = movePercent;
	}

	public CraftState getState() {
		return state;
	}

	public void setState(CraftState state) {
		this.state = state;
	}
    
	public String toString() {
		return "Turn to="+Formatter.fraction(to)+" move%="+Formatter.fraction(movePercent);
	}
}
