/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.bean;

import java.util.ArrayList;
import java.util.List;

import mot.common.xml.XMLInput;

/**
 * Contains graphical information about planets. All information used to determine the
 * size and image of a planet's image comes from this container class. The information 
 * comes from animation-config.xml - see PlanetGraphicsFactory for details!
 */
public class PlanetGraphicsConfig implements XMLInput {

	/**
	 * This is the maximum size of any planet's image.
	 * In several area of the game it is important to know the maximum size an image can 
	 * be so space is left! e.g. size of planets orbiting a sun - must leave space between 
	 * orbits!
	 */
	private int maxPlanetSize = -1;
	
	/**
	 * This is a list of scales applied to a planets image size.
	 * A planet may use image abc of size 100,100. If the planet is size 100
	 * then the image may be displayed at full size. However, if the planets 
	 * size is 40 then the planet must be drawn much smaller.
	 */
	private List planetSizeScales;
	private PlanetSizeScale [] _planetSizeScales;

	/**
	 * List of images and animation stages used to animate a planet on the battle window,
	 * galaxy map or dialog box (everywhere!).
	 */
	private List planetGraphics;
	private PlanetGraphics [] _planetGraphics;
	

	public int getMaxPlanetSize() {
		return maxPlanetSize;
	}

	public void setPlanetGraphics(PlanetGraphics v) {
		if (planetGraphics == null) planetGraphics = new ArrayList();
		planetGraphics.add(v);
		_planetGraphics = null;
	}
	
	public PlanetGraphics [] getPlanetGraphics() {
		if (_planetGraphics == null && planetGraphics != null) {
			_planetGraphics = (PlanetGraphics []) planetGraphics.toArray(new PlanetGraphics[planetGraphics.size()]);
		}
		return _planetGraphics;
	}

	public void setPlanetSizeScales(List planetSizeScales) {
		this.planetSizeScales = planetSizeScales;
	}
	
	public void setPlanetSizeScale(PlanetSizeScale v) {
		if (planetSizeScales == null) planetSizeScales = new ArrayList();
		planetSizeScales.add(v);
		_planetSizeScales = null;
	}
	
	public PlanetSizeScale [] getPlanetSizeScales() {
		if (_planetSizeScales == null && planetSizeScales != null) {
			_planetSizeScales = (PlanetSizeScale []) planetSizeScales.toArray(new PlanetSizeScale[planetSizeScales.size()]);
		}
		return _planetSizeScales;
	}

	public void setMaxPlanetSize(int maxPlanetSize) {
		this.maxPlanetSize = maxPlanetSize;
	}
	
}
