/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.bean;

import java.io.Serializable;

public class PlayerAiSettings  implements Serializable {

	/**
	 * Does this player declare war early and attack its neighbors or try to stay out of wars and build up
	 * its power undisturbed.
	 * Expansionism = 1
	 * Normal = 0;
	 * Isolationist = -1
	 */
	private int foreignPolicy;

	/**
	 * Does this player like to trade assets and technologies with other players.
	 * Eager = 1
	 * Normal = 0;
	 * Reluctant = -1
	 */
	private int diplomaticTrade;

	/**
	 * Does this player design custom craft designs to fit its abilities.
	 * On = 1
	 * Off = -1;
	 */
	private int playerPersonality;

	public PlayerAiSettings(int foreignPolicy, int diplomaticTrade, int playerPersonality) {
		super();
		this.foreignPolicy = foreignPolicy;
		this.diplomaticTrade = diplomaticTrade;
		this.playerPersonality = playerPersonality;
	}

	public PlayerAiSettings() {
	}

	public int getForeignPolicy() {
		return foreignPolicy;
	}

	public void setForeignPolicy(int foreignPolicy) {
		this.foreignPolicy = foreignPolicy;
	}

	public int getDiplomaticTrade() {
		return diplomaticTrade;
	}

	public void setDiplomaticTrade(int diplomaticTrade) {
		this.diplomaticTrade = diplomaticTrade;
	}

	public int getPlayerPersonality() {
		return playerPersonality;
	}

	public void setPlayerPersonality(int playerPersonality) {
		this.playerPersonality = playerPersonality;
	}


}
