/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.bean;

import java.io.Serializable;

/**
 * This is used to hold the current resources held by a player. It provides cached
 * value for all the bonuses that resources may offer.
 * This class should be flushed or recreated every time the owning player loses or 
 * gains a new planet.
 */
public class PlayerResources implements Serializable {

    /**
     * 10% is a value of 0.1 
     */
    protected int psiBonus;

    /**
     * Additional amount of cloak 
     */
    protected int cloakBonus;

    /**
     * 10% is a value of 0.1 
     */
    protected float speedBonus;

    /**
     * 10% is a value of 0.1 
     */
    protected float damageBonus;

    /**
     * 10% is a value of 0.1 
     */
    protected float maxDamageBonus;

    /**
     * 10% is a value of 0.1 
     */
    protected float shieldBonus;

    /**
     * 10% is a value of 0.1 
     */
    protected float researchBonus;

    /**
     * true => Player has ability to move in one turn to any other solar system from the black hole and infinite maximum travel distance (range).
     */
    private boolean infinateRangeAbility;

    public void setPsiBonus(int psiBonus) {
        this.psiBonus = psiBonus;
    }


    public int getPsiBonus() {
        return psiBonus;
    }


    public void setCloakBonus(int cloakBonus) {
        this.cloakBonus = cloakBonus;
    }


    public int getCloakBonus() {
        return cloakBonus;
    }


    public void setSpeedBonus(float speedBonus) {
        this.speedBonus = speedBonus;
    }


    public float getSpeedBonus() {
        return speedBonus;
    }


    public void setDamageBonus(float damageBonus) {
        this.damageBonus = damageBonus;
    }


    public float getDamageBonus() {
        return damageBonus;
    }


    public void setMaxDamageBonus(float maxDamageBonus) {
        this.maxDamageBonus = maxDamageBonus;
    }


    public float getMaxDamageBonus() {
        return maxDamageBonus;
    }


	public float getResearchBonus() {
		return researchBonus;
	}


	public void setResearchBonus(float researchBonus) {
		this.researchBonus = researchBonus;
	}


	public boolean isInfinateRangeAbility() {
		return infinateRangeAbility;
	}


	public void setInfinateRangeAbility(boolean infinateRangeAbility) {
		this.infinateRangeAbility = infinateRangeAbility;
	}

	public float getShieldBonus() {
		return shieldBonus;
	}

	public void setShieldBonus(float shieldBonus) {
		this.shieldBonus = shieldBonus;
	}

	
}