/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.bean;

import java.io.Serializable;

import mot.common.util.ApplicationError;
import mot.common.util.Comp;

public class PlayerSummary implements Serializable {
	
	public static final String TYPE_COMPUTER = "Computer";
	public static final String TYPE_HUMAN = "Human";

	/**
	 * The name of the player (this is actually the player's race name)
	 */
	private String name;
	
	/**
	 * This is the type of player - should be either computer or human
	 */
	private String type;
	
	/**
	 * This is the colour this player is playing as
	 */
	private String colour;


	public PlayerSummary() {
	}

	public PlayerSummary(String name, String type, PlayerColor colour) {
		super();
		this.name = name;
		this.type = type;
		this.colour = colour == null ? null : colour.getName();
	}

	public String getColour() {
		return colour;
	}

	public void setColour(String color) {
		this.colour = color;
	}

	public PlayerColor getPlayerColor() throws ApplicationError {
		return colour == null ? null : PlayerColor.getColorForName(colour);
	}


	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public String getType() {
		return type;
	}

	public void setType(String type) {
		this.type = type;
	}
	
	public boolean isTypeHuman() {
		return Comp.same(TYPE_HUMAN, type);
	}
	
}
