/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.bean;

import mot.common.xml.DomNode;

public class RaceGraphicsForColony {
	/**
	 * The name of the directory all the images are in
	 */
	private String imageName;
	
	/**
	 * The extensio of the image name for all the images are in
	 */
	private String imageType;
	
	/**
	 * Comma seperated list of images to animate an colony in the solar
	 * system window.
	 */
	private String imagesSuffixes;
	private transient String [] _imagesSuffixes;

	public RaceGraphicsForColony() {
	}

	public RaceGraphicsForColony(String imageName, String imageType, String imagesSuffixes) {
		this.imageName = imageName;
		this.imageType = imageType;
		this.imagesSuffixes = imagesSuffixes;
	}

	public RaceGraphicsForColony(DomNode cg) {
		imageName = cg.getNodeValueByName_String("image-name");
		imageType = cg.getNodeValueByName_String("image-type");
		imagesSuffixes = cg.getNodeValueByName_String("images-suffixes");
	}

	public String [] getImagesSuffixesAsArray() {
		if (_imagesSuffixes == null && imagesSuffixes != null) {
			_imagesSuffixes = imagesSuffixes.split(",");
		}
		return _imagesSuffixes;
	}

	public String getImageName() {
		return imageName;
	}

	public void setImageName(String imageName) {
		this.imageName = imageName;
	}

	public String getImagesSuffixes() {
		return imagesSuffixes;
	}

	public void setImagesSuffixes(String imagesSuffixes) {
		this.imagesSuffixes = imagesSuffixes;
	}

	public String getImageType() {
		return imageType;
	}

	public void setImageType(String imageType) {
		this.imageType = imageType;
	}

}
