/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.bean;

import mot.client.deligates.UserPlayerDelegate;
import mot.common.technology.Technology;
import mot.common.technology.TechnologyList;
import mot.common.util.ApplicationError;

public class SalvageList extends TechnologyList {
	
	public SalvageList() {
		super();
	}

	public SalvageList(String[] fullNames) throws ApplicationError {
		super(fullNames);
	}

	public SalvageList(Technology t) {
		super(t);
	}

	public SalvageList(Technology t, int qty) {
		super(t, qty);
	}

	public SalvageList(Technology[] t) throws ApplicationError {
		super(t);
	}

	public SalvageList(TechnologyList tl) {
		super(tl);
	}

    public SalvageList getSalvage(int qtyToCollect) {
		if (getQuantity() > qtyToCollect) {
			TechnologyList tl = get(0, qtyToCollect);
			return new SalvageList(tl);
		} else {
			return this;
		}
	}
    
    public int addSalvageTo(int qtyToCollect, TechnologyList destList) {
		if (getQuantity() > qtyToCollect) {
			TechnologyList tl = get(0, qtyToCollect);
			destList.add(tl);
			return qtyToCollect;
		} else {
			destList.add(this);
			return getQuantity();
		}
	}
    
    public void removeOtherContent(TechnologyList techsToRemain) {
    	if (techsToRemain == null) {
    		removeAll();
    		return;
    	}
    	Technology[] ta = getAllAsArray();
    	if (ta == null) return;
    	for (int i = 0; i < ta.length; i++) {
			if (!techsToRemain.contains(ta[i])) {
				remove(ta[i]);
			}
		}
    }    

	public void removeAllTechsDiscoveredBy(UserPlayerDelegate player) throws ApplicationError {
    	Technology[] ta = getAllAsArray();
    	if (ta == null) return;
    	removeAll();
    	for (int i = 0; i < ta.length; i++) {
			if (!player.hasDiscovered((ta[i]))) {
				add(ta[i]);
			}
		}
	}

	@Override
	protected void changed() {
	}

	@Override
	protected String getElementName() {
		return "salvage-list";
	}

}
