/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.bean;

import java.io.Serializable;
import java.util.ArrayList;

import mot.common.util.Comp;


public class SectorInfluenceList implements Serializable {
	
	private ArrayList<SectorInfluenceItem> items = new ArrayList<SectorInfluenceItem>();

	public SectorInfluenceList() {
	}

	public ArrayList<SectorInfluenceItem> getItems() {
		return items;
	}

	public SectorInfluenceItem [] getItemsArray() {
		if (items.size() > 0) {
			return items.toArray(new SectorInfluenceItem[items.size()]);
		} else {
			return null;
		}
	}

	public void setItems(ArrayList<SectorInfluenceItem> items) {
		this.items = items;
	}

	public void clear() {
		if (items == null) return;
		for (SectorInfluenceItem i : items) {
			i.setInfluence(0);
		}
	}

	public void add(String player, int influence) {
		SectorInfluenceItem i = getInfluenceItem(player);
		if (i != null) {
			i.addInfluence(influence);			
		} else {
			items.add(new SectorInfluenceItem(player, influence));
		}
	}

	public SectorInfluenceItem getInfluenceItem(String player) {
		if (items == null) return null;
		for (SectorInfluenceItem i : items) {
			if (Comp.same(player, i.getPlayer())) {
				return i;
			}
		}
		return null;
	}	

	public int getInfluence(String player) {
		if (items == null) return 0;
		for (SectorInfluenceItem i : items) {
			if (Comp.same(player, i.getPlayer())) {
				return i.getInfluence();
			}
		}
		return 0;
	}

	public SectorInfluenceItem getOwner() {
		if (items == null) return null;
		SectorInfluenceItem best = null;
		for (SectorInfluenceItem i : items) {
			if (best == null || best.getInfluence() < i.getInfluence()) {
				best = i;
			}
		}
		return best;
	}

	public boolean isOwnedBy(String player) {
		SectorInfluenceItem owner = getOwner();
		if (owner == null) return false;
		return Comp.same(owner.getPlayer(), player);
	}
	
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("[");
		for (SectorInfluenceItem i : items) {
			sb.append(i.getPlayer()+" "+i.getInfluence()+",");
		}
		sb.append("]");
		return sb.toString();
	}
	
}
