/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.bean;

public class SimpleLocatedArea implements LocatedArea {

	private Location loc;
	private Size size;
	
	public SimpleLocatedArea(Location loc, Size size) {
		this.loc = loc;
		this.size = size;
	}

	public int getHeight() {
		return size.getX();
	}

	public Location getLocation() {
		return loc;
	}

	public int getWidth(){
		return size.getX();
	}

	public boolean isInside(Location l) {
		return isInside(l.getX(), l.getY());
	}

	public boolean isInside(int x, int y) {
		int width = size.getX();
		int height = size.getY();
		int left = getLocation().getX() - width/2;
		int top = getLocation().getY() - height/2;
		int right = left + width;
		int bottom = top + height;
		return (x >= left && x <= right && y >= top && y <= bottom);
	}

}
