/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.bean;

import java.io.Serializable;

import mot.common.util.ApplicationError;
import mot.common.xml.DomNode;
import mot.common.xml.XMLBean;
import mot.common.xml.XMLWriter;

/**
 * @author Paul Davis
 * 
 * Represents the size of an object on the map.
 */
public class Size extends XMLBean implements Serializable {

	private int x;
	private int y;

	public Size() {
	}

	public Size(int x, int y) {
		this.x = x;
		this.y = y;
	}

	public Size(Size size) {
		if (size != null) {			
			x = size.getX();
			y = size.getY();
		}
	}

	public Size(DomNode n) {
		x = n.getNodeValueByName_Int("x");
		y = n.getNodeValueByName_Int("y");
	}

	public int getX() { return x; }
	public int getY() { return y; }

	public void setX(int v) { x = v; }
	public void setY(int v) { y = v; }
    
    public boolean isLarger(Size other) {
        int totalThis = x + y;
        int totalOther = other.getX() + other.getY();
        return (totalThis > totalOther);
    }
    
	public boolean equals(Size o) { return o != null && o.getX() == x && o.getY() == y; }

	protected void encode(XMLWriter writer) throws ApplicationError {
		writer.addElement("x", x);
		writer.addElement("y", y);
	}
	protected String getElementName() { return "size"; }
	
	public String toString() {
		return "w="+x+" h="+y;
	}
}