/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.bean;

import java.awt.Color;
import java.io.Serializable;

import mot.common.vo.StellarObjectVO;

/**
 * Contains summary information about a stellar object.
 * DO NTO CONFUSE THIS OBJECT WITH StellarObjectVO - This is not a value object.
 * It is not used to hold / transfer information for a RemoteStellarObjectDeligate.
 */
public class StellarObjectSummary implements Serializable {

    /**
     * The name of this stellar object.
     */
    private String name;
    
    /**
     * The location on the galaxy map.
     */
    private Location location;
    
    /**
     * The graphical information to use to display this stellar object.
     */
    private String starType;
    
    /**
     * The color to display this stellar object as.
     */
    private Color textColor;

	private boolean isVisible;
    
    public StellarObjectSummary() {
    }

    public StellarObjectSummary(String name, Location location, String starType, Color textColor, boolean isVisible) {
        this.name = name;
        this.location = location;
        this.starType = starType;
        this.textColor= textColor;
		this.isVisible = isVisible;
    }
    
    public StellarObjectVO getStellarObjectVO() {
    	return new StellarObjectVO(name, location, null, textColor, isVisible, -1, null);
    }


    public void setName(String name) {
        this.name = name;
    }


    public String getName() {
        return name;
    }


    public void setLocation(Location location) {
        this.location = location;
    }


    public Location getLocation() {
        return location;
    }

    public void setTextColor(Color textColor) {
        this.textColor = textColor;
    }


    public Color getTextColor() {
        return textColor;
    }


	public String getStarType() {
		return starType;
	}

	public void setStarType(String starType) {
		this.starType = starType;
	}

	public boolean isVisible() {
		return isVisible;
	}

	public void setVisible(boolean isVisible) {
		this.isVisible = isVisible;
	}
}