/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.bean;

import mot.client.swing.config.AnimationConfigFactory;
import mot.client.swing.config.ImageAnimationConfig;
import mot.common.util.ApplicationError;

/**
 * Defines the area on the battle field that contains the wreckage of a craft.
 */
public class WreckageDetails extends AnimatedBattleAreaDetails {
	
	private String craftName;

	public WreckageDetails() { 
	}
	
	public WreckageDetails(Rectangle loc, String craftName) throws ApplicationError {
		super(loc.getLeft(), loc.getTop(), getSize(), getSize());
		this.craftName = craftName;
	}
	
	public void setCraftName(String craftName) {
		this.craftName = craftName;
	}

	public String getCraftName() {
		return craftName;
	}

	public boolean tileArea() {
		return false;
	}

	public ImageAnimationConfig getAnimationConfig() throws ApplicationError {
		return AnimationConfigFactory.getInstance().getCraftWreckageAnimationConfig();
	}
	
	public static ImageAnimationConfig _getAnimationConfig() throws ApplicationError {
		return AnimationConfigFactory.getInstance().getCraftWreckageAnimationConfig();
	}
	
	private static int SIZE = -1;
	private static int getSize() throws ApplicationError {
		if (SIZE < 0) {
			SIZE = _getAnimationConfig().getImageSize().getX();
		}
		return SIZE;
	}
}
