/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.bean.stats;

import java.io.Serializable;

import mot.common.technology.Hull;
import mot.common.technology.Technologies;
import mot.common.technology.TechnologyReference;
import mot.common.util.ApplicationError;
import mot.common.xml.XMLBean;
import mot.common.xml.XMLWriter;

/**
 * A record of how many craft was built during this game by a 
 * user player using this hull. This information is used to 
 * score a game.
 */
public class CraftQuantityData extends XMLBean implements Serializable {
	
	private String hull;
	private int qty;

	public CraftQuantityData() {
	}
	
	public CraftQuantityData(Hull hull, int qty) {
		this.hull = hull.getName();
		this.qty = qty;		
	}

	public String getHull() {
		return hull;
	}

	public void setHull(String hull) {
		this.hull = hull;
	}

	public Hull getHullTech() throws ApplicationError {
		return Technologies.getHull(hull);
	}
	
	public void setTechnologyReference(TechnologyReference hull) {
		this.hull = hull.getName(); 
	}

	public int getQty() {
		return qty;
	}

	public void setQty(int qty) {
		this.qty = qty;
	}

	public void increaseQty(int v) {
		qty += v;
	}

	protected void encode(XMLWriter writer) throws ApplicationError {
		writer.addElement("hull", hull);
		writer.addElement("qty", qty);
	}

	protected String getElementName() {
		return "craft-quantity-data";
	}

}
