/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.bean.stats;

import java.io.Serializable;

import mot.common.util.ApplicationError;
import mot.common.util.BasicNameValueList;
import mot.common.util.NameValuePair;
import mot.common.xml.XMLBean;
import mot.common.xml.XMLWriter;

/**
 * This is a value date pair used to hold a statistic about an empire at a point 
 * in time. For example, at Year 350, the empire had a population of 300.
 */
public class Statistic extends XMLBean implements Serializable {

    /**
     * This is the date at which the statistic had the value.
     */
    private int date;

    /**
     * This is the value of the statistic.
     */
    private long value;

    public Statistic() {
    }
    
    public Statistic(int date, long value) {
        this.date = date;
        this.value = value;
    }


    public void setDate(int date) {
        this.date = date;
    }


    public int getDate() {
        return date;
    }


    public void setValue(long value) {
        this.value = value;
    }


    public long getValue() {
        return value;
    }

    protected boolean beanHasBody() { return false; }

	protected void encode(XMLWriter writer) {
		// does not have a bean body
	}

    protected BasicNameValueList getAttributes(boolean generateClassAttribute, boolean generateSchemaAttribute) throws ApplicationError {
    	BasicNameValueList params = getAttributesNotNull(generateClassAttribute);
		params.add( new NameValuePair("date", ""+date) );
		params.add( new NameValuePair("value", ""+value) );

		return params;
	}

	protected String getElementName() { return "statistic"; }
}