/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.command_delegates;

import mot.common.bean.LocationAndDirection;


/**
 * This command causes the source craft to attack the enemy craft in a battle.
 * All weapons in the source are fired at the target providing they are in range.
 **/
public class BattleAttackCmdDeligate extends BattleCommandDeligate {

    /**
     * The source of this command.
     */
    protected String source;

    /**
     * The target of this command.
     */
    protected String target;

    private LocationAndDirection attackFrom;


	/**
     * The weapon the source craft is to fire at the target.
     * If this is null all weapons are fired.
     */
    protected String weapon;

    /**
     * The The quantity of weapon the source craft is to fire at the target.
     * If weapon is not null this is the quantity of this weapon to fire. If weapon is null
     * this is ignored
     */
    protected int qtyToFire;

    /**
     * If this command is permitted to move the source craft towards the 
     * destination.
     */
	private boolean move;
    
    /**
     * If this command will discharge all weapons (providing time warp has not fired to restart the turn again)
     * and set move remaining to 0.
     */
	private boolean discharge;
    
    /**
     * If this command will automatically fire missile defence weapons at incoming automatons.
     */
	private boolean missileDefence;

    public BattleAttackCmdDeligate() {
    }

    /**
     * @param owner The player who has submitted this command.
     * @param battle The battle this attack is taking place in.
     * @param source The object to attack.
     * @param target The object to be attacked.
     * @param canMove If this command is permitted to move the source craft towards the
     * destination. This command will only move the craft when there are some weapons out
     * of range and this is true.
     * @param weapon The weapon the source craft is to fire at the target. If this is null
     * all weapons are fired.
     * @param qtyToFire The The quantity of weapon the source craft is to fire at the target.
     * If weapon is not null this is the quantity of this weapon to fire. If weapon is null
     * this is ignored
     */
    public BattleAttackCmdDeligate(String battle, String source, String target, boolean move, boolean discharge, boolean missileDefence, LocationAndDirection attackFrom, String weapon, int qtyToFire) {
        super(battle);
        this.source = source;
        this.target = target;
		this.move = move;
		this.discharge = discharge;
		this.missileDefence = missileDefence;
        this.attackFrom = attackFrom;
        this.weapon = weapon;
        this.qtyToFire = qtyToFire;
	}


    public void setSource(String source) {
        this.source = source;
    }


    public String getSource() {
        return source;
    }


    public void setTarget(String target) {
        this.target = target;
    }


    public String getTarget() {
        return target;
    }

    public void setWeapon(String weapon) {
        this.weapon = weapon;
    }

    public LocationAndDirection getAttackFrom() {
		return attackFrom;
	}

	public void setAttackFrom(LocationAndDirection attackFrom) {
		this.attackFrom = attackFrom;
	}


    public String getWeapon() {
        return weapon;
    }


    public void setQtyToFire(int qtyToFire) {
        this.qtyToFire = qtyToFire;
    }


    public int getQtyToFire() {
        return qtyToFire;
    }

	public boolean isMove() {
		return move;
	}

	public void setMove(boolean move) {
		this.move = move;
	}

	public boolean isDischarge() {
		return discharge;
	}

	public void setDischarge(boolean discharge) {
		this.discharge = discharge;
	}

	public boolean isMissileDefence() {
		return missileDefence;
	}

	public void setMissileDefence(boolean missileDefence) {
		this.missileDefence = missileDefence;
	}

    public String toString() {
    	return "BattleAttackCmdDeligate "+getSequence()+" "+source;
    }


}