/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.command_delegates;

import mot.common.bean.Location;


/**
 * This command causes the source planet to attack the enemy object in a battle.
 * All weapons in the source are fired at the target providing they are in range.
 **/
public class BattleAttackLocationCmdDeligate extends BattleCommandDeligate {

    /**
     * The source of this command.
     */
    protected String source;

    /**
     * The target of this command.
     */
    protected Location target;

    /**
     * The weapon the source craft is to fire at the target.
     * If this is null all weapons are fired.
     */
    protected String weapon;

    /**
     * The The quantity of weapon the source craft is to fire at the target.
     * If weapon is not null this is the quantity of this weapon to fire. If weapon is null
     * this is ignored
     */
    protected int qtyToFire;

    public BattleAttackLocationCmdDeligate() {
    }

    /**
     * @param owner The player who has submitted this command.
     * @param battle The battle this attack is taking place in.
     * @param source The object to attack.
     * @param target The object to be attacked.
     * @param weapon The weapon the source craft is to fire at the target. If this is null
     * all weapons are fired.
     * @param qtyToFire The The quantity of weapon the source craft is to fire at the target.
     * If weapon is not null this is the quantity of this weapon to fire. If weapon is null
     * this is ignored
     */
    public BattleAttackLocationCmdDeligate(String battle, String source, Location target, String weapon, int qtyToFire) {
        super(battle);
        this.source = source;
        this.target = target;
        this.weapon = weapon;
        this.qtyToFire = qtyToFire;
	}


    public void setSource(String source) {
        this.source = source;
    }


    public String getSource() {
        return source;
    }


    public void setTarget(Location target) {
        this.target = target;
    }


    public Location getTarget() {
        return target;
    }


    public void setWeapon(String weapon) {
        this.weapon = weapon;
    }


    public String getWeapon() {
        return weapon;
    }


    public void setQtyToFire(int qtyToFire) {
        this.qtyToFire = qtyToFire;
    }


    public int getQtyToFire() {
        return qtyToFire;
    }

    public String toString() {
    	return "BattleAttackLocationCmdDeligate "+getSequence()+" "+source;
    }
}