/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.command_delegates;

import mot.common.bean.LocationAndDirection;

/**
 * This command causes the source craft to attack the enemy craft in a battle.
 * All weapons in the source are fired at the target providing they are in range.
 **/
public class BattleCraftMoveToCmdDeligate extends BattleCommandDeligate {

    /**
     * The source of this command.
     */
    protected String source;

    /**
     * The target of this command.
     */
    protected LocationAndDirection moveToDest;

    /**
     * If this is true the move will stop at STOP_ON_ATTACK% of the move before a missile strikes
     * if the craft has weapons that can destroy missiles that have not been fored this turn.
     * This gives the owner an opportunity to destroy the missiles before they damage the craft.
     */
    private boolean stopOnMissileAttack;

	private String target;

	private boolean missileDefence;

    public BattleCraftMoveToCmdDeligate() {
    }

    public BattleCraftMoveToCmdDeligate(String battle, String source, LocationAndDirection moveToDest, String target, boolean stopOnMissileAttack, boolean missileDefence) {
        super(battle);
        this.source = source;
        this.moveToDest = moveToDest;
		this.target = target;
        this.stopOnMissileAttack = stopOnMissileAttack;
		this.missileDefence = missileDefence;
	}


    public void setSource(String source) {
        this.source = source;
    }


    public String getSource() {
        return source;
    }


    public void setMoveToDest(LocationAndDirection target) {
        this.moveToDest = target;
    }


    public LocationAndDirection getMoveToDest() {
        return moveToDest;
    }


    public void setStopOnMissileAttack(boolean stopOnMissileAttack) {
        this.stopOnMissileAttack = stopOnMissileAttack;
    }


    public boolean isStopOnMissileAttack() {
        return stopOnMissileAttack;
    }

	public String getTarget() {
		return target;
	}

	public void setTarget(String target) {
		this.target = target;
	}

	public boolean isMissileDefence() {
		return missileDefence;
	}

	public void setMissileDefence(boolean missileDefence) {
		this.missileDefence = missileDefence;
	}

    public String toString() {
    	return "BattleCraftMoveToCmdDeligate "+getSequence()+" "+source;
    }
}