/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.command_delegates;

import mot.common.technology.Technologies;
import mot.common.technology.Weapon;
import mot.common.util.ApplicationError;

/**
 * This command causes the source craft end its turn in this battle.
 **/
public class BattleEndTurnCmdDeligate extends BattleCommandDeligate {

    /**
     * The source of this command.
     */
    protected String source;
	private boolean endMove;
	private boolean dischargeWeapons;
	private String weapon;
	private int qtyWeapons;

    public BattleEndTurnCmdDeligate() {
    }

    public BattleEndTurnCmdDeligate(String battle, String source, boolean endMove, boolean dischargeWeapons, String weapon, int qtyWeapons)  throws ApplicationError {
        super(battle);
        this.source = source;
		this.endMove = endMove;
		this.dischargeWeapons = dischargeWeapons;
		this.weapon = weapon;
		this.qtyWeapons = qtyWeapons;
	}


    public void setSource(String source) {
        this.source = source;
    }


    public String getSource() {
        return source;
    }

	public boolean isEndMove() {
		return endMove;
	}

	public void setEndMove(boolean endMove) {
		this.endMove = endMove;
	}

	public boolean isDischargeWeapons() {
		return dischargeWeapons;
	}

	public void setDischargeWeapons(boolean dischargeWeapons) {
		this.dischargeWeapons = dischargeWeapons;
	}

	public String getWeapon() {
		return weapon;
	}

	public Weapon getWeaponTechnology() throws ApplicationError {
		if (weapon == null) {
			return null;
		} else {
			return Technologies.getWeapon(weapon);
		}
	}


	public void setWeapon(String weapon) {
		this.weapon = weapon;
	}

	public int getQtyWeapons() {
		return qtyWeapons;
	}

	public void setQtyWeapons(int qtyWeapons) {
		this.qtyWeapons = qtyWeapons;
	}

    public String toString() {
    	return "BattleEndTurnCmdDeligate "+getSequence()+" "+source;
    }
}