/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.command_delegates;



/**
 * This is a command issued by a user to the engine.
 * A command is independent of the type of UI that asked for the command to be
 * performed. A command must be an Java Bean so that all commands issued to the
 * system can be saved in a Trace and we can re-run a game play.
 **/
public abstract class CommandDeligate implements Request {

	/**
	 * Each command has a unique identifier - this is the identifier of this command.
	 * This identifier is used to match command result with submitted command - should one command
	 * time out, how would we know which command the next response is intended for?
	 */
    private int sequence;

    protected CommandDeligate() {
    }

	public int getSequence() {
		return sequence;
	}

	public void setSequence(int sequence) {
		this.sequence = sequence;
	}

}