/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.command_delegates;
import mot.common.bean.DiplomaticProposal;


/**
 * This command causes the owning player to send a request to the receiving
 * player asking asking to swap assets. Note a response does not come back
 * Immediately - An event will be sent some time soon containing the response.
 */
public class DiplomaticRequestCmdDeligate extends CommandDeligate {

    /**
     * This is the player receiving the offer to swap assets
     */
    private String receiver;

    private DiplomaticProposal proposal;

	private String message; 

    public DiplomaticRequestCmdDeligate() {
    }

    public DiplomaticRequestCmdDeligate(String receiver, DiplomaticProposal message) {
        this.receiver = receiver;
        this.proposal = message;
	}

    public DiplomaticRequestCmdDeligate(String receiver, DiplomaticProposal proposal, String message) {
        this.receiver = receiver;
        this.proposal = proposal;
		this.message = message;
	}

	public DiplomaticProposal getProposal() {
		return proposal;
	}

	public void setProposal(DiplomaticProposal proposal) {
		this.proposal = proposal;
	}
	
    public void setReceiver(String receiver) {
        this.receiver = receiver;
    }

    public String getReceiver() {
        return receiver;
    }

	public String getMessage() {
		return message;
	}

	public void setMessage(String reason) {
		this.message = reason;
	}
	
    public String toString() {
    	return "DiplomaticProposalRequestCmdDeligate "+getSequence()+" ["+receiver+"]";
    }



}