/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.command_delegates;
import mot.common.bean.DiplomaticProposal;


/**
 * This is a command issued by a user to accept an offer to swap assets.
 * The player must have already requested the treaty and this command
 * is issued by the receiver of the offer to accept it.
 **/
public class DiplomaticResponseCmdDeligate extends CommandDeligate {

    /**
     * The player receiving the accept swap response.
     * This should be the player that asked for the swap!
     */
    private String receiver;

    private DiplomaticProposal proposal; 
    
    private String message;

	private boolean accept;

    public DiplomaticResponseCmdDeligate() {
    }

    public DiplomaticResponseCmdDeligate(String receiver, DiplomaticProposal proposal, boolean accept, String message) {
        this.receiver = receiver;
        this.proposal = proposal;
		this.accept = accept;
        this.message = message;
        this.proposal = proposal;
	}

	public DiplomaticProposal getProposal() {
		return proposal;
	}

	public void setProposal(DiplomaticProposal proposal) {
		this.proposal = proposal;
	}

    public void setMessage(String message) {
        this.message = message;
    }

    public String getMessage() {
        return message;
    }

    public void setReceiver(String receiver) {
        this.receiver = receiver;
    }

    public String getReceiver() {
        return receiver;
    }
    
	public boolean isAccept() {
		return accept;
	}

	public void setAccept(boolean accept) {
		this.accept = accept;
	}

    public String toString() {
    	return "DiplomaticProposalResponseCmdDeligate "+getSequence()+" ["+accept+"]";
    }

}