/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.command_delegates;

import mot.common.designs.CraftDesign;
import mot.common.util.ApplicationError;
import mot.common.vo.CraftDesignVO;

/**
 * Task : Statistics about the performance of this craft design if it was built by player owner
 * Return : CraftDesignStatistics  
 */
public class GetCraftDesignStatistics extends CommandDeligate {

    private CraftDesignVO design;
    
    /**
     * This the name of the race to crew the craft.
     */
    private String origin;

    /**
     * The owner of this design
     */
	private String owner;

    public GetCraftDesignStatistics(CraftDesign design, String owner, String origin) {
    	this(new CraftDesignVO(design, 0), owner, origin);
    }
    
    public GetCraftDesignStatistics(CraftDesignVO design, String owner, String origin) {
        this.design = design;
		this.owner = owner;
		this.origin = origin;
    }


    public void setDesign(CraftDesignVO design) {
        this.design = design;
    }


    public CraftDesignVO getDesign() {
        return design;
    }

    public CraftDesign getCraftDesign() throws ApplicationError {
    	if (design == null) {
    		return null;
    	} else {
    		return new CraftDesign(design);
    	}
    }
    

    public void setOrigin(String origin) {
        this.origin = origin;
    }


    public String getOrigin() {
        return origin;
    }


	public String getOwner() {
		return owner;
	}


	public void setOwner(String owner) {
		this.owner = owner;
	}
	
    public String toString() {
    	return "GetCraftDesignStatistics "+getSequence()+" ["+owner+"]";
    }
}