/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.command_delegates;

import mot.common.bean.NewGameUserPlayerData;


/**
 * This is a command issued by a user to the engine.
 * It stores up the options selected by a user players as they register for a new game, then
 * when a NewGameCmd is fired, the accumulated options for all the users are consumed to create
 * a game.
 **/
public class NewGameUserPlayerCmdDeligate extends CommandDeligate {

	private String clientId;
    private NewGameUserPlayerData userData;

    public NewGameUserPlayerCmdDeligate(String clientId, NewGameUserPlayerData userData) {
		this.clientId = clientId;
		this.userData = userData;
	}

	public String getClientId() {
		return clientId;
	}

	public void setClientId(String clientId) {
		this.clientId = clientId;
	}

	public NewGameUserPlayerData getUserData() {
		return userData;
	}

	public void setUserData(NewGameUserPlayerData userData) {
		this.userData = userData;
	}

	public String getRaceName() {
		return userData == null ? null : userData.getRaceName();
	}

    public String toString() {
    	return "NewGameUserPlayerCmdDeligate "+getSequence()+" ["+clientId+"]";
    }

}