/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.command_delegates;

import java.io.Serializable;

/**
 * This is the interface that all request must implement.
 * A request is a object sent from a remote client to the server to make a request.
 * A Request may be any of the following;
 *  - Send me the Player details for the player named XXX
 *  - Send me an array of CraftVO objects, one object for each craft in the game.
 *  - Execute this command for me.
 *  
 *  All requests involve sending an object to the server. This constitutes the request. The server
 *  will then process the request and send back a response which will also be an object. The type
 *  of object sent back will depend on the request sent. See the doco on the request to see what type 
 *  of response object is expected.
 */
public interface Request extends Serializable {
	
	public int getSequence();
	
}