/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.command_delegates;

import mot.common.util.ApplicationError;

/**
 * If development is not null, then planet auto development percent is set to development.
 * If ecology is not null, then planet auto ecology percent is set to ecology.
 * If planet auto development percent is set to automatic, this command causes development
 * on a planet allocated to be calculated automatically.
 * If planet auto ecology percent percent is set to automatic, this command causes ecology
 * on a planet allocated to be calculated automatically.
 **/
public class SetPlanetAutoPercentsCmdDeligate extends PlanetCmdDeligate {

    private Boolean development;
    private Boolean ecology;
	private Boolean production;
	private Boolean research;

    public SetPlanetAutoPercentsCmdDeligate() {
	}

    public SetPlanetAutoPercentsCmdDeligate(String planet) throws ApplicationError {
        super(planet);
	}

    public SetPlanetAutoPercentsCmdDeligate(String planet, Boolean production, Boolean research, Boolean development, Boolean ecology) throws ApplicationError {
        super(planet);
		this.production = production;
		this.research = research;
        this.development = development;
        this.ecology = ecology;
	}


    public void setDevelopment(Boolean development) {
        this.development = development;
    }


    public Boolean getDevelopment() {
        return development;
    }


    public void setEcology(Boolean ecology) {
        this.ecology = ecology;
    }


    public Boolean getEcology() {
        return ecology;
    }

    public String toString() {
    	return "SetPlanetAutoPercentsCmdDeligate "+getSequence()+" "+getPlanet();
    }

	public Boolean getProduction() {
		return production;
	}

	public void setProduction(Boolean production) {
		this.production = production;
	}

	public Boolean getResearch() {
		return research;
	}

	public void setResearch(Boolean research) {
		this.research = research;
	}

}