/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.command_delegates;

import mot.common.util.ApplicationError;

/**
 * If development is not null, then planet auto development percent is set to development.
 * If ecology is not null, then planet auto ecology percent is set to ecology.
 * If planet auto development percent is set to automatic, this command causes development
 * on a planet allocated to be calculated automatically.
 * If planet auto ecology percent percent is set to automatic, this command causes ecology
 * on a planet allocated to be calculated automatically.
 **/
public class SetPlanetPercentsCmdDeligate extends PlanetCmdDeligate {

    private double developmentPercent;
    private double ecologyPercent;
    private double productionPercent;
    private double researchPercent;

    public SetPlanetPercentsCmdDeligate() {
	}

    public SetPlanetPercentsCmdDeligate(String planet, double developmentPercent, double ecologyPercent, double productionPercent, double researchPercent) throws ApplicationError {
        super(planet);
        this.developmentPercent = developmentPercent;
        this.ecologyPercent = ecologyPercent;
        this.productionPercent = productionPercent;
        this.researchPercent = researchPercent;
	}


    public void setDevelopmentPercent(double developmentPercent) {
        this.developmentPercent = developmentPercent;
    }


    public double getDevelopmentPercent() {
        return developmentPercent;
    }


    public void setEcologyPercent(double ecologyPercent) {
        this.ecologyPercent = ecologyPercent;
    }


    public double getEcologyPercent() {
        return ecologyPercent;
    }


    public void setProductionPercent(double productionPercent) {
        this.productionPercent = productionPercent;
    }


    public double getProductionPercent() {
        return productionPercent;
    }


    public void setResearchPercent(double researchPercent) {
        this.researchPercent = researchPercent;
    }


    public double getResearchPercent() {
        return researchPercent;
    }
    
    public String toString() {
    	return "SetPlanetPercentsCmdDeligate "+getSequence()+" "+getPlanet();
    }

}