/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.command_delegates;

import mot.common.designs.ProjectDesign;
import mot.common.util.ApplicationError;
import mot.common.util.Comp;

/**
 * This is used for a user's planets and what its next project should be.
 **/
public class SetProjectCmdDeligate extends CommandDeligate  {

    /**
     * This is the craft/fleet to which this command is being issued.
     */
    private String [] planets;

    /**
     * The project this planet should build. The planet project should be serialized 
     * to a string and passed to this proxy.
     */
    private ProjectDesign project;

    /**
     * The quantity of times this planet should repeat this project.
     */
    private int repeat;

	private boolean allIdle;

	private boolean useSalvage;

    public SetProjectCmdDeligate() {
	}

    public SetProjectCmdDeligate(String planet, ProjectDesign project, int repeat, boolean allIdle, boolean useSalvage) throws ApplicationError {
		this.planets = new String[1];
        this.planets[0] = planet;
        this.project = project;
        this.repeat = repeat;
		this.allIdle = allIdle;
		this.useSalvage = useSalvage;
	}

    public SetProjectCmdDeligate(String [] planets, ProjectDesign project, int repeat, boolean allIdle) throws ApplicationError {
        this.planets = planets;
        this.project = project;
        this.repeat = repeat;
		this.allIdle = allIdle;
	}
    
    public void setPlanet(String planet) {
        this.planets = new String[1];
        this.planets[0] = planet;
    }

    public void setPlanets(String [] planet) {
        this.planets = planet;
    }

    public String [] getPlanets() {
        return planets;
    }

    public void setProject(ProjectDesign project) {
        this.project = project;
    }


    public ProjectDesign getProject() {
        return project;
    }

    public void setRepeat(int repeat) {
        this.repeat = repeat;
    }

    public int getRepeat() {
        return repeat;
    }

	public boolean isAllIdle() {
		return allIdle;
	}

	public void setAllIdle(boolean allIdle) {
		this.allIdle = allIdle;
	}

    public String toString() {
    	return "SetProjectCmdDeligate "+getSequence()+" "+Comp.toString(planets) + " to " + project;
    }

	public boolean isUseSalvage() {
		return useSalvage;
	}

	public void setUseSalvage(boolean useSalvage) {
		this.useSalvage = useSalvage;
	}

}