/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.command_results;

import java.util.ArrayList;

import mot.common.util.ApplicationError;
import mot.common.util.Comp;
import mot.common.xml.XMLWriter;

public class NameListCR extends StateUpdateCommandResult {

	   private ArrayList<String> names = new ArrayList();

	    public NameListCR() {
	    }

	    public NameListCR(String name) {
	        this.names.add(name);
	    }

	    public NameListCR(String [] names) {
	    	for (int i = 0; i < names.length; i++) {
				this.names.add(names[i]);
			}
	    }

	    protected String getElementName() {
	        return "name-list-cr";
	    }

	    protected void encode(XMLWriter writer) throws ApplicationError {
	    	for (String name : names) {
				writer.addElement("names", name);
			}
	    }


	    public void setName(String name) {
	    	names.add(name);
	    }

	    public void setName(String [] names) {
	    	for (int i = 0; i < names.length; i++) {
				this.names.add(names[i]);
			}
	    }

	    public String [] getNames() {
	    	if (names.size() == 0) {
	    		return null;
	    	} else {
	    		return names.toArray(new String[names.size()]);
	    	}
	    }

	    public int getQuantity() {
	    	return names.size();
	    }

		public String toString() {
			return "NamesListCR "+getSequence()+" [" + Comp.toString(getNames()) + "]";
		}

		public int findIndexOf(String name) {
			if (names.size() == 0) return -1;
			String[] na = getNames();
	    	for (int i = 0; i < na.length; i++) {
	    		if (na[i].equals(name)) return i;
			}
	    	return -1;
		}

		public String getNameAtIndex(int i) {
			return names.get(i);
		}

		public void swap(int index1, int index2) {
			String t = names.get(index1);
			names.set(index1, names.get(index2));
			names.set(index2, t);
		}

}