/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.command_results;

import java.util.ArrayList;

import mot.common.bean.SectorOwnerGrid;
import mot.common.event.StateContainer;
import mot.common.util.ApplicationError;
import mot.common.util.Comp;
import mot.common.vo.NamedValueObject;
import mot.common.vo.ValueObject;
import mot.common.vo.ValueObjectList;
import mot.common.xml.XMLWriter;

public class StateUpdateCommandResult extends CommandResult implements StateContainer {

	private ArrayList<ValueObject> state;
	
    public StateUpdateCommandResult() {
    }

    public StateUpdateCommandResult(ValueObject v) {
    	addStateUpdate(v);
    }

	public StateUpdateCommandResult(ValueObject v1, ValueObject v2) {
    	addStateUpdate(v1);
    	addStateUpdate(v2);
	}

	public StateUpdateCommandResult(ValueObject v1, ValueObject v2, ValueObject v3) {
    	addStateUpdate(v1);
    	addStateUpdate(v2);
    	addStateUpdate(v3);
	}

	public StateUpdateCommandResult(ValueObject[] voa) {
		if (voa != null) {
			for (int i = 0; i < voa.length; i++) {
				addStateUpdate(voa[i]);
			}
		}
	}

	public StateUpdateCommandResult(ValueObjectList vol) {
		if (vol != null) {
			ValueObject[] l = vol.getStateUpdates();
			for (int i = 0; i < l.length; i++) {
				addStateUpdate(l[i]);
			}
		}
	}

	public void addStateUpdate(ValueObjectList vol) {
		if (vol != null) {
			ValueObject[] l = vol.getStateUpdates();
			for (int i = 0; i < l.length; i++) {
				addStateUpdate(l[i]);
			}
		}
	}

	public void addStateUpdate(ValueObject v) {
		if (state == null) state = new ArrayList<ValueObject>();
		state.add(v);
	}
	
	public void addStateUpdate(ValueObject [] vol) throws ApplicationError {
		if (vol == null) return;
		for (int i = 0; i < vol.length; i++) {
			addStateUpdate(vol[i]);
		}		
	}
	
	public ValueObject [] getStateUpdates() {
		if (state == null) return null;
		return state.toArray(new ValueObject[state.size()]);
	}

	public ValueObject getState(String name) {
		if (state == null) return null;
		for (ValueObject vo : state) {
			if (vo instanceof NamedValueObject && Comp.same(((NamedValueObject)vo).getName(), name)) {
				return vo;
			}
		}
		return null;
	}
	
	public ValueObject getType(Class clazz) {
		if (state == null) return null;
		for (ValueObject vo : state) {
			if (vo.getClass() == clazz) {
				return vo;
			}
		}
		return null;
	}
	
    protected String getElementName() {
        return "stateful-cr";
    }

    protected void encode(XMLWriter writer) throws ApplicationError {
    	if (state != null) {
    		for (ValueObject v : state) {
    			//writer.addElement("state", v);
    		}
    	}
    }

	@Override
	public String toString() {
		String r = "Empty";
    	if (state != null) {
    		r = "";
    		for (ValueObject v : state) {
    			if (v instanceof SectorOwnerGrid) {
    				r = r + " SectorOwnerGrid";
    			} else {
    				String s = v.toString();
    				if (s != null) r = r + " "+ v;
    			}
    		}
    	}
		return "StateUpdateCommandResult "+getSequence()+" [" + r + "]";
	}



}