/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.coms.protocols;

import mot.common.event.MotEvent;
import mot.common.util.ApplicationError;

/**
 * This interface defines the functionality required by the server to communicate with a user client.
 */
public interface ClientEventProcessor {
	
    /**
     * Processes an event in a client (this will send the event to the client on a remote connection). 
     */
    public void process(MotEvent event) throws ApplicationError;
    
    /**
     * @return The name of the player that owns this event processor (connection to the client). 
     */
    public String getOwnerName();

    /**
     * Set the name of the player that owns this event processor (connection to the client). 
     */
    public void setOwnerName(String v);

}