/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.coms.protocols;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.net.InetAddress;
import java.net.Socket;
import java.net.UnknownHostException;

import mot.common.util.ApplicationError;
import mot.common.util.Logger;
import mot.common.util.PropertyManager;
import mot.common.util.ValidationError;

public class MotSocket {

    public static boolean log = false;
    
    private String ip;
    
    private Socket socket;
	private ObjectOutputStream outputStream;
	private ObjectInputStream inputStream;


    public MotSocket(String ip) throws ApplicationError, ValidationError {
    	this.ip = ip;
		connect();
    }
    
    public MotSocket(Socket socket) {
		this.socket = socket;
    }
    
    public void connect() throws ApplicationError, ValidationError {
    	int port = Integer.parseInt( PropertyManager.getMandatory("server.port") ); 
        try {
            InetAddress address = InetAddress.getByName(ip);
            socket = new Socket(address, port);
            socket.setReceiveBufferSize(64*1024);
            socket.setSendBufferSize(64*1024);
        } catch (UnknownHostException e) {
            throw new ValidationError("Invalid host "+ip);
        } catch (IOException e) {
            throw new ValidationError("Unable to connect to server @ "+ip+":"+port);
        }
    }
    
    public synchronized void _write(Object o) throws IOException, ApplicationError {
//		if (o != null && o instanceof StateUpdateContainerEvent) {
//			StateUpdateContainerEvent su = (StateUpdateContainerEvent) o;
//			ValueObject[] sa = su.getStateUpdates();
//			if (sa != null) {
//				for (int i = 0; i < sa.length; i++) {
//					if (sa[i] instanceof CraftVO) {
//						Logger.logDebug("XCX  Send "+((CraftVO)sa[i]).getName()+"@"+((CraftVO)sa[i]).getLocation());
//					}
//				}
//			}
//		}
    	if (outputStream == null) {
    		outputStream = new ObjectOutputStream(socket.getOutputStream());
    	}
    	outputStream.reset(); // clear the cache so object changes get sent
    	outputStream.writeObject(o); 
    }
    
    public Object _read() throws IOException, ApplicationError {
    	if (inputStream == null) {
    		inputStream = new ObjectInputStream(socket.getInputStream());
    	}
    	try {
			Object o = inputStream.readObject();
//			if (o != null && o instanceof StateUpdateContainerEvent) {
//				StateUpdateContainerEvent su = (StateUpdateContainerEvent) o;
//				ValueObject[] sa = su.getStateUpdates();
//				if (sa != null) {
//					for (int i = 0; i < sa.length; i++) {
//						if (sa[i] instanceof CraftVO) {
//							Logger.logDebug("XCX  Recieve "+((CraftVO)sa[i]).getName()+"@"+((CraftVO)sa[i]).getLocation());
//						}
//					}
//				}
//			}
			return o;
		} catch (ClassNotFoundException e) {
			Logger.logError(e.getMessage(), e);
			throw new ApplicationError("Unable to read object due to "+e.getMessage());
		}
    }

	public boolean isConnected() {
		return socket != null && socket.isConnected();
	}

	public boolean isClosed() {
		return socket != null && socket.isClosed();
	}

	public Socket getSocket() {
		return socket;
	}

}