/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.coms.protocols;

import mot.client.proxy.LocalServerProxy;
import mot.client.proxy.RemoteConnectionServerProxy;
import mot.common.command_delegates.CommandDeligate;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

/**
 * This interface defines the functionality required by the client to communicate with the server.
 */
public interface ServerConnection {
	
	public static final String LOCAL_CLIENT_ID = "LocalClientId";
	
	public void connect(String ip) throws ApplicationError, ValidationError;
	
	public void disconnect();
    
    /**
     * Sends a command to the server.
     * @return The response
     * @param param The object to send to the server
     */
    public void send(CommandDeligate param) throws ApplicationError, ValidationError;

    /**
     * @return A proxy supplying write access to information on the server
     * if one is available. This is used by the editor and is only available on local
     * clients.
     */
    public LocalServerProxy getLocalServerProxy();

    /**
     * @return A proxy supplying remote connectivity to this client's engine
     * if one is available. This is used in multi-player games for remote players
     * to connect to this VM and join the game3.
     * @throws ApplicationError 
     */
    public RemoteConnectionServerProxy getRemoteConnectionServerProxy() throws ApplicationError;
    public boolean supportsRemoteConnection();

    /**
     * @return If this is connected to the server.
     */
	public boolean isConnected();

    /**
     * Register an event processor to process events sent from the server
     * @param eventProcessor
     */
	//public void register(MotClientEventProcessor eventProcessor);


}