/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.coms.protocols;

import java.io.IOException;

import mot.common.util.ApplicationError;

/**
 * This is the interface that all objects that convert Value Objects (VOs) to raw data ready for
 * sending over a connection and convert the raw data back to Value Objects again. Possible 
 * implementations would include;
 *      a) XML serializer / deserializer using the standard JDK encoder decoder.
 *      b) XML serializer / deserializer such as xstream.
 */
public interface XMLEncoderDecoder  {

    /**
     * Converts a Java object to its serialized form.
     * @return The serialized data form, Typically XML.
     * @param o The Java object to be serialised.
     */
    public String toString(Object o) throws IOException;
    
    /**
     * Converts serialized data to a Java object.
     * @return The Java object that has been serialised.
     * @param o The serialized data form, Typically XML..
     */
    public Object toObject(String data) throws IOException;
    
    /**
     * @return A string exactly 6 bytes containing the length of the contents 
     * of the serialized data.  
     */
    public String getLength(String xml) throws ApplicationError;
}