/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.designs;

import mot.common.technology.AsteroidFieldConstruction;
import mot.common.technology.Technologies;
import mot.common.util.ApplicationError;

/**
 * This is a planetary project to build a shield on a planet.
 */
public class AsteroidDesign extends BuildDesign implements ProjectDesign {

    public AsteroidDesign() {
    }

    public AsteroidDesign(AsteroidFieldConstruction asteroids) {
    	super(asteroids);
    }

    public int getCostToBuildOnPlanet() throws ApplicationError {
        return getAsteroids().getCostToBuild();
    }

	protected String getElementName() { return "asteroid-design"; }

	public AsteroidFieldConstruction getAsteroids() throws ApplicationError {
		if (name == null) {
			return null;
		} else {
			return (AsteroidFieldConstruction) Technologies.getMiscTechnology(name);
		}
	}

	public boolean same(ProjectDesign project) {
		if (project == null) return false;
		return (project instanceof AsteroidDesign);
	}

}