/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.designs;

import mot.common.technology.Hull;
import mot.common.technology.Technologies;
import mot.common.util.ApplicationError;
import mot.common.util.Comp;

/**
 * This is a planetary project to build a BattleStation on a planet.
 */
public class BattleStationDesign extends BuildDesign implements ProjectDesign {

    public BattleStationDesign() {
    }

    public BattleStationDesign(Hull battleStation) {
    	super(battleStation);
    }

    public int getCostToBuildOnPlanet() throws ApplicationError {
        return getBattleStation().getCostToBuild();
    }

	public Hull getBattleStation() throws ApplicationError {
		if (name == null) {
			return null;
		} else {
			return (Hull) Technologies.getHull(name);
		}
	}

	protected String getElementName() { return "battle-station-design"; }

	public boolean same(ProjectDesign project) {
		if (project == null) return false;
		return (project instanceof BattleStationDesign && Comp.same(name, project.getName()));
	}

}