/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.designs;

import mot.common.technology.PlanetConstruction;
import mot.common.technology.Technologies;
import mot.common.util.ApplicationError;
import mot.common.util.Comp;
import mot.common.xml.XMLWriter;

/**
 * This is a planetary project to build a new planet in a solar system.
 */
public class ConstructPlanetDesign extends BuildDesign implements ProjectDesign {

    public static final int BORALIUM_COST = 200;
    
	/**
	 * The solar system into which to build this planet.
	 */
	private String solarSystem;
	
    public ConstructPlanetDesign() {
    }

    public ConstructPlanetDesign(PlanetConstruction tech, String solarSystem) {
        super(tech);
        this.solarSystem = solarSystem;
    }

    public int getCostToBuildOnPlanet() throws ApplicationError {
        return getPlanetConstructionTech().getCostToBuild();
    }

	protected String getElementName() { return "construct-planet-design"; }

	protected void encode(XMLWriter writer) throws ApplicationError {
        super.encode(writer);
        writer.addElement("solar-system", solarSystem);
    }

	public PlanetConstruction getPlanetConstructionTech() throws ApplicationError {
		if (name == null) {
			return null;
		} else {
			return (PlanetConstruction) Technologies.getMiscTechnology(name);
		}
	}


	public void setSolarSystem(String solarSystem) {
		this.solarSystem = solarSystem;
	}

	public String getSolarSystem() {
		return solarSystem;
	}

	public boolean same(ProjectDesign project) {
		if (project == null) return false;
		return (project instanceof ConstructPlanetDesign && Comp.same(name, project.getName()));
	}

}