/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.designs;

import java.io.Serializable;

import mot.common.util.ApplicationError;
import mot.common.xml.XMLBeanInterface;

/**
 * This contains the design details of a planetary project. A planetary project is
 * an object being built on a planet - like a new craft. This object is shared between 
 * clients and a server. The server side equivalent is Project.
 * Implementations of a ProjectDesign should also extend XMLBean - Thus this interfaces 
 * extends XMLBeanInterface. This is because projects need saving!
 */
public interface ProjectDesign extends XMLBeanInterface, Serializable {

    /**
     * NB - If freeList contains 5 fusion beams this implies that the project may use upto 
     * 5 of them without having the cost added to the cost to build this structure.
     * @param freeTechs A list of technologies to use on this project. 
     * @return The cost to build this object. See Planet production for details.
     * @throws ApplicationError 
     */
    public int getCostToBuildOnPlanet() throws ApplicationError;

    /**
     * @return The name of this object being built. For a CraftDesign it may be
     * something like FighterI.
     */
    public String getName();

	public boolean same(ProjectDesign project);

}