/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.designs;

import mot.common.technology.Scanner;
import mot.common.technology.Technologies;
import mot.common.util.ApplicationError;
import mot.common.util.Comp;

/**
 * This is a planetary project to build a scanner on a planet.
 */
public class ScannerDesign extends BuildDesign implements ProjectDesign {

    /**
     * The extra cost applied to the cost to build this technology because it is
     * being built on a planet.
     */
    public static final int PLANET_COST_FACTOR = 3;

    public ScannerDesign() {
    }

    public ScannerDesign(Scanner scanner) {
        super(scanner);
    }

    public int getCostToBuildOnPlanet() throws ApplicationError {
        return PLANET_COST_FACTOR*getScanner().getCostToBuild();
    }

    public Scanner getScanner() throws ApplicationError {
		if (name == null) {
			return null;
		} else {
			return (Scanner) Technologies.getScanner(name);
		}
    }

	protected String getElementName() { return "scanner-design"; }

	public boolean same(ProjectDesign project) {
		if (project == null) return false;
		return (project instanceof ScannerDesign && Comp.same(name, project.getName()));
	}

}