/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.designs;

import mot.common.util.ApplicationError;
import mot.common.xml.XMLBean;
import mot.common.xml.XMLWriter;

/**
 * This is a project to build a transport on a planet.
 * Transports may be used to move colonists between planets.
 */
public class TransportDesign extends XMLBean implements ProjectDesign {

    public TransportDesign() {
    }

    private static final int COST_TO_BUILD = 200;

    /**
     * @return The name of this object being built. For a CraftDesign it may be
     * something like FighterI.
     */
    public String getName() {
        return "Transport";
    }

    protected String getElementName() {
        return "transport-design";
    }

    public int getCostToBuildOnPlanet() {
        return COST_TO_BUILD;
    }

    
    public static final String PROJECT_IMAGE = "images/backgrounds/transport.png";
    public static String getProjectImage() { return PROJECT_IMAGE; }
    

    /**
     * @return The cost to build this object. See Planet production for details.
     */
    public static int getCostToBuild() {
        return COST_TO_BUILD;
    }

    private static final int SPACE_ON_TRANSPORT = 25;

    public static int getSpace() { return SPACE_ON_TRANSPORT; }

    protected void encode(XMLWriter writer) throws ApplicationError {
    }
    
	public String getProjectElementName() {
        return getElementName();
    }
    
    public String getDescription() {
        return "Commercial Transport with capacity "+SPACE_ON_TRANSPORT;
    }

	public boolean same(ProjectDesign project) {
		if (project == null) return false;
		return (project instanceof TransportDesign);
	}

}