/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.designs;

import mot.common.technology.GeneralTechnologyList;
import mot.common.technology.Technology;
import mot.common.technology.TechnologyBundle;
import mot.common.technology.TechnologyList;
import mot.common.util.Comp;

public class WorkTupple {
	
	/**
	 * List of technologies that need building to construct a craft of this design.
	 */
	public GeneralTechnologyList buildList = new GeneralTechnologyList();
	
	/**
	 * List of technologies can be used from the free list to construct a craft of this design.
	 */
	public GeneralTechnologyList useList = new GeneralTechnologyList();
	
	public void fill(Technology a, TechnologyList freeTechs) {
		if (a != null) {
			if (freeTechs != null && freeTechs.contains(a)) {
				useList.add(a);
			} else {
				buildList.add(a);				
			}
		}
	}
	
	public void fill(TechnologyBundle[] a, TechnologyList freeTechs) {
		if (a == null) return;
		for (int i = 0; i < a.length; i++) {
			if (freeTechs != null && freeTechs.contains(a[i].technology)) {
				int qtyFree = freeTechs.getQuantity(a[i].technology);
				useList.add(a[i].technology, Comp.min(qtyFree, a[i].qty));
				int remaining = a[i].qty - qtyFree;
				if (remaining > 0) {
					buildList.add(a[i].technology, remaining);
				}
			} else {
				buildList.add(a[i].technology, a[i].qty);				
			}
		}			
	}

}
