/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.event;

import mot.common.bean.CraftState;
import mot.common.vo.BattleCraftVO;
import mot.common.vo.ValueObject;

/**
 * This event is caused when a craft is created in a battle through a duplicate beam or some
 * other such process. It causes an animation to be executed in the battle window showing the
 * new craft appear in the battle field. 
 */
public class BattleCraftNewEvent extends LinkedEventBase implements BattleStateUpdateSingleEventAdapter {

    /**
     * The craft that is appearing.
     */
    private BattleCraftVO battleCraft;
    
    private boolean useMaterialiseAnimation;
    
    /**
     * The name of the battle this event is in
     */
	private String battle;


	public BattleCraftNewEvent(String battle, BattleCraftVO battleCraft, boolean useMaterialiseAnimation) {
		this.battle = battle;
		this.battleCraft = battleCraft;
		this.useMaterialiseAnimation = useMaterialiseAnimation;
	}

	public String toString() {
		return "BattleCraftNewEvent: craft="+battleCraft+super.toString();
	}

	public boolean isGalaxyEvent() {
		return false;
	}

	public boolean isBattleEvent() {
		return true;
	}

	public BattleCraftVO getBattleCraft() {
		return battleCraft;
	}

	public void setBattleCraft(BattleCraftVO craft) {
		this.battleCraft = craft;
	}

	@Override
	public String getUpdatedObjectName() {
		return battleCraft.getName();
	}
	
	@Override
	public CraftState fetchStateUpdate() {
		return null;
	}

	@Override
	public ValueObject fetchValueObjectUpdate() {
		return battleCraft;
	}

	@Override
	public String getBattle() {
		return battle;
	}

	public void setBattle(String battle) {
		this.battle = battle;
	}

	public boolean isUseMaterialiseAnimation() {
		return useMaterialiseAnimation;
	}

	public void setUseMaterialiseAnimation(boolean useMaterialiseAnimation) {
		this.useMaterialiseAnimation = useMaterialiseAnimation;
	}
}