/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.event;

import mot.common.bean.CraftState;
import mot.common.vo.ValueObject;

/**
 * Caused when a craft surrenders in a battle.
 * This occurs when a craft attacks this craft and has a much higher psi rating.
 */
public class BattleCraftSurrenderEvent implements BattleStateUpdateSingleEventAdapter {

	private CraftState oldState;
	private CraftState newState;
	
	private String battle;
	private String craft;

	public BattleCraftSurrenderEvent(String battle, String craft, CraftState oldState, CraftState newState) {
		this.battle = battle;
		this.craft = craft;
		this.oldState = oldState;
		this.newState = newState;
	}

    public String getCraft() {
        return craft;
    }

    public void setCraft(String craft) {
        this.craft = craft;
    }

	public String toString() {
		return "CraftSurrenderEvent: craft="+craft;
	}

	public boolean isGalaxyEvent() {
		return false;
	}

	public boolean isBattleEvent() {
		return true;
	}

	public CraftState getOldState() {
		return oldState;
	}

	public void setOldState(CraftState oldState) {
		this.oldState = oldState;
	}

	public CraftState getNewState() {
		return newState;
	}

	public void setNewState(CraftState newState) {
		this.newState = newState;
	}

	@Override
	public String getUpdatedObjectName() {
		return craft;
	}

	@Override
	public CraftState fetchStateUpdate() {
		return newState;
	}

	@Override
	public ValueObject fetchValueObjectUpdate() {
		return null;
	}

	public String getBattle() {
		return battle;
	}

	public void setBattle(String battle) {
		this.battle = battle;
	}
}