/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.event;

import mot.common.bean.CraftState;
import mot.common.vo.ValueObject;

public class BattleCraftUpdateEvent extends LinkedEventBase implements BattleStateUpdateSingleEventAdapter {
	
	/**
	 * The name of the battle this event takes part in.
	 */
	private String battle;

    private String craft;

	private CraftState newState;

    public BattleCraftUpdateEvent(String battle, String craft, CraftState newState) {
		this.battle = battle;
		this.craft = craft;
		this.newState = newState;
	}

	public String toString() {
		return "BattleCraftUpdateEvent: craft="+craft;
	}
	
	public String getCraft() {
		return craft;
	}

	public void setCraft(String craft) {
		this.craft = craft;
	}

	public CraftState getNewState() {
		return newState;
	}

	public void setNewState(CraftState newState) {
		this.newState = newState;
	}

	public boolean isGalaxyEvent() {
		return false;
	}

	public boolean isBattleEvent() {
		return true;
	}

	@Override
	public String getUpdatedObjectName() {
		return craft;
	}

	@Override
	public CraftState fetchStateUpdate() {
		return newState;
	}

	@Override
	public ValueObject fetchValueObjectUpdate() {
		return null;
	}

	public String getBattle() {
		return battle;
	}

	public void setBattle(String battle) {
		this.battle = battle;
	}
}
