/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.event;

import mot.common.bean.CraftState;
import mot.common.bean.Location;
import mot.common.technology.Technologies;
import mot.common.technology.Weapon;
import mot.common.util.ApplicationError;
import mot.common.vo.ValueObject;

public class BattleDamageRingEvent extends LinkedEventBase implements BattleStateUpdateSingleEventAdapter {

	/**
	 * The name of the battle this event takes part in.
	 */
	private String battle;

	/**
     * The object that has caused the warp core breach.
     */
    private String source;
    
    /**
     * The state of the craft before it was destroyed.
     */
    private CraftState oldState;

    /**
     * The location of this event (note the craft may have moved after this event)
     */
    private Location location;
    
    /**
     * This is the amount of explosive damage produced by the blast.
     */
    private int damage;

    /**
     * This is the weapon that caused this Damage Ring.
     * This may be NULL - Mines do not have weapons and cause Warp Core Overloads.
     */
	private String weapon;

	/**
	 * State after craft was destroyed
	 */
	private CraftState newState;

    public BattleDamageRingEvent() {
    }

    public BattleDamageRingEvent(String battle, String source, CraftState oldState, CraftState newState, Location location, int damage, String weapon) {
        this.battle = battle;
		this.source = source;
		this.oldState = oldState;
		this.newState = newState;
		this.location = location;
        this.damage = damage;
		this.weapon = weapon;
    }

	public String toString() {
		return "DamageRingEvent source="+source+" damage="+damage+super.toString();
	}


    public void setSource(String source) {
        this.source = source;
    }


    public String getSource() {
        return source;
    }


    public void setDamage(int damage) {
        this.damage = damage;
    }


    public int getDamage() {
        return damage;
    }


	public boolean isGalaxyEvent() {
		return false;
	}

	public boolean isBattleEvent() {
		return true;
	}

	public String getWeapon() {
		return weapon;
	}

	public Weapon getWeaponTechnology() throws ApplicationError {
		return Technologies.getWeapon(weapon);
	}

	public void setWeapon(String weapon) {
		this.weapon = weapon;
	}

	public Location getLocation() {
		return location;
	}

	public void setLocation(Location location) {
		this.location = location;
	}

	public CraftState getOldState() {
		return oldState;
	}

	public void setOldState(CraftState oldState) {
		this.oldState = oldState;
	}
	
	public String getBattle() {
		return battle;
	}

	public void setBattle(String battle) {
		this.battle = battle;
	}

	@Override
	public String getUpdatedObjectName() {
		return source;
	}
	
	@Override
	public CraftState fetchStateUpdate() {
		return newState;
	}

	@Override
	public ValueObject fetchValueObjectUpdate() {
		return null;
	}

	public CraftState getNewState() {
		return newState;
	}

	public void setNewState(CraftState newState) {
		this.newState = newState;
	}	
}