/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.event;

import mot.common.bean.CraftState;
import mot.common.bean.Location;
import mot.common.vo.ValueObject;

/**
 * This event is sent to all when a missile has moved on the battle map.
 * This gives UIs a chance to animate missile movement.
 */
public class BattleDroidMineMoveEvent implements BattleStateUpdateSingleEventAdapter {

    private String battle;
	private String droidMine;
    private Location from;
    private Location to;

    /**
     * State of the automaton after this event / animation.
     */
    private CraftState state;
    
    /**
     * The craft damage at the point this animations is taking place.
     * This will usually be different from the crafts damage at this point in time!!
     */
    private CraftState targetState;

    public BattleDroidMineMoveEvent() {
    }

    public BattleDroidMineMoveEvent(String battle, String droidMine, Location from, Location to, CraftState state, CraftState targetState) {
        this.battle = battle;
		this.droidMine = droidMine;
        this.from = from;
        this.to = to;
        this.state = state;
        this.targetState = targetState;
    }
    
	public String toString() {
		return "DroidMineMoveEvent: droidMine="+droidMine+" from="+from+" to="+to;
	}
 
    public void setDroidMine(String droidMine) {
        this.droidMine = droidMine;
    }


    public String getDroidMine() {
        return droidMine;
    }


    public void setFrom(Location from) {
        this.from = from;
    }


    public Location getFrom() {
        return from;
    }


    public void setTo(Location to) {
        this.to = to;
    }


    public Location getTo() {
        return to;
    }

    public void setState(CraftState state) {
        this.state = state;
    }


    public CraftState getState() {
        return state;
    }

	public boolean isGalaxyEvent() {
		return false;
	}

	public boolean isBattleEvent() {
		return true;
	}

	@Override
	public String getUpdatedObjectName() {
		return droidMine;
	}

	@Override
	public CraftState fetchStateUpdate() {
		return state;
	}

	@Override
	public ValueObject fetchValueObjectUpdate() {
		return null;
	}

	public String getBattle() {
		return battle;
	}

	public void setBattle(String battle) {
		this.battle = battle;
	}

	public CraftState getTargetState() {
		return targetState;
	}

	public void setTargetState(CraftState targetState) {
		this.targetState = targetState;
	}

}

