/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.event;

import mot.common.lang.L;

/**
 * Notifies player that a battle has completed. This will cause the next battle in a
 * queue to be executed (if one exists).
 * @see mot.proxy.eventNewBattleEvent for more details.
 */
public class BattleEndEvent extends StateUpdateContainerEvent implements BattleEvent {

	/**
	 * The name of the battle this event takes part in.
	 */
	private String battle;
	
	private String [] craftDestroyd;

    public BattleEndEvent() {
	}

    public BattleEndEvent(String battle, String [] craftDestroyd) {
        this.battle = battle;
		this.setCraftDestroyd(craftDestroyd);
	}

    public String getBattle() {
        return battle;
    }

    public void setBattle(String battle) {
        this.battle = battle;
    }

	public String [] getCraftDestroyd() {
		return craftDestroyd;
	}

	public void setCraftDestroyd(String [] craftDestroyd) {
		this.craftDestroyd = craftDestroyd;
	}

	public String getCraftDestroydAsString() {
        if (craftDestroyd == null) return L.NONE;
        StringBuilder sb = new StringBuilder();
        boolean first = true;
        for (String i : craftDestroyd) {
            if (i != null) {
            	if (first) {
            		first = false;
            	} else {
            		sb.append(" + ");
            	}
           		sb.append(i.toString());
            }
        }
        if (sb == null || sb.length() == 0) {
        	return L.NONE;
        } else {
        	return sb.toString();
        }
	}

	public String toString() {
		return "EndBattleEvent: battle="+battle+" [" + getStateString() + "]";
	}

	public boolean isGalaxyEvent() {
		return true;
	}

	public boolean isBattleEvent() {
		return true;
	}
	
}