/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.event;

import mot.common.bean.Location;

/**
 * Caused when a craft attempts fires a weapon in a battle but the target
 * craft has a higher psi ability and has caused the source craft to lose
 * their chance to fire (weapons discharged).
 */
public class BattleFearEvent implements BattleEvent {

    private String battle;
    private String source;
    private String target;
	private Location location;

	public BattleFearEvent() {
	}

	public BattleFearEvent(String battle, String source, Location location, String target) {
        this.battle = battle;
		this.source = source;
        this.target = target;
		this.location = location;
	}

    public String getSource() {
        return source;
    }

    public void setSource(String source) {
        this.source = source;
    }

    public String getTarget() {
        return target;
    }

    public void setTarget(String target) {
        this.target = target;
    }
    
	public String toString() {
		return "FearEvent: target="+target+" source="+source;
	}
 
	public boolean isGalaxyEvent() {
		return false;
	}

	public boolean isBattleEvent() {
		return true;
	}

	public Location getLocation() {
		return location;
	}

	public void setLocation(Location location) {
		this.location = location;
	}

	public String getBattle() {
		return battle;
	}

	public void setBattle(String battle) {
		this.battle = battle;
	}

}