/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.event;

import mot.common.bean.CraftState;
import mot.common.vo.MissilesVO;
import mot.common.vo.ValueObject;

/**
 * Caused when a craft fires a missile in a battle.
 * The battle craft source has fired on battle craft target using weapon weapon.
 * There should now be an automaton object in the battle being the missile.
 */
public class BattleMissileLaunchEvent implements BattleStateUpdateSingleEventAdapter {

	/**
	 * The name of the battle this event takes part in.
	 */
	private String battle;
	
    private MissilesVO missile;

	public BattleMissileLaunchEvent() {
	}

	public String toString() {
		return "MissileLaunchEvent missile="+missile;
	}

	public BattleMissileLaunchEvent(String battle, MissilesVO missile) {
        this.battle = battle;
		this.missile = missile;
	}


    public void setMissile(MissilesVO missile) {
        this.missile = missile;
    }


    public MissilesVO getMissile() {
        return missile;
    }

	public boolean isGalaxyEvent() {
		return false;
	}

	public boolean isBattleEvent() {
		return true;
	}

	@Override
	public String getUpdatedObjectName() {
		return missile.getName();
	}
	
	@Override
	public CraftState fetchStateUpdate() {
		return null;
	}

	@Override
	public ValueObject fetchValueObjectUpdate() {
		return missile;
	}

	public String getBattle() {
		return battle;
	}

	public void setBattle(String battle) {
		this.battle = battle;
	}
	
}