/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.event;

import mot.common.bean.CraftState;
import mot.common.vo.ValueObject;

/**
 * This is a generic message to be animated on the battle field for
 * BattleObject. It should appear as text moving above the object.
 */
public class BattleObjectNotificationEvent implements BattleStateUpdateSingleEventAdapter {

	/**
	 * The name of the battle this event takes part in.
	 */
	private String battle;

    private String target;

    /**
     * Generic message intended for display above the target
     */
    private String message;

    /**
     * The name of an icon that should be used with this notification.
     * This icon may also connect to a sound.
     */
    private BattleObjectNotificationType type;
    
    /**
     * The target craft state before this animations is taking place.
     */
    private CraftState oldTargetState;

    /**
     * The target craft state while this animations is taking place.
     */
    private CraftState newTargetState;

    public BattleObjectNotificationEvent(String battle, String target, String message, BattleObjectNotificationType type, CraftState oldTargetState, CraftState newTargetState) {
        this.battle = battle;
		this.target = target;
        this.message = message;
        this.type = type;
        this.oldTargetState = oldTargetState;
        this.newTargetState = newTargetState;
	}

    public String getTarget() {
        return target;
    }

    public void setTarget(String target) {
        this.target = target;
    }

    public void setOldTargetState(CraftState oldTargetState) {
        this.oldTargetState = oldTargetState;
    }


    public CraftState getOldTargetState() {
        return oldTargetState;
    }


    public void setNewTargetState(CraftState newTargetState) {
        this.newTargetState = newTargetState;
    }


    public CraftState getNewTargetState() {
        return newTargetState;
    }


    public void setMessage(String message) {
        this.message = message;
    }


    public String getMessage() {
        return message;
    }
    
	public String toString() {
		return "BattleObjectNotificationEvent: bo="+((target == null)?"none":target+" message="+message+super.toString());
	}

	public boolean isGalaxyEvent() {
		return false;
	}

	public boolean isBattleEvent() {
		return true;
	}

	public BattleObjectNotificationType getType() {
		return type;
	}

	public void setType(BattleObjectNotificationType type) {
		this.type = type;
	}

	public String getBattle() {
		return battle;
	}

	public void setBattle(String battle) {
		this.battle = battle;
	}

	@Override
	public String getUpdatedObjectName() {
		return target;
	}

	@Override
	public CraftState fetchStateUpdate() {
		return newTargetState;
	}

	@Override
	public ValueObject fetchValueObjectUpdate() {
		return null;
	}

	
}