/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.event;

import mot.common.bean.CraftState;
import mot.common.vo.ValueObject;

/**
 * Caused when a trigger executes that has an effect on a craft.
 */
public class BattleObjectTriggerEvent implements BattleStateUpdateSingleEventAdapter {

	/**
	 * The name of the battle this event takes part in.
	 */
	private String battle;

	/**
	 * The object this trigger effects
	 */
    private String battleObject;
    
    /**
     * This is the group name of the weapon that generated this bot.
     * @see mot.common.technology.Weapon for details
     */
    private String type;
    
    /**
     * The state before this event
     */
    private CraftState originalState;

    /**
     * The state after this event
     */
    private CraftState newState;

    /**
     * Some weapon fire animations have special messages for the user.
     */
    private String description;  
    
    public BattleObjectTriggerEvent(String battle, String battleObject, String type, CraftState originalState, CraftState newState, String description) {
		this.battle = battle;
		this.battleObject = battleObject;
		this.type = type;
		this.originalState = originalState;
		this.newState = newState;
		this.description = description;
	}

	public String getBattleObject() {
		return battleObject;
	}

	public void setBattleObject(String battleObject) {
		this.battleObject = battleObject;
	}

	public String getDescription() {
		return description;
	}

	public void setDescription(String description) {
		this.description = description;
	}

	public CraftState getNewState() {
		return newState;
	}

	public void setNewState(CraftState newState) {
		this.newState = newState;
	}

	public CraftState getOriginalState() {
		return originalState;
	}

	public void setOriginalState(CraftState originalState) {
		this.originalState = originalState;
	}



	public String getType() {
		return type;
	}



	public void setType(String type) {
		this.type = type;
	}

	public String toString() {
		return "BattleObjectTriggerEvent: bo="+((battleObject == null)?"none":battleObject+" type="+type);
	}

	public boolean isGalaxyEvent() {
		return false;
	}

	public boolean isBattleEvent() {
		return true;
	}

	@Override
	public String getUpdatedObjectName() {
		return battleObject;
	}

	@Override
	public CraftState fetchStateUpdate() {
		return newState;
	}

	@Override
	public ValueObject fetchValueObjectUpdate() {
		return null;
	}

	public String getBattle() {
		return battle;
	}

	public void setBattle(String battle) {
		this.battle = battle;
	}

}