/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.event;

import mot.common.bean.CraftState;
import mot.common.technology.Technologies;
import mot.common.technology.Weapon;
import mot.common.util.ApplicationError;
import mot.common.vo.ValueObject;

public class BattlePulseEvent extends LinkedEventBase implements BattleStateUpdateSingleEventAdapter {

	/**
	 * The name of the battle this event takes part in.
	 */
	private String battle;

	/**
     * The object that has caused the warp core breach.
     */
    private String source;
    
    /**
     * The state of the craft before it was destroyed.
     */
    private CraftState oldState;

    /**
     * This is the weapon that caused this Damage Ring.
     */
	private String weapon;

	/**
	 * State after craft was destroyed
	 */
	private CraftState newState;

    public BattlePulseEvent() {
    }

    public BattlePulseEvent(String battle, String source, CraftState oldState, CraftState newState, String weapon) {
        this.battle = battle;
		this.source = source;
		this.oldState = oldState;
		this.newState = newState;
		this.weapon = weapon;
    }

	public String toString() {
		return "BattlePulseEvent source="+source+super.toString();
	}

    public void setSource(String source) {
        this.source = source;
    }

    public String getSource() {
        return source;
    }

	public boolean isGalaxyEvent() {
		return false;
	}

	public boolean isBattleEvent() {
		return true;
	}

	public String getWeapon() {
		return weapon;
	}

	public Weapon getWeaponTechnology() throws ApplicationError {
		return Technologies.getWeapon(weapon);
	}

	public void setWeapon(String weapon) {
		this.weapon = weapon;
	}

	public CraftState getOldState() {
		return oldState;
	}

	public void setOldState(CraftState oldState) {
		this.oldState = oldState;
	}
	
	public String getBattle() {
		return battle;
	}

	public void setBattle(String battle) {
		this.battle = battle;
	}

	@Override
	public String getUpdatedObjectName() {
		return source;
	}
	
	@Override
	public CraftState fetchStateUpdate() {
		return newState;
	}

	@Override
	public ValueObject fetchValueObjectUpdate() {
		return null;
	}

	public CraftState getNewState() {
		return newState;
	}

	public void setNewState(CraftState newState) {
		this.newState = newState;
	}	
}