/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.event;

import mot.common.bean.Location;
import mot.common.technology.Technologies;
import mot.common.technology.Weapon;
import mot.common.util.ApplicationError;


/**
 * Caused when a craft attempts fires a weapon in a battle at a target
 * craft but it missed entirely. This is usually because the craft is cloaked.
 */
public class BattleWeaponMissEvent implements BattleEvent, WeaponSourceToTargetEvent {

	/**
	 * The name of the battle this event takes part in.
	 */
	private String battle;
	
    private String source;
    private String target;
    private String weaponName;
	private Location sourceLocation;
	private Location targetLocation;
	private int sourceDirection;

    public BattleWeaponMissEvent() {
    }

    public BattleWeaponMissEvent(String battle, String source, String target, Weapon weapon, Location sourceLocation, int sourceDirection, Location targetLocation) {
        this.battle = battle;
		this.source = source;
        this.target = target;
        this.weaponName = (weapon == null) ? null : weapon.getName();
		this.sourceLocation = sourceLocation;
		this.sourceDirection = sourceDirection;
		this.targetLocation = targetLocation;
	}

    public BattleWeaponMissEvent(String battle, String source, String target, String weapon, Location sourceLocation, int sourceDirection, Location targetLocation) {
        this.battle = battle;
        this.source = source;
        this.target = target;
        this.weaponName = weapon;
		this.sourceLocation = sourceLocation;
		this.sourceDirection = sourceDirection;
		this.targetLocation = targetLocation;
	}
    
	public String toString() {
		return "MissTargetEvent source="+source+" target="+target+" weaponName="+weaponName+"["+sourceLocation+"->"+targetLocation+"]";
	}

    public String getSource() {
        return source;
    }

    public void setSource(String source) {
        this.source = source;
    }

    public String getTarget() {
        return target;
    }

    public void setTarget(String target) {
        this.target = target;
    }


    public void setWeaponName(String weapon) {
        this.weaponName = weapon;
    }


    public String getWeaponName() {
        return weaponName;
    }
    
    public Weapon getWeapon() throws ApplicationError {
        if (weaponName == null) {
            return null;
        } else {
            return Technologies.getWeapon(weaponName);
        }
    }

	public boolean isGalaxyEvent() {
		return false;
	}

	public boolean isBattleEvent() {
		return true;
	}

	public Location getSourceLocation() {
		return sourceLocation;
	}

	public void setSourceLocation(Location sourceLocation) {
		this.sourceLocation = sourceLocation;
	}

	public Location getTargetLocation() {
		return targetLocation;
	}

	public void setTargetLocation(Location targetLocation) {
		this.targetLocation = targetLocation;
	}

	public int getSourceDirection() {
		return sourceDirection;
	}

	public void setSourceDirection(int sourceDirection) {
		this.sourceDirection = sourceDirection;
	}

	public String getBattle() {
		return battle;
	}

	public void setBattle(String battle) {
		this.battle = battle;
	}
}