/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.event;

/**
 * Caused when a player declares war or requests a treaty from another player..
 */
public class DiplomaticEvent extends StateUpdateContainerEvent {

	/**
	 * The player requesting or causing this diplomatic event.
	 * e.g. The player requesting peace.
	 */
 	private String player;
 	
 	/**
 	 * This is a human readable message containing a description of the request 
 	 * or response in this diplomatic event.
 	 */
 	private String message;

	public DiplomaticEvent() {
    }

	public DiplomaticEvent(String player, String message) {
		this.player = player;
		this.message = message;
    }

	public String toString() {
		String name = getClass().getSimpleName();
		return name+" player="+player + getStateString();
	}
	

    public void setPlayer(String player) {
        this.player = player;
    }


    public String getPlayer() {
        return player;
    }

	public String getMessage() {
		return message;
	}

	public void setMessage(String message) {
		this.message = message;
	}
	
	public boolean isGalaxyEvent() {
		return true;
	}

	public boolean isBattleEvent() {
		return false;
	}

}