/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.event;

import mot.common.bean.DiplomaticProposal;

/**
 * Caused when a player makes a diplomatic request (Propose a treaty, request an exchange of 
 * technology, money and or a planet).  This is sent to a single player who is the player that 
 * is receiving the request to. 
 */
public class DiplomaticRequestEvent extends DiplomaticEvent {

    private DiplomaticProposal proposal;

	public DiplomaticRequestEvent() {
    }

    /**
     * @param wantedAssets The assets that the player who made this swap request is offering
     * @param offeredAssets The assets that the player who made this swap request is wants in exchange
     * @param player The player who request the swap.
     */
	public DiplomaticRequestEvent(String player, DiplomaticProposal proposal, String message) {
		super(player, message);
        this.proposal= proposal;
    }

	public DiplomaticProposal getProposal() {
		return proposal;
	}

	public void setProposal(DiplomaticProposal proposal) {
		this.proposal = proposal;
	}

}