/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.event;

import mot.common.bean.DiplomaticProposal;
import mot.common.lang.L;

/**
 * Caused when a player makes diplomatic request (Propose a treaty, request an exchange of 
 * technology, money and or a planet).
 */
public class DiplomaticResponseEvent extends DiplomaticEvent implements MotEvent {

    private DiplomaticProposal proposal;
    private boolean accept;

	public DiplomaticResponseEvent() {
    }
    
    /**
     * @param accept True if the sending player accepts the request and false otherwise
     * @param wantedAssets The assets that the player who made this swap request is offering
     * @param offeredAssets The assets that the player who made this swap request is wants in exchange
     * @param player The player who received the swap request and is sending this response.
     */
	public DiplomaticResponseEvent(String player, DiplomaticProposal proposal, boolean accept, String message) {
		super(player, message);
        this.proposal= proposal;
        this.accept = accept;
    }

    public boolean isAccept() {
        return accept;
    }

    public void setAccept(boolean accept) {
        this.accept = accept;
    }

    public String getResponseVerb() {
        if (accept) {
            return L.ACCEPTED;
        } else {
            return L.REJECTED;
        }
    }


	public DiplomaticProposal getProposal() {
		return proposal;
	}

	public void setProposal(DiplomaticProposal proposal) {
		this.proposal = proposal;
	}

    
}