/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.event;

/**
 * If a player has no money to pay for the upkeep of his/her/its fleet then
 * one of the players items are sold and the money credited to the players
 * account. Then this event is sent to the player informing them of the situation.
 */
public class FundsGoneEvent extends StateUpdateContainerEvent {

    public String object;
    private String planet;
    public int money;

    public FundsGoneEvent() {
	}

    public FundsGoneEvent(String object, String planet, int money) {
        this.object = object;
		this.planet = planet;
        this.money = money;
	}

    public String getObject() {
        return object;
    }

    public void setObject(String object) {
        this.object = object;
    }

    public int getMoney()  {
        return money;
    }

    public void setMoney(int money)  {
       this.money = money;
    }
    
	public String toString() {
		return "FundsGoneEvent: money="+money;
	}

	public boolean isGalaxyEvent() {
		return true;
	}

	public boolean isBattleEvent() {
		return false;
	}

	public String getPlanet() {
		return planet;
	}

	public void setPlanet(String planet) {
		this.planet = planet;
	}
}