/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.event;

import java.util.ArrayList;

import mot.common.util.ApplicationError;

/**
 * This is the base class for all events that may contain other linked events.
 */
public abstract class LinkedEventBase extends StateUpdateContainerEvent {

    private ArrayList linkedEvents;
    
    public LinkedEventBase() {
    }

    protected void setLinkedEvents(LinkedEventBase event) throws ApplicationError {
    	MotEvent [] linked = getLinkedEvents();
        if (linked != null) {
            for (int i=0; i<linked.length; i++) {
                event.link(linked[i]);
            }
        }
    }
    
    public void link(MotEvent event) {
        if (linkedEvents == null) linkedEvents = new ArrayList();
        linkedEvents.add(event);
    }

    public void link(MotEvent[] events) {
        if (linkedEvents == null) linkedEvents = new ArrayList();
        for (int i=0; i<events.length; i++) {
            link(events[i]);
        }
    }

    public MotEvent[] getLinkedEvents() {
        if (linkedEvents == null) return null;
        return (MotEvent[])linkedEvents.toArray(new MotEvent[(linkedEvents.size())]);
    }

	public String toString() {
        if (linkedEvents == null) return getStateString();
        StringBuilder sb = new StringBuilder();
        boolean first = true;
        for (Object i : linkedEvents) {
        	MotEvent e = (MotEvent) i;
            if (e != null) {
            	if (first) {
            		sb.append(" [Linked events - ");
            		first = false;
            	} else {
            		sb.append(" , ");
            	}
            	sb.append(e.toString());
            }
        }
        if (sb == null || sb.length() == 0) {
        	return " [" + getStateString() + "]";
        } else {
        	return sb.toString()+"] [ State - " + getStateString() + "]";
        }
	}

    
}