/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.event;

import mot.common.bean.MessageType;

/**
 * This is an event caused when the engine wishes to send a message to a user
 * player.
 */
public class MessageEvent extends StateUpdateContainerEvent {

    /**
     * Causes a message to be displayed to user players while computer players
     * ignore it.
     */
    protected String message;

	/**
	 * If true this message flashes when it is displayed. Otherwise it does not.
	 */
 	protected MessageType messageType;

	/**
	 * If not null the sound that should play when this message is displayed
	 */
 	private String sound;



    public MessageEvent() {
    }

	public String toString() {
		return "MessageEvent message="+message+" [" + getStateString() + "]";
	}

    public MessageEvent(String message, MessageType messageType, String sound) {
        this.message = message;
        this.messageType = messageType;
        this.sound = sound;
    }

    public String getMessage() { return message; }

	public MessageType getMessageType() {
		return messageType;
	}

	public boolean isGalaxyEvent() {
		return true;
	}

	public boolean isBattleEvent() {
		return true;
	}

	public String getSound() {
		return sound;
	}

	public void setSound(String sound) {
		this.sound = sound;
	}
}