/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.event;

import mot.common.vo.ValueObject;

/**
 * The engine informs clients of changes (weapons firing, craft destruction etc)
 * by generating events.
 */
public interface MotEvent extends ValueObject {

	String toString();

	/**
	 * MotInternalWindow issues NPE is a child window is opened in the battle window.
	 * @return True if this event is processed in the galaxy window.
	 */
	boolean isGalaxyEvent();

	/**
	 * WeaponFireEvents etc only have meaning in the battle window.
	 * @return True if this event is processed in the battle window.
	 */
	boolean isBattleEvent();

}