/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.event;

import mot.common.bean.AnimatedBattleAreaDetails;
import mot.common.vo.BattleStateVO;
import mot.common.vo.BattleVO;

/**
 * Notifies player that a new battle is about to start.
 * At the end of each turn a NewBattleEvent will be generated for each battle that must take
 * place AND has a UserPlayer involved. If more than one battle must be fought at the end of
 * a turn only a single battle will be played at a time -  so NewBattleEvent will be sent out
 * for the first battle but subsequent battles will not have a NewBattleEvent generated until
 * the first battle has completed.
 */
public class NewBattleEvent extends StateUpdateContainerEvent {

    private BattleVO battle;
	private BattleStateVO battleState;
    private AnimatedBattleAreaDetails[] annimatedBattleAreas;

	public NewBattleEvent() {
    }

    public NewBattleEvent(BattleVO battle, BattleStateVO battleState) {
		this.battle = battle;
		this.battleState = battleState;
	}

    public BattleVO getBattle() {
        return battle;
    }

    public void setBattle(BattleVO battle) {
        this.battle = battle;
    }

	public String toString() {
		return "NewBattleEvent battle="+battle+" [" + getStateString() + "]";
	}

	public boolean isGalaxyEvent() {
		return true;
	}

	public boolean isBattleEvent() {
		return true;
	}

	public BattleStateVO getBattleState() {
		return battleState;
	}

	public void setBattleState(BattleStateVO battleState) {
		this.battleState = battleState;
	}

	public AnimatedBattleAreaDetails[] getAnnimatedBattleAreas() {
		return annimatedBattleAreas;
	}

	public void setAnnimatedBattleAreas(AnimatedBattleAreaDetails[] annimatedBattleAreas) {
		this.annimatedBattleAreas = annimatedBattleAreas;
	}


}