/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.event;

import mot.common.bean.NewGameUserPlayerData;


/**
 * Sent by the engine to a client to inform a client that a new UserPlayer has pressed the JOIN button
 * in a multi-player client.
 **/
public class NewGameUserPlayerEvent implements MotEvent {

	private String clientId;
    private NewGameUserPlayerData userData;

    public NewGameUserPlayerEvent(String clientId, NewGameUserPlayerData userData) {
		this.clientId = clientId;
		this.userData = userData;
	}

	public NewGameUserPlayerData getUserData() {
		return userData;
	}

	public void setUserData(NewGameUserPlayerData userData) {
		this.userData = userData;
	}

	public String getRaceName() {
		return userData == null ? null : userData.getRaceName();
	}

    public String toString() {
    	return "NewGameUserPlayerEvent ["+userData+"]";
    }

	@Override
	public boolean isGalaxyEvent() {
		return true;
	}

	@Override
	public boolean isBattleEvent() {
		return false;
	}

	public String getClientId() {
		return clientId;
	}

	public void setClientId(String clientId) {
		this.clientId = clientId;
	}

}