/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.event;

/**
 * Caused when a planet has no work assigned to it.
 * e.g. it has just finished its last task.
 */
public class NoProjectEvent implements MotEvent {
	
	/**
	 * A textual description, suitable for displaying to a user for the reason 
	 * there is no project - This may be null - but is usually a description of 
	 * the project that has just been completed.
	 */
	private String reason;

	/**
	 * This is the planet that has just been colonised.
	 */
	private String planet;

	public NoProjectEvent() {
	}

	public NoProjectEvent(String planet, String reason) {
		this.planet = planet;
		this.reason = reason;
	}
	
	public String toString() {
		return "NoProjectEvent planet="+planet;
	}

	public String getReason() {
		return reason;
	}

	public void setReason(String reason) {
		this.reason = reason;
	}

	public boolean isGalaxyEvent() {
		return true;
	}

	public boolean isBattleEvent() {
		return false;
	}

	public String getPlanet() {
		return planet;
	}

	public void setPlanet(String planet) {
		this.planet = planet;
	}

}