/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.event;

/**
 * Sent to a player when a leader is being offered. For details of how leaders
 * are assigned to players see com.common.leaders.Leader. The user must submit
 * the accept leader command to the engine to accept the leader on offer.
 */
public class OfferLeaderEvent implements MotEvent {

	/**
	 * This is the name of the leader.
	 */
    private String name;

    public OfferLeaderEvent() {
    }
    
	public String toString() {
		return "OfferLeaderEvent name="+name;
	}


    public OfferLeaderEvent(String name) {
        this.name = name;
    }


    public void setLeader(String name) {
        this.name = name;
    }


    public String getLeader() {
        return name;
    }


	public boolean isGalaxyEvent() {
		return true;
	}

	public boolean isBattleEvent() {
		return false;
	}
}