/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.event;

/**
 * Caused when a planet has been bombarded by an enemy player.
 */
public class PlanetBombardedEvent extends StateUpdateContainerEvent {

    /**
     * The name of the planet that was bombed.
     */
    private String target;
    
    /**
     * The quantity of people on the planet destroyed.
     */
    private double populationDestroyed;

    /**
     * The quantity of factories on the planet destroyed.
     */
    private double factoriesDestroyed;

    public PlanetBombardedEvent() {
    }

    public PlanetBombardedEvent(String target, double populationDestroyed, double factoriesDestroyed) {
        this.target = target;
        this.populationDestroyed = populationDestroyed;
        this.factoriesDestroyed = factoriesDestroyed;
    }

	public String toString() {
		return "PlanetBombardedEvent target="+target+" populationDestroyed="+populationDestroyed+" factoriesDestroyed="+factoriesDestroyed+" [" + getStateString() + "]";
	}

    public String getTarget() {
        return target;
    }

    public void setTarget(String target) {
        this.target = target;
    }


    public void setPopulationDestroyed(double populationDestroyed) {
        this.populationDestroyed = populationDestroyed;
    }


    public double getPopulationDestroyed() {
        return populationDestroyed;
    }


    public void setFactoriesDestroyed(double factoriesDestroyed) {
        this.factoriesDestroyed = factoriesDestroyed;
    }


    public double getFactoriesDestroyed() {
        return factoriesDestroyed;
    }
    
	public boolean isGalaxyEvent() {
		return true;
	}

	public boolean isBattleEvent() {
		return false;
	}

}