/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.event;

/**
 * Caused when a craft colonises a new planet.
 * Tells a GUI to open a planet window and a computer player to set a project etc.
 */
public class PlanetColonisedEvent extends StateUpdateContainerEvent {

	/**
	 * This is the planet that has just been colonised.
	 */
	private String planet;

	public PlanetColonisedEvent() {
	}

	public PlanetColonisedEvent(String planet) {
		this.planet = planet;
	}

	public String toString() {
		return "PlanetColonisedEvent planet="+planet+" [" + getStateString() + "]";
	}

    public void setPlanet(String planet) {
        this.planet = planet;
    }


    public String getPlanet() {
        return planet;
    }

	public boolean isGalaxyEvent() {
		return true;
	}

	public boolean isBattleEvent() {
		return false;
	}

}