/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.event;

/**
 * Caused when a craft has invaded a planet during a battle and conquered.
 * This planet now belongs to the same player as the craft that conquered it
 * but it used to belong to oldOwner.
 */
public class PlanetConqueredEvent extends StateUpdateContainerEvent {

    /**
     * The name of the craft that has conquered this planet.
     */
    private String source;
    
    /**
     * The name of the planet that has been conquered.
     */
    private String target;
    
    /**
     * The old owner of this planet
     */
 	private String oldOwner;

    public PlanetConqueredEvent() {
    }

    public PlanetConqueredEvent(String source, String target, String oldOwner) {
        this.source = source;
        this.target = target;
        this.oldOwner = oldOwner;
    }

	public String toString() {
		return "PlanetConqueredEvent source="+source+" target="+target;
	}

    public void setSource(String source) {
        this.source = source;
    }


    public String getSource() {
        return source;
    }


    public void setTarget(String target) {
        this.target = target;
    }


    public String getTarget() {
        return target;
    }


    public void setOldOwner(String oldOwner) {
        this.oldOwner = oldOwner;
    }


    public String getOldOwner() {
        return oldOwner;
    }

	public boolean isGalaxyEvent() {
		return true;
	}

	public boolean isBattleEvent() {
		return false;
	}

}