/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.event;

/**
 * Caused when a craft attempt to invade a planet during a battle.
 */
public class PlanetInvadeEvent extends StateUpdateContainerEvent {

    /**
     * The name of the player that is attacking this planet.
     */
    private String attackerRace;
    
    /**
     * The name of the player owns this planet.
     */
    private String defenderRace;
    
    /**
     * The name of the planet that has been attacked.
     */
    private String target;

    private int qtyAttackers;
    private int qtyDefenders;
    private double attackerAdvantage;
    private int remainingAttackers;
    private int remainingDefenders;
    
    public PlanetInvadeEvent() {
    }

    public PlanetInvadeEvent(String attackerRace, String defenderRace, String target, int qtyAttackers, int qtyDefenders, double attackerAdvantage, int remainingAttackers, int remainingDefenders) {
        this.attackerRace = attackerRace;
        this.defenderRace = defenderRace;
        this.target = target;

        this.qtyAttackers = qtyAttackers;
        this.qtyDefenders = qtyDefenders;
        this.attackerAdvantage = attackerAdvantage;
        this.remainingAttackers = remainingAttackers;
        this.remainingDefenders = remainingDefenders;
    }

	public String toString() {
		return "InvadePlanetEvent target="+target+" remainingAttackers="+remainingAttackers+" remainingDefenders="+remainingDefenders;
	}

    public String getTarget() {
        return target;
    }

    public void setTarget(String target) {
        this.target = target;
    }

    public double getAttackerAdvantage() {
        return attackerAdvantage;
    }

    public void setAttackerAdvantage(double attackerAdvantage) {
        this.attackerAdvantage = attackerAdvantage;
    }

    public int getQtyAttackers() {
        return qtyAttackers;
    }

    public void setQtyAttackers(int qtyAttackers) {
        this.qtyAttackers = qtyAttackers;
    }

    public int getQtyDefenders() {
        return qtyDefenders;
    }

    public void setQtyDefenders(int qtyDefenders) {
        this.qtyDefenders = qtyDefenders;
    }

    public int getRemainingAttackers() {
        return remainingAttackers;
    }

    public void setRemainingAttackers(int remainingAttackers) {
        this.remainingAttackers = remainingAttackers;
    }

    public int getRemainingDefenders() {
        return remainingDefenders;
    }

    public void setRemainingDefenders(int remainingDefenders) {
        this.remainingDefenders = remainingDefenders;
    }

	public String getAttackerRace() {
		return attackerRace;
	}

	public void setAttackerRace(String attackerRace) {
		this.attackerRace = attackerRace;
	}

	public String getDefenderRace() {
		return defenderRace;
	}

	public void setDefenderRace(String defenderRace) {
		this.defenderRace = defenderRace;
	}

	public boolean isGalaxyEvent() {
		return true;
	}

	public boolean isBattleEvent() {
		return false;
	}


}