/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.event;

/**
 * This event is sent to players when another user player has pressed automate in a battle and is waiting for other players to complete.
 * NB Complete a battle only takes effect when all user players complete!
 */
public class PlayersWaitingForBattleAutomateEvent extends UrgentEvent implements BattleEvent {
	
    private String battle;

	public PlayersWaitingForBattleAutomateEvent() {
    }
    
	public PlayersWaitingForBattleAutomateEvent(String battle) {
		this.battle = battle;
	}
	
	public String toString() {
		return "PlayersWaitingForBattleAutomateEvent";
	}
	
	public boolean isGalaxyEvent() {
		return false;
	}

	public boolean isBattleEvent() {
		return true;
	}

	public String getBattle() {
		return battle;
	}

	public void setBattle(String battle) {
		this.battle = battle;
	}

}