/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.event;

/**
 * This event is sent to a player when that player has released a prize. The description contains
 * details of the prize to display to the user. For details on prizes see the class Prize.
 */
public class PrizeGiftEvent extends StateUpdateContainerEvent {


	private String imageConfigName;
    private String description;
	private String techFullName;
	private boolean isPrize;

	public PrizeGiftEvent() {
    }

	public PrizeGiftEvent(boolean isPrize, String imageConfigName, String techName, String description) {
		this.isPrize = isPrize;
		this.techFullName = techName;
        this.description = description;
        this.imageConfigName = imageConfigName;
	}

	public String toString() {
		return "PrizeGiftEvent techName="+techFullName+" imageConfigName="+imageConfigName;
	}

    public void setDescription(String description) {
        this.description = description;
    }


    public String getDescription() {
        return description;
    }

	public String getImageConfigName() {
		return imageConfigName;
	}

	public void setImageConfigName(String imageConfigName) {
		this.imageConfigName = imageConfigName;
	}

	public String getTechFullName() {
		return techFullName;
	}

	public void setTechFullName(String techName) {
		this.techFullName = techName;
	}

	public boolean isGalaxyEvent() {
		return true;
	}

	public boolean isBattleEvent() {
		return false;
	}

	public boolean isPrize() {
		return isPrize;
	}

	public void setPrize(boolean isPrize) {
		this.isPrize = isPrize;
	}


}