/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.event;

import mot.common.util.Comp;

/**
 * Caused when a player refuses to fight a battle. When a player refuses to fight a
 * battle (by retreating all craft or closing the battle window) then all crafts at
 * that stellar object are destroyed owned by this player.
 */
public class RoutedEvent implements MotEvent {

    private String player;
    private String orbit;
	private String [] craftDestroyed;

	public RoutedEvent(String player, String orbit, String [] craftDestroyed) {
		this.player = player;
		this.orbit = orbit;
		this.craftDestroyed = craftDestroyed;
    }

	public RoutedEvent(String player, String orbit) {
        this.player = player;
        this.orbit = orbit;
	}
	
	public String toString() {
		return "RoutedEvent player="+player+" orbit="+orbit;
	}

    public String getPlayer() {
        return player;
    }

    public void setPlayer(String player) {
        this.player = player;
    }

    public String getOrbit() {
        return orbit;
    }

    public void setOrbit(String orbit) {
        this.orbit = orbit;
    }

	public String [] getCraftDestroyed() {
		return craftDestroyed;
	}
	
	public String getCraftDestroyedAsString(String seperator) {
		return Comp.toString(craftDestroyed, seperator);
	}

	public void setCraftDestroyed(String [] craftDestroyed) {
		this.craftDestroyed = craftDestroyed;
	}

	public boolean isGalaxyEvent() {
		return true;
	}

	public boolean isBattleEvent() {
		return false;
	}

}