/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.event;

import mot.common.lang.L;

/**
 * Caused when a player sabotages another players planet.
 */
public class SabotageEvent implements MotEvent {


	/**
	 * This is the planet that has just been sabotaged.
	 */
	private String planet;

    private int qtyProductionSabotaged;
    private int qtyFactoriesSabotaged;
    private int qtyPopulationSabotaged;

    /**
     * The player who performed the sabotage
     */
    private String player;

	public SabotageEvent() {
    }

	public SabotageEvent(String planet, String player, int qtyFactoriesSabotaged, int qtyPopulationSabotaged, int qtyProductionSabotaged) {
		this.planet = planet;
        this.player = player;
		this.qtyFactoriesSabotaged = qtyFactoriesSabotaged;
		this.qtyPopulationSabotaged = qtyPopulationSabotaged;
		this.qtyProductionSabotaged = qtyProductionSabotaged;
	}

	public String toString() {
		return "SabotageEvent player="+player+" planet="+planet;
	}

    public String getPlanet() { return planet; }

    public int getQtyProductionSabotaged() {
        return qtyProductionSabotaged;
    }

    public void setQtyProductionSabotaged(int qtyProductionSabotaged) {
        this.qtyProductionSabotaged = qtyProductionSabotaged;
    }

    public int getQtyFactoriesSabotaged() {
        return qtyFactoriesSabotaged;
    }

    public void setQtyFactoriesSabotaged(int qtyFactoriesSabotaged) {
        this.qtyFactoriesSabotaged = qtyFactoriesSabotaged;
    }

    public int getQtyPopulationSabotaged() {
        return qtyPopulationSabotaged;
    }

    public void setQtyPopulationSabotaged(int qtyPopulationSabotaged) {
        this.qtyPopulationSabotaged = qtyPopulationSabotaged;
    }

    public String getPlayer() {
        return player;
    }

    public void setPlayer(String player) {
        this.player = player;
    }

    public String getDescription(boolean perpetrator) {
        String msg = "";
        if (perpetrator) {
            msg += L.YOU_HAVE;
        } else {
            msg += L.PLAYER_+getPlayer()+L.HAS;
        }
        if (qtyProductionSabotaged > 0) {
            msg += L.SABOTAGED+qtyProductionSabotaged+L._PRODUCTION_;
        }
        if (qtyPopulationSabotaged > 0) {
            msg += L.KILLED+qtyPopulationSabotaged+L.POPULATION2;
        }
        if (qtyFactoriesSabotaged > 0) {
            msg += L.DESTROYED+" "+qtyFactoriesSabotaged+L._FACTORIES_;
        }
        if (qtyProductionSabotaged == 0 && qtyPopulationSabotaged == 0 && qtyFactoriesSabotaged == 0) {
            msg += L.ATTEMPTED_A_SABBOTAGE;
        }
        if (planet != null) {
            msg += L.AT+planet;
        }
        return msg;
    }


    public void setPlanet(String planet) {
        this.planet = planet;
    }

	public boolean isGalaxyEvent() {
		return true;
	}

	public boolean isBattleEvent() {
		return false;
	}

}