/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.event;

import mot.common.technology.Technologies;
import mot.common.technology.Technology;
import mot.common.util.ApplicationError;

/**
 * Caused when a player has stolen a technology from another player.
 * This event is sent to both players.
 */
public class TechnologyStolenEvent extends StateUpdateContainerEvent implements MotEvent {

	/**
	 * This is the technology that has just been discovered.
	 */
	private String tech;

    private String giver;
    private String receiver;

	public TechnologyStolenEvent() {
    }

	public TechnologyStolenEvent(String tech, String receiver, String giver) {
		this.tech = tech;
        this.receiver = receiver;
        this.giver = giver;
	}

	public String toString() {
		return "StealTechnologyEvent receiver="+receiver+" tech="+tech+" [" + getStateString() + "]";
	}

   public Technology getTechnology() throws ApplicationError {
        return Technologies.getTechnology(tech);
    }

    public String getGiver() {
        return giver;
    }

    public void setGiver(String giver) {
        this.giver = giver;
    }

    public String getReceiver() {
        return receiver;
    }

    public void String(String receiver) {
        this.receiver = receiver;
    }

    public void setTech(String tech) {
        this.tech = tech;
    }

    public String getTech() {
        return tech;
    }

	public boolean isGalaxyEvent() {
		return true;
	}

	public boolean isBattleEvent() {
		return false;
	}
	
}