/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.event;

/**
 * Sent at the end of a turn when a trade route is found to be invalid (usually sector between the
 * planets of a trade route is controlled by another player)
 */
public class TradeRouteInvalidEvent implements MotEvent {

	private String solarSystem1;
	private String solarSystem2;

	public TradeRouteInvalidEvent() {
	}

	public TradeRouteInvalidEvent(String planet1, String planet2) {
		this.setSolarSystem1(planet1);
		this.setSolarSystem2(planet2);
	}

	public String getSolarSystem1() {
		return solarSystem1;
	}

	public void setSolarSystem1(String planet1) {
		this.solarSystem1 = planet1;
	}

	public String getSolarSystem2() {
		return solarSystem2;
	}

	public void setSolarSystem2(String planet2) {
		this.solarSystem2 = planet2;
	}

	@Override
	public boolean isGalaxyEvent() {
		return true;
	}

	@Override
	public boolean isBattleEvent() {
		return false;
	}

}
