/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.factory;

import mot.common.bean.CraftGraphics;
import mot.common.bean.GalaxyGraphicsList;
import mot.common.bean.RaceGraphicsList;
import mot.common.technology.Hull;
import mot.common.util.ApplicationError;
import mot.common.xml.DomFactory;
import mot.common.xml.XMLDocumentHandler;

public class GraphicsFactory {

	private static final String RACE_GRAPHICS_FILE = "xml/graphics_race.xml";
	private static final String GALAXY_GRAPHICS_FILE = "xml/graphics_galaxy.xml";
	
	private static RaceGraphicsList graphicsList = null;

	public static synchronized  RaceGraphicsList getRaceGraphicsList() throws ApplicationError {
		if (graphicsList == null) {
			graphicsList = (RaceGraphicsList) XMLDocumentHandler.parseResource(RACE_GRAPHICS_FILE);
		}
		return graphicsList;
	}

	private static GalaxyGraphicsList galaxyGraphicsList = null;

	public static synchronized  GalaxyGraphicsList getGalaxyGraphicsList() throws ApplicationError {
		if (galaxyGraphicsList == null) {
			galaxyGraphicsList = (GalaxyGraphicsList) XMLDocumentHandler.parseResource(GALAXY_GRAPHICS_FILE);
		}
		return galaxyGraphicsList;
	}

	public static void flush() {
		graphicsList = null;
		galaxyGraphicsList = null;
	}


	public static CraftGraphics getStationGraphics(String player, Hull hull) throws ApplicationError {
        RaceGraphicsList graphicsList = GraphicsFactory.getRaceGraphicsList();
        CraftGraphics graphics = graphicsList.getHullGraphics(player, hull.getName());
        if (graphics == null) {
            throw new ApplicationError("Craft.getCraftGraphics() No graphics defined for player="+player+" Hull="+hull.getName());
        }
		return graphics;
	}

	public static void preLoadGalaxyGraphics() throws ApplicationError {
		galaxyGraphicsList = new GalaxyGraphicsList(DomFactory.load(GALAXY_GRAPHICS_FILE));
	}

	public static void preLoadRaceGraphics() throws ApplicationError {
		graphicsList = new RaceGraphicsList(DomFactory.load(RACE_GRAPHICS_FILE));
	}

	public static RaceGraphicsList _createEmptyRaceGraphics() throws ApplicationError {
		graphicsList = new RaceGraphicsList();
		return graphicsList;
	}


}