/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.factory;

import mot.common.bean.PlanetGraphics;
import mot.common.bean.PlanetGraphicsConfig;
import mot.common.bean.PlanetSizeScale;
import mot.common.util.ApplicationError;
import mot.common.xml.XMLDocumentHandler;

public class PlanetGraphicsFactory {

	private static PlanetGraphicsConfig planetGraphicsConfig = null;

	public static synchronized  PlanetGraphicsConfig getPlanetGraphicsConfig() throws ApplicationError {
		if (planetGraphicsConfig == null) {
			planetGraphicsConfig = (PlanetGraphicsConfig) XMLDocumentHandler.parseResource("xml/planet_config.xml");
		}
		return planetGraphicsConfig;
	}
	
    public static PlanetGraphics getPlanetGraphics(double teraforming) throws ApplicationError {
    	getPlanetGraphicsConfig(); 
    	if (planetGraphicsConfig != null) {
			PlanetGraphics[] planetGraphics = planetGraphicsConfig.getPlanetGraphics();
    		for (int i = 0; i < planetGraphics.length; i++) {
				if (teraforming >= planetGraphics[i].getMinTerraform() &&
					teraforming <  planetGraphics[i].getMaxTerraform() ) {
					return planetGraphics[i];
				}
			}
    		return planetGraphics[0];
    	}
    	return null;
    }
    
    public static int getMaxPlanetSize() throws ApplicationError {
    	if (planetGraphicsConfig == null) {
    		getPlanetGraphicsConfig();
    	}
    	if (planetGraphicsConfig != null) {
    		return planetGraphicsConfig.getMaxPlanetSize();
    	} else {
    		return 0;
    	}
    }

    /**
     * @return The percentage of the maximum size this planet consumes on the
     * galaxy map.
     */
    public static double getScale(int planetSize) {
		PlanetSizeScale[] scales = planetGraphicsConfig.getPlanetSizeScales();
		for (int i = 0; i < scales.length; i++) {
			if (planetSize >= scales[i].getMinSize() &&
				planetSize <  scales[i].getMaxSize() ) {
				return scales[i].getScale();
			}
		}
		return 1.0;
    }
    
}
