/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.gifts;

import mot.common.setup.SetupOption;
import mot.common.technology.Technologies;
import mot.common.technology.Technology;
import mot.common.util.ApplicationError;
import mot.common.xml.DomNode;
import mot.common.xml.XMLBean;
import mot.common.xml.XMLWriter;

public class AncientGift extends XMLBean {

	private String giftName;
	
	private String ancientName;
	
	private int round;

	private String description;
	
	private SetupOption option;

	private Technology technology;
	
	public AncientGift() {
	}

	public AncientGift(DomNode node) throws ApplicationError {
		giftName = node.getNodeValueByName_String("gift-name");
		ancientName = node.getNodeValueByName_String("ancient-name");
		round = node.getNodeValueByName_Int("round");
		option = node.getNodeValueByName_SetupOption("option");
		technology = node.getNodeValueByName_Technology("technology");
		description = node.getNodeValueByName_String("description");
	}

	protected String getElementName() {
		return "gift-type";
	}

	protected void encode(XMLWriter writer) throws ApplicationError {
		writer.addElement("gift-name", giftName);
		writer.addElement("ancient-name", ancientName);
		writer.addElement("round", round);
		if (option != null) option.toXML(writer);
		if (technology != null) writer.addElement("technology", technology.getFullName());
		writer.addElement("description", description);
	}

	public String getGiftName() {
		return giftName;
	}

	public void setGiftName(String giftName) {
		this.giftName = giftName;
	}

	public String getName() {
		if (technology != null) {
			return technology.getFullName();
		} else if (option != null) {
			return option.getName();
		}
		return null;
	}

	public String getAncientName() {
		return ancientName;
	}

	public void setAncientName(String ancientName) {
		this.ancientName = ancientName;
	}

	public SetupOption getOption() {
		return option;
	}

	public void setOption(SetupOption option) {
		this.option = option;
	}

	public Technology getTechnology() {
		return technology;
	}

	public void setTechnology(Technology technology) {
		this.technology = technology;
	}

	public void setTechnology(String technologyName) throws ApplicationError {
		this.technology = Technologies.getTechnology(technologyName);
	}

	public String toString() {
		return "ancientName=" + ancientName + " option=" + option + " technology=" + technology;
	}

	public String getDescription() {
		return description;
	}

	public void setDescription(String description) {
		this.description = description;
	}

	public int getRound() {
		return round;
	}

	public void setRound(int round) {
		this.round = round;
	}

}
