/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.gifts;

import java.util.ArrayList;

import mot.common.util.ApplicationError;
import mot.common.util.Comp;
import mot.common.xml.DomNode;
import mot.common.xml.DomTree;

public class AncientGifts  {
	
	private ArrayList<AncientGift> gifts = new ArrayList<AncientGift>();
	
	public AncientGifts() {
	}
	
	public AncientGifts(DomTree doc) throws ApplicationError {
    	DomNode root = doc.getNodeByName("gifts");
		DomNode [] n = root.getNodesByName("gift");
		if (n != null) {
			for (int i = 0; i < n.length; i++) {
				setGift(new AncientGift(n[i]));
			}
		}
	}

	public void setGift(AncientGift gift) {
		gifts.add(gift);
	}
	
	public int getQtyGifts() {
		return gifts.size();
	}
	
	public AncientGift getGiftAt(int index) {
		return gifts.get(index);
	}
	
	public AncientGift [] getGifts(int round, String ancientName) {
		ArrayList candidates = new ArrayList();
		for (AncientGift gift : gifts) {
			if (gift.getRound() == round && Comp.same(gift.getAncientName(), ancientName)) {
				candidates.add(gift);
			}
		}
        return (AncientGift []) candidates.toArray(new AncientGift[candidates.size()]);
	}

	public AncientGift [] getGifts() {
		if (gifts.size() == 0) return null;
        return (AncientGift []) gifts.toArray(new AncientGift[gifts.size()]);
	}

}
