/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.gifts;

import mot.common.util.ApplicationError;
import mot.common.util.Logger;
import mot.common.util.Utils;
import mot.common.xml.DomFactory;
import mot.common.xml.XMLDocumentHandler;

/**
 * This is the set of technologies and setup bonus options that the ancients can give to players
 * that are aligned to them.
 */
public class AncientGiftsFactory {

	private static final String FILE = "xml/ancient_alignment_gifts.xml";
	
	private static AncientGifts ancientGifts = null;
	
    public static synchronized AncientGifts getAncientGifts() throws ApplicationError {
        if (ancientGifts == null) {
        	ancientGifts = (AncientGifts)XMLDocumentHandler.parseResource(FILE);
        	if (ancientGifts == null) throw new ApplicationError("AncientGiftsFactory.getAncientGifts() NONE EXIST");
        }
        return ancientGifts;
    }

    public static synchronized void preLoad() throws ApplicationError {
		ancientGifts = new AncientGifts(DomFactory.load(FILE));
    }

	public static AncientGift selectRandomGift(int round, String ancientName) throws ApplicationError {
		AncientGifts ancientGifts = getAncientGifts();
        if (ancientGifts == null) {
        	Logger.logWarning("AncientGiftsFactory.selectRandomGift() No Gifts"); 
            return null;
        }
        AncientGift[] candidates = ancientGifts.getGifts(round, ancientName);
        if (candidates == null || candidates.length == 0) {
        	Logger.logWarning("AncientGiftsFactory.selectRandomGift() No Gifts for round "+round+" ancient "+ancientName); 
        	return null;
        }
        if (candidates.length == 1) {
        	return candidates[0];
        } else {
        	int i = Utils.random(candidates.length);
        	return candidates[i];
        }
	}

}
