/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.leaders;

import mot.common.util.ApplicationError;
import mot.common.xml.DomNode;
import mot.common.xml.XMLWriter;

public class GeneralDetails extends LeaderDetails {

	/**
	 * Bonus (%) to turning speed of craft in battle.
	 */
	private Double battleTurningBonus;

	/**
	 * Bonus (%) to speed of craft in battle.
	 */
	private Double battleSpeedBonus;

	/**
	 * Bonus (%) to maximum hit points of all crafts owned by this player.
	 */
	private Double maxDamageBonus;

	/**
	 * Bonus (%) to damage produced by all weapons on all crafts owned by this player.
	 */
	private Double damageBonus;

	/**
	 * Bonus (%) to speed of craft on galaxy map (between stellar objects).
	 */
	private Double speedBonus;

	/**
	 * This is the amount of cloak added to all crafts owned by this player. For details on
     * how cloak works see
	 */
	private Integer cloakLevel;

    /**
     * Bonus (%) to the initiative of a craft in battle.
     **/
    public Double initiativeBonus;

    /**
     * Bonuses to ground combat operations.
     */
    private Double assaultBonus;

	/**
	 * Bonus (%) to the amount of maximum charge energy shields can hold during a battle by objects owned by this player.
	 */
	private Double shieldPowerBonus;

    public GeneralDetails() {
    }

	public GeneralDetails(DomNode n) {
		super(n);
		
		battleTurningBonus = n.getNodeValueByName_Double("battle-turning-bonus");
		battleSpeedBonus = n.getNodeValueByName_Double("battle-speed-bonus");
		maxDamageBonus = n.getNodeValueByName_Double("max-damage-bonus");
		damageBonus = n.getNodeValueByName_Double("damage-bonus");
		speedBonus = n.getNodeValueByName_Double("speed-bonus");
		cloakLevel = n.getNodeValueByName_Integer("cloak-level");
		initiativeBonus = n.getNodeValueByName_Double("initiative-bonus");
		assaultBonus = n.getNodeValueByName_Double("assault-bonus");
		shieldPowerBonus = n.getNodeValueByName_Double("shield-power-bonus");
		
	}

	protected void encode(XMLWriter writer) throws ApplicationError {
        super.encode(writer);
		writer.addElement("battle-turning-bonus", battleTurningBonus);
		writer.addElement("battle-speed-bonus", battleSpeedBonus);
		writer.addElement("max-damage-bonus", maxDamageBonus);
		writer.addElement("damage-bonus", damageBonus);
		writer.addElement("speed-bonus", speedBonus);
		writer.addElement("cloak-level", cloakLevel);
		writer.addElement("initiative-bonus", initiativeBonus);
		writer.addElement("assault-bonus", assaultBonus);
		writer.addElement("shield-power-bonus", shieldPowerBonus);
	}

    protected String getElementName() { return "general"; }

    public void setBattleTurningBonus(Double battleTurningBonus) {
        this.battleTurningBonus = battleTurningBonus;
    }


    public Double getBattleTurningBonus() {
        return battleTurningBonus;
    }


    public void setBattleSpeedBonus(Double battleSpeedBonus) {
        this.battleSpeedBonus = battleSpeedBonus;
    }


    public Double getBattleSpeedBonus() {
        return battleSpeedBonus;
    }


    public void setMaxDamageBonus(Double maxDamageBonus) {
        this.maxDamageBonus = maxDamageBonus;
    }


    public Double getMaxDamageBonus() {
        return maxDamageBonus;
    }


    public void setSpeedBonus(Double speedBonus) {
        this.speedBonus = speedBonus;
    }


    public Double getSpeedBonus() {
        return speedBonus;
    }


    public void setCloakLevel(Integer cloakLevel) {
        this.cloakLevel = cloakLevel;
    }


    public Integer getCloakLevel() {
        return cloakLevel;
    }


    public void setInitiativeBonus(Double initiativeBonus) {
        this.initiativeBonus = initiativeBonus;
    }


    public Double getInitiativeBonus() {
        return initiativeBonus;
    }


    public void setAssaultBonus(Double assaultBonus) {
        this.assaultBonus = assaultBonus;
    }


    public Double getAssaultBonus() {
        return assaultBonus;
    }


    public void setDamageBonus(Double damageBonus) {
        this.damageBonus = damageBonus;
    }


    public Double getDamageBonus() {
        return damageBonus;
    }

	public Double getShieldPowerBonus() {
		return shieldPowerBonus;
	}

}