/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.leaders;
import mot.common.util.ApplicationError;
import mot.common.xml.DomNode;
import mot.common.xml.XMLWriter;

public class GovenorDetails extends LeaderDetails {

	/**
	 * Increase in production on planets
	 */
	private Double productionBonus;

	/**
	 * Increase in research
	 */
	private Double researchBonus;

	/**
	 * Increase in developing a planet's factories
	 */
	private Double developmentBonus;

	/**
	 * Increase in population growth
	 */
	private Double reproductionBonus;

	/**
	 * Bonus offered to the qty factory units allowed per population unit.
	 */
	private Double factoryPerPopulationBonus;

	/**
	 * The increase in ecology work performed per turn for this player.
	 */
	private Double ecologyBonus;

    /**
     * The Maximum population bonus for tlayers with this character.
     */
    private Double maxPopulationBonus;

	/**
	 * The Psi rating for this player.
	 */
	private Integer psiRating;

    /**
     * Bonuses to trading this player receives.
     */
    private Double tradingBonus;

    /**
     * Bonus to spying operations.
     */
    private Double spyBonus;

    /**
     * The maximum amount of trade routes this player can support
     */
    private Integer maxTradeRoutes;

    public GovenorDetails() {
    }

	public GovenorDetails(DomNode n) {
		super(n);
		
		productionBonus = n.getNodeValueByName_Double("production-bonus");
		researchBonus = n.getNodeValueByName_Double("research-bonus");
		developmentBonus = n.getNodeValueByName_Double("development-bonus");
		reproductionBonus = n.getNodeValueByName_Double("reproduction-bonus");
		factoryPerPopulationBonus = n.getNodeValueByName_Double("factory-per-population-bonus");
		ecologyBonus = n.getNodeValueByName_Double("ecology-bonus");
		maxPopulationBonus = n.getNodeValueByName_Double("max-population-bonus");
		tradingBonus = n.getNodeValueByName_Double("trading-bonus");
		spyBonus = n.getNodeValueByName_Double("spy-bonus");
		psiRating = n.getNodeValueByName_Integer("psi-rating");
		maxTradeRoutes = n.getNodeValueByName_Integer("max-trade-routes");
	}

	protected void encode(XMLWriter writer) throws ApplicationError  {
        super.encode(writer);
		writer.addElement("productionBonus", productionBonus);
		writer.addElement("researchBonus", researchBonus);
		writer.addElement("developmentBonus", developmentBonus);
		writer.addElement("reproductionBonus", reproductionBonus);
		writer.addElement("factoryPerPopulationBonus", factoryPerPopulationBonus);
		writer.addElement("ecologyBonus", ecologyBonus);
		writer.addElement("maxPopulationBonus", maxPopulationBonus);
		writer.addElement("psiRating", psiRating);
		writer.addElement("tradingBonus", tradingBonus);
		writer.addElement("spyBonus", spyBonus);
		writer.addElement("maxTradeRoutes", maxTradeRoutes);
	}

    protected String getElementName() { return "govenor"; }

    public void setProductionBonus(Double productionBonus) {
        this.productionBonus = productionBonus;
    }


    public Double getProductionBonus() {
        return productionBonus;
    }


    public void setResearchBonus(Double researchBonus) {
        this.researchBonus = researchBonus;
    }


    public Double getResearchBonus() {
        return researchBonus;
    }


    public void setDevelopmentBonus(Double developmentBonus) {
        this.developmentBonus = developmentBonus;
    }


    public Double getDevelopmentBonus() {
        return developmentBonus;
    }


    public void setReproductionBonus(Double reproductionBonus) {
        this.reproductionBonus = reproductionBonus;
    }


    public Double getReproductionBonus() {
        return reproductionBonus;
    }




    public void setFactoryPerPopulationBonus(Double factoryPerPopulationBonus) {
        this.factoryPerPopulationBonus = factoryPerPopulationBonus;
    }


    public Double getFactoryPerPopulationBonus() {
        return factoryPerPopulationBonus;
    }


    public void setEcologyBonus(Double ecologyBonus) {
        this.ecologyBonus = ecologyBonus;
    }


    public Double getEcologyBonus() {
        return ecologyBonus;
    }


    public void setMaxPopulationBonus(Double maxPopulationBonus) {
        this.maxPopulationBonus = maxPopulationBonus;
    }


    public Double getMaxPopulationBonus() {
        return maxPopulationBonus;
    }


    public void setPsiRating(Integer psiRating) {
        this.psiRating = psiRating;
    }


    public Integer getPsiRating() {
        return psiRating;
    }


    public void setTradingBonus(Double tradingBonus) {
        this.tradingBonus = tradingBonus;
    }


    public Double getTradingBonus() {
        return tradingBonus;
    }


    public void setSpyBonus(Double spyBonus) {
        this.spyBonus = spyBonus;
    }


    public Double getSpyBonus() {
        return spyBonus;
    }


    public void setMaxTradeRoutes(Integer maxTradeRoutes) {
        this.maxTradeRoutes = maxTradeRoutes;
    }


    public Integer getMaxTradeRoutes() {
        return maxTradeRoutes;
    }
}