/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.leaders;
import java.util.ArrayList;
import java.util.Iterator;

import mot.common.util.ApplicationError;
import mot.common.util.Comp;
import mot.common.xml.DomFactory;
import mot.common.xml.DomNode;
import mot.common.xml.DomTree;
import mot.common.xml.XMLDocumentHandler;

/**
 * The list of Govenors defined in the game.
 * This is a list of GovenorDetails - each object representing the definition of a 
 * Govenor defined in the game.
 */
public class GovenorDetailsList  {

    private static final String XML_FILE = "xml/leaders_govenor.xml";
	private static final String ROOT_ELEMENT_NAME = "govenors";
    
	private static GovenorDetailsList instance;
    
    public static GovenorDetailsList getInstance() throws ApplicationError {
        if (instance == null) {
            instance = (GovenorDetailsList) XMLDocumentHandler.parseResource(XML_FILE); 
        }
        return instance;
    }
    
    public static void setInstance(GovenorDetails v) {
        instance = new GovenorDetailsList();
        instance.add(v);
    }
    
	public static void preLoad() throws ApplicationError {
		instance = new GovenorDetailsList(DomFactory.load(XML_FILE));
	}
    
	public static void flush() {
		instance = null;
	}

    private ArrayList list;
    private transient GovenorDetails [] array;
    
    public GovenorDetailsList() {
    }
    
    public GovenorDetailsList(GovenorDetailsList other) {
        this(other.getGovenors());
    }
    
    public GovenorDetailsList(GovenorDetails [] others) {
        if (others == null) return;
        list = new ArrayList();
        for (int i=0; i<others.length; i++) {
            list.add(others[i]);
        }
    }

    public GovenorDetailsList(DomTree doc) {
    	DomNode root = doc.getNodeByName(ROOT_ELEMENT_NAME);
    	
    	DomNode[] ga = root.getNodesByName("govenor");
    	if (ga != null) {
    		for (int i = 0; i < ga.length; i++) {
    			add(new GovenorDetails(ga[i]));
			}
    	}
	}

	public void setGovenor(GovenorDetails v) {
        add(v);        
    }

    public void add(GovenorDetails v) {
        if (list == null) list = new ArrayList();
        list.add(v);
        array = null;
    }

    public void remove(String name) {
        if (list == null) return;
        Iterator i = list.iterator(); 
        while (i.hasNext()) {
            GovenorDetails v = (GovenorDetails) i.next();
            if (Comp.same(name, v.getName())) {
                i.remove();
                array = null;
                return;
            }
        }
    }

    public GovenorDetails [] getGovenors() {
        if (array == null && list != null) {
            array = (GovenorDetails []) list.toArray(new GovenorDetails [list.size()]);
        }
        return array;
    }

    public GovenorDetails getGovenorDetails(String name) {
        GovenorDetails [] array = getGovenors();
        if (array == null) {
            return null;
        }
        for (int i=0; i<array.length; i++) {
            if (Comp.same(array[i].getName(), name)) {
                return array[i];
            }
        }
        return null;
    }

}