/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.leaders;

import mot.common.bean.NamedObject;
import mot.common.util.ApplicationError;
import mot.common.xml.DomNode;
import mot.common.xml.XMLWriter;

abstract public class LeaderDetails extends NamedObject {

    /**
     * This is a description of the leaders. This message should be suitable to display 
     * to a user.
     */
    private String description;

    /**
     * This is the name of the picture of this leader. This is a relative path of an JPG file
     * from the root directory of the project.
     */
    private String picture;

    public LeaderDetails() {
    }


    public LeaderDetails(DomNode n) {
    	super(n.getNodeValueByName_String("name"));
    	description = n.getNodeValueByName_String("description");
    	picture = n.getNodeValueByName_String("picture");

	}


	public void setDescription(String description) {
        this.description = description;
    }


    public String getDescription() {
        return description;
    }


    public void setPicture(String picture) {
        this.picture = picture;
    }


    public String getPicture() {
        return picture;
    }

	protected void encode(XMLWriter writer) throws ApplicationError {
        super.encode(writer);
		writer.addElement("description", description);
		writer.addElement("picture", picture);
	}
}