/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.morals;

import mot.common.util.ApplicationError;
import mot.common.xml.DomFactory;
import mot.common.xml.XMLDocumentHandler;

/**
 * Defines the complete set of moral choices on offer in the game.
 */
public class MoralChoices {

	private static final String XML_FILE = "xml/moral_choices.xml";
	private static MoralChoiceList list;

	public static void flush() {
		list = null;
	}

	public static MoralChoiceList getMoralChoices() throws ApplicationError {
		if (list == null) {
			list = (MoralChoiceList)XMLDocumentHandler.parseResource(XML_FILE);

		}
		return list;
	}

	public static MoralChoice getMoralChoice(String name) throws ApplicationError {
		MoralChoiceList list = getMoralChoices();
		if (list == null) {
			throw new ApplicationError("MoralChoices.getMoralChoice() No MoralChoices defined");
		}
		return (MoralChoice)list.get(name);
	}

	public static MoralChoiceList getList() {
		return list;
	}

	public static void setList(MoralChoiceList list) {
		MoralChoices.list = list;
	}
	
	public static void preLoad() throws ApplicationError {
		list = new MoralChoiceList(DomFactory.load(XML_FILE));
	}


}
