/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.proxy;

import mot.common.event.MotEvent;
import mot.common.util.ApplicationError;
import mot.engine.event.MotEventFactory;
import mot.engine.players.Player;

/**
 * Interface through which the engine can send events to its clients. The engine will contain
 * an instance of a ClientProxy for each user. If the game engine wishes to send an event 
 * notification to a client, the proxy notify method should be used.
 * 
 * For local implementations, this would be implemented by directly opening and closing
 * windows. However, a remote implementation would serialise the event to XML, send it to the
 * client and the client would have to deserialise and handle the event.
 **/
public interface ClientProxy {

    /**
     * The engine informs clients of changes (weapons firing, craft destruction etc)
     * by generating events.
     */
	public abstract void notify(MotEvent e) throws ApplicationError;

    /**
     * The engine informs clients of changes (weapons firing, craft destruction etc)
     * by generating events.
     */
	public abstract void notify(MotEventFactory e) throws ApplicationError;

    /**
     * Returns the player that owns this proxy.
     */
	public Player getOwner();
    
}