/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.setup;

import mot.common.util.ApplicationError;
import mot.common.xml.DomFactory;
import mot.common.xml.XMLDocumentHandler;

/**
 * Relics are ancient pieces of technology that provide the player who owns them
 * bonuses. They are added to the players character as a SetupOption - however,
 * unlike race options they cannot be selected at startup. They must be won or
 * discovered during the game.
 */
public class RelicsFactory {

	private static final String XML_FILE = "xml/relics.xml";
	private static SetupOptions relics = null;
	
    public static synchronized SetupOptions getRelics() throws ApplicationError {
        if (relics == null) {
        	relics = (SetupOptions)XMLDocumentHandler.parseResource(XML_FILE, true, "xml/options.xsd");
        	if (relics == null) throw new ApplicationError("RelicaFactory.getRelics() NONE EXIST");
        }
        return relics;
    }

	public static SetupOption getRelic(String relicName) throws ApplicationError {
		return getRelics().getForName(relicName);
	}

	public static void preLoad() throws ApplicationError {
		relics = new SetupOptions(DomFactory.load(XML_FILE));
	}

	public static void setRelics(SetupOptions v) {
		relics = v;
	}
}
