/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.technology;

import mot.common.util.ApplicationError;
import mot.common.util.Comp;
import mot.common.xml.DomNode;
import mot.common.xml.XMLBean;
import mot.common.xml.XMLWriter;

/**
 * The technology that owns this restriction is only available for research who have
 * the same ancient alignment as this restriction. This is used to allocate special 
 * technologies to only be available to races of a specific alignment.
 */
public class AlignmentRestriction extends XMLBean implements Restriction {

    public static final String ELEMENT_NAME = "alignment-restriction";
    
	/**
     * The alignment a player must have to research this technology.
     */
    private String alignment;

    public AlignmentRestriction() {
    }

    public AlignmentRestriction(DomNode node) {
    	alignment = node.getNodeValueByName_String("alignment");
	}

	/**
     * Removes tech from the available list if the available list has technologies that cost 
     * less than minCost to research.
     * @param tech The technology whom this restriction applies.
     * @param available The list of technologies that are available for research to this player.
     * @param player The player who wants to discover a technology from the available list.
     */
    public void apply(Technology tech, TechnologyList list, TechnologyOwner player) {
        if ( !Comp.same(alignment, player.getAlignment()) ) {
            list.remove(tech);
        }
    }

	protected void encode(XMLWriter writer) throws ApplicationError {
		writer.addElement("alignment", alignment);
    }

	protected String getElementName() { return ELEMENT_NAME; }


    public void setAlignment(String alignment) {
        this.alignment = alignment;
    }


    public String getAlignment() {
        return alignment;
    }

}