/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.technology;

import mot.common.util.ApplicationError;
import mot.common.util.NameValuePair;
import mot.common.xml.DomNode;
import mot.common.xml.XMLWriter;

/**
 * One discovered, all the players space stations and battle stations are loaded with missiles at the start of a battle.
 */
public class GalacticLore extends MiscTechnology {

	/**
	 * Zero implies no lore. One implied player knows all planets in the galaxy.
	 */
	private int qtyGalacticLore;


	public GalacticLore() {
	}

	public GalacticLore(DomNode node) {
		super(node);
		
		qtyGalacticLore = node.getNodeValueByName_Int("qty-galactic-lore");
	}

	protected void encode(XMLWriter writer) throws ApplicationError {
		writer.addElement("name", getName());
		writer.addElement("qty-galactic-lore", qtyGalacticLore);
		writer.addElement("description", super.getDescription());
		writer.addElement("image", getImage());
        writer.addElement("cost-to-build", getCostToBuild());
		writer.addElement("cost-to-research", getCostToResearch());
	}

	public NameValuePair[] getAsData() {
		NameValuePair[] r = new NameValuePair[9];
		r[0] = new NameValuePair("name", getName());
		r[1] = new NameValuePair("description", getDescription());
		r[2] = new NameValuePair("image", super.getImage());
		r[3] = new NameValuePair("galactic lore", qtyGalacticLore);
		r[4] = new NameValuePair("space", getSpace());
        r[5] = new NameValuePair("cost to build", getCostToBuild());
		r[6] = new NameValuePair("cost to research", getCostToResearch());
		r[7] = new NameValuePair("maintenance cost", getMaintenanceCost());
		r[8] = new NameValuePair("group", getGroup());
		return r;
	}

	protected String getElementName() { return "galactic-lore"; }

    public String getDescription() {
        String description = super.getDescription();
        if (description != null) {
            return description;
        } else {
       		return "Provides player knowledge of all planets in the solar system";
        }
    }

	public int getQtyGalacticLore() {
		return qtyGalacticLore;
	}

	public void setQtyGalacticLore(int qtyGalacticLore) {
		this.qtyGalacticLore = qtyGalacticLore;
	}



}