/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.technology;

import mot.common.util.ApplicationError;
import mot.common.util.NameValuePair;
import mot.common.xml.DomNode;
import mot.common.xml.XMLWriter;

/**
 * @author Paul Davis
 *
 */
public class Laboratory extends Technology {


	public static final String ELEMENT_NAME = "laboratory";
	

	/**
	 * The research production enjoyed for this laboratory per turn.
	 */
	private int production;
	
	/**
	 * The effect this factory has on our chances to discover the secrets behind 
	 * Salvaged technology.
	 */
	private Double chanceToDiscoverSalvagedTechBonus;

	public Laboratory() {
	}
	
	public Laboratory(DomNode node) {
		super(node);
		production = node.getNodeValueByName_Integer("production");
		chanceToDiscoverSalvagedTechBonus = node.getNodeValueByName_Double("chance-to-discover-salvaged-tech-bonus");
	}
	
	public int getProduction() { return production;	}
	public void setProduction(int v) { production = v;	}


	protected void encode(XMLWriter writer) throws ApplicationError {
		writer.addElement("name", getName());
		writer.addElement("description", getDescription());
		writer.addElement("production", production);
		writer.addElement("chance-to-discover-salvaged-tech-bonus", chanceToDiscoverSalvagedTechBonus);
		writer.addElement("group", getGroup());
        writer.addElement("cost-to-build", getCostToBuild());
		writer.addElement("cost-to-research", getCostToResearch());
	}

	public NameValuePair[] getAsData() {
		NameValuePair[] r = new NameValuePair[9];
		r[0] = new NameValuePair("name", getName());
		r[1] = new NameValuePair("description", getDescription());
		r[2] = new NameValuePair("image", super.getImage());
		r[3] = new NameValuePair("production", production);
		r[4] = new NameValuePair("chance to discover salvaged tech bonus", chanceToDiscoverSalvagedTechBonus);
        r[5] = new NameValuePair("cost to build", getCostToBuild());
		r[6] = new NameValuePair("cost to research", getCostToResearch());
		r[7] = new NameValuePair("maintenance cost", getMaintenanceCost());
		r[8] = new NameValuePair("group", getGroup());
		return r;
	}

	protected String getElementName() { return ELEMENT_NAME; }

    public String getTechType() {
        return Technologies.TECH_TYPE_LABORATORY;
    }
    
	public void setChanceToDiscoverSalvagedTechBonus(Double chanceToDiscoverSalvagedTechBonus) {
		this.chanceToDiscoverSalvagedTechBonus = chanceToDiscoverSalvagedTechBonus;
	}
	
	public Double getChanceToDiscoverSalvagedTechBonus() {
		return chanceToDiscoverSalvagedTechBonus;
	}
}