/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.technology;

import mot.common.util.ApplicationError;
import mot.common.util.NameValuePair;
import mot.common.xml.DomNode;
import mot.common.xml.XMLWriter;

/**
 * 
 * Once a player has discovered this technology all the player's contains a mine field. 
 * Each battle started at the players planets will contain a number of mines laid randomly
 * across the battle field (see MineLayoutManager for details).
 * A Mine in a battle is a stationary battle object with a detonator weapon (See BattleMine).
 * It uses the detonator to explode. See detonator for details of how damage is calculated.
 */
public class MineField extends MiscTechnology {

	/**
	 * This is the distance away from the mine a craft needs to be for the mine to explode.
	 */
	private int range;

	/**
	 * The quantity of mines to place in this mine field.
	 */
	private int qty;

	public MineField() {
	}

	public MineField(DomNode node) {
		super(node);
		
		range = node.getNodeValueByName_Integer("range");
		qty = node.getNodeValueByName_Integer("qty");
	}

	protected void encode(XMLWriter writer) throws ApplicationError {
		writer.addElement("name", getName());
		writer.addElement("range", range);
		writer.addElement("qty", qty);
		writer.addElement("description", super.getDescription());
		writer.addElement("image", getImage());
        writer.addElement("cost-to-build", getCostToBuild());
		writer.addElement("cost-to-research", getCostToResearch());
	}

	public NameValuePair[] getAsData() {
		NameValuePair[] r = new NameValuePair[9];
		r[0] = new NameValuePair("name", getName());
		r[1] = new NameValuePair("description", getDescription());
		r[2] = new NameValuePair("image", super.getImage());
		r[3] = new NameValuePair("qty", qty);
		r[4] = new NameValuePair("range", range);
        r[5] = new NameValuePair("cost to build", getCostToBuild());
		r[6] = new NameValuePair("cost to research", getCostToResearch());
		r[7] = new NameValuePair("maintenance cost", getMaintenanceCost());
		r[8] = new NameValuePair("group", getGroup());
		return r;
	}

	protected String getElementName() { return "mine-field"; }

    public String getDescription() {
        String description = super.getDescription();
        if (description != null) {
            return description;
        } else {
            return "Mine field of "+qty+" mines. The damage each mine produces is proportional to the engine technology discovered by its owner";
        }
    }

	public int getRange() {
		return range;
	}

	public void setRange(int range) {
		this.range = range;
	}

	public int getQty() {
		return qty;
	}

	public void setQty(int qty) {
		this.qty = qty;
	}

}