/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.technology;

import mot.common.util.Comp;
import mot.common.util.Logger;
import mot.common.xml.DomNode;


/** 
 * This is a type of technology that does not fit into any one category.
 * It is a collection of odd ball technologies collected into a single group.
 * 
 * This is really just a base class because there is a separate class for
 * each type of misc technology.
 */
public abstract class MiscTechnology extends Technology {

    public MiscTechnology() {
    }
    
    public MiscTechnology(DomNode node) {
    	super(node);
	}

	public String getTechType() {
        return Technologies.TECH_TYPE_MISC;
    }

	public static MiscTechnology create(DomNode node) {
		if (Comp.same("mine-field", node.getNodeName())) {
			return new MineField(node);
		} else if (Comp.same("news-system", node.getNodeName())) {
			return new NewsSystem(node);
		} else if (Comp.same("asteroid-field-construction", node.getNodeName())) {
			return new AsteroidFieldConstruction(node);
		} else if (Comp.same("planet-construction", node.getNodeName())) {
			return new PlanetConstruction(node);
		} else if (Comp.same("station-missile-base", node.getNodeName())) {
			return new StationMissileBase(node);
		} else if (Comp.same("galactic-lore", node.getNodeName())) {
			return new GalacticLore(node);
		}
		Logger.logWarning("MiscTechnology.create() Unknown MiscTechnology "+node.getNodeName());
		return null;
	}

}