/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.technology;

import mot.common.util.ApplicationError;
import mot.common.util.NameValuePair;
import mot.common.xml.DomNode;
import mot.common.xml.XMLWriter;

/**
 * 
 * News systems allow the government to use propaganda to improve morale.
 * Once a player has discovered this technology all battles containing a battle planet owned
 * by this player will receive a boot to morale.
 * @see mot.engine.battles.BattleObject for details on morale.
 */
public class NewsSystem extends MiscTechnology {

	/**
	 * This is the distance away from the mine a craft needs to be for the mine to explode.
	 */
	private double influence;

	public NewsSystem() {
	}

	public NewsSystem(DomNode node) {
		super(node);
		
		influence = node.getNodeValueByName_Double("influence");
	}

	protected void encode(XMLWriter writer) throws ApplicationError {
		writer.addElement("name", getName());
		writer.addElement("influence", influence);
		writer.addElement("description", super.getDescription());
		writer.addElement("image", getImage());
        writer.addElement("cost-to-build", getCostToBuild());
		writer.addElement("cost-to-research", getCostToResearch());
	}


	public NameValuePair[] getAsData() {
		NameValuePair[] r = new NameValuePair[6];
		r[0] = new NameValuePair("name", getName());
		r[1] = new NameValuePair("description", getDescription());
		r[2] = new NameValuePair("image", super.getImage());
		r[3] = new NameValuePair("influence", influence);
        r[4] = new NameValuePair("cost to build", getCostToBuild());
		r[5] = new NameValuePair("cost to research", getCostToResearch());
		return r;
	}

	protected String getElementName() { return "news-system"; }

    public String getDescription() {
        String description = super.getDescription();
        if (description != null) {
            return description;
        } else {
            return "News System providing influence of "+influence;
        }
    }

	public double getInfluence() {
		return influence;
	}

	public void setInfluence(double influence) {
		this.influence = influence;
	}

}