/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.technology;

import mot.common.util.ApplicationError;
import mot.common.util.NameValuePair;
import mot.common.xml.DomNode;
import mot.common.xml.XMLWriter;

/**
 * Allows the player to build a new planet in a solar system - see ProjectCreatePlanet for details.
 */
public class PlanetConstruction extends MiscTechnology {

	private int planetSize;
	private double planetTerraform;
	private double planetProductionBonus;
	private double planetResearchBonus;
	private double planetReproductionBonus;
	
	private int planetPopulation;
	private int planetQtyFactories;
	
	public PlanetConstruction() {
	}

	public PlanetConstruction(DomNode node) {
		super(node);
		
		planetSize = node.getNodeValueByName_Integer("planet-size");

		planetTerraform = node.getNodeValueByName_Double("planet-terraform");
		planetProductionBonus = node.getNodeValueByName_Double("planet-production-bonus");
		planetResearchBonus = node.getNodeValueByName_Double("planet-research-bonus");
		planetReproductionBonus = node.getNodeValueByName_Double("planet-reproduction-bonus");
}

	protected void encode(XMLWriter writer) throws ApplicationError {
		writer.addElement("name", getName());
		writer.addElement("description", super.getDescription());
		writer.addElement("image", getImage());
        writer.addElement("cost-to-build", getCostToBuild());
		writer.addElement("cost-to-research", getCostToResearch());
		writer.addElement("planet-size", planetSize);
		writer.addElement("planet-terraform", planetTerraform);
		writer.addElement("planet-production-bonus", planetProductionBonus);
		writer.addElement("planet-research-bonus", planetResearchBonus);
		writer.addElement("planet-reproduction-bonus", planetReproductionBonus);
	}

	public NameValuePair[] getAsData() {
		NameValuePair[] r = new NameValuePair[11];
		r[0] = new NameValuePair("name", getName());
		r[1] = new NameValuePair("description", getDescription());
		r[2] = new NameValuePair("image", super.getImage());
		r[3] = new NameValuePair("planet size", planetSize);
		r[4] = new NameValuePair("planet terraform", planetTerraform);
		r[5] = new NameValuePair("planet production bonus", planetProductionBonus);
		r[6] = new NameValuePair("planet research bonus", planetResearchBonus);
		r[7] = new NameValuePair("planet reproduction bonus", planetReproductionBonus);
        r[8] = new NameValuePair("cost to build", getCostToBuild());
		r[9] = new NameValuePair("cost to research", getCostToResearch());
		r[10] = new NameValuePair("group", getGroup());
		return r;
	}

	protected String getElementName() { return "planet-construction"; }

    public String getDescription() {
        String description = super.getDescription();
        if (description != null) {
            return description;
        } else {
            return "Use energy to matter conversion to build new a planet in an existing solar system. This requires 10 boralium crystals per planet created and created a large baren planet ready for terraforming";
        }
    }

	public int getPlanetSize() {
		return planetSize;
	}

	public void setPlanetSize(int planetSize) {
		this.planetSize = planetSize;
	}

	public double getPlanetTerraform() {
		return planetTerraform;
	}

	public void setPlanetTerraform(double planetTerraform) {
		this.planetTerraform = planetTerraform;
	}

	public double getPlanetProductionBonus() {
		return planetProductionBonus;
	}

	public void setPlanetProductionBonus(double planetProductionBonus) {
		this.planetProductionBonus = planetProductionBonus;
	}

	public double getPlanetResearchBonus() {
		return planetResearchBonus;
	}

	public void setPlanetResearchBonus(double planetResearchBonus) {
		this.planetResearchBonus = planetResearchBonus;
	}

	public double getPlanetReproductionBonus() {
		return planetReproductionBonus;
	}

	public void setPlanetReproductionBonus(double planetReproductionBonus) {
		this.planetReproductionBonus = planetReproductionBonus;
	}

	public void setPlanetPopulation(int planetPopulation) {
		this.planetPopulation = planetPopulation;
	}

	public int getPlanetPopulation() {
		return planetPopulation;
	}

	public void setPlanetQtyFactories(int planetQtyFactories) {
		this.planetQtyFactories = planetQtyFactories;
	}

	public int getPlanetQtyFactories() {
		return planetQtyFactories;
	}
}