/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.technology;

import mot.common.util.ApplicationError;

/**
 * This restricts a players ability to research a technology. Typical implementations
 * are:
 *  - You cannot discover a technology until some condition has been satisfied.
 *  - Particular technologies are dependent on a players character.
 */
public interface Restriction {

    /**
     * Applies this restriction to the list of technologies passed in for player player.
     * Note - This method modifies the available technology list passed in - removing any 
     * technologies that do not satisfy the restriction (typically the technology this
     * restriction applies to but it does not have to be).
     * @param tech The technology whom this restriction applies.
     * @param available The list of technologies that are available for research to this player.
     * @param player The player who wants to discover a technology from the available list.
     */
    public abstract void apply(Technology tech, TechnologyList list, TechnologyOwner player) throws ApplicationError;
}