/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.technology;

import java.io.Serializable;

import mot.common.util.ApplicationError;
import mot.common.xml.DomNode;
import mot.common.xml.XMLBean;
import mot.common.xml.XMLWriter;

/**
 * Specials with the shield span value allow a craft to transfer shield 
 * recharges that have not been used to recharge shields on this craft
 * to be transfered to another craft. 
 */
public class ShieldSpan extends XMLBean implements Serializable {

	/**
	 * This is the percentage of unused shield charge that can be transfered to 
	 * another craft 
	 */
	private double spanPercent;
	
	/**
	 * This is the maximum distance a craft has to be for this craft to transfer 
	 * its shield recharge capacity.
	 */
	private int range;

	
	public ShieldSpan() {
	}
	
	public ShieldSpan(double spanPercent, int range) {
		this.spanPercent = spanPercent;
		this.range = range;
	}

	public ShieldSpan(DomNode node) {
		spanPercent = node.getNodeValueByName_Double("span-percent");
		range = node.getNodeValueByName_Int("range");
	}

	@Override
	protected void encode(XMLWriter writer) throws ApplicationError {
		writer.addElement("span-percent", getSpanPercent());
		writer.addElement("range", getRange());
	}

	@Override
	protected String getElementName() {
		return "shield-span";
	}

	public void setSpanPercent(double spanPercent) {
		this.spanPercent = spanPercent;
	}

	public double getSpanPercent() {
		return spanPercent;
	}

	public void setRange(int range) {
		this.range = range;
	}

	public int getRange() {
		return range;
	}

	public String toString() {
		return "Span Percent=" + spanPercent + " Range=" + range;
	}


}
