/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.technology;

/**
 * This class is used to hold a list of technologies that are of the same type.
 * Each technology must belong to the same technology list (e.g. Weapons object).
 * 
 * To save space screen space/user effort weapons are displayed to the user as quantity, type pairs.
 * So a craft can have 100 lasers without a list of 100 lasers!
 */
public class TechnologyBundle  {

    /**
     * The quantity of technologies in this bundle.
     */
    public int qty;
    
    /**
     * The name of this technology (e.g. Laser10).
     */
    public Technology technology;
    
    public TechnologyBundle() {
    }

    public TechnologyBundle(Technology tech) {
        this.technology = tech;
        this.qty = 1;
    }
    
    public TechnologyBundle(Technology tech, int qty) {
        this.technology = tech;
        this.qty = qty;
    }

    public String getName() {
    	if (technology == null) {
    		return null;
    	} else {
    		return technology.getName();
    	}
    }
    
    public String getFullName() {
        return technology.getFullName();
    }
    
    public Technology getTechnology() {
        return technology;
    }
    
    public void setTechnology(Technology v) {
        technology = v;
    }
    
    public int getQty() {
        return qty;
    }

    public void setQty(int v) {
        qty = v;
    }

	public String getFullNameSpaceSeperated() {
		return technology.getFullNameSpaceSeperated();
	}
    
    public String getNameWithQty() {
    	if (qty < 2) {
    		return getName();
    	} else {
    		return getName()+"x"+qty;
    	}
    }
    
    public String toString() {
    	return getName()+"x"+qty;
    }


}