/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.technology;

import mot.common.bean.NamedObject;
import mot.common.util.ApplicationError;
import mot.common.util.BasicNameValueList;
import mot.common.util.NameValuePair;
import mot.common.xml.XMLWriter;

/**
 * Technologies MUST NOT be serialised (e.g. when saving a game).
 * This is because it is creating 'new instances' of a technology.
 * 
 * Classes that serialise a technology must use a technology reference
 * so when the object is re-loaded the same instance of technology is
 * used.
 * 
 * CANT HWVE TWO INSTANCES OF WEAPON MASS DRIVER 1
 *
 */
public class TechnologyReference extends NamedObject {

	private transient Technology tech;
    
    private String type;
    
    public String getType() { return type; }
    public void setType(String v) { type = v; }
    
    public void setFullName(String fullName) throws ApplicationError {
        tech = Technologies.getTechnology(fullName);
        setType(tech.getTechType());
        setName(tech.getName());
    }

	public Technology getTechnology() throws ApplicationError {
		if (tech == null) {
			tech = Technologies.getTechnology(getType(), getName());
		}
		return tech;
	}

	public void setTechnology(Technology v) {
		tech = v;
		setName(tech.getName());
		setType(tech.getTechType());
	}

	public TechnologyReference() {
	}

	public TechnologyReference(Technology tech) {
		super(tech.getName());
		this.type = tech.getTechType();
		this.tech = tech;
	}

	protected void encode(XMLWriter writer) throws ApplicationError {
		// does not have a bean body
	}

    protected BasicNameValueList getAttributes(boolean generateClassAttribute, boolean generateSchemaAttribute) throws ApplicationError {
		if (getTechnology() == null) {
			return null;
		}

		BasicNameValueList params = getAttributesNotNull(generateClassAttribute);
		params.add( new NameValuePair("type", tech.getTechType()) );
		params.add( new NameValuePair("name", tech.getName()) );

		return params;
	}

	protected String getElementName() { return "technology-reference"; }
    protected boolean beanHasBody() { return false; }

}