/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.technology;

import java.util.ArrayList;
import java.util.Iterator;

import mot.common.util.ApplicationError;
import mot.common.xml.XMLBean;
import mot.common.xml.XMLWriter;

/**
 * 
 */
public class TechnologyReferenceList extends XMLBean {

    private ArrayList references;

    public TechnologyReferenceList() {
    }

    public TechnologyReferenceList(TechnologyList tl) {
        add(tl);
    }

    public TechnologyReferenceList(Technology t) {
        add(t);
    }
    
    public TechnologyReference [] getAllAsArray() {
        if (references == null) {
            return null;
        } else {
            return (TechnologyReference[]) references.toArray(new TechnologyReference[references.size()]);
        }
    }

    public void add(TechnologyList tl) {
        if (tl == null) return;
        Technology [] ta = tl.getAllAsArray(true);
        if (ta == null) return;
        for (int i=0; i<ta.length; i++) {
            add(ta[i]);
        }
    }

    public void add(Technology t) {
        if (t == null) return;
        if (references == null) references = new ArrayList();
        references.add( new TechnologyReference(t));
    }

    public void setTechnologyReference(TechnologyReference t) {
        if (references == null) references = new ArrayList();
        references.add( t );
    }

    protected String getElementName() {
        return "technology-reference-list";
    }

    protected void encode(XMLWriter writer) throws ApplicationError {
		if (references != null) {
			Iterator i = references.iterator();
			while (i.hasNext()) {
				TechnologyReference v = (TechnologyReference)i.next();
				v.toXML(writer);
			}
		}
    }
}