/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.technology;

import mot.common.util.ApplicationError;
import mot.common.xml.DomNode;
import mot.common.xml.XMLBean;
import mot.common.xml.XMLWriter;

/**
 * 
 */
public class TechnologyTreeConditionPercentage extends XMLBean implements TechnologyTreeCondition {

	
	private double percentage;
	
	private Technology rootDependency;
	private TechnologyList _dependencies;
	
	public TechnologyTreeConditionPercentage() {
	}
	
	public TechnologyTreeConditionPercentage(Technology root, double p) {
		this.rootDependency = root;
		this.percentage = p;
	}

	public TechnologyTreeConditionPercentage(DomNode pc) throws ApplicationError {
		percentage = pc.getNodeValueByName_Double("percentage");
		rootDependency = pc.getNodeValueByName_Technology("root-dependency");
	}

	public boolean isSatisfied(TechnologyOwner player, TechnologyList exclude) throws ApplicationError {
		if (getRootDependency() == null || getPercentage() < 0.1) return true;
		if (_dependencies == null) {
			TechnologyTree tt = TechnologyTree.getInstance(); 
			_dependencies = tt.getChildren(getRootDependency());
		}
		TechnologyList discovered = player.getTechnologies();
		if (discovered == null) return false;
		int qty = discovered.getQuantityFrom(_dependencies);
		TechnologyList missedTechnologies = player.getMissedTechnologies();
		if (missedTechnologies != null) {
			qty += missedTechnologies.getQuantityFrom(_dependencies);
		}
		if (qty > _dependencies.getQuantity() * getPercentage()) {
			return true;
		} else {			
			return false;
		}
	}

	public double getPercentage() {
		return percentage;
	}

	public void setPercentage(double percentage) {
		this.percentage = percentage;
	}

	public void setPercentage(String percentage) {
		this.percentage = Double.parseDouble(percentage);
	}

	public Technology getRootDependency() {
		return rootDependency;
	}

	public void setRootDependency(String rootDependency) throws ApplicationError {
		this.rootDependency = Technologies.getTechnology(rootDependency);
		_dependencies = null;
	}

	protected String getElementName() {
		return "condition-percentage";
	}

	protected void encode(XMLWriter writer) throws ApplicationError {
		writer.addElement("percentage", percentage);
		if (rootDependency != null) writer.addElement("root-dependency", rootDependency.getFullName());
	}
	
}
