/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.technology;

import java.util.Collection;
import java.util.Iterator;

import mot.common.util.ApplicationError;
import mot.common.util.BasicNameValueList;
import mot.common.util.NameValuePair;
import mot.common.util.UnsortedNameValuePairList;
import mot.common.xml.DomNode;
import mot.common.xml.DomTree;

/**
 * 
 */
public class Theories extends TechnologyList {

	private static final String ELEMENT_NAME = "theories";
	private transient Integer strength;

    public Theories() {

    }

    public Theories(Theories o) throws ApplicationError {
        super(o);
    }

    public Theories(Theory w) {
        add(w);
    }

    public Theories(String [] names) throws ApplicationError {
        if (names != null) {
            for (int i=0; i<names.length; i++) {
                add( Technologies.getTheory(names[i]) );
            }
        }
    }

    public Theories(DomTree doc) {
    	DomNode root = doc.getNodeByName(ELEMENT_NAME);
		DomNode [] n = root.getNodesByName(Theory.ELEMENT_NAME);
		if (n != null) {
			for (int i = 0; i < n.length; i++) {
				setTheory(new Theory(n[i]));
			}
		}
	}

	private transient Theory [] theories = null;

    /**
     * @return The shield in the list
     */
    public Theory [] getTheories() {
        if (theories == null) {
			Collection list = getAll(true);
			if (list == null) return null;
            theories = new Theory[list.size()];
			Iterator i = list.iterator();
            int index = 0;
			while (i.hasNext()) {
                Theory v = (Theory)i.next();
                theories[index++] = v;
			}
		}
        return theories;
	}

    public void setTheory(String v) throws ApplicationError {
        add( Technologies.getTheories().get(v) );
	}

	protected void changed() {
	}

    protected BasicNameValueList getAttributes(boolean generateClassAttribute, boolean generateSchemaAttribute) throws ApplicationError { 
    	if (generateSchemaAttribute) {
    		BasicNameValueList nvl = new UnsortedNameValuePairList();
    		nvl.add( new NameValuePair("xmlns:xsi", "http://www.w3.org/2001/XMLSchema-instance") );
    		nvl.add( new NameValuePair("xsi:noNamespaceSchemaLocation", "xml/tech_theories.xsd") );
    		return nvl;
    	} else {
    		return super.getAttributes(generateClassAttribute, generateSchemaAttribute);
    	}
    }

    protected String getElementName() { return ELEMENT_NAME; }

    public Theory getTheory(String name) {
        return (Theory)super.get(name);
    }

    public void setTheory(Theory v) {
        add(v);
    }

    public Theory getTheoryAtIndex(int index) {
        return (Theory)getTechnologyAtIndex(index);
    }
}