/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.util;
import java.text.DecimalFormat;

import mot.common.technology.ShieldSpan;

/**
 * 
 */
public class Formatter extends Exception {
    static DecimalFormat wholeNumberFormat = new DecimalFormat("######0");
    static DecimalFormat fractionNumberFormat1 = new DecimalFormat("###0");
    static DecimalFormat fractionNumberFormat2 = new DecimalFormat("###0.0");
    static DecimalFormat fractionNumberFormat3 = new DecimalFormat("0.0#");
    static DecimalFormat fractionNumberFormat4 = new DecimalFormat("0.0##");
    static DecimalFormat fractionNumberFormat5 = new DecimalFormat("0.0###");
    static DecimalFormat fractionNumberFormat6 = new DecimalFormat("0.##E0");

    public static String wholeNoUnits(double v) {
		 return wholeNumberFormat.format(v);
	 }

    public static String whole(double v) {
		 if (v > 1000000) {
			 return wholeNumberFormat.format(v/1000000)+"M";
		 } else if (v > 1000) {
			 return wholeNumberFormat.format(v/1000)+"K";
		 } else {
			 return wholeNumberFormat.format(v);
		 }
	 }

    public static String wholeRoundedUp(double v) {
    	return whole(Math.ceil(v));
	 }

    public static String whole(int v) {
		 if (v > 9999999) {
			 return wholeNumberFormat.format(v/1000000)+"M";
		 } else if (v > 9999) {
			 return wholeNumberFormat.format(v/1000)+"K";
		 } else {
			 return wholeNumberFormat.format(v);
		 }
	 }

    public static String whole(long v) {
		 if (v > 9999999) {
			 return wholeNumberFormat.format(v/1000000)+"M";
		 } else if (v > 9999) {
			 return wholeNumberFormat.format(v/1000)+"K";
		 } else {
			 return wholeNumberFormat.format(v);
		 }
	 }

    public static String wholeWithSign(long v) {
         String sign = "+";
         if (v < 0) {
             sign = "-";
             v = -v;
         }
		 if (v > 9999999) {
			 return sign+wholeNumberFormat.format(v/1000000)+"M";
		 } else if (v > 9999) {
			 return sign+wholeNumberFormat.format(v/1000)+"K";
		 } else {
			 return sign+wholeNumberFormat.format(v);
		 }
	 }

    /**
     * 10000000 -> 1M
     * 1000 -> 1K
     * 100 -> 100;
     * 10.0001 -> 10;
     * @param v
     * @return
     */
    public static String fraction(double v) {
        double vp = (v < 0) ? -v : v;
		if (vp > 1000000) {
             return fractionNumberFormat1.format(v/1000000)+"M";
		} else if (vp > 1000) {
             return fractionNumberFormat1.format(v/1000)+"K";
        } else if (vp >= 1) {
             return fractionNumberFormat2.format(v);
        } else if (vp >= 0.1) {
             return fractionNumberFormat3.format(v);
        } else if (vp >= 0.01) {
             return fractionNumberFormat4.format(v);
        } else if (vp >= 0.0001) {
             return fractionNumberFormat5.format(v);
        //} else if (vp >= 0.000001) {
        //     return fractionNumberFormat6.format(v);
        } else {
             return "0";
        }
	 }

    public static String fractionWithSign(double v) {
        if (v >= 0) {
             return "+"+fraction(v);
        } else {
             return fraction(v);
        }
	 }

    /**
     * -0.1 -> -10
     * 0.1 -> 10
     */
    public static String percentLabelNoSymbols(double v) {
        if (v < 0) {
             return "-"+whole(v*100);
        } else {
             return whole(v*100);
        }
	 }

    /**
     * -0.1 -> -10%
     * 0.1 -> 10%
     */
    public static String percentLabelNoSign(double v) {
        if (v < 0) {
             return "-"+whole(v*100)+"%";
        } else {
             return whole(v*100)+"%";
        }
	 }

    /**
     * 2 -> 50%
     * 20 -> 5%
     */
    public static String intToPercentLabelNoSign(int v) {
        if (v < 0) {
             return whole(1.0/(v*100))+"%";
        } else if (v == 0) {
        	return "0%";
        } else {
             return whole(1.0/(v*100))+"%";
        }
	 }


    /**
     * -0.1 -> -10%
     * 0.1 -> +10%
     */
    public static String percentLabel(double v) {
        if (v < 0) {
             return "-"+whole(v*100)+"%";
        } else {
             return "+"+whole(v*100)+"%";
        }
	 }

    /**
     * -0.1 -> -10%
     * 0.1 -> +10%
     */
    public static String changeLabel(double v) {
        if (v > 0) {
            return "+"+whole(1*100);
        }
        if (v < 0) {
            return "-"+whole(v*100);
        }
        return "";
    }

    /**
     * -0.1 -> -10%
     * 0.1 -> +10%
     */
    public static String changeLabel(String prefix, double v) {
        return changeLabel(prefix, prefix, v);
    }
    
    /**
     * -0.1 -> -10%
     * 0.1 -> +10%
     */
    public static String changeLabel(String negPrefix, String posPrefix, double v) {
        if (v > 0) {
            return posPrefix+"+"+whole(v*100)+"%";
        }
        if (v < 0) {
            return negPrefix+whole(v*100)+"%";
        }
        return "";
    }

    public static String roundedToTwoDP(double v) {
    	String sign = (v < 0.0) ? "-" : "+";
    	if (v < 0.0) v = -v;
    	if (v < 1.0) {
    		int r = (int) (v * 100.0);
    		return sign + ((double)r)/100.0;
    	} else if (v >= 1000000){
    		int r = (int) v;
    		return sign + r/1000000 + "M";
    	} else if (v >= 1000){
    		int r = (int) v;
    		return sign + r/1000 + "K";
    	} else {
    		int r = (int) v;
    		return sign + r;
    	}
    }
    
    public static String getDamageDescription(double damage, double damageBlockedByShields) {
		//return Formatter.fraction(damage) + "+" + Formatter.fraction(damageBlockedByShields);
		return Formatter.fraction(damage);
	}

	public static String nnv(ShieldSpan v) {
		if (v == null) {
			return "";
		} else {			
			return v.toString();
		}
	}	

	public static String nnv(Double v) {
		if (v == null) {
			return "";
		} else {			
			return v.toString();
		}
	}	

	public static String nnv(Integer v) {
		if (v == null) {
			return "";
		} else {			
			return v.toString();
		}
	}	

	public static String nnv(Float v) {
		if (v == null) {
			return "";
		} else {			
			return v.toString();
		}
	}

	public static String nnv(Boolean v) {
		if (v == null) {
			return "";
		} else {			
			return v.toString();
		}
	}	

	public static String nnv(int v) { return ""+v; }
	public static String nnv(double v) { return ""+v; }
	public static String nnv(float v) { return ""+v; }
	public static String nnv(boolean v) { return ""+v; }

	/**
	 * Value 5 of length 4 with padding 0 => 0005 
	 */
	public static String fixedSizeCardinal(int v, int length, char c) {
		StringBuffer r = new StringBuffer();
		// log works for all values, but is much slower that this and I do not need other numbers!
		int vl = 1;
		if (v >= 100000000) {
			vl = 9;
		} else if (v >= 10000000) {
			vl = 8;
		} else if (v >= 1000000) {
			vl = 7;
		} else if (v >= 100000) {
			vl = 6;
		} else if (v >= 10000) {
			vl = 5;
		} else if (v >= 1000) {
			vl = 4;
		} else if (v >= 100) {
			vl = 3;
		} else if (v >= 10) {
			vl = 2;
		}
		while (vl < length) {
			r.append(c);
			vl++;
		}
		r.append(v);
		return r.toString();
	}
}

