/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.util;

import java.util.HashMap;
import java.util.Iterator;

import mot.common.xml.XMLBean;
import mot.common.xml.XMLWriter;

/**
 * Generates unique names for crafts, fleets or anything else that requires a unique 
 * name. Each unique name starts with a prefix (like craft or fleet), then every time
 * you get a new name for a prefix, the name will be the prefix followed by a number 
 * one greater than the last name created by the generator.
 */
public class NameGenerator extends XMLBean {

    private HashMap table = new HashMap();

    public NameGenerator() {
    }

	protected void encode(XMLWriter writer) throws ApplicationError {
		Iterator i = table.keySet().iterator();
		while (i.hasNext()) {
			String name = (String) i.next();
			NameGeneratorItem value = (NameGeneratorItem) table.get(name);
			value.toXML(writer);
		}
	}

	protected String getElementName() { return "name-generator"; }

	public String getNextName(String prefix) {
		NameGeneratorItem value = (NameGeneratorItem) table.get(prefix);
		if (value == null) {
			value = new NameGeneratorItem(prefix, 1);
			table.put(prefix, value);
		} else {
			value.setValue( value.getValue()+1 );
		}
		return prefix+value.getValue();
	}

    /**
     * This is used by XMLDocumentHandler to load saved games.
     */
    public void setNameGeneratorItem(NameGeneratorItem v) {
        table.put(v.getName(), v);
    }
}