/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.util;

import mot.common.xml.XMLBean;
import mot.common.xml.XMLWriter;

/**
 * Container for NameGenerator.
 * For a specific prefix, it hold the value of the last value used to generate unique names.
 * */
public class NameGeneratorItem extends XMLBean {

    public NameGeneratorItem() {
    }

    public NameGeneratorItem(String name, int value) {
		this.name = name;
		this.value = value;
    }

    /**
     * The name of this name generator - Usually the prefix to put before every name
     * generated by the name generator.
     */
    private String name;
    
    /**
     * The last value of the names generated for this prefix/name.
     */
    private int value;

    public String getName() { return name; }
    public int getValue() { return value; }

    public void setName(String v) { name = v; }
    public void setValue(int v) { value = v; }

    protected boolean beanHasBody() { return true; }

	protected String getElementName() { return "name-generator-item"; }

	protected void encode(XMLWriter writer) throws ApplicationError {
        writer.addElement("name", name);
        writer.addElement("value", value);
	}
}