/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.util;

import mot.common.bean.NamedObject;
import mot.common.xml.XMLWriter;

/**
 * 
 */
public class NameValuePair extends NamedObject implements java.io.Serializable {
    private String value;

    public String getValue() { return value; }
    public void setValue(String v) { value=v; }

    public int getValueAsInt() { return Integer.parseInt(value); }

    public NameValuePair() {
    }
    
    public NameValuePair(String name, String value) {
        super(name);
        this.value = value;
    }

    public NameValuePair(String name, Integer value) {
        super(name);
        this.value = value == null ? "" : ""+value;
    }

    public NameValuePair(String name, int value) {
        super(name);
        this.value = ""+value;
    }

    public NameValuePair(String name, Double value) {
        super(name);
        this.value = value == null ? "" : ""+value;
    }

    public NameValuePair(String name, double value) {
        super(name);
        this.value = ""+value;
    }

    public NameValuePair(String name, Boolean value) {
        super(name);
        this.value = value == null ? "" : ""+value;
    }

    public NameValuePair(String name, boolean value) {
        super(name);
        this.value = ""+value;
    }

    public String toString() { return "name="+getName()+" value="+value; }

	protected String getElementName() { return "setup-option"; }

	protected void encode(XMLWriter writer) throws ApplicationError {
        super.encode(writer);
        writer.addElement("value", value);
	}
}