/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.util;

/**
 * Use this to report errors that are expected and caused by invalid
 * user requests. They will result in the failure of the request, But
 * no system error will be logged or displayed. Instead the message
 * should be user friendly and will be displayed to the user describing
 * the error that has occurred - you could even tell the user how to fix
 * the problem in the message.
 * The DB will be rolled back.
 */
public class ValidationError extends Exception {
	
	private ValidationErrorSettings settings;
	
    public ValidationError() {
    }
    
    public ValidationError(String m) {
    	super(m);
    }

    public ValidationError(String m, ValidationErrorSettings settings) {
    	super(m);
		this.settings = settings;
    }

	public ValidationErrorSettings getSettings() {
		return settings;
	}

	public void setSettings(ValidationErrorSettings settings) {
		this.settings = settings;
	}
}

