/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.vo;
import mot.common.bean.CraftState;

public class BattleObjectVO extends ImageObjectVO implements BattleValueObject, NamedValueObject {

    private String battle;
    private CraftState state;
    private BattleObjectWeaponStateVO weaponState;
    
    public BattleObjectVO() {
    }
    
    public BattleObjectVO(String name, String battle, CraftState state, BattleObjectWeaponStateVO weaponState) {
        super(name);
        this.battle = battle;
        this.state = state;
		this.weaponState = weaponState;
    }

    public double getDamageAsPercent() {
        return state.getDamagePercent();
    }

    public double getShieldAsPercent() {
        return state.getShieldPercent();
    }

    public double getMovementDamageAsPercent() {
        return state.getMovementDamagePercent();
    }

    public double getPsiDamageAsPercent() {
        return state.getPsiDamagePercent();
    }

    public double getCrewAsPercent() {
        return state.getCrewPercent();
    }

    public boolean isDestroyed() {
        return state.isDestroyed();
    }

    public void setBattle(String battle) {
        this.battle = battle;
    }


    public String getBattle() {
        return battle;
    }

    public void setState(CraftState state) {
        this.state = state;
    }

    public CraftState getState() {
        return state;
    }

	public BattleObjectWeaponStateVO getWeaponState() {
		return weaponState;
	}

	public void setWeaponState(BattleObjectWeaponStateVO weaponState) {
		this.weaponState = weaponState;
	}

	public String getOwner() {
		return state.getOwner();
	}

	public String getController() {
		return state.getController();
	}


	@Override
	public String toString() {
		return "battleObjectVO ["+getName()+"]";
	}

}