/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.vo;


/**
 * When the weapon status of a battle object changes, this event is sent to the clients to
 * update the delegates. It contains information about what weapon are ready to fire or have 
 * already been fired.
 */
public class BattleObjectWeaponStateUpdateVO implements BattleValueObject {

    private String battle;
    private String source;
	private BattleObjectWeaponStateVO state;

	public BattleObjectWeaponStateUpdateVO() {
	}

	public BattleObjectWeaponStateUpdateVO(String battle, String source, BattleObjectWeaponStateVO state) {
        this.battle = battle;
		this.source = source;
		this.state = state;
	}

    public String getSource() {
        return source;
    }

    public void setSource(String source) {
        this.source = source;
    }

	public String toString() {
		return "BattleWeaponStateUpdateVO "+source+" "+(state == null ? "no weapons" : state.toShortString());
	}
 
	public String getBattle() {
		return battle;
	}

	public void setBattle(String battle) {
		this.battle = battle;
	}

	public BattleObjectWeaponStateVO getState() {
		return state;
	}

	public void setState(BattleObjectWeaponStateVO state) {
		this.state = state;
	}

}