/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.vo;

import java.util.Arrays;

import mot.common.designs.CraftDesign;
import mot.common.designs.CraftDesigns;
import mot.common.util.ApplicationError;
import mot.common.util.Comp;

public class CraftDesignsVO implements ValueObject {
	
	private String player;	
	
	/**
	 * List of craft designs this player currently has.
	 */
	private CraftDesignVO[] designs;
	
    /**
     * The name of the last craft that this player has designed.
     */
	private String lastCraftDesigned;

	public CraftDesignsVO() {
	}

	public CraftDesignsVO(String player, CraftDesignVO [] designs, String lastCraftDesigned) {
		this.player = player;
		this.designs = designs;
		this.lastCraftDesigned = lastCraftDesigned;
	}
	
	public CraftDesigns getCraftDesigns() throws ApplicationError {
		if (designs != null && designs.length > 0) {
			CraftDesigns r = new CraftDesigns();
			for (int i = 0; i < designs.length; i++) {
				r.add(new CraftDesign(designs[i]));
			}
			return r;
		} else {
			return null;
		}
	}

	public double getBuildQuality(String name) {
		if (designs == null) return 0.0;
		for (int i = 0; i < designs.length; i++) {
			if (Comp.same(designs[i].getName(), name)) {
				return designs[i].getBuildQuality();
			}
		}
		return 0.0;
	}

	@Override
	public String toString() {
		return "CraftDesignListVO [" + Arrays.toString(designs) + "]";
	}

	public String getLastCraftDesigned() {
		return lastCraftDesigned;
	}

	public void setLastCraftDesigned(String lastCraftDesigned) {
		this.lastCraftDesigned = lastCraftDesigned;
	}

	public String getPlayer() {
		return player;
	}

	public void setPlayer(String player) {
		this.player = player;
	}

	public void update(CraftDesignVO vo) {
		CraftDesignVO cd = (CraftDesignVO) Comp.findIn(vo.getName(), designs);
		if (cd != null) {
			for (int i = 0; i < designs.length; i++) {
				if (designs[i] == cd) {
					designs[i] = cd;
				}
			}
		} else {
			int qty = designs == null ? 0 : designs.length;
			CraftDesignVO [] r = new CraftDesignVO[qty+1]; 
			for (int i = 0; i < qty; i++) {
				r[i] = designs[i];
			}
			r[qty] = vo;
			designs = r;
		}
	}
}
