/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.vo;

import mot.common.bean.Location;
import mot.common.designs.CraftDesign;
import mot.common.technology.Computers;
import mot.common.technology.Engine;
import mot.common.technology.Hull;
import mot.common.technology.Scanners;
import mot.common.technology.Shields;
import mot.common.technology.Specials;
import mot.common.technology.Weapons;
import mot.common.util.ApplicationError;
import mot.common.xml.XMLWriter;

public class CraftVO extends MoveableOwnedObjectVO {

    private String origin;
    private String fleet;
    private int maintenanceCost;
    private CraftDesign design;
	private double damageAsPercent;
	private double buildQualityAsPercent;
	private boolean temporaryCraft;
	private boolean hasMoved;

    public CraftVO() {
    }

    public CraftVO(String name, String owner, Location location, NavigatorVO navigator, OrbitVO orbit, int visibility, int range, boolean sleeping,
    			   String origin, String fleet, CraftDesign design, int maintenanceCost, double damageAsPercent, double buildQualityAsPercent,
    			   boolean temporaryCraft, boolean hasMoved) {
        super(name, owner, location, navigator, orbit, visibility, range, sleeping);
        this.origin = origin;
        this.fleet = fleet;
        this.design = design;
        this.maintenanceCost = maintenanceCost;
		this.damageAsPercent = damageAsPercent;
		this.buildQualityAsPercent = buildQualityAsPercent;
		this.temporaryCraft = temporaryCraft;
		this.hasMoved = hasMoved;
		//Logger.logDebug("XCX  CraftVO() "+name+"@"+location);
    }


    public void setFleet(String fleet) {
        this.fleet = fleet;
    }

    public String getFleet() {
        return fleet;
    }

    public void setMaintenanceCost(int maintenanceCost) {
        this.maintenanceCost = maintenanceCost;
    }


    public int getMaintenanceCost() {
        return maintenanceCost;
    }


    public void setOrigin(String origin) {
        this.origin = origin;
    }


    public String getOrigin() {
        return origin;
    }

	public CraftDesign getDesign() {
		return design;
	}

	public void setDesign(CraftDesign design) {
		this.design = design;
	}

	public void setCraftDesign(CraftDesign design) {
		this.design = design;
	}

	public String getHullName() {
		if (design != null && design.getHull() != null) {
			return design.getHull();
		} else {			
			return null;
		}
	}

	public Hull getHull() throws ApplicationError {
		if (design != null && design.getHull() != null) {
			return design.getHullTech();
		} else {			
			return null;
		}
	}

	public Engine getEngine() throws ApplicationError {
		if (design != null && design.getEngine() != null) {
			return design.getEngineTech();
		} else {			
			return null;
		}
	}

	public Computers getComputers() throws ApplicationError {
		if (design != null && design.getComputers() != null) {
			return design.getComputerTechs();
		} else {			
			return null;
		}
	}

	public Scanners getScanners() throws ApplicationError {
		if (design != null && design.getScanners() != null) {
			return design.getScannerTechs();
		} else {			
			return null;
		}
	}

	public Shields getShields() throws ApplicationError {
		if (design != null && design.getShields() != null) {
			return design.getShieldTechs();
		} else {			
			return null;
		}
	}

	public Weapons getWeapons() throws ApplicationError {
		if (design != null && design.getWeapons() != null) {
			return design.getWeaponTechs();
		} else {			
			return null;
		}
	}

	public Specials getSpecials() throws ApplicationError {
		if (design != null && design.getSpecials() != null) {
			return design.getSpecialTechs();
		} else {			
			return null;
		}
	}

	public double getDamageAsPercent() {
		return damageAsPercent;
	}

	public void setDamageAsPercent(double damageAsPercent) {
		this.damageAsPercent = damageAsPercent;
	}

	public double getBuildQualityAsPercent() {
		return buildQualityAsPercent;
	}

	public void setBuildQualityAsPercent(double buildQualityAsPercent) {
		this.buildQualityAsPercent = buildQualityAsPercent;
	}

	@Override
	public String toString() {
		return "CraftVO ["+getName()+"]";
	}

	public boolean isTemporaryCraft() {
		return temporaryCraft;
	}

	public void setTemporaryCraft(boolean temporaryCraft) {
		this.temporaryCraft = temporaryCraft;
	}
	
	protected void encode(XMLWriter writer) throws ApplicationError {
		super.encode(writer);
		writer.addElement("origin", origin);
		writer.addElement("fleet", fleet);
		writer.addElement("maintenanceCost", maintenanceCost);
		if (design != null) design.toXML(writer);
		writer.addElement("damageAsPercent", damageAsPercent);
		writer.addElement("buildQualityAsPercent", buildQualityAsPercent);
		writer.addElement("temporaryCraft", temporaryCraft);
		writer.addElement("has-moved", hasMoved);
	}

	public boolean isHasMoved() {
		return hasMoved;
	}

	public void setHasMoved(boolean hasMoved) {
		this.hasMoved = hasMoved;
	}

}