/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.vo;

import mot.client.deligates.UserPlayerDelegate;
import mot.common.bean.DatedMessage;
import mot.common.bean.DiplomaticHistory;
import mot.common.bean.DiplomaticHistoryEvent;
import mot.common.util.ApplicationError;
import mot.common.util.Comp;

/**
 * The diplomatic history between two players.
 *
 */
public class DiplomaticHistoryVO implements ValueObject {

	/**
	 * A Player One for who this is the history between.
	 */
	private String player1;

	/**
	 * A Player Two for who this is the history between.
	 */
	private String player2;
	
	/**
	 * The diplomatic history between the player this information is being sent to and the player named in this bean.
	 */
	private DiplomaticHistory history;
	
	public DiplomaticHistoryVO() {
	}
	
	public DiplomaticHistoryVO(DiplomaticHistory history, String player1, String player2) {
		this.history = history;
		this.player1 = player1;
		this.player2 = player2;
	}
	
	public int getQuantityOfEvents() {
		if (history == null) return 0;
		return history.getQuantityOfEvents();
	}

	public String getPlayer1() {
		return player1;
	}

	public void setPlayer1(String player1) {
		this.player1 = player1;
	}

	public String getPlayer2() {
		return player2;
	}

	public void setPlayer2(String player2) {
		this.player2 = player2;
	}

	public DiplomaticHistoryEvent [] getHistoryEvents() {
		if (history == null) {
			return null;
		} else {
			return history.getEvents();
		}
	}

	public DiplomaticHistory getHistory() {
		return history;
	}

	public void setHistory(DiplomaticHistory history) {
		this.history = history;
	}

	public boolean containsPlayer(String name) {
		if (name == null) return false;
		return Comp.same(name, player1) || Comp.same(name, player2);
	}

	public boolean containsPlayers(String name1, String name2) {
		if (name1 == null) return false;
		if (name2 == null) return false;
		return Comp.same(name1, player1) && Comp.same(name2, player2) ||
				Comp.same(name1, player2) && Comp.same(name2, player1);
	}

	public String getPlayerOther(UserPlayerDelegate owner) {
		if (owner == null) return null;
		if (Comp.same(owner.getName(), player1)) {
			return player2;
		} else {
			return player1;
		}
			
	}

	public DatedMessage[] getOneLineSummaries() throws ApplicationError {
		if (history == null) return null;
		return history.getOneLineSummaries(player1, player2);
	}

}
