/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.vo;

import mot.common.bean.Location;
import mot.common.bean.NamedObject;
import mot.common.util.ApplicationError;
import mot.common.xml.XMLWriter;

public class MoveableOwnedObjectVO extends NamedObject implements NamedValueObject {

    private Location location;
    private String owner;
    private NavigatorVO navigator;
    private OrbitVO orbit;
    private int visibility;
	private int range;
	private boolean sleeping = false;

    public MoveableOwnedObjectVO() {
    }

    public MoveableOwnedObjectVO(String name, String owner, Location location, NavigatorVO navigator, OrbitVO orbit, int visibility, int range, boolean sleeping) {
        super(name);
        this.location = location;
        this.owner = owner;
        this.navigator = navigator;
        this.orbit = orbit;
        this.visibility = visibility;
		this.range = range;
		this.sleeping = sleeping;
    }

    public void setLocation(Location location) {
        this.location = location;
    }


    public Location getLocation() {
        return location;
    }


    public void setOwner(String owner) {
        this.owner = owner;
    }


    public String getOwner() {
        return owner;
    }


    public void setNavigator(NavigatorVO navigator) {
        this.navigator = navigator;
    }


    public NavigatorVO getNavigator() {
        return navigator;
    }

    protected String getElementName() { return "moveable-owned-object"; }

	public int getVisibility() {
		return visibility;
	}

	public void setVisibility(int visibility) {
		this.visibility = visibility;
	}

	public OrbitVO getOrbit() {
		return orbit;
	}

	public void setOrbit(OrbitVO orbit) {
		this.orbit = orbit;
	}

	public int getRange() {
		return range;
	}

	public void setRange(int range) {
		this.range = range;
	}
	
	protected void encode(XMLWriter writer) throws ApplicationError {
		super.encode(writer);
		if (location != null) location.toXML(writer);
		writer.addElement("owner", owner);
		if (navigator != null) navigator.toXML(writer);
		if (orbit != null) orbit.toXML(writer);
		writer.addElement("visibility", visibility);
		writer.addElement("range", range);
		if (sleeping) writer.addElement("sleeping", sleeping);
	}

	public boolean isSleeping() {
		return sleeping;
	}

	public void setSleeping(boolean sleeping) {
		this.sleeping = sleeping;
	}

}