/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.vo;

import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.Logger;
import mot.common.xml.XMLBean;
import mot.common.xml.XMLWriter;

public class NavigatorVO extends XMLBean implements ValueObject {

    private OrbitVO destination;
    private int eta;

    public NavigatorVO() {
    }

	public NavigatorVO(OrbitVO destination, int eta) {
		this.destination = destination;
		this.eta = eta;
	}

	public OrbitVO getDestination() {
		return destination;
	}

	public void setDestination(OrbitVO destination) {
		this.destination = destination;
	}

	public int getEta() {
		return eta;
	}

	public void setEta(int eta) {
		this.eta = eta;
	}

	public String getDescription() throws ApplicationError {
		OrbitVO destination = getDestination();
		String name = destination.getPlanet() == null ? destination.getStellarObject() : destination.getPlanet(); 
		return L.HEADING_TO_+ name + " [ETA " + getEta()+"]";
	}
	@Override
	public String toString() {
		try {
			return "CraftVO ["+getDescription()+"]";
		} catch (ApplicationError e) {
			Logger.logError("", e);
		}
		return "CraftVO";
	}

	protected void encode(XMLWriter writer) throws ApplicationError {
		if (destination != null) destination.toXML(writer);
		writer.addElement("eta", eta);
	}

	protected String getElementName() {
		return "navigator";
	}
}