/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.vo;

import mot.common.util.ApplicationError;
import mot.common.util.Comp;
import mot.common.xml.XMLBean;
import mot.common.xml.XMLWriter;

public class OrbitVO extends XMLBean implements ValueObject {
	
	private String stellarObject;
	private String planet;

	public OrbitVO() {
	}
	
	public OrbitVO(String stellarObject, String planet) {
		this.stellarObject = stellarObject;
		this.planet = planet;
	}
	public String getPlanet() {
		return planet;
	}
	public void setPlanet(String planet) {
		this.planet = planet;
	}
	public String getStellarObject() {
		return stellarObject;
	}
	public void setStellarObject(String stellarObject) {
		this.stellarObject = stellarObject;
	}

	/**
	 * @return The name of the planet if a planet exists 
	 * otherwise the name of the stellar object.
	 */
	public String getName() {
		if (planet != null) {
			return planet;
		} else {
			return stellarObject;
		}
	}
	
	/**
	 * @return The description of an orbit is the name of the stellar object 
	 * and the name of the planet within that stellar object is a planet exists.
	 */
	public String getDescription() {
		if (planet != null) {
			return stellarObject + " ["+planet + "]";
		} else {
			return stellarObject;
		}
	}

	public boolean equals(OrbitVO o) {
		if (this == o) return true;
		if (o == null) return false;
		if (planet != null || o.getPlanet() != null) return Comp.same(planet, o.getPlanet());
		return Comp.same(stellarObject, o.getStellarObject());
	}

	@Override
	public String toString() {
		return "OrbitVO ["+getDescription()+"]";
	}

	protected void encode(XMLWriter writer) throws ApplicationError {
		writer.addElement("stellarObject", stellarObject);
		writer.addElement("planet", planet);
	}

	protected String getElementName() {
		return "orbit";
	}

}
