/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.vo;

import mot.common.bean.NamedObject;
import mot.common.designs.Orbital;
import mot.common.designs.ProjectDesign;

public class PlanetVO extends NamedObject implements NamedValueObject {

    private String owner;
    private String origin;
    private String solarSystem;
    
    private int size;
    private int moneyBonus;
    private double maxPopulation;
    private double minimumEcologyOutput;
    private double productionBonus;
    private double reproductionBonus;
    private double researchBonus;

    private double population;
    private double qtyFactories;
    private double teraforming;
    private int qtyColonistsOnrouteTo;
    private int colonistsEtaOnrouteTo;
    private int qtyGroundDefense;
    private int influence;
    
    private String moneyBonusName;
    
    private double percentDevelopment;
    private double percentEcology;
    private double percentProduction;
    private double percentResearch;

    private boolean autoDevelopment;
    private boolean autoEcology;
    private boolean varyProduction;
    private boolean varyResearch;
    
    private double factoriesGrowth;
    private double populationGrowth;
    
    private int production;
    private double ecologyOutput;
    private int productionOutput;
    private int researchOutput;
    private double developmentOutput;
    private double teraformingGrowth;
    
    private int moneyOutput;
    private int moneyWasted;
    
    private int lostProductionOutput;
    private int lostResearchOutput;
    
    private double minimumEcologyPercent;
    
    private boolean blockaded;
    private boolean dominated;
    
    private String [] scanners;
    private String [] shields;
    private String [] weapons;
    private Orbital orbital;
    
    private boolean notifiedFactoriesComplete;
    private boolean notifiedTerraformComplete;
    private boolean ownerWantsNoProject;
    private boolean hasAsteroids;

    /**
     * This is the name of a planet containing an orbital which is a mine for this planet.
     */
    private String miningColony;
    
    private int repeatProject;
    
    private PlanetProjectVO project;
    
    private String resource;

    private int miningPopulation;

    private boolean hasNatives;
    
    private boolean isViewable;
    
    private PlanetCrisisVO crisis;

    public PlanetVO() {
    }


    public void setOwner(String owner) {
        this.owner = owner;
    }


    public String getOwner() {
        return owner;
    }


    public void setSolarSystem(String solarSystem) {
        this.solarSystem = solarSystem;
    }


    public String getSolarSystem() {
        return solarSystem;
    }


    public void setSize(int size) {
        this.size = size;
    }


    public int getSize() {
        return size;
    }


    public void setMoneyBonus(int moneyBonus) {
        this.moneyBonus = moneyBonus;
    }


    public int getMoneyBonus() {
        return moneyBonus;
    }


    public void setMaxPopulation(double maxPopulation) {
        this.maxPopulation = maxPopulation;
    }


    public double getMaxPopulation() {
        return maxPopulation;
    }


    public void setMinimumEcologyOutput(double minimumEcologyOutput) {
        this.minimumEcologyOutput = minimumEcologyOutput;
    }


    public double getMinimumEcologyOutput() {
        return minimumEcologyOutput;
    }


    public void setProductionBonus(double productionBonus) {
        this.productionBonus = productionBonus;
    }


    public double getProductionBonus() {
        return productionBonus;
    }


    public void setReproductionBonus(double reproductionBonus) {
        this.reproductionBonus = reproductionBonus;
    }


    public double getReproductionBonus() {
        return reproductionBonus;
    }


    public void setResearchBonus(double researchBonus) {
        this.researchBonus = researchBonus;
    }


    public double getResearchBonus() {
        return researchBonus;
    }


    public void setPopulation(double population) {
        this.population = population;
    }


    public double getPopulation() {
        return population;
    }


    public void setQtyFactories(double qtyFactories) {
        this.qtyFactories = qtyFactories;
    }


    public double getQtyFactories() {
        return qtyFactories;
    }


    public void setTeraforming(double teraforming) {
        this.teraforming = teraforming;
    }


    public double getTeraforming() {
        return teraforming;
    }


    public void setQtyColonistsOnrouteTo(int qtyColonistsOnrouteTo) {
        this.qtyColonistsOnrouteTo = qtyColonistsOnrouteTo;
    }


    public int getQtyColonistsOnrouteTo() {
        return qtyColonistsOnrouteTo;
    }


    public void setQtyGroundDefense(int qtyGroundDefense) {
        this.qtyGroundDefense = qtyGroundDefense;
    }


    public int getQtyGroundDefense() {
        return qtyGroundDefense;
    }


    public void setMoneyBonusName(String moneyBonusName) {
        this.moneyBonusName = moneyBonusName;
    }


    public String getMoneyBonusName() {
        return moneyBonusName;
    }


    public void setPercentDevelopment(double percentDevelopment) {
        this.percentDevelopment = percentDevelopment;
    }


    public double getPercentDevelopment() {
        return percentDevelopment;
    }


    public void setPercentEcology(double percentEcology) {
        this.percentEcology = percentEcology;
    }


    public double getPercentEcology() {
        return percentEcology;
    }


    public void setPercentProduction(double percentProduction) {
        this.percentProduction = percentProduction;
    }


    public double getPercentProduction() {
        return percentProduction;
    }


    public void setPercentResearch(double percentResearch) {
        this.percentResearch = percentResearch;
    }

    public double getPercentResearch() {
        return percentResearch;
    }

    public void setAutoDevelopment(boolean autoDevelopment) {
        this.autoDevelopment = autoDevelopment;
    }

    public boolean isAutoDevelopment() {
        return autoDevelopment;
    }

    public boolean getAutoDevelopment() {
        return autoDevelopment;
    }

    public void setAutoEcology(boolean autoEcology) {
        this.autoEcology = autoEcology;
    }

    public boolean isAutoEcology() {
        return autoEcology;
    }

    public boolean getAutoEcology() {
        return autoEcology;
    }


    public void setFactoriesGrowth(double factoriesGrowth) {
        this.factoriesGrowth = factoriesGrowth;
    }


    public double getFactoriesGrowth() {
        return factoriesGrowth;
    }


    public void setPopulationGrowth(double populationGrowth) {
        this.populationGrowth = populationGrowth;
    }


    public double getPopulationGrowth() {
        return populationGrowth;
    }


    public void setProduction(int production) {
        this.production = production;
    }


    public int getProduction() {
        return production;
    }


    public void setEcologyOutput(double ecologyOutput) {
        this.ecologyOutput = ecologyOutput;
    }


    public double getEcologyOutput() {
        return ecologyOutput;
    }


    public void setProductionOutput(int productionOutput) {
        this.productionOutput = productionOutput;
    }


    public int getProductionOutput() {
        return productionOutput;
    }


    public void setResearchOutput(int researchOutput) {
        this.researchOutput = researchOutput;
    }


    public int getResearchOutput() {
        return researchOutput;
    }


    public void setDevelopmentOutput(double developmentOutput) {
        this.developmentOutput = developmentOutput;
    }


    public double getDevelopmentOutput() {
        return developmentOutput;
    }


    public void setTeraformingGrowth(double teraformingGrowth) {
        this.teraformingGrowth = teraformingGrowth;
    }


    public double getTeraformingGrowth() {
        return teraformingGrowth;
    }


    public void setMinimumEcologyPercent(double minimumEcologyPercent) {
        this.minimumEcologyPercent = minimumEcologyPercent;
    }


    public double getMinimumEcologyPercent() {
        return minimumEcologyPercent;
    }


    public void setScanners(String[] scanners) {
        this.scanners = scanners;
    }


    public String[] getScanners() {
        return scanners;
    }


    public void setShields(String[] shields) {
        this.shields = shields;
    }


    public String[] getShields() {
        return shields;
    }


    public void setWeapons(String[] weapons) {
        this.weapons = weapons;
    }


    public String[] getWeapons() {
        return weapons;
    }


    public void setColonistsEtaOnrouteTo(int colonistsEtaOnrouteTo) {
        this.colonistsEtaOnrouteTo = colonistsEtaOnrouteTo;
    }


    public int getColonistsEtaOnrouteTo() {
        return colonistsEtaOnrouteTo;
    }


    public void setMoneyOutput(int moneyOutput) {
        this.moneyOutput = moneyOutput;
    }


    public int getMoneyOutput() {
        return moneyOutput;
    }


    public void setNotifiedFactoriesComplete(boolean notifiedFactoriesComplete) {
        this.notifiedFactoriesComplete = notifiedFactoriesComplete;
    }


    public boolean isNotifiedFactoriesComplete() {
        return notifiedFactoriesComplete;
    }

    public boolean getNotifiedFactoriesComplete() {
        return notifiedFactoriesComplete;
    }


    public void setNotifiedTerraformComplete(boolean notifiedTerraformComplete) {
        this.notifiedTerraformComplete = notifiedTerraformComplete;
    }


    public boolean isNotifiedTerraformComplete() {
        return notifiedTerraformComplete;
    }

    public boolean getNotifiedTerraformComplete() {
        return notifiedTerraformComplete;
    }

    public void setOwnerWantsNoProject(boolean ownerWantsNoProject) {
        this.ownerWantsNoProject = ownerWantsNoProject;
    }


    public boolean isOwnerWantsNoProject() {
        return ownerWantsNoProject;
    }
    
    public boolean getOwnerWantsNoProject() {
        return ownerWantsNoProject;
    }

    public void setRepeatProject(int repeatProject) {
        this.repeatProject = repeatProject;
    }


    public int getRepeatProject() {
        return repeatProject;
    }


    public void setProject(PlanetProjectVO project) {
        this.project = project;
    }


    public PlanetProjectVO getProject() {
        return project;
    }

    public ProjectDesign getProjectDesign() {
        if (project != null) {
            return project.getDesign();
        } else {
            return null;
        }
    }

    public long getCostToPurchaseProject() {
        if (project != null) {
            return project.getCostToPurchase();
        } else {
            return -1;
        }
    }
    
    


    public void setBlockaded(boolean blockaded) {
        this.blockaded = blockaded;
    }


    public boolean isBlockaded() {
        return blockaded;
    }


    protected String getElementName() { return "planetvo"; }


    public void setOrbital(Orbital orbital) {
        this.orbital = orbital;
    }


    public Orbital getOrbital() {
        return orbital;
    }


    public void setMiningColony(String miningStation) {
        this.miningColony = miningStation;
    }


    public String getMiningColony() {
        return miningColony;
    }


    public void setResource(String resource) {
        this.resource = resource;
    }


    public String getResource() {
        return resource;
    }

    public void setMiningPopulation(int miningPopulation) {
        this.miningPopulation = miningPopulation;
    }


    public int getMiningPopulation() {
        return miningPopulation;
    }


 

    public void setOrigin(String origin) {
        this.origin = origin;
    }


    public String getOrigin() {
        return origin;
    }

	public int getInfluence() {
		return influence;
	}


	public void setInfluence(int influence) {
		this.influence = influence;
	}


	public boolean hasAsteroids() {
		return hasAsteroids;
	}


	public void setHasAsteroids(boolean hasAsteroids) {
		this.hasAsteroids = hasAsteroids;
	}


	public boolean hasNatives() {
		return hasNatives;
	}

	public void setHasNatives(boolean hasNatives) {
		this.hasNatives = hasNatives;
	}

	public boolean isViewable() {
		return isViewable;
	}


	public void setViewable(boolean isViewable) {
		this.isViewable = isViewable;
	}

	@Override
	public String toString() {
		return "PlanetVO ["+getName()+"]";
	}

	public PlanetCrisisVO getCrisis() {
		return crisis;
	}

	public void setCrisis(PlanetCrisisVO crisis) {
		this.crisis = crisis;
	}

	public int getLostProductionOutput() {
		return lostProductionOutput;
	}

	public void setLostProductionOutput(int lostProductionOutput) {
		this.lostProductionOutput = lostProductionOutput;
	}

	public int getLostResearchOutput() {
		return lostResearchOutput;
	}

	public void setLostResearchOutput(int lostResearchOutput) {
		this.lostResearchOutput = lostResearchOutput;
	}

	public boolean isDominated() {
		return dominated;
	}

	public void setDominated(boolean dominated) {
		this.dominated = dominated;
	}

	public int getMoneyWasted() {
		return moneyWasted;
	}

	public void setMoneyWasted(int moneyWasted) {
		this.moneyWasted = moneyWasted;
	}

	public boolean isVaryProduction() {
		return varyProduction;
	}

	public boolean getVaryProduction() {
		return varyProduction;
	}

	public void setVaryProduction(boolean varyProduction) {
		this.varyProduction = varyProduction;
	}

	public boolean isVaryResearch() {
		return varyResearch;
	}

	public boolean getVaryResearch() {
		return varyResearch;
	}

	public void setVaryResearch(boolean varyResearch) {
		this.varyResearch = varyResearch;
	}


}