/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.vo;

import mot.common.bean.PlayerCharacterBasic;
import mot.common.bean.PlayerColor;
import mot.common.util.ApplicationError;

public class PlayerConstantsVO implements NamedValueObject {
	
	private String name;
    private String alignment;
    private String color;
	private PlayerCharacterBasic playerCharacter;

	/**
	 * The percentage more or less planet defence maintenance costs in this galaxy
	 * NOTE - Easy games have lower maintenance costs.
	 */
	private double planetMaintenanceFactor;

    public PlayerConstantsVO() {
    }

    public PlayerConstantsVO(String name, PlayerColor color, String alignment, PlayerCharacterBasic playerCharacter, double planetMaintenanceFactor) {
    	this.name = name;
    	this.color = color == null ? null : color.getName();
        this.alignment = alignment;
        this.playerCharacter = playerCharacter;
		this.planetMaintenanceFactor = planetMaintenanceFactor;
    }

	public String toString() {
		return "PlayerConstantsVO ["+name+"]";
	}

    public String getAlignment() {
        return alignment;
    }

    public void setAlignment(String alignment) {
        this.alignment = alignment;
    }

    public String getColor() {
        return color;
    }

    public void setColor(String color) {
        this.color = color;
    }

    public PlayerColor getPlayerColor() throws ApplicationError {
    	if (color == null) {
    		return null;
    	} else {
    		return PlayerColor.getColorForName(color);
    	}
    }
    
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

	public PlayerCharacterBasic getPlayerCharacter() {
		return playerCharacter;
	}

	public void setPlayerCharacter(PlayerCharacterBasic playerCharacter) {
		this.playerCharacter = playerCharacter;
	}

	public double getPlanetMaintenanceFactor() {
		return planetMaintenanceFactor;
	}

	public void setPlanetMaintenanceFactor(double planetMaintenanceFactor) {
		this.planetMaintenanceFactor = planetMaintenanceFactor;
	}

}