/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.vo;

import mot.common.technology.Biotechnologies;
import mot.common.technology.Biotechnology;
import mot.common.technology.Computer;
import mot.common.technology.Computers;
import mot.common.technology.Engine;
import mot.common.technology.Engines;
import mot.common.technology.Factories;
import mot.common.technology.Factory;
import mot.common.technology.GeneralTechnologyList;
import mot.common.technology.Hull;
import mot.common.technology.Hulls;
import mot.common.technology.Humanities;
import mot.common.technology.Humanity;
import mot.common.technology.Laboratories;
import mot.common.technology.Laboratory;
import mot.common.technology.MiscTechnologies;
import mot.common.technology.MiscTechnology;
import mot.common.technology.Module;
import mot.common.technology.Modules;
import mot.common.technology.Scanner;
import mot.common.technology.Scanners;
import mot.common.technology.Shield;
import mot.common.technology.Shields;
import mot.common.technology.Special;
import mot.common.technology.Specials;
import mot.common.technology.Technology;
import mot.common.technology.TechnologyContainer;
import mot.common.technology.TechnologyList;
import mot.common.technology.Theories;
import mot.common.technology.Theory;
import mot.common.technology.Weapon;
import mot.common.technology.Weapons;
import mot.common.util.ApplicationError;

public class PlayerTechnologiesVO implements ValueObject {

	private String player;
	
	private String [] biotechnologies;
	private String [] computers;
	private String [] engines;
	private String [] factories;
	private String [] hulls;
	private String [] laboratories;
	private String [] scanners;
	private String [] shields;
	private String [] specials;
    private String [] weapons;
    private String [] modules;
    private String [] humanities;
    private String [] theories;
    private String [] misc;

	private transient Biotechnologies biotechnologiesList;
	private transient Computers computersList;
	private transient Engines enginesList;
	private transient Factories factoriesList;
	private transient Hulls hullsList;
	private transient Laboratories laboratoriesList;
	private transient Scanners scannersList;
	private transient Shields shieldsList;
	private transient Specials specialsList;
    private transient Weapons weaponsList;
    private transient Modules modulesList;
    private transient Humanities humanitiesList;
    private transient Theories theoriesList;
    private transient MiscTechnologies miscList;

    public PlayerTechnologiesVO() {
    }
    
    public PlayerTechnologiesVO(String player, TechnologyContainer tc) throws ApplicationError {
        this.player = player;
        if (tc != null) {
			if (tc.getBiotechnologies() != null) {
	            biotechnologies = tc.getBiotechnologies().getNamesAsArray();
	        }
	        if (tc.getComputers() != null) {
	            computers = tc.getComputers().getNamesAsArray();
	        }
	        if (tc.getEngines() != null) {
	            engines = tc.getEngines().getNamesAsArray();
	        }
	        if (tc.getFactories() != null) {
	            factories = tc.getFactories().getNamesAsArray();
	        }
	        if (tc.getHulls() != null) {
	            hulls = tc.getHulls().getNamesAsArray();
	        }
	        if (tc.getLaboratories() != null) {
	            laboratories = tc.getLaboratories().getNamesAsArray();
	        }
	        if (tc.getScanners() != null) {
	            scanners = tc.getScanners().getNamesAsArray();
	        }
	        if (tc.getShields() != null) {
	            shields = tc.getShields().getNamesAsArray();
	        }
	        if (tc.getSpecials() != null) {
	            specials = tc.getSpecials().getNamesAsArray();
	        }
	        if (tc.getWeapons() != null) {
	            weapons = tc.getWeapons().getNamesAsArray();
	        }
	        if (tc.getModules() != null) {
	            modules = tc.getModules().getNamesAsArray();
	        }
	        if (tc.getHumanities() != null) {
	            humanities = tc.getHumanities().getNamesAsArray();
	        }
	        if (tc.getTheories() != null) {
	            theories = tc.getTheories().getNamesAsArray();
	        }
	        if (tc.getMiscTechnologies() != null) {
	            misc = tc.getMiscTechnologies().getNamesAsArray();
	        }
        }
    }

    public void add(Technology t) throws ApplicationError {
    	if (t == null) return;
		if (t instanceof Biotechnology) {
            Biotechnologies l = getBiotechnologiesAsList();
            if (l == null) l = new Biotechnologies();
            l.add(t);
			biotechnologies = l.getNamesAsArray(); 
        }
        if (t instanceof Computer) {
            Computers l = getComputersAsList();
            if (l == null) l = new Computers();
            l.add(t);
            computers = l.getNamesAsArray(); 
        }
        if (t instanceof Engine) {
            Engines l = getEnginesAsList();
            if (l == null) l = new Engines();
            l.add(t);
            engines = l.getNamesAsArray(); 
        }
        if (t instanceof Factory) {
            Factories l = getFactoriesAsList();
            if (l == null) l = new Factories();
            l.add(t);
            factories = l.getNamesAsArray(); 
        }
        if (t instanceof Hull) {
            Hulls l = getHullsAsList();
            if (l == null) l = new Hulls();
            l.add(t);
            hulls = l.getNamesAsArray(); 
        }
        if (t instanceof Laboratory) {
            Laboratories l = getLaboratoriesAsList();
            if (l == null) l = new Laboratories();
            l.add(t);
            laboratories = l.getNamesAsArray(); 
        }
        if (t instanceof Scanner) {
            Scanners l = getScannersAsList();
            if (l == null) l = new Scanners();
            l.add(t);
            scanners = l.getNamesAsArray(); 
        }
        if (t instanceof Shield) {
            Shields l = getShieldsAsList();
            if (l == null) l = new Shields();
            l.add(t);
            shields = l.getNamesAsArray(); 
        }
        if (t instanceof Special) {
            Specials l = getSpecialsAsList();
            if (l == null) l = new Specials();
            l.add(t);
            specials = l.getNamesAsArray(); 
        }
        if (t instanceof Weapon) {
            Weapons l = getWeaponsAsList();
            if (l == null) l = new Weapons();
            l.add(t);
            weapons = l.getNamesAsArray(); 
        }
        if (t instanceof Module) {
            Modules l = getModulesAsList();
            if (l == null) l = new Modules();
            l.add(t);
            modules = l.getNamesAsArray(); 
        }
        if (t instanceof Humanity) {
        	Humanities l = getHumanitiesAsList();
            if (l == null) l = new Humanities();
            l.add(t);
            humanities = l.getNamesAsArray(); 
        }
        if (t instanceof Theory) {
            Theories l = getTheoriesAsList();
            if (l == null) l = new Theories();
            l.add(t);
            theories = l.getNamesAsArray(); 
        }
        if (t instanceof MiscTechnology) {
            MiscTechnologies l = getMiscTechnologiesAsList();
            if (l == null) l = new MiscTechnologies();
            l.add(t);
            misc = l.getNamesAsArray(); 
        }
    }



    public void setBiotechnologies(String[] biotechnologies) {
        this.biotechnologies = biotechnologies;
    }

    public Biotechnologies getBiotechnologiesAsList() throws ApplicationError {
        if (biotechnologiesList == null && biotechnologies != null) {
            biotechnologiesList = new Biotechnologies(biotechnologies);
        }
        return biotechnologiesList;
    }

    public String[] getBiotechnologies() {
        return biotechnologies;
    }

    public void setComputers(String[] computers) {
        this.computers = computers;
    }

    public Computers getComputersAsList() throws ApplicationError {
        if (computersList == null && computers != null) {
            computersList = new Computers(computers);
        }
        return computersList;
    }

    public String[] getComputers() {
        return computers;
    }

    public void setEngines(String[] engines) {
        this.engines = engines;
    }

    public Engines getEnginesAsList() throws ApplicationError {
        if (enginesList == null && engines != null) {
            enginesList = new Engines(engines);
        }
        return enginesList;
    }

    public String[] getEngines() {
        return engines;
    }

    public void setFactories(String[] factories) {
        this.factories = factories;
    }

    public Factories getFactoriesAsList() throws ApplicationError {
        if (factoriesList == null && factories != null) {
            factoriesList = new Factories(factories);
        }
        return factoriesList;
    }

    public String[] getFactories() {
        return factories;
    }

    public void setHulls(String[] hulls) {
        this.hulls = hulls;
    }

    public Hulls getHullsAsList() throws ApplicationError {
        if (hullsList == null && hulls != null) {
            hullsList = new Hulls(hulls);
        }
        return hullsList;
    }

    public String[] getHulls() {
        return hulls;
    }

    public void setLaboratories(String[] laboratories) {
        this.laboratories = laboratories;
    }

    public Laboratories getLaboratoriesAsList() throws ApplicationError {
        if (laboratoriesList == null && laboratories != null) {
            laboratoriesList = new Laboratories(laboratories);
        }
        return laboratoriesList;
    }

    public String[] getLaboratories() {
        return laboratories;
    }


    public void setScanners(String[] scanners) {
        this.scanners = scanners;
    }

    public Scanners getScannersAsList() throws ApplicationError {
        if (scannersList == null && scanners != null) {
            scannersList = new Scanners(scanners);
        }
        return scannersList;
    }

    public String[] getScanners() {
        return scanners;
    }

    public void setShields(String[] shields) {
        this.shields = shields;
    }

    public Shields getShieldsAsList() throws ApplicationError {
        if (shieldsList == null && shields != null) {
            shieldsList = new Shields(shields);
        }
        return shieldsList;
    }

    public String[] getShields() {
        return shields;
    }

    public void setSpecials(String[] specials) {
        this.specials = specials;
    }

    public Specials getSpecialsAsList() throws ApplicationError {
        if (specialsList == null && specials != null) {
            specialsList = new Specials(specials);
        }
        return specialsList;
    }

    public String[] getSpecials() {
        return specials;
    }

    public void setWeapons(String[] weapons) {
        this.weapons = weapons;
    }

    public Weapons getWeaponsAsList() throws ApplicationError {
        if (weaponsList == null && weapons != null) {
            weaponsList = new Weapons(weapons);
        }
        return weaponsList;
    }

    public String[] getWeapons() {
        return weapons;
    }

    public void setModules(String[] modules) {
        this.modules = modules;
    }

    public Modules getModulesAsList() throws ApplicationError {
        if (modulesList == null && modules != null) {
            modulesList = new Modules(modules);
        }
        return modulesList;
    }

    public void setHumanities(String[] humanities) {
        this.humanities = humanities;
    }

    public Humanities getHumanitiesAsList() throws ApplicationError {
        if (humanitiesList == null && humanities != null) {
        	humanitiesList = new Humanities(humanities);
        }
        return humanitiesList;
    }

    public String[] getModules() {
        return modules;
    }

    public String[] getHumanities() {
        return humanities;
    }

    public void setTheories(String[] theories) {
        this.theories = theories;
    }

    public Theories getTheoriesAsList() throws ApplicationError {
        if (theoriesList == null && theories != null) {
            theoriesList = new Theories(theories);
        }
        return theoriesList;
    }

    public String[] getTheories() {
        return theories;
    }
 
    public void setMiscTechnologies(String[] theories) {
        this.misc = theories;
    }

    public MiscTechnologies getMiscTechnologiesAsList() throws ApplicationError {
        if (miscList == null && misc != null) {
        	miscList = new MiscTechnologies(misc);
        }
        return miscList;
    }

    public String[] getMiscTechnologies() {
        return misc;
    }
 
    public TechnologyList getAllAsList() throws ApplicationError {
        TechnologyList tl = new GeneralTechnologyList();
        tl.add(getBiotechnologiesAsList());
        tl.add(getComputersAsList());
        tl.add(getEnginesAsList());
        tl.add(getFactoriesAsList());
        tl.add(getHullsAsList());
        tl.add(getLaboratoriesAsList());
        tl.add(getScannersAsList());
        tl.add(getShieldsAsList());
        tl.add(getSpecialsAsList());
        tl.add(getWeaponsAsList());
        tl.add(getModulesAsList());
        tl.add(getTheoriesAsList());
        tl.add(getMiscTechnologiesAsList());
        tl.add(getHumanitiesAsList());
        return tl;
    }

	@Override
	public String toString() {
		return "PlayerTechnologiesVO";
	}

	public String getPlayer() {
		return player;
	}

	public void setPlayer(String player) {
		this.player = player;
	}

}