/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.vo;

import mot.common.technology.TechnologyList;
import mot.common.util.Comp;

public class RelationResearchAgreementVO implements ValueObject {

	private int date;
	private String player1;
	private String player2;
	private int research;
	private TechnologyListVO player1VoidedMissedTechnologies;
	private TechnologyListVO player2VoidedMissedTechnologies;

	public RelationResearchAgreementVO(int date, String player1, String player2, int research, TechnologyList player1VoidedMissedTechnologies, TechnologyList player2VoidedMissedTechnologies) {
		this.date = date;
		this.player1 = player1;
		this.setPlayer2(player2);
		this.research = research;
		this.player1VoidedMissedTechnologies = new TechnologyListVO(player1VoidedMissedTechnologies);
		this.player2VoidedMissedTechnologies = new TechnologyListVO(player2VoidedMissedTechnologies);
	}

	public int getResearch() {
		return research;
	}

	public void setResearch(int research) {
		this.research = research;
	}

	public String toString() {
		return "RelationResearchAgreementVO [research "+research+", player1VoidedMissedTechnologies"+player1VoidedMissedTechnologies+", player2VoidedMissedTechnologies"+player2VoidedMissedTechnologies+"]";
	}
	
	public TechnologyListVO getPlayer1VoidedMissedTechnologies() {
		return player1VoidedMissedTechnologies;
	}

	public void setPlayer1VoidedMissedTechnologies(TechnologyListVO player1VoidedMissedTechnologies) {
		this.player1VoidedMissedTechnologies = player1VoidedMissedTechnologies;
	}

	public TechnologyListVO getPlayer2VoidedMissedTechnologies() {
		return player2VoidedMissedTechnologies;
	}

	public void setPlayer2VoidedMissedTechnologies(TechnologyListVO player2VoidedMissedTechnologies) {
		this.player2VoidedMissedTechnologies = player2VoidedMissedTechnologies;
	}

	public int getDate() {
		return date;
	}

	public void setDate(int date) {
		this.date = date;
	}

	public TechnologyListVO getVoidedMissedTechnologies(String name) {
		if (Comp.same(name, player1)) {			
			return player1VoidedMissedTechnologies;
		} else {
			return player2VoidedMissedTechnologies;
		}
	}	

	public String getPlayer1() {
		return player1;
	}

	public void setPlayer1(String player1) {
		this.player1 = player1;
	}

	public String getPlayer2() {
		return player2;
	}

	public void setPlayer2(String player2) {
		this.player2 = player2;
	}


}
