/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.vo;

import mot.common.bean.DiplomaticHistory;
import mot.common.util.Comp;

public class RelationVO implements ValueObject {

	private String player1Name;
	private String player2Name;

    private boolean aliance;
    private boolean nonAgression;
    private boolean peace;
    private boolean war;
    
    private RelationResearchAgreementVO researchAgreement;
    private RelationTradeAgreementVO tradeAgreement;
    
    private int value;
    
    private DiplomaticHistory diplomaticHistory;
    
	private int player1Rating;
	private int player2Rating;
    
    public RelationVO() {
    }

    public RelationVO(String player1Name, String player2Name, int player1Rating, int player2Rating,
					  boolean aliance, boolean nonAgression, boolean peace, boolean war,
                      RelationResearchAgreementVO researchAgreement, RelationTradeAgreementVO tradeAgreement,
                      int value,
                      DiplomaticHistory diplomaticHistory) {
        this.player1Name = player1Name;
		this.player2Name = player2Name;
		this.player1Rating = player1Rating;
		this.player2Rating = player2Rating;
		this.aliance = aliance;
        this.nonAgression = nonAgression;
        this.peace = peace;
        this.researchAgreement = researchAgreement;
        this.tradeAgreement = tradeAgreement;
        this.war = war;   
        this.value = value;
		this.diplomaticHistory = diplomaticHistory;
    }

    public void setAliance(boolean aliance) {
        this.aliance = aliance;
    }

    public boolean isAliance() {
        return aliance;
    }

    public void setNonAgression(boolean nonAgression) {
        this.nonAgression = nonAgression;
    }

    public boolean isNonAgression() {
        return nonAgression;
    }

    public void setPeace(boolean peace) {
        this.peace = peace;
    }

    public boolean isPeace() {
        return peace;
    }

    public void setResearchAgreement(RelationResearchAgreementVO researchAgreement) {
        this.researchAgreement = researchAgreement;
    }

    public RelationResearchAgreementVO getResearchAgreement() {
        return researchAgreement;
    }

    public void setTradeAgreement(RelationTradeAgreementVO tradeAgreement) {
        this.tradeAgreement = tradeAgreement;
    }

    public RelationTradeAgreementVO getTradeAgreement() {
        return tradeAgreement;
    }

    public void setWar(boolean war) {
        this.war = war;
    }

    public boolean isWar() {
        return war;
    }

    public void setValue(int value) {
        this.value = value;
    }

    public int getValue() {
        return value;
    }

	public String getPlayer1Name() {
		return player1Name;
	}

	public void setPlayer1Name(String player1Name) {
		this.player1Name = player1Name;
	}

	public String getPlayer2Name() {
		return player2Name;
	}

	public void setPlayer2Name(String player2Name) {
		this.player2Name = player2Name;
	}

	public boolean equals(String name1, String name2) {
		return Comp.same(name1, player1Name) && Comp.same(name2, player2Name) ||
				Comp.same(name1, player2Name) && Comp.same(name2, player1Name);
	}
	
	@Override
	public String toString() {
		return "RelationVO [player1Name=" + player1Name + ", player2Name=" + player2Name + ", aliance=" + aliance
				+ ", nonAgression=" + nonAgression + ", peace=" + peace + ", war=" + war + ", researchAgreement="
				+ researchAgreement + ", tradeAgreement=" + tradeAgreement + ", value=" + value + "]";
	}

	public DiplomaticHistory getDiplomaticHistory() {
		return diplomaticHistory;
	}

	public void setDiplomaticHistory(DiplomaticHistory diplomaticHistory) {
		this.diplomaticHistory = diplomaticHistory;
	}

	public int getPlayer1Rating() {
		return player1Rating;
	}

	public void setPlayer1Rating(int player1Rating) {
		this.player1Rating = player1Rating;
	}

	public int getPlayer2Rating() {
		return player2Rating;
	}

	public void setPlayer2Rating(int player2Rating) {
		this.player2Rating = player2Rating;
	}

}