/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.vo;

public class ResearchProjectVO implements ValueObject {

    /**
     * The long name of this technology.
     */
    private String technology;
    
    /**
     * The work done so far on this research project.
     */
    private int work;

    /**
     * If 0.0 implies this research project is not from salvage.
     * If fromSalvageProbability > 0.0 this this is the chance 
     * per turn a technology will be discovered from salvage
     */
	private double fromSalvageProbability;

    public ResearchProjectVO() {
    }

    public ResearchProjectVO(String technology, int work, double fromSalvageProbability) {
        this.technology = technology;
        this.work = work;
		this.fromSalvageProbability = fromSalvageProbability;
    }

    public void setTechnology(String technology) {
        this.technology = technology;
    }

    public String getTechnology() {
        return technology;
    }

    public void setWork(int work) {
        this.work = work;
    }

    public int getWork() {
        return work;
    }
    
	@Override
	public String toString() {
		return "ResearchProjectVO ["+technology+"]";
	}

	public double getFromSalvageProbability() {
		return fromSalvageProbability;
	}

	public void setFromSalvageProbability(double fromSalvageProbability) {
		this.fromSalvageProbability = fromSalvageProbability;
	}

}