/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.vo;

import java.awt.Color;

import mot.common.bean.Location;

public class StellarObjectVO implements NamedValueObject {

    /**
     * The name of this stellar object.
     */
    private String name;
    
    /**
     * The location on the galaxy map.
     */
    private Location location;
    
    /**
     * True if and only if this stellar object has an owner.
     */
    private String [] owners;
    
    /**
     * The colour to display this stellar object as.
     */
    private Color textColor;
    
    /**
     * When a stellar object is visible its name is displayed on the galaxy map and details of the planets it contains can be viewed.
     * Do not confuse this with a planet's view ability. A planet is viewable if a player can see its production details.
     */
    private boolean isVisible;

    /**
     * The outpost located at this stellar object of one exists.
     */
    private StellarObjectOrbitalVO orbital;
    
    /**
     * The date of the last visit to this stellar object by the player this object is sent to.
     */
    private int lastVisitiedDate;
    
    public StellarObjectVO() {
    }

    public StellarObjectVO(String name, Location location, String [] owners, Color textColor, boolean isVisible, int lastVisitedDate, StellarObjectOrbitalVO orbital) {
        this.name = name;
        this.location = location;
        this.owners = owners;
        this.textColor= textColor;
		this.isVisible = isVisible;
        this.lastVisitiedDate = lastVisitedDate;
        this.orbital = orbital;
    }


    public void setName(String name) {
        this.name = name;
    }


    public String getName() {
        return name;
    }


    public void setLocation(Location location) {
        this.location = location;
    }


    public Location getLocation() {
        return location;
    }

    public void setTextColor(Color textColor) {
        this.textColor = textColor;
    }


    public Color getTextColor() {
        return textColor;
    }


	public String [] getOwners() {
		return owners;
	}

	public void setOwners(String [] owners) {
		this.owners = owners;
	}

	public int getLastVisitiedDate() {
		return lastVisitiedDate;
	}

	public void setLastVisitiedDate(int lastVisitiedDate) {
		this.lastVisitiedDate = lastVisitiedDate;
	}

	public StellarObjectOrbitalVO getOrbital() {
		return orbital;
	}

	public void setOrbital(StellarObjectOrbitalVO orbital) {
		this.orbital = orbital;
	}
	
	@Override
	public String toString() {
		return "StellarObjectVO ["+getName()+"]";
	}

	public boolean isVisible() {
		return isVisible;
	}

	public void setVisible(boolean isVisible) {
		this.isVisible = isVisible;
	}

}