/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.vo;

import mot.common.bean.DatedMessage;

/**
 * This is an action a player has performed to a computer player that the computer player's 
 * strategist remembers and is effecting the relationship.
 */
public class StrategistEventVO implements ValueObject, DatedMessage {

	/**
	 * The date of this event - Note it is a decimal as several things can occur in a single year
	 */
	private double date;
	
	/**
	 * The computer player that that is remembering these events.
	 */
 	private String player;
 	
 	/**
 	 * This is a human readable message containing a description of the request 
 	 * or response in this diplomatic event.
 	 */
 	private String message;

	public StrategistEventVO() {
    }

	public StrategistEventVO(double date, String player, String message) {
		this.date = date;
		this.player = player;
		this.message = message;
    }

	public String toString() {
		return player +" "+message;
	}

    public void setPlayer(String player) {
        this.player = player;
    }

    public String getPlayer() {
        return player;
    }

	public String getMessage() {
		return message;
	}

	public void setMessage(String message) {
		this.message = message;
	}

	public double getDate() {
		return date;
	}

	public void setDate(double date) {
		this.date = date;
	}

}