/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.vo;

import mot.common.technology.Technologies;
import mot.common.technology.Technology;
import mot.common.util.ApplicationError;

public class TechnologyVO implements ValueObject {
	
	private String techName;

	public TechnologyVO() {
	}

	public TechnologyVO(String techName) {
		this.techName  = techName;		
	}

	public TechnologyVO(Technology tech) {
		if (tech != null) {
			this.techName = tech.getFullName();
		}
	}

	@Override
	public String toString() {
		return "TechnologyVO ["+getTechName()+"]";
	}

	public Technology getTechnology() throws ApplicationError {
		if (techName != null) {
			return Technologies.getTechnology(techName);
		} else {
			return null;
		}
	}

	public void setTechnology(Technology tech) {
		if (tech != null) {
			this.techName = tech.getFullName();
		}
	}
	
	public String getTechName() {
		return techName;
	}

	public void setTechName(String techName) {
		this.techName = techName;
	}
}
