/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.vo;

import mot.common.util.NameValuePairList;

/**
 * A Trade route is a link between two planets that is visible on the galaxy map 
 * that increases economic activity on each planet.
 * 
 * This objects is a state holder of the TradeRoute class found in the engine code.
 * 
 * @author paul
 *
 */
public class TradeRouteVO implements ValueObject {

	private String solarSystem1;
	private String solarSystem2;
	private int startDate;
	
	/**
	 * This is a list of bonuses provided to all planets by this trade route
	 */
	private NameValuePairList productionOutput;
	
	/**
	 * This is a list of bonuses provided to all planets by this trade route
	 */
	private NameValuePairList researchOutput;
	
	public TradeRouteVO(){
	}
	
	public TradeRouteVO(String solarSystem1, String solarSystem2, int startDate, NameValuePairList productionOutput, NameValuePairList researchOutput){
		this.solarSystem1 = solarSystem1;
		this.solarSystem2 = solarSystem2;
		this.startDate = startDate;
		this.productionOutput = productionOutput;
		this.researchOutput = researchOutput;
	}

	public String getSolarSystem1() {
		return solarSystem1;
	}

	public void setSolarSystem1(String v) {
		this.solarSystem1 = v;
	}

	public String getSolarSystem2() {
		return solarSystem2;
	}

	public void setSolarSystem2(String v) {
		this.solarSystem2 = v;
	}

	public int getStartDate() {
		return startDate;
	}

	public void setStartDate(int startDate) {
		this.startDate = startDate;
	}
	
	@Override
	public String toString() {
		return "TradeRouteVO [" + solarSystem1 + "=>" + solarSystem2
				+ " date " + startDate + "]";
	}

	public NameValuePairList getProductionOutput() {
		return productionOutput;
	}

	public void setProductionOutput(NameValuePairList industryOutput) {
		this.productionOutput = industryOutput;
	}

	public NameValuePairList getResearchOutput() {
		return researchOutput;
	}

	public void setResearchOutput(NameValuePairList researchOutput) {
		this.researchOutput = researchOutput;
	}

	
}
