/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.vo;

import mot.common.bean.PlayerResources;

public class UserPlayerVO extends PlayerVO {

    private String generalName;
    private String govenorName;
    private int generalExperience;
    private int govenorExperience;

    /**
     * A list of player names whose this player has assigned a spy against. Allows a 
     * player to view the details of another player. See Spy Centre for details.
     */
    private String [] playerSpies;
    
	/**
	 * The orbit all new ships must be sent to.
	 */
	private OrbitVO fleetWayPoint;
	
	/**
	 * This players research project.
	 */
	private ResearchProjectVO researchProject;
	
    /**
     * The home planet of this player.
     */
	private String homePlanet;

	/**
	 * Resources controlled by this player
	 */
	private PlayerResources playerResources;

	/**
	 * Salvage collected by this player
	 */
	private String[] salvage;
    
    /**
     * Net income per turn
     */
    private int netIncome;
    
    /**
     * The quantity of free transports
     */
    private int qtyFreeTransport;
    
    /**
     * Quantity of spies not assigned and in defence
     */
    private int qtySpiesDefending;

    /**
     * When a research project from salvage is started, its the chance of success
     */
    private double chanceToDiscoverSalvaged;
    
    public UserPlayerVO() {
    }

    public UserPlayerVO(String name) {
        super(name);
    }


    public void setPlayerSpies(String[] playerSpies) {
        this.playerSpies = playerSpies;
    }


    public String[] getPlayerSpies() {
        return playerSpies;
    }

    public void setGeneralName(String generalName) {
        this.generalName = generalName;
    }

    public String getGeneralName() {
        return generalName;
    }

    public void setGovenorName(String govenorName) {
        this.govenorName = govenorName;
    }

    public String getGovenorName() {
        return govenorName;
    }

    public void setGeneralExperience(int generalExperience) {
        this.generalExperience = generalExperience;
    }

    public int getGeneralExperience() {
        return generalExperience;
    }

    public void setGovenorExperience(int govenorExperience) {
        this.govenorExperience = govenorExperience;
    }

    public int getGovenorExperience() {
        return govenorExperience;
    }

	public OrbitVO getFleetWayPoint() {
		return fleetWayPoint;
	}

	public void setFleetWayPoint(OrbitVO fleetWayPoint) {
		this.fleetWayPoint = fleetWayPoint;
	}

	public ResearchProjectVO getResearchProject() {
		return researchProject;
	}

	public void setResearchProject(ResearchProjectVO researchProject) {
		this.researchProject = researchProject;
	}

	public String getHomePlanet() {
		return homePlanet;
	}

	public void setHomePlanet(String homePlanet) {
		this.homePlanet = homePlanet;
	}

	public PlayerResources getPlayerResources() {
		return playerResources;
	}

	public void setPlayerResources(PlayerResources playerResources) {
		this.playerResources = playerResources;
	}

	public String[] getSalvage() {
		return salvage;
	}

	public void setSalvage(String[] salvage) {
		this.salvage = salvage;
	}

	public int getNetIncome() {
		return netIncome;
	}

	public void setNetIncome(int netIncome) {
		this.netIncome = netIncome;
	}

	public int getQtyFreeTransport() {
		return qtyFreeTransport;
	}

	public void setQtyFreeTransport(int qtyFreeTransport) {
		this.qtyFreeTransport = qtyFreeTransport;
	}
	
    public void setQtySpiesDefending(int qtySpiesDefending) {
        this.qtySpiesDefending = qtySpiesDefending;
    }

    public int getQtySpiesDefending() {
        return qtySpiesDefending;
    }

	@Override
	public String toString() {
		return "UserPlayerVO ["+getName()+"]";
	}

	public double getChanceToDiscoverSalvage() {
		return chanceToDiscoverSalvaged;
	}

	public void setChanceToDiscoverSalvaged(double chanceToDiscoverSalvaged) {
		this.chanceToDiscoverSalvaged = chanceToDiscoverSalvaged;
	}

}