/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.vo;

import java.util.ArrayList;

import mot.common.bean.NameList;
import mot.common.designs.WeaponBayDesign;
import mot.common.technology.Weapons;
import mot.common.util.ApplicationError;
import mot.engine.crafts.WeaponBay;

public class WeaponBayVO implements ValueObject {

    private ArrayList<String> weapons;

    private transient Weapons weaponsList;

    public WeaponBayVO() {
    }

    public WeaponBayVO(WeaponBay wb) {
    	if (wb != null) { 
    		Weapons w = wb.getWeapons();
    		if (w != null) {
    			weapons = w.getNamesAsList();
    		}
    	}
        weaponsList = null;
    }

    public WeaponBayVO(WeaponBayDesign wb) {
    	if (wb != null) { 
    		NameList w = wb.getWeapons();
    		if (w != null) {
    			weapons = w.getNames();
    		}
    	}
        weaponsList = null;
    }

    public void setWeapons(ArrayList<String> weapons) {
        this.weapons = weapons;
        weaponsList = null;
    }

    public Weapons getWeaponsAsList() throws ApplicationError {
        if (weaponsList == null && weapons != null) {
            weaponsList = new Weapons(weapons);
        }
        return weaponsList;
    }

    public NameList getNamesList() {
        if (weapons == null || weapons.size() == 0) return null;
        return new NameList(weapons);
    }

    public ArrayList<String> getWeapons() {
        return weapons;
    }
    
    public WeaponBayDesign getWeaponBayDesign() throws ApplicationError {
        if (weapons != null) {
            WeaponBayDesign bay = new WeaponBayDesign(getNamesList());
            return bay;
        } else {
            return null;
        }
    }

}