/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.vo;
import mot.common.technology.Technologies;
import mot.common.technology.Weapon;
import mot.common.util.ApplicationError;

public class WeaponInstanceVO implements ValueObject {

    private int qty;
    private String weaponName;
    private int qtyFired;
    private boolean hasWeaponsToFire;
	private int range;

    public WeaponInstanceVO() {
    }

    public WeaponInstanceVO(int qty, String weaponName, int qtyFired, boolean hasWeaponsToFire, int range) {
        this.qty = qty;
        this.weaponName = weaponName;
        this.qtyFired = qtyFired;
        this.hasWeaponsToFire = hasWeaponsToFire;
		this.range = range;
    }

    public Weapon getWeapon() throws ApplicationError {
		return Technologies.getWeapon(weaponName);
	}

	public boolean canAttackLocation() throws ApplicationError {
		Weapon w = getWeapon();
		return (w != null) && w.isSpacialDistortion();
	}

	public boolean canAttackWreckage() throws ApplicationError {
		Weapon w = getWeapon();
		return (w != null) && (w.isTimeWarpBeam() || w.isSalvageBeam());
	}

	public boolean canAttackAutomaton() throws ApplicationError {
		Weapon w = getWeapon();
		return (w != null) && (w.isRetargetBeam());
	}

	public boolean canAttackBattleObject() throws ApplicationError {
		Weapon w = getWeapon();
		return (w != null) && !w.isTimeWarpBeam() && !w.isSalvageBeam() && !w.isSpacialDistortion();
	}
	
    public void setQty(int qty) {
        this.qty = qty;
    }

    public int getQty() {
        return qty;
    }

    public void setWeaponName(String weaponName) {
        this.weaponName = weaponName;
    }

    public String getWeaponName() {
        return weaponName;
    }

    public Weapon getWeaponObject() throws ApplicationError {
        if (weaponName == null) {
            return null;
        } else {
            return Technologies.getWeapon(weaponName);
        }
    }

    public void setQtyFired(int qtyFired) {
        this.qtyFired = qtyFired;
    }

    public int getQtyFired() {
        return qtyFired;
    }

    public void setHasWeaponsToFire(boolean hasWeaponsToFire) {
        this.hasWeaponsToFire = hasWeaponsToFire;
    }

    public boolean isHasWeaponsToFire() {
        return hasWeaponsToFire;
    }

    public boolean hasWeaponsToFire() {
        return hasWeaponsToFire;
    }

	public int getRange() {
		return range;
	}

	public void setRange(int range) {
		this.range = range;
	}
	
	@Override
	public String toString() {
		return "WeaponInstanceVO ["+getWeaponName()+"]";
	}

	public String toShortString() {
		return getWeaponName()+"x"+qty+"-"+qtyFired;
	}
	
}