/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.xml;

import java.util.HashMap;
import java.util.Map;

/**
 * Permits definition of replacement class names during load game to provide backwards compatibility.
 * 
 * @author paul
 *
 */
public class BackwardsCompatibility {

	private static Map<String, String> replacementClasses = new HashMap();
	
	static {
		replacementClasses.put("mot.engine.relations.ResearchTreaty", "mot.engine.relations.ResearchAgreementTreaty"); // Game version 1.21
		replacementClasses.put("mot.engine.relations.TradeTreaty", "mot.engine.relations.TradeAgreementTreaty"); // Game version 1.21
		replacementClasses.put("mot.engine.players.strategists.StrategistEventInvadePlanet", "mot.engine.players.strategists.StrategistEventColonyLost"); // Game version 1.21
	}
	
	public static String replaceClassName(String className) {
		String replacement = replacementClasses.get(className);
		if (replacement != null) {
			return replacement;
		} else {
			return className;
		}
	}


	private static Map<String, String> replacementContent = new HashMap();
	
	static {
//		replacementContent.put("Electronic 50", "Battle Computer 50"); // Game version 1.22
//		replacementContent.put("Electronic 80", "Battle Computer 50"); // Game version 1.22
//		replacementContent.put("Electronic 100", "Battle Computer 50"); // Game version 1.22
//		replacementContent.put("Hybrid 120", "Battle Computer 50"); // Game version 1.22
//		replacementContent.put("Electronic 50", "Battle Computer 50"); // Game version 1.22
	}
	
	public static String replaceContent(String content) {
		String replacement = replacementContent.get(content);
		if (replacement != null) {
			return replacement;
		} else {
			return content;
		}
	}

}
