/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.xml;

import java.io.InputStream;
import java.net.URL;
import java.util.ArrayList;

import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;

import org.w3c.dom.Document;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;

import mot.common.util.ApplicationError;
import mot.common.util.Comp;
import mot.common.util.Logger;

public class DomTree {

	private Document doc;

	public DomTree(String path, String schemaPath) throws ApplicationError {
		try {

	    	DocumentBuilderFactory dbFactory = DocumentBuilderFactory.newInstance();
	    	DocumentBuilder dBuilder = dbFactory.newDocumentBuilder();

	    	ClassLoader contextClassLoader = Thread.currentThread().getContextClassLoader();
	    	if (schemaPath != null) {
	    		//This does not work in Java Web Start
	    		//URL schemaLocation = ClassLoader.getSystemResource(schemaPath);
		    	URL schemaLocation = contextClassLoader.getResource(schemaPath);
	            if (schemaLocation != null) {
	            	//parser.setProperty("http://apache.org/xml/properties/schema/external-noNamespaceSchemaLocation",  schemaLocation.toExternalForm());
	            }
	    	}

	    	//This does not work in Java Web Start
	    	//InputStream is = ClassLoader.getSystemResourceAsStream(path);
			InputStream is = contextClassLoader.getResourceAsStream(path);

			doc = dBuilder.parse(is);
		} catch (Exception e) {
			Logger.logError("Unable to parse "+path, e);
			throw new ApplicationError(e.toString());
		}
	}

	public DomNode getNodeByName(String name) {
		NodeList children = doc.getChildNodes();
		for (int i = 0; i < children.getLength(); i++) {
			Node child = children.item(i);
			if (Comp.same(name, child.getNodeName())) {
				return new DomNode(child);
			}
		}
		return null;
	}

	public DomNode [] getNodesByName(String name) {
		NodeList children = doc.getChildNodes();
		ArrayList<DomNode> r = null;  
		for (int i = 0; i < children.getLength(); i++) {
			Node child = children.item(i);
			if (Comp.same(name, child.getNodeName())) {
				if (r == null) r= new ArrayList<DomNode>();
				r.add(new DomNode(child));
			}
		}
		if (r == null) {
			return null;
		} else {
			return r.toArray(new DomNode[r.size()]);
		}
	}

}
