/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.xml;

import java.util.Date;

/**
 * @author Paul Davis
 * 
 * Base class for all writer objects.
 * A writer objects are used to build textual documents containing structured
 * information. There are two know sub classes of GenericWriter
 * XMLWriter - The information is writen into an XML Document.
 * TextWriter - The information is writen a tabular textual format.
 */
public abstract class GenericWriter extends Indenter {

    public abstract void openElement(String name);
    public abstract void closeElement(String name);
    public abstract void addElement(String name, String value);
    public abstract void addElement(String name, Number value);
    public abstract void addElement(String name, int value);
    public abstract void addElement(String name, Boolean value);
    public abstract void addElement(String name, Date value);
    public abstract String getDocument();

}
