/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.xml;

import mot.common.util.ApplicationError;

/**
 * @author Paul Davis
 * 
 * Defines a method to iterate through a beans state using
 * its list of attributes.
 */
public class PropertyAttributeIterator implements AttributeIterator {

    Object bean;
    IntrospectionBean ib;
    String [] attributes;

    int index = -1;

    public PropertyAttributeIterator(Object bean) {
		this.bean = bean;
		this.ib = new IntrospectionBean(bean);
		this.attributes = ib.getAttributes();
    }

    public boolean hasNext() {
		return index < (attributes.length-1);
    }

    public void next() {
        index++;
    }

    public String getName() {
        return attributes[index];
    }

    public Object getValue() throws ApplicationError {
		try {
			return ib.callGetByFieldName(attributes[index]);
		} catch (Exception e) {
			throw new ApplicationError("PropertyAttributeIterator.getValue() Unable to call get method on "+bean.getClass().getName()+" for attribute "+attributes[index]+" due to error "+e);
		}
    }

    public AttributeIterator clone(Object bean) {
		return new PropertyAttributeIterator(bean);
    }

    public Object getBean() {
		return bean;
    }

}
