/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.xml;

import mot.common.util.ApplicationError;
import mot.common.util.PropertyManager;

/**
 * @author Paul Davis
 * 
 * Renders an XML document.
 */
public abstract class XMLDocument {


    protected XMLWriter writer;
    private String rootElementName;
    private String dtd;

    /**
     * Construct an XML document with root element name passed in.
     * This class is a base class and the root element name would usually be the name
     * of the class implementing the XML document. The DTD for the document is fetched
     * from the properties files.
     */
    protected XMLDocument(String rootElementName) {
        this(rootElementName, PropertyManager.get(rootElementName+".dtd"));
    }


    /**
     * Construct an XML document with root element name passed in.
     * This class is a base class and the root element name would usually be the name
     * of the class implementing the XML document.
     */
    protected XMLDocument(String rootElementName, String dtd) {
        this.rootElementName = rootElementName;
        this.dtd = dtd;
        this.writer = new XMLWriter(dtd, rootElementName);
    }

    /**
     * Renders the XML document into the HTTP response to send it back to the clients
     * browser.
     */
    public void renderPage() throws ApplicationError {
        writer.openElement(rootElementName);
        renderXML(writer);
        writer.closeElement(rootElementName);
    }

    /**
     * All sub classes of XMLDocument must implement renderXML. The renderXML method
     * is called to write all the beans state into the XMLWriter which will be used
     * to generate the XML bean.
     */
    protected abstract void renderXML(XMLWriter writer) throws ApplicationError;
}