/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.editor.swing.controls;

import javax.swing.JComboBox;

import mot.client.deligates.PlayerDelegate;
import mot.client.proxy.LocalServerProxy;
import mot.client.proxy.ProxyStore;
import mot.client.swing.renderers.CellRendererCraftDesign;
import mot.common.bean.Size;
import mot.common.designs.CraftDesign;
import mot.common.designs.CraftDesigns;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;
import mot.engine.players.ComputerPlayer;
import mot.engine.players.MonsterPlayer;
import mot.engine.players.Player;
import mot.engine.players.UserPlayer;

public class CraftDesignCombo extends JComboBox {

	public CraftDesignCombo() throws ApplicationError {
		setRenderer(new CellRendererCraftDesign(new Size(25, 25), true));
	}

    public void setSelection(PlayerDelegate p) throws ApplicationError, ValidationError {
		LocalServerProxy localDelegate = ProxyStore.getInstance().getLocalServerProxy();
		if (localDelegate == null) {
			throw new ValidationError(L.EDITOR_REQUIRES_LOCAL_CLIENT);
		}
		Player player = localDelegate.getPlayer(p);
		if (player == null) {
			throw new ValidationError("Unknown player "+p);
		}
    	CraftDesign[] designs = null;
    	if (player instanceof UserPlayer) {
    		designs = ((UserPlayer)player).getCraftDesignsAsArray();
    	} else if (player instanceof ComputerPlayer) {
    		designs = ((ComputerPlayer)player).getMayor().getCraftDesignerFactory().getCraftDesigns();
    	} else if (player instanceof MonsterPlayer) {
    		designs = CraftDesigns.getInstance().getCraftDesigns();
    	}
    	removeAllItems();
    	if (designs != null) {
	    	for (int i = 0; i < designs.length; i++) {			
	    		addItem(designs[i]);
			}			
    	}
    }
    
    public CraftDesign getCraftDesign() throws ApplicationError {
    	CraftDesign cd = (CraftDesign) getSelectedItem();
    	return cd;
    }
 
	public void clear() {
		setSelectedIndex(-1);
	}
}
