/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.editor.swing.controls;

import javax.swing.JComboBox;

import mot.client.swing.renderers.CellRendererPrize;
import mot.common.util.ApplicationError;
import mot.common.xml.XMLWriter;
import mot.engine.common.StellarObject;
import mot.engine.players.Player;
import mot.engine.prizes.BoraliumPrize;
import mot.engine.prizes.CraftPrize;
import mot.engine.prizes.MoneyPrize;
import mot.engine.prizes.Prize;
import mot.engine.prizes.PrizeFactory;
import mot.engine.prizes.RelicPrize;
import mot.engine.prizes.TechnologyPrize;

public class PrizeCombo extends JComboBox {

	private Prize none;

	public PrizeCombo(Prize prize) throws ApplicationError {
    	setRenderer(new CellRendererPrize());

    	none = new Prize() {
			protected String getElementName() {
				return null;
			}
			protected void encode(XMLWriter writer) throws ApplicationError {
			}
			public void release(Player player, StellarObject so) throws ApplicationError {
			}
		};
    	
		int selectedIndex = 0;
		if (prize != null) {
	    	Class clazz = prize.getClass();
			if (clazz == MoneyPrize.class) {
				selectedIndex = 1;
	    	} else if (clazz == TechnologyPrize.class) {
	    		selectedIndex = 2;
	    	} else if (clazz == CraftPrize.class) {
	    		selectedIndex = 3;
	    	} else if (clazz == RelicPrize.class) {
	    		selectedIndex = 4;
	    	} else if (clazz == BoraliumPrize.class) {
	    		selectedIndex = 5;
	    	}
		}

		addItem(none);
		addItem(selectedIndex == 1 ? prize : PrizeFactory.createMoneyPrize());
		addItem(selectedIndex == 2 ? prize : PrizeFactory.createTechnologyPrize());
		addItem(selectedIndex == 3 ? prize : PrizeFactory.createCraftPrize());
		addItem(selectedIndex == 4 ? prize : PrizeFactory.createRelicPrize());
		addItem(selectedIndex == 5 ? prize : PrizeFactory.createBoraliumPrize());

		setSelectedIndex(selectedIndex);
	}

    public Prize getPrize() {
    	Prize r = (Prize) getSelectedItem();
    	if (r == none) {
    		return null;
    	} else {
    		return r;
    	}
    }
    
//    public void setSelection(Prize prize) {
//    	Class clazz = prize.getClass();
//		if (clazz == MoneyPrize.class) {
//    		setSelectedIndex(0);
//    		MoneyPrize p = (MoneyPrize) getPrize();
//    		p.setAmount( ((MoneyPrize)prize).getAmount() );
//    	} else if (clazz == TechnologyPrize.class) {
//    		setSelectedIndex(1);
//    		TechnologyPrize p = (TechnologyPrize) getPrize();
//    		p.setTech( ((TechnologyPrize)prize).getTech() );
//    	} else if (clazz == CraftPrize.class) {
//    		setSelectedIndex(2);
//    	} else if (clazz == RelicPrize.class) {
//    		setSelectedIndex(3);
//    		RelicPrize p = (RelicPrize) getPrize();
//    		p.setRelic( ((RelicPrize)prize).getRelic() );
//    	} else if (clazz == BoraliumPrize.class) {
//    		setSelectedIndex(4);
//    	} else {
//    		setSelectedIndex(0);
//    	}
//    }

	public void clear() {
		setSelectedIndex(-1);
	}
}
