/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.editor.swing.controls;

import javax.swing.JComboBox;

import mot.client.swing.renderers.CellRendererResource;
import mot.common.lang.L;
import mot.common.resources.Resource;
import mot.common.resources.ResourceAntiMatter;
import mot.common.resources.ResourceBoralium;
import mot.common.resources.ResourceCloakPalm;
import mot.common.resources.ResourceEnergySpores;
import mot.common.resources.ResourcePsiFungus;
import mot.common.resources.ResourceTritanOre;
import mot.common.resources.ResourceWarpCrystal;

public class ResourceCombo extends JComboBox {

	public ResourceCombo() {
    	setRenderer(new CellRendererResource());
		addItem(L.NONE);
		addItem(new ResourceAntiMatter());
		addItem(new ResourceCloakPalm());
		addItem(new ResourcePsiFungus());
		addItem(new ResourceTritanOre());
		addItem(new ResourceWarpCrystal());
		addItem(new ResourceBoralium());
		addItem(new ResourceEnergySpores());
	}

    public Resource getResource() {
    	Object selection = getSelectedItem();
    	if (selection instanceof Resource) {
    		Resource r = (Resource) selection;
    		return r;
    	} else {
    		return null;
    	}
    }

    
    public void setSelection(Resource r) {
    	if (r == null) {
    		setSelectedIndex(0);
    		return;
    	}
    	if (r instanceof ResourceAntiMatter) {
    		setSelectedIndex(1);
    	} else if (r instanceof ResourceCloakPalm) {
    		setSelectedIndex(2);
    	} else if (r instanceof ResourcePsiFungus) {
    		setSelectedIndex(3);
    	} else if (r instanceof ResourceTritanOre) {
    		setSelectedIndex(4);
    	} else if (r instanceof ResourceWarpCrystal) {
    		setSelectedIndex(5);
    	} else if (r instanceof ResourceBoralium) {
    		setSelectedIndex(6);
    	} else if (r instanceof ResourceEnergySpores) {
    		setSelectedIndex(7);
    	} else {
    		setSelectedIndex(0);
    	}
    }

	public void clear() {
		setSelectedIndex(-1);
	}
}
