/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.editor.swing.window;

import javax.swing.JPanel;

import mot.client.deligates.MoveableOwnedObjectDelegate;
import mot.client.deligates.NamedObjectDelegate;
import mot.client.deligates.PlanetDelegate;
import mot.client.deligates.PlayerDelegate;
import mot.client.deligates.SolarSystemDelegate;
import mot.client.swing.common.ComponentTable;
import mot.client.swing.common.PadPanel;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;
import mot.editor.swing.window.actions.CloseEditorButton;

public class EditorPanel extends ComponentTable {

	private JPanel editorContent;
	private EditorWindowListener listener;
	
	public EditorPanel(EditorWindowListener listener) throws ApplicationError, ValidationError {
		super("HVSP", 2, 1, 0, 0, 0);
		this.listener = listener;
		
		NamedObjectDelegate selection = listener.getState().getSelection();
		
		setContent(selection, null);
	}
	
	public void setContent(NamedObjectDelegate selection, NamedObjectDelegate[] selectionList) throws ApplicationError, ValidationError {		
		removeAll();
		
		if (selection == null) {
			add(new JPanel());
		} else if (selection instanceof PlayerDelegate) {
			add(new EditorPlayerPanel(listener, (PlayerDelegate) selection));
		} else if (selection instanceof PlanetDelegate) {
			add(new EditorPlanetPanel(listener, (PlanetDelegate) selection));
		} else if (selection instanceof SolarSystemDelegate) {
			add(new EditorSolarSystemPanel(listener, (SolarSystemDelegate) selection));
		} else if (selection instanceof MoveableOwnedObjectDelegate) {
			add(new EditorCraftPanel(listener, (MoveableOwnedObjectDelegate) selection, (MoveableOwnedObjectDelegate [])selectionList));
		} else {
			add(new JPanel());
		}
		add(new PadPanel(new CloseEditorButton(),10),"");
		
		validate();
		repaint();
	}

}
