/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.editor.swing.window.actions;

import mot.client.animation.GalaxyAnimationRegister;
import mot.client.deligates.UserPlayerDelegate;
import mot.client.proxy.CompletedCallback;
import mot.client.proxy.ProxyStore;
import mot.client.swing.buttons.MotButton;
import mot.client.swing.window.galaxy.GalaxyWindowListener;
import mot.client.swing.window.galaxy.GalaxyWindowView;
import mot.client.swing.window.main.MainWindow;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;

public class CloseEditorButton extends MotButton implements CompletedCallback {
    
	public CloseEditorButton() {
		super(L.CLOSE_EDITOR);
	}

	protected void _doAction() throws ApplicationError, ValidationError {
		ProxyStore.getInstance().updateDelegates(this);
	}

	public void complete(Object result) throws ApplicationError, ValidationError {
		MainWindow mainWindow = MainWindow.getInstance();
    	GalaxyWindowListener gwl = mainWindow.getGalaxyMapListener();
    	gwl.clearSelection();
    	
    	GalaxyWindowView galaxyView = mainWindow.getGalaxyMapConfiguration().getGalaxyView();
		GalaxyWindowView view = galaxyView;
        view.getMapPanel().rebuildContent();
		view.getRadarPanel().repaint();
		GalaxyAnimationRegister.clean();
		
        mainWindow.toGalaxyWindow();
        
        UserPlayerDelegate owner = MainWindow.getOwner();
        galaxyView.getStatusPanel().updateStatus(owner);
        galaxyView.getMapPanel().rebuildContent();
	}
	
}
