/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.editor.swing.window.actions;

import mot.client.deligates.MoveableOwnedObjectDelegate;
import mot.client.deligates.cache.DeligateCacheManager;
import mot.client.proxy.CompletedClientCallbackSyncroniser;
import mot.client.proxy.LocalServerProxy;
import mot.client.proxy.ProxyStore;
import mot.client.swing.buttons.MotButton;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;
import mot.editor.swing.window.EditorWindowListener;
import mot.engine.MotEngine;
import mot.engine.common.MoveableOwnedObject;
import mot.engine.crafts.Craft;
import mot.engine.crafts.Fleet;
import mot.engine.transports.Transport;

public class DeleteCraftButton extends MotButton {
    
	private EditorWindowListener listener;
	private MoveableOwnedObjectDelegate craftDelegate;

	public DeleteCraftButton(EditorWindowListener listener, MoveableOwnedObjectDelegate craft) {
		super("Delete Craft");
		this.listener = listener;
		this.craftDelegate = craft;
	}

	public DeleteCraftButton(EditorWindowListener listener) {
		super("Delete Craft");
		this.listener = listener;
	}

	protected void _doAction() throws ApplicationError, ValidationError {
		LocalServerProxy localDelegate = ProxyStore.getInstance().getLocalServerProxy();
		if (localDelegate == null) {
			throw new ValidationError(L.EDITOR_REQUIRES_LOCAL_CLIENT);
		}
		
		if (craftDelegate == null) return;
		
		MoveableOwnedObject moo = localDelegate.getMoveableOwnedObject(craftDelegate);
		
		if (moo instanceof Transport) {
			Transport transport = (Transport) moo;
			transport.destroy();
		} else if (moo instanceof Craft) {
			Craft craft = (Craft) moo;
			if (craft.getFleet() != null) {
				throw new ValidationError("Must delete fleet or remove craft from fleet first");
			}
			craft.destroy();
		} else if (moo instanceof Fleet) {
			Fleet fleet = (Fleet) moo;
			if (fleet.getTask() != null) {
				throw new ValidationError("This Fleet is part of a Computer Players AI");
			}
			fleet.destroy();
		}
				
		MotEngine.instance.getInfluence().update();
		DeligateCacheManager.flush();
		CompletedClientCallbackSyncroniser callbackSync = new CompletedClientCallbackSyncroniser();
		ProxyStore.getInstance().updateDelegates(callbackSync);
        callbackSync.waitTillComplete();
		//GalaxyAnimationRegister.clean();
		listener.getView().getMapPanel().rebuildContent();
		
		craftDelegate = null;
	}

	public MoveableOwnedObjectDelegate getCraftDelegate() {
		return craftDelegate;
	}

	public void setCraftDelegate(MoveableOwnedObjectDelegate planetDelegate) {
		this.craftDelegate = planetDelegate;
	}
}
