/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.editor.swing.window.actions;

import mot.client.deligates.NamedObjectDelegate;
import mot.client.deligates.PlanetDelegate;
import mot.client.deligates.PlayerDelegate;
import mot.client.deligates.StellarObjectDelegate;
import mot.client.deligates.cache.DeligateCacheManager;
import mot.client.proxy.CompletedClientCallbackSyncroniser;
import mot.client.proxy.LocalServerProxy;
import mot.client.proxy.ProxyStore;
import mot.client.swing.buttons.MotButton;
import mot.client.swing.combos.OrbitCombo;
import mot.client.swing.combos.PlayerCombo;
import mot.common.designs.CraftDesign;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;
import mot.editor.swing.controls.CraftDesignCombo;
import mot.editor.swing.window.EditorWindowListener;
import mot.engine.common.Orbit;
import mot.engine.crafts.CraftFactory;
import mot.engine.players.Player;

public class NewCraftButton extends MotButton {
    
	private EditorWindowListener listener;
	private PlayerCombo newCraftOwnerSelect;
	private CraftDesignCombo newCraftDesignSelectCombo;
	private OrbitCombo newCraftOrbitSelectCombo;

	public NewCraftButton(EditorWindowListener listener, PlayerCombo newCraftOwnerSelect, CraftDesignCombo newCraftDesignSelectCombo, OrbitCombo newCraftOrbitSelectCombo) {
		super("Create Craft");
		this.listener = listener;
		this.newCraftOwnerSelect = newCraftOwnerSelect;
		this.newCraftDesignSelectCombo = newCraftDesignSelectCombo;
		this.newCraftOrbitSelectCombo = newCraftOrbitSelectCombo;
	}

	protected void _doAction() throws ApplicationError, ValidationError {
		LocalServerProxy localDelegate = ProxyStore.getInstance().getLocalServerProxy();
		if (localDelegate == null) {
			throw new ValidationError(L.EDITOR_REQUIRES_LOCAL_CLIENT);
		}
		
		PlayerDelegate player = newCraftOwnerSelect.getSelectedPlayer();
		if (player == null) throw new ValidationError("Must Select an Owner");
		Player owner = localDelegate.getPlayer(player);
		
		CraftDesign craftDesign = newCraftDesignSelectCombo.getCraftDesign();
		if (craftDesign == null) throw new ValidationError("Must Select a Craft Design");
		
		NamedObjectDelegate s = newCraftOrbitSelectCombo.getNamedObject();
		if (s == null) throw new ValidationError("Must Select an Orbit");

		Orbit orbit = null;
		if (s instanceof PlanetDelegate) orbit = localDelegate.getPlanet((PlanetDelegate)s).getOrbit();
		if (s instanceof StellarObjectDelegate) orbit = localDelegate.getStellarObject((StellarObjectDelegate)s).getOrbit();
		if (orbit == null) throw new ValidationError("Must Select a Valid Orbit");

		CraftFactory.getCraftInstance(craftDesign, owner, owner, orbit, false, false);
		
		DeligateCacheManager.flush();
		CompletedClientCallbackSyncroniser callbackSync = new CompletedClientCallbackSyncroniser();
		ProxyStore.getInstance().updateDelegates(callbackSync);
        callbackSync.waitTillComplete();
		//GalaxyAnimationRegister.clean();
		listener.getView().getMapPanel().rebuildContent();
		
	}
}
