/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.editor.swing.window.actions;

import mot.client.deligates.PlanetDelegate;
import mot.client.deligates.SolarSystemDelegate;
import mot.client.deligates.cache.DeligateCacheManager;
import mot.client.proxy.CompletedClientCallbackSyncroniser;
import mot.client.proxy.LocalServerProxy;
import mot.client.proxy.ProxyStore;
import mot.client.swing.buttons.MotButton;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;
import mot.editor.swing.window.EditorWindowListener;
import mot.engine.MotEngine;
import mot.engine.planets.PlanetFactory;
import mot.engine.planets.SolarSystem;

public class NewPlanetButton extends MotButton {
    
	private EditorWindowListener listener;
	private SolarSystemDelegate solarSystem;

	public NewPlanetButton(EditorWindowListener listener, SolarSystemDelegate solarSystem) {
		super("New Planet");
		this.listener = listener;
		this.solarSystem = solarSystem;
	}

	protected void _doAction() throws ApplicationError, ValidationError {
		LocalServerProxy localDelegate = ProxyStore.getInstance().getLocalServerProxy();
		if (localDelegate == null) {
			throw new ValidationError(L.EDITOR_REQUIRES_LOCAL_CLIENT);
		}
		
		PlanetDelegate[] planets = solarSystem.getPlanets();
		if (planets != null && planets.length > PlanetFactory.PLANET_SUFFIXES.length-3) {
			throw new ValidationError("This solar system already has the maximum quantity of planets");
		}
		
		SolarSystem ss = localDelegate.getSolarSystem(solarSystem);
		PlanetFactory.createRandomPlanet(ss);
		
		MotEngine.instance.getInfluence().update();
		DeligateCacheManager.flush();
		CompletedClientCallbackSyncroniser callbackSync = new CompletedClientCallbackSyncroniser();
		ProxyStore.getInstance().updateDelegates(callbackSync);
        callbackSync.waitTillComplete();
		//GalaxyAnimationRegister.clean();
		listener.getView().getMapPanel().rebuildContent();
		
		solarSystem = (SolarSystemDelegate) DeligateCacheManager.getStellarObject(ss.getName());
	}
}
