/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine;

import java.io.File;

import mot.client.deligates.CraftDelegate;
import mot.client.deligates.PlayerDelegate;
import mot.client.deligates.UserPlayerDelegate;
import mot.client.deligates.cache.DeligateCacheManager;
import mot.client.deligates.debug.DebugStateBattleMovement;
import mot.client.proxy.ProxyStore;
import mot.client.swing.window.common.MotInputDialog;
import mot.client.swing.window.common.SelectTechByTypeWindow;
import mot.client.swing.window.craft.SelectCraftWindow;
import mot.client.swing.window.galaxy.GalaxyWindowListener;
import mot.client.swing.window.main.MainWindow;
import mot.client.telemetry.Telemetry;
import mot.common.bean.Location;
import mot.common.bean.NameList;
import mot.common.bean.Nebula;
import mot.common.bean.PlayerColor;
import mot.common.bean.SalvageList;
import mot.common.bean.Size;
import mot.common.coms.protocols.MotSocket;
import mot.common.designs.CraftDesign;
import mot.common.morals.MoralChoices;
import mot.common.setup.OptionsFactory;
import mot.common.setup.RaceOptions;
import mot.common.technology.Computers;
import mot.common.technology.Engine;
import mot.common.technology.Engines;
import mot.common.technology.Hulls;
import mot.common.technology.Scanner;
import mot.common.technology.Scanners;
import mot.common.technology.Shields;
import mot.common.technology.Special;
import mot.common.technology.Technologies;
import mot.common.technology.Technology;
import mot.common.technology.TechnologyTree;
import mot.common.technology.Weapon;
import mot.common.technology.Weapons;
import mot.common.util.ApplicationError;
import mot.common.util.Logger;
import mot.common.util.Utils;
import mot.common.util.ValidationError;
import mot.common.xml.XMLWriter;
import mot.engine.common.CompletedServerCallbackSyncroniser;
import mot.engine.common.StellarObject;
import mot.engine.crafts.Craft;
import mot.engine.event.StateUpdateEF;
import mot.engine.event.TechnologyDiscoveredEF;
import mot.engine.leaders.LeaderFactory;
import mot.engine.planets.Planet;
import mot.engine.planets.SolarSystem;
import mot.engine.players.Player;
import mot.engine.players.Players;
import mot.engine.players.UserPlayer;
import mot.engine.players.mayor.CraftDesignerMilitary;
import mot.engine.players.morals.MoralPolicyAdvisorBasic;
import mot.engine.players.strategists.StratagistBasic;
import mot.engine.setup.MotFactory;
import mot.engine.setup.ResourceFactory;
import mot.test.BattleGraphicsTest;
import mot.test.TestBase;

/**
 * Cheat codes 500 - 599 are safe and can be used at will.
 * Cheat codes 600 - 699 cannot be saved in a save game.
 * 
 * USE Key 'z'
 * 
 */
public class Cheat  {

    public static void cheat(PlayerDelegate playerDeligate) {
    	String playerName = playerDeligate.getName();
        try {
        	Player player = MotEngine.instance.getPlayers().getPlayer(playerName);
        	String code = MotInputDialog.showInPopup(null, "Enter cheat code", "CHEAT");
            if (code.equalsIgnoreCase("visitall")) {
                visitAll(player, 0);
            } else if (code.equalsIgnoreCase("spyall")) {
                visitAll(player, 1);
            } else if (code.equalsIgnoreCase("superscanner")) {
                player.getPlanetWithHighestProduction().setScanners(new Scanners(new Scanner("SuperScanner", 2000)));
            } else if (code.equalsIgnoreCase("discover")) {
                discover(player);
            } else if (code.equalsIgnoreCase("alldiscover")) {
                allDiscover();
            } else if (code.equalsIgnoreCase("money")) {
                giveMoney(player);
            } else if (code.equalsIgnoreCase("salvage")) {
            	player.addSalvage(Technologies.getWeapons().getAllAsArray());
            	player.addSalvage(Technologies.getSpecials().getAllAsArray());
            } else if (code.equalsIgnoreCase("_debug_505")) {
                moveSS();
            } else if (code.equalsIgnoreCase("_debug_506")) {
                setPlanet();
            } else if (code.equalsIgnoreCase("_debug_507")) {
            	createSpecialCraft(player);
            } else if (code.equalsIgnoreCase("_debug_508")) {
                Players players = MotEngine.instance.getPlayers();
                players.getComputerPlayers()[0].steelTechnology(player, null);
            } else if (code.equalsIgnoreCase("offerleader")) {
                LeaderFactory._debugMustOfferLeader = player;
            } else if (code.equalsIgnoreCase("releasekaan")) {
            	Nebula[] nebulae = MotEngine.instance.getStellarObjects().getNebulae();
            	if (nebulae != null && nebulae.length > 0) {
            		Nebula nebula = (Nebula) Utils.random(nebulae);
            		MotEngine.instance.getMonsterPlayer().dispatchKaan(nebula, null);
            	}
            } else if (code.equalsIgnoreCase("_debug_510")) {
            	MoralPolicyAdvisorBasic mpa = (MoralPolicyAdvisorBasic) player.getMoralPolicyAdvisorNotNull();
            	mpa.createNewAdvice(player);
            } else if (code.equalsIgnoreCase("_debug_511")) {
        		MotEngine.instance.broadcast( new TechnologyDiscoveredEF(Technologies.getWeapon("FusionBeam"), true), player);
            } else if (code.equalsIgnoreCase("_debug_600")) {
                giveMeSuperScanner(player);
            } else if (code.equalsIgnoreCase("_debug_601")) {
                newMoralChoice(player);
            } else if (code.equalsIgnoreCase("_debug_602")) {
            	StratagistBasic.__TEST_REQUEST_ALLIANCE__ = player;
            } else if (code.equalsIgnoreCase("_debug_603")) {
            	StratagistBasic.__TEST_REQUEST_TRADE__ = player;
            } else if (code.equalsIgnoreCase("_debug_700")) {
                newGame1();
            } else if (code.equalsIgnoreCase("telemetry_on")) {
                Telemetry.ON = true;
            } else if (code.equalsIgnoreCase("telemetry_off")) {
                Telemetry.ON = false;
            } else if (code.equalsIgnoreCase("telemetry_clear")) {
                Telemetry.clear();
            } else if (code.equalsIgnoreCase("telemetry_save")) {
                Telemetry.save();
            } else if (code.equalsIgnoreCase("_debug_999")) {
                MotSocket.log = !MotSocket.log;
            } else if (code.equalsIgnoreCase("_debug_savetechs")) {
				saveTechs();
            } else if (code.equalsIgnoreCase("_debug_battle_craft")) {
            	CraftDelegate[] crafts = DeligateCacheManager.getCrafts();
            	SelectCraftWindow scw = new SelectCraftWindow(MainWindow.getOwner(), null, crafts, "Select a craft to monitor");
            	scw.waitUntilClosed();
				if (scw.craft != null) {
					CraftDelegate craft = (CraftDelegate) scw.craft;
					craft.setDebugState(new DebugStateBattleMovement());
				}
            } else if (code.equalsIgnoreCase("_debug_battle")) {
				createTestBattle();
            }
            StateUpdateEF stateUpdateEvent = new StateUpdateEF();
            MotEngine.instance.addStateUpdate(stateUpdateEvent, player, true, false, true, true, true, true, true, false, true, false, true);
            MotEngine.instance.broadcast(stateUpdateEvent, player);
        } catch (Exception e) {
            Logger.logError("Error", e);
        }
    }

	private static void createTestBattle() throws Exception {
		new BattleGraphicsTest("XX").runInGame(MotEngine.instance, MainWindow.getExestingInstance());
	}

	private static void saveTechs() throws ApplicationError {
		XMLWriter writer = new XMLWriter(null, null, null, true);
		Technologies.getWeapons().toXML(writer);
		writer.save(new File("updates/tech_weapons.xml"));
		writer = new XMLWriter(null, null, null, true);
		Technologies.getBiotechnologies().toXML(writer);
		writer.save(new File("updates/tech_bios.xml"));
		writer = new XMLWriter(null, null, null, true);
		Technologies.getComputers().toXML(writer);
		writer.save(new File("updates/tech_computers.xml"));
		writer = new XMLWriter(null, null, null, true);
		Technologies.getEngines().toXML(writer);
		writer.save(new File("updates/tech_engines.xml"));
		writer = new XMLWriter(null, null, null, true);
		Technologies.getFactories().toXML(writer);
		writer.save(new File("updates/tech_factories.xml"));
		writer = new XMLWriter(null, null, null, true);
		Technologies.getHulls().toXML(writer);
		writer.save(new File("updates/tech_hulls.xml"));
		writer = new XMLWriter(null, null, null, true);
		Technologies.getLaboratories().toXML(writer);
		writer.save(new File("updates/tech_labs.xml"));
		writer = new XMLWriter(null, null, null, true);
		Technologies.getMiscTechnologies().toXML(writer);
		writer.save(new File("updates/tech_misc.xml"));
		writer = new XMLWriter(null, null, null, true);
		Technologies.getModules().toXML(writer);
		writer.save(new File("updates/tech_modules.xml"));
		writer = new XMLWriter(null, null, null, true);
		Technologies.getScanners().toXML(writer);
		writer.save(new File("updates/tech_scanners.xml"));
		writer = new XMLWriter(null, null, null, true);
		Technologies.getShields().toXML(writer);
		writer.save(new File("updates/tech_shields.xml"));
		writer = new XMLWriter(null, null, null, true);
		Technologies.getSpecials().toXML(writer);
		writer.save(new File("updates/tech_specials.xml"));
		writer = new XMLWriter(null, null, null, true);
		Technologies.getTheories().toXML(writer);
		writer.save(new File("updates/tech_theories.xml"));
		writer = new XMLWriter(null, null, null, true);
		TechnologyTree.getInstance().toXML(writer);
		writer.save(new File("updates/tech_tree.xml"));
	}

    public static void visitAll(Player player, int qtySpies) throws ApplicationError {
        StellarObject [] sos = MotEngine.instance.getStellarObjects().getStellarObjects();
        for (int i=0; sos != null && i<sos.length; i++) {
            sos[i].addVisitor(player, qtySpies, false);
        }
    }

    public static void discover(Player player) throws ApplicationError, ValidationError {
    	SelectTechByTypeWindow selectWin = new SelectTechByTypeWindow(null, SelectTechByTypeWindow.getAllTechTypeList(), MainWindow.getOwner(), null, true);
    	selectWin.show();
    	selectWin.waitUntilClosed();
    	Technology tech = selectWin.getSelection();
        if (tech != null) {
	        player.addTechnology(tech);
	        player.notifyTechnologyDiscovered(tech, true);
        }
    }

    public static void allDiscover() throws ApplicationError, ValidationError {
    	SelectTechByTypeWindow selectWin = new SelectTechByTypeWindow(null, SelectTechByTypeWindow.getAllTechTypeList(), MainWindow.getOwner(), null, true);
    	selectWin.show();
    	selectWin.waitUntilClosed();
    	Technology tech = selectWin.getSelection();
        if (tech != null) {
	        Player [] players = MotEngine.instance.getPlayers().getPlayers();
	        for (int i=0; i<players.length; i++) {
	            players[i].addTechnology(tech);
		        players[i].notifyTechnologyDiscovered(tech, true);
	        }
        }
    }
    
    public static void giveMoney(Player player) throws ApplicationError, ValidationError {
        String v = MotInputDialog.showInPopup(null, "Enter the amount", "Dialog");
        if (v == null) {
            return;
        }
        try {
            player.addFunds(Integer.parseInt(v));
        } catch (NumberFormatException e) { Logger.logError("Unable to add Money", e); }
    }

    public static void newMoralChoice(Player player) throws ApplicationError, ValidationError {
        String v = MotInputDialog.showInPopup(null, "Enter Moral Choice", "Dialog");
        if (v == null) {
            return;
        }
        try {
            player.add(MoralChoices.getMoralChoice(v));
        } catch (NumberFormatException e) { Logger.logError("Unable to add moral choice", e); }
    }

    public static void giveMeSuperScanner(Player player) throws ApplicationError {
        Scanner superScanner = getSuperScanner();
        Planet [] planets = player.getPlanets();
        for (int i=0; planets != null && i<planets.length; i++) {
            if (planets[i].getScanners() == null) planets[i].setScanners(new Scanners());
            planets[i].getScanners().add(superScanner);
        }
    }

    public static void moveSS() throws ApplicationError, ValidationError {
        String v = MotInputDialog.showInPopup(null, "Enter the SS Name", "Dialog");
        if (v == null) {
            return;
        }
        StellarObject so = MotEngine.instance.getStellarObjects().getStellarObject(v);
        if (so == null) {
            return;
        }
        Location oldLoc = so.getLocation();
        int x = getInteger("Enter X");
        int y = getInteger("Enter Y");
        if (x > 0 && y > 0) {
            so.setLocation(new Location(x,y));
        }
        Craft [] crafts = MotEngine.instance.getCrafts().getAt(oldLoc);
        if (crafts != null) {
            for (int i=0; i<crafts.length; i++) {
                crafts[i].setLocation(new Location(so.getLocation()));
            }
        }
    }

    public static void setPlanet() throws ApplicationError, ValidationError {
        String v = MotInputDialog.showInPopup(null, "Enter the Planet Name", "Dialog");
        if (v == null) {
            return;
        }
        Planet p = MotEngine.instance.getPlanets().getPlanet(v);
        if (p == null) {
            return;
        }
        int size = getInteger("Enter Size (10 - 130)");
        double quality = getDouble("Enter Terraform (0.1 - 1.0)");
        double prodBonus = getDouble("Enter Production Bonus (0.5 - 4.0)");
        double resBonus = getDouble("Enter Research Bonus (0.5 - 4.0)");
        double reproBonus = getDouble("Enter Reproduction Bonus (0.5 - 4.0)");
        int moneyBonus = getInteger("Enter Money Bonus (0-100)");
        if (size > 0) {
            p.setSize(size);
        }
        if (quality > 0) {
            p.setTeraforming(quality);
        }
        if (prodBonus > 0) {
            p.setProductionBonus(prodBonus);
        }
        if (resBonus > 0) {
            p.setResearchBonus(resBonus);
        }
        if (reproBonus > 0) {
            p.setReproductionBonus(reproBonus);
        }
        if (moneyBonus > 0) {
            p.setMoneyBonus(moneyBonus);
        }
    }
    
    private static int getInteger(String question) throws ApplicationError {
        String v = MotInputDialog.showInPopup(null, question, "Dialog");
        try {
            return Integer.parseInt(v);
        } catch (Exception e) {
            return -1;
        }
    }

    private static double getDouble(String question) throws ApplicationError {
        String v = MotInputDialog.showInPopup(null, question, "Dialog");
        try {
            return Double.parseDouble(v);
        } catch (Exception e) {
            return -1;
        }
    }

    public static Scanner getSuperScanner() throws ApplicationError {
        Scanner superScanner = new Scanner();
        superScanner.setStrength(99000);
        superScanner.setName("SuperScanner");
        superScanner.setDescription("Scanner Made by Cheating");
        return superScanner;
    }

    public static MainWindow newGame1() throws ApplicationError, ValidationError {
    	boolean withPlanet = true;
    	boolean withAsteroids = true;
    	
        String [] races = new String [] { "Humans", "Birds"};
    
        MotEngine.newInstance();
        MotEngine.instance.setDate(3000);
        MotEngine.instance.getStellarObjectsNotNull().setSize(new Size(600,600));
        
        MainWindow mainWin = MainWindow.getInstance();

        RaceOptions userOptions = OptionsFactory.getRaceOptions(races[0]);
        RaceOptions enemyOptions = OptionsFactory.getRaceOptions(races[1]);

        UserPlayer user = TestBase.newUserPlayer(races[0],PlayerColor.getColorForName("blue"), null, userOptions);
        Player enemy = TestBase.newPlayer(races[1], PlayerColor.getColorForName("green"), enemyOptions, races);
        
        // IS USER CLOAKED?
        //user.getPlayerCharacter().setCloakLevel(1000);
        
        // IS ENEMY IMUNE?
        //enemy.getPlayerCharacter().setImmunity(null);
        
        Technology [] all = TechnologyTree.getInstance().getTechnologies();
        user.addTechnologies(all);
        enemy.addTechnologies(all);
        
        user.setFunds(10000);
        enemy.setFunds(10000);
        user.setBoralium(20);

        // Create a proxy which acts as the glue between the user interface and the engine.
        CompletedServerCallbackSyncroniser callback = new CompletedServerCallbackSyncroniser();
        ProxyStore.getInstance().register(user.getName(), true, callback, null);
        callback.waitTillComplete();

        UserPlayerDelegate upd = (UserPlayerDelegate) DeligateCacheManager.getPlayer(user.getName());
        mainWin._setWindowOwner(upd);

        RaceOptions [] options = new RaceOptions [] {userOptions, enemyOptions};
        MotFactory.setupRelations(options, races, null, null, false);
        
        SolarSystem ss1 = TestBase.newSolarSystem("SS1", 200, 300);
        SolarSystem ss2 = TestBase.newSolarSystem("SS2", 400, 300);

        SolarSystem ss3 = TestBase.newSolarSystem("SS3", 300, 200);
        SolarSystem ss4 = TestBase.newSolarSystem("SS4", 300, 300);
        SolarSystem ss5 = TestBase.newSolarSystem("SS5", 300, 400);

        SolarSystem ssa = TestBase.newSolarSystem("SSA", 200, 200);
        SolarSystem ssb = TestBase.newSolarSystem("SSB", 400, 400);
        
        Planet planet1 = TestBase.newPlanet("SS1-A", ss1, user);
        planet1.setSize(150);
        planet1.setPopulation(150);
        planet1.setQtyFactories(500);
        planet1.setProductionBonus(4.0);

        Planet planet2 = TestBase.newPlanet("SS2-A", ss2, enemy);
        planet2.setSize(150);
        planet2.setPopulation(150);
        planet2.setQtyFactories(500);
        planet2.setProductionBonus(4.0);
        
        Planet planetA = TestBase.newPlanet("SSA-A", ssa, user);
        planetA.setSize(100);
        planetA.setPopulation(50);
        planetA.setQtyFactories(50);

        Planet planetB = TestBase.newPlanet("SSB-A", ssb, enemy);
        planetB.setSize(100);
        planetB.setPopulation(50);
        planetB.setQtyFactories(50);

        Planet planet4;
        if (withPlanet) {
        	planet4 = TestBase.newPlanet("SS4-A", ss4, enemy);
        	planet4.setSize(100);
        	planet4.setPopulation(50);
        	planet4.setQtyFactories(50);
        	planet4.setWeapons(new Weapons("IonCannon", 1));
        	planet4.getWeapons().add(new Weapons("Missile6", 2));
        	//planet4.getWeapons().add(new Weapons("SpacialDistortion", 1));
        } else {
            planet4 = TestBase.newPlanet("SS4-A", ss4, null, 100, 0.4);
        }
        ResourceFactory.createResource(planet4);

        // ************   DO WE WANT ASTEROIDS?
        //planet4.setHasAsteroids(withAsteroids);

        enemy.getEngines().removeGroup(Engine.GROUP_TELEPORT);
        CraftDesign cd1 = new CraftDesignerMilitary().designCraft(enemy, CraftDesignerMilitary.SIZE_LARGE, 0.0, 0.0);
        TestBase.newCraft(cd1, enemy, ss4);
        TestBase.newCraft(cd1, enemy, ss4);
        
        CraftDesign cd2 = new CraftDesign();
        cd2.setHull(user.getHulls().getBiggestCraftHull());
        cd2.setEngine(user.getEngines().getFastestEngine(Engine.GROUP_ANTI_MATTER));
        cd2.setComputer(user.getComputers().getMostPowerfulComputer());
        cd2.setShield(user.getShields().getBestShield());
        cd2.setScanner(user.getScanners().getBestScanner());
        
        cd2.setName("BioShip");
        cd2.setWeapon((Weapon)user.getWeapons().getMostAdvancedWithGroup(Weapon.GROUP_SHIELD_DRAIN), 0, 5);
        cd2.fillWithWeapon((Weapon)user.getWeapons().getMostAdvancedWithGroup(Weapon.GROUP_BIO), 0);
        TestBase.newCraft(cd2, user, ss4);
        
        cd2.setName("TheftShip");
        cd2.removeAllWeapons();
        cd2.setWeapon((Weapon)user.getWeapons().getMostAdvancedWithGroup(Weapon.GROUP_SHIELD_DRAIN), 0, 5);
        cd2.fillWithWeapon((Weapon)user.getWeapons().getMostAdvancedWithGroup(Weapon.GROUP_TRANSPORT), 0);
        TestBase.newCraft(cd2, user, ss4);
        
        cd2.setName("PsiShip");
        cd2.removeAllWeapons();
        cd2.fillWithWeapon((Weapon)user.getWeapons().getMostAdvancedWithGroup(Weapon.GROUP_PSI), 0);
        TestBase.newCraft(cd2, user, ss4);
        //TestBase.newCraft(cd2, enemy, ss4);
        
        cd2.setName("GiroShip");
        cd2.removeAllWeapons();
        cd2.fillWithWeapon((Weapon)user.getWeapons().getMostAdvancedWithGroup(Weapon.GROUP_GIRATOR), 0);
        cd2.setWeapon((Weapon)user.getWeapons().getMostAdvancedWithGroup(Weapon.GROUP_GIRATOR), 0, 30);
        TestBase.newCraft(cd2, user, ss4);
        
        cd2.setName("InvaderShip");
        cd2.removeAllWeapons();
        cd2.setWeapon((Weapon)user.getWeapons().getMostAdvancedWithGroup(Weapon.GROUP_SHIELD_DRAIN), 0, 4);
        cd2.setWeapon((Weapon)user.getWeapons().getMostAdvancedWithGroup(Weapon.GROUP_BIO), 0, 5);
        cd2.fillWithWeapon((Weapon)user.getWeapons().getMostAdvancedWithGroup(Weapon.GROUP_TROOP_TRANSPORT), 0);
        TestBase.newCraft(cd2, user, ss4);
        cd2.setSpecials((NameList)null);
/*
        cd2.setName("CheatInvaderShip");
        cd2.removeAllWeapons();
        cd2.setWeapon((Weapon)user.getWeapons().getMostAdvancedWithGroup(Weapon.GROUP_SHIELD_DRAIN), 0, 4);
        cd2.setWeapon((Weapon)user.getWeapons().getMostAdvancedWithGroup(Weapon.GROUP_TROOP_TRANSPORT), 0, 15);
        cd2.setSpecial(user.getSpecials().getBestQtyBerths());
        TestBase.newCraft(cd2, user, ss4);
        cd2.setSpecials(null);
 */

        cd2.setName("SuicideShip");
        cd2.removeAllWeapons();
        cd2.setHull(user.getHulls().getSmallestCraftHullWithSpaceFor(cd2.getEngineTech(), user.getWeapons().getMostAdvancedWithGroup(Weapon.GROUP_DETONATOR)));        
        cd2.setWeapon((Weapon)user.getWeapons().getMostAdvancedWithGroup(Weapon.GROUP_DETONATOR), 0, 1);
        TestBase.newCraft(cd2, user, ss4);

        cd2.setName("HoloShip");
        cd2.removeAllWeapons();
        cd2.setSpecial((Special)user.getSpecials().getMostAdvancedWithGroup(Special.GROUP_HOLO_EMITER));
        cd2.setWeapon((Weapon)user.getWeapons().getMostAdvancedWithGroup(Weapon.GROUP_BEAM), 0, 1);
        cd2.setWeapon((Weapon)user.getWeapons().getMostAdvancedWithGroup(Weapon.GROUP_REPLICA_BEAM), 0, 1);
        TestBase.newCraft(cd2, user, ss4);

        TestBase.newCraft(cd1, user, ss4);
        
        cd1.setName("StallWalt");
        cd1.removeAllWeapons();
        cd1.setWeapon((Weapon)user.getWeapons().getMostAdvancedWithGroup(Weapon.GROUP_PROJECTILE), 0, 10);
        cd1.setWeapon((Weapon)user.getWeapons().getMostAdvancedWithGroup(Weapon.GROUP_BEAM), 0, 50);
        cd1.setWeapon((Weapon)user.getWeapons().getMostAdvancedWithGroup(Weapon.GROUP_SHIELD_DRAIN), 0, 10);
        cd1.setSpecial((Special)user.getSpecials().getMostAdvancedWithGroup(Special.GROUP_SHIELD_SPAN));
        TestBase.newCraft(cd1, user, ss4);
        
        cd1.setName("NewShip");
        cd1.removeAllWeapons();
        cd1.setWeapon((Weapon)user.getWeapons().getMostAdvancedWithGroup(Weapon.GROUP_DAMAGE_BOT), 0, 5);
        cd1.setWeapon((Weapon)user.getWeapons().getMostAdvancedWithGroup(Weapon.GROUP_PLAGUE), 0, 5);
        cd1.setWeapon((Weapon)user.getWeapons().getMostAdvancedWithGroup(Weapon.GROUP_SPACIAL_DESTORTION), 0, 1);
        cd1.setWeapon((Weapon)user.getWeapons().getMostAdvancedWithGroup(Weapon.GROUP_TIME_WARP), 0, 1);
        cd1.setWeapon((Weapon)user.getWeapons().getMostAdvancedWithGroup(Weapon.GROUP_TIME_WARP_BEAM), 0, 1);
        cd1.setWeapon((Weapon)user.getWeapons().getMostAdvancedWithGroup(Weapon.GROUP_SALVAGE_BEAM), 0, 1);
        TestBase.newCraft(cd1, user, ss4);
        
        CraftDesign cd3 = new CraftDesign(cd1);
        cd3.setName("MindShip");
        cd3.removeAllWeapons();
        cd3.setWeapon((Weapon)user.getWeapons().getMostAdvancedWithGroup(Weapon.GROUP_MIND_CONTROL), 0, 1);
        cd3.setWeapon((Weapon)user.getWeapons().getMostAdvancedWithGroup(Weapon.GROUP_COWARDICE), 0, 1);
        cd3.setWeapon((Weapon)user.getWeapons().getMostAdvancedWithGroup(Weapon.GROUP_BERSERKER), 0, 1);
        cd3.setWeapon((Weapon)user.getWeapons().getMostAdvancedWithGroup(Weapon.GROUP_DROID_MINE), 0, 1);
        cd3.setWeapon((Weapon)user.getWeapons().getMostAdvancedWithGroup(Weapon.GROUP_RETARGET), 0, 1);
        cd3.setEngine((Engine)user.getEngines().getMostAdvancedWithGroup(Engine.GROUP_TELEPORT));
        TestBase.newCraft(cd3, user, ss4);
        
        MotEngine.instance.getSpiesNotNull().addDefendingSpies(user, 25);
        
        user.setSalvage(new SalvageList(Technologies.getWeapons().getMostAdvancedWithGroup(Weapon.GROUP_BEAM)));

        // Setup main window to display the galaxy!
        MainWindow mainWindow = MainWindow.getInstance();
        mainWindow.getGalaxyMapConfiguration().setOwner(upd.getName());
        mainWindow.getBattleWinConfig().setOwner(upd.getName());
    	GalaxyWindowListener gwl = mainWindow.getGalaxyMapListener();
    	gwl.clearSelection();
         
        gwl.setMapWindowSize();
        gwl.focusOnHomeSolarSystem();
        mainWindow.getGalaxyMapConfiguration().getGalaxyView().updateStatus(upd);

        user.startWar(enemy, null, false);
        
        return mainWin;
    }
    
    public static void createSpecialCraft(Player user) throws ApplicationError {
        CraftDesign cd = new CraftDesign();
        SolarSystem ss = user.getCapitol().getSolarSystem();
        
        Hulls hulls = Technologies.getHulls();
        Weapons weapons = Technologies.getWeapons();
        Engines engines = Technologies.getEngines();
        Scanners scanners = Technologies.getScanners();
        Computers computers = Technologies.getComputers();
        Shields shields = Technologies.getShields();
        
        cd.setHull(hulls.getHull("Legion350"));
        cd.setEngine(engines.getFastestEngine());
        cd.setScanner(scanners.getBestScanner());
        cd.setComputer(computers.getMostPowerfulComputer());
        cd.setShield(shields.getBestDefenseShield());
        
        cd.setName("InvaderShip");
        cd.removeAllWeapons();
		cd.setWeapon((Weapon)weapons.getMostAdvancedWithGroup(Weapon.GROUP_SHIELD_DRAIN), 0, 4);
        cd.setWeapon((Weapon)weapons.getMostAdvancedWithGroup(Weapon.GROUP_BIO), 0, 5);
        cd.setWeapon((Weapon)weapons.getMostAdvancedWithGroup(Weapon.GROUP_TROOP_TRANSPORT), 0, 2);
        TestBase.newCraft(new CraftDesign(cd), user, ss);
        cd.setSpecials((NameList)null);

        cd.setName("StallWalt");
        cd.removeAllWeapons();
        cd.setWeapon((Weapon)weapons.getMostAdvancedWithGroup(Weapon.GROUP_PROJECTILE), 0, 10);
        cd.setWeapon((Weapon)weapons.getMostAdvancedWithGroup(Weapon.GROUP_BEAM), 0, 50);
        cd.setWeapon((Weapon)weapons.getMostAdvancedWithGroup(Weapon.GROUP_SHIELD_DRAIN), 0, 10);
        cd.setWeapon((Weapon)weapons.getMostAdvancedWithGroup(Weapon.GROUP_REPLICA_BEAM), 0, 1);
        cd.setSpecial((Special)user.getSpecials().getMostAdvancedWithGroup(Special.GROUP_SHIELD_SPAN));
        TestBase.newCraft(new CraftDesign(cd), user, ss);
        
        cd.setName("NewShip");
        cd.removeAllWeapons();
        cd.setWeapon((Weapon)weapons.getMostAdvancedWithGroup(Weapon.GROUP_DAMAGE_BOT), 0, 5);
        cd.setWeapon((Weapon)weapons.getMostAdvancedWithGroup(Weapon.GROUP_PLAGUE), 0, 5);
        cd.setWeapon((Weapon)weapons.getMostAdvancedWithGroup(Weapon.GROUP_SPACIAL_DESTORTION), 0, 1);
        cd.setWeapon((Weapon)weapons.getMostAdvancedWithGroup(Weapon.GROUP_TIME_WARP), 0, 1);
        cd.setWeapon((Weapon)weapons.getMostAdvancedWithGroup(Weapon.GROUP_TIME_WARP_BEAM), 0, 1);
        cd.setWeapon((Weapon)weapons.getMostAdvancedWithGroup(Weapon.GROUP_SALVAGE_BEAM), 0, 1);
        TestBase.newCraft(new CraftDesign(cd), user, ss);
        
        cd.setName("MindShip");
        cd.removeAllWeapons();
        cd.setWeapon((Weapon)weapons.getMostAdvancedWithGroup(Weapon.GROUP_MIND_CONTROL), 0, 1);
        cd.setWeapon((Weapon)weapons.getMostAdvancedWithGroup(Weapon.GROUP_COWARDICE), 0, 1);
        cd.setWeapon((Weapon)weapons.getMostAdvancedWithGroup(Weapon.GROUP_BERSERKER), 0, 1);
        cd.setWeapon((Weapon)weapons.getMostAdvancedWithGroup(Weapon.GROUP_DROID_MINE), 0, 1);
        cd.setWeapon((Weapon)weapons.getMostAdvancedWithGroup(Weapon.GROUP_RETARGET), 0, 1);
        TestBase.newCraft(new CraftDesign(cd), user, ss);

    }


}