/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine;

import java.util.ArrayList;

import mot.client.coms.LocalServerConnection;
import mot.common.event.ShutdownEvent;
import mot.common.util.ApplicationError;
import mot.common.util.Comp;
import mot.common.util.Logger;

public class ConnectionList {

	private static LocalServerConnection localServerConnection;

	private static ArrayList<SocketHandlerThreadEngine> remoteServerConnections = new ArrayList();
	

	public static void setLocalServerConnection(LocalServerConnection v) {
		localServerConnection = v;
	}

	public static LocalServerConnection getLocalServerConnection() {
		return localServerConnection;
	}

	public static void addRemoteServerConnection(SocketHandlerThreadEngine s) {
		if (Logger.isDebug()) {
			Logger.logDebug("ConnectionList.addRemoteServerConnection() "+s.getOwnerName() );
		}
		remoteServerConnections.add(s);
	}

	public static void removeRemoteServerConnection(SocketHandlerThreadEngine s) {
		if (Logger.isDebug()) {
			Logger.logDebug("ConnectionList.removeRemoteServerConnection() "+s.getOwnerName());
		}
		remoteServerConnections.remove(s);
	}

	public static SocketHandlerThreadEngine[] getRemoteServerConnections() {
		return remoteServerConnections.toArray(new SocketHandlerThreadEngine[remoteServerConnections.size()]);
	}

	public static SocketHandlerThreadEngine getRemoteServerConnectionFor(String userName) {
		for (SocketHandlerThreadEngine s : remoteServerConnections) {
			if (Comp.same(userName, s.getOwnerName())) {
				return s;
			}
		}
		return null;
	}

	public static void removeRemoteServerConnections() {
		for (SocketHandlerThreadEngine s : remoteServerConnections) {
			try {
				s.process(new ShutdownEvent());
			} catch (ApplicationError e) {
				Logger.logError("Unable to send ShutdownEvent", e);
			}
		}
	}

}
