/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine;

import java.util.HashMap;

import mot.common.command_delegates.AbandonCmdDeligate;
import mot.common.command_delegates.AcceptLeaderCmdDeligate;
import mot.common.command_delegates.AcceptMoralChoiceCmdDeligate;
import mot.common.command_delegates.AddCraftDesignDeligate;
import mot.common.command_delegates.BattleAttackCmdDeligate;
import mot.common.command_delegates.BattleAttackLocationCmdDeligate;
import mot.common.command_delegates.BattleAutomateCmdDeligate;
import mot.common.command_delegates.BattleCraftLaunchFightersCmdDeligate;
import mot.common.command_delegates.BattleCraftMoveToCmdDeligate;
import mot.common.command_delegates.BattleCraftWaitCmdDeligate;
import mot.common.command_delegates.BattleEndTurnCmdDeligate;
import mot.common.command_delegates.BattleGetNextObjectCmdDeligate;
import mot.common.command_delegates.BattleGetNextOrdersCmdDeligate;
import mot.common.command_delegates.BattleRetreatCmdDeligate;
import mot.common.command_delegates.ClientClosesWindowCmdDeligate;
import mot.common.command_delegates.CommandDeligate;
import mot.common.command_delegates.CraftBombardPlanetCmdDeligate;
import mot.common.command_delegates.CraftColoniseCmdDeligate;
import mot.common.command_delegates.CraftLeaveFleetCmdDeligate;
import mot.common.command_delegates.DesignColonyCraftCmdDeligate;
import mot.common.command_delegates.DesignMillitaryCraftCmdDeligate;
import mot.common.command_delegates.DiplomaticRequestCmdDeligate;
import mot.common.command_delegates.DiplomaticResponseCmdDeligate;
import mot.common.command_delegates.EndTurnCmdDeligate;
import mot.common.command_delegates.FetchDelegateStateCmdDelegate;
import mot.common.command_delegates.FetchGalaxyPreview;
import mot.common.command_delegates.FetchPlayerDetailsCmdDelegate;
import mot.common.command_delegates.FetchRegisteredPlayersCmdDelegate;
import mot.common.command_delegates.FetchSavedGameFiles;
import mot.common.command_delegates.FetchTechnologiesCmdDelegate;
import mot.common.command_delegates.GetCraftDesignStatistics;
import mot.common.command_delegates.GetGraphCmdDeligate;
import mot.common.command_delegates.IncreaseDevelopmentCmdDeligate;
import mot.common.command_delegates.IncreaseEcologyCmdDeligate;
import mot.common.command_delegates.JoinFleetCmdDeligate;
import mot.common.command_delegates.LoadCmdDeligate;
import mot.common.command_delegates.MooDeleteCmdDeligate;
import mot.common.command_delegates.MooDeployCmdDeligate;
import mot.common.command_delegates.MooMoveCmdDeligate;
import mot.common.command_delegates.MooRenameCmdDeligate;
import mot.common.command_delegates.MooSleepCmdDeligate;
import mot.common.command_delegates.NewGameCmdDeligate;
import mot.common.command_delegates.NewGameUserPlayerCmdDeligate;
import mot.common.command_delegates.NotificationCommandDelegate;
import mot.common.command_delegates.PurchaseProjectCmdDeligate;
import mot.common.command_delegates.RegisterProxyCmdDeligate;
import mot.common.command_delegates.RemoveCraftDesignDeligate;
import mot.common.command_delegates.RenamePlanetCmdDeligate;
import mot.common.command_delegates.RenameStellarObjectCmdDeligate;
import mot.common.command_delegates.Request;
import mot.common.command_delegates.RequestResponseCR;
import mot.common.command_delegates.SaveCmdDeligate;
import mot.common.command_delegates.SellSalvageCmdDeligate;
import mot.common.command_delegates.SetFleetWayPointCmdDelegate;
import mot.common.command_delegates.SetPlanetAutoPercentsCmdDeligate;
import mot.common.command_delegates.SetPlanetPercentsCmdDeligate;
import mot.common.command_delegates.SetPlanetWantsNoProjectCmdDeligate;
import mot.common.command_delegates.SetPlayerCharacterPercentsDeligate;
import mot.common.command_delegates.SetProjectCmdDeligate;
import mot.common.command_delegates.SetRecruiteSpyEffortCmdDeligate;
import mot.common.command_delegates.SetResearchProjectCmdDeligate;
import mot.common.command_delegates.SpyRoleAddEspionageCmdDeligate;
import mot.common.command_delegates.SpyRoleAddPlayerCmdDeligate;
import mot.common.command_delegates.SpyRoleAddSabotageCmdDeligate;
import mot.common.command_delegates.SpyRoleAddStellarObjectCmdDeligate;
import mot.common.command_delegates.SpyRoleSetEspionageTargetCmdDeligate;
import mot.common.command_delegates.SpyStealableTechnologiesCmdDelegate;
import mot.common.command_delegates.StartNextBattleInQueueCmdDeligate;
import mot.common.command_delegates.TransportLoadCmdDeligate;
import mot.common.command_results.ApplicationErrorCR;
import mot.common.command_results.CommandResult;
import mot.common.command_results.ValidationErrorCR;
import mot.common.coms.protocols.ClientEventProcessor;
import mot.common.util.ApplicationError;
import mot.common.util.Logger;
import mot.common.util.ValidationError;
import mot.engine.command_handlers.AbandonCmdHandler;
import mot.engine.command_handlers.AcceptLeaderCmdHandler;
import mot.engine.command_handlers.AcceptMoralChoiceCmdHandler;
import mot.engine.command_handlers.AddCraftDesignHandler;
import mot.engine.command_handlers.BattleAttackCmdHandler;
import mot.engine.command_handlers.BattleAttackLocationCmdHandler;
import mot.engine.command_handlers.BattleAutomateCmdHandler;
import mot.engine.command_handlers.BattleCraftLaunchFightersCmdHandler;
import mot.engine.command_handlers.BattleCraftMoveToCmdHandler;
import mot.engine.command_handlers.BattleCraftWaitCmdHandler;
import mot.engine.command_handlers.BattleEndTurnCmdHandler;
import mot.engine.command_handlers.BattleGetNextObjectCmdHandler;
import mot.engine.command_handlers.BattleGetNextOrdersCmdHandler;
import mot.engine.command_handlers.BattleRetreatCmdHandler;
import mot.engine.command_handlers.ClientClosesWindowCmdHandler;
import mot.engine.command_handlers.CraftAttackCmdHandler;
import mot.engine.command_handlers.CraftBombardPlanetCmdHandler;
import mot.engine.command_handlers.CraftColoniseCmdHandler;
import mot.engine.command_handlers.CraftLeaveFleetCmdHandler;
import mot.engine.command_handlers.DesignColonyCraftCmdHandler;
import mot.engine.command_handlers.DesignMilitaryCraftCmdHandler;
import mot.engine.command_handlers.DiplomaticRequestCmdHandler;
import mot.engine.command_handlers.DiplomaticResponseCmdHandler;
import mot.engine.command_handlers.EndTurnCmdHandler;
import mot.engine.command_handlers.FetchCraftDesignStatisticsHandler;
import mot.engine.command_handlers.FetchDelegateStateCmdHandler;
import mot.engine.command_handlers.FetchGalaxyPreviewCmdHandler;
import mot.engine.command_handlers.FetchGraphCmdHandler;
import mot.engine.command_handlers.FetchPlayerDetailsCmdHandler;
import mot.engine.command_handlers.FetchRegisteredPlayersHandler;
import mot.engine.command_handlers.FetchSavedGameFilesCmdHandler;
import mot.engine.command_handlers.FetchTechnologiesCmdHandler;
import mot.engine.command_handlers.IncreaseDevelopmentCmdHandler;
import mot.engine.command_handlers.IncreaseEcologyCmdHandler;
import mot.engine.command_handlers.JoinFleetCmdHandler;
import mot.engine.command_handlers.LoadCmdHandler;
import mot.engine.command_handlers.MessageHandler;
import mot.engine.command_handlers.MooDeleteCmdHandler;
import mot.engine.command_handlers.MooDeployCmdDeligateHandler;
import mot.engine.command_handlers.MooMoveCmdHandler;
import mot.engine.command_handlers.MooRenameCmdDeligateHandler;
import mot.engine.command_handlers.MooSleepCmdDeligateHandler;
import mot.engine.command_handlers.NewGameCmdHandler;
import mot.engine.command_handlers.NewGameUserPlayerCmdHandler;
import mot.engine.command_handlers.PurchaseProjectCmdHandler;
import mot.engine.command_handlers.RegisterProxyCmdHandler;
import mot.engine.command_handlers.RemoveCraftDesignHandler;
import mot.engine.command_handlers.RenamePlanetCmdDeligateHandler;
import mot.engine.command_handlers.RenameStellarObjectCmdDeligateHandler;
import mot.engine.command_handlers.SaveCmdHandler;
import mot.engine.command_handlers.SellSalvageCmdHandler;
import mot.engine.command_handlers.SetFleetWayPointCmdHandler;
import mot.engine.command_handlers.SetPlanetAutoPercentsCmdHandler;
import mot.engine.command_handlers.SetPlanetPercentsCmdHandler;
import mot.engine.command_handlers.SetPlanetWantsNoProjectCmdHandler;
import mot.engine.command_handlers.SetPlayerCharacterPercentsHandler;
import mot.engine.command_handlers.SetProjectCmdHandler;
import mot.engine.command_handlers.SetRecruiteSpyEffortCmdHandler;
import mot.engine.command_handlers.SetResearchProjectCmdHandler;
import mot.engine.command_handlers.SpyRoleAddEspionageCmdHandler;
import mot.engine.command_handlers.SpyRoleAddPlayerCmdHandler;
import mot.engine.command_handlers.SpyRoleAddSabotageCmdHandler;
import mot.engine.command_handlers.SpyRoleAddStellarObjectCmdHandler;
import mot.engine.command_handlers.SpyRoleSetEspionageTargetCmdHandler;
import mot.engine.command_handlers.SpyStealableTechnologiesCmdHandler;
import mot.engine.command_handlers.StartNextBattleInQueueCmdHandler;
import mot.engine.command_handlers.TransportLoadCmdHandler;

/**
 * This is the entry point into the engine for all remote requests from a client. Local clients
 * use the engine to submit commands directly by passing this handler, however, remote clients
 * send messages to the server and it is this handler that processes those messages an runs the
 * correct command on the server.
 *
 * Requests fall into two categories -
 * a) Fetches - These are requests by a client for information. These are processed directly in
 *              this class.
 * b) Commands - These are requests by a client to execute a command. This class starts the command
 *               and returns the command's response the client client.
 */
public class RequestHandler {

    private HashMap handlers = null;
    
    public RequestHandler() throws ApplicationError {
        handlers = new HashMap();
        put(GetCraftDesignStatistics.class.getName(), new FetchCraftDesignStatisticsHandler());
        put(RenamePlanetCmdDeligate.class.getName(), new RenamePlanetCmdDeligateHandler());
        put(RenameStellarObjectCmdDeligate.class.getName(), new RenameStellarObjectCmdDeligateHandler());
        put(MooDeployCmdDeligate.class.getName(), new MooDeployCmdDeligateHandler());
        put(MooSleepCmdDeligate.class.getName(), new MooSleepCmdDeligateHandler());
        put(FetchSavedGameFiles.class.getName(), new FetchSavedGameFilesCmdHandler());
        put(FetchGalaxyPreview.class.getName(), new FetchGalaxyPreviewCmdHandler());
        put(AbandonCmdDeligate.class.getName(), new AbandonCmdHandler());
        put(DiplomaticRequestCmdDeligate.class.getName(), new DiplomaticRequestCmdHandler());
        put(DiplomaticResponseCmdDeligate.class.getName(), new DiplomaticResponseCmdHandler());
        put(AddCraftDesignDeligate.class.getName(), new AddCraftDesignHandler());
        put(BattleAutomateCmdDeligate.class.getName(), new BattleAutomateCmdHandler());
        put(BattleCraftWaitCmdDeligate.class.getName(), new BattleCraftWaitCmdHandler());
        put(BattleAttackCmdDeligate.class.getName(), new BattleAttackCmdHandler());
        put(BattleCraftLaunchFightersCmdDeligate.class.getName(), new BattleCraftLaunchFightersCmdHandler());
        put(BattleCraftMoveToCmdDeligate.class.getName(), new BattleCraftMoveToCmdHandler());
        put(BattleEndTurnCmdDeligate.class.getName(), new BattleEndTurnCmdHandler());
        put(BattleGetNextOrdersCmdDeligate.class.getName(), new BattleGetNextOrdersCmdHandler());
        put(BattleGetNextObjectCmdDeligate.class.getName(), new BattleGetNextObjectCmdHandler());
        put(BattleAttackLocationCmdDeligate.class.getName(), new BattleAttackLocationCmdHandler());
        put(BattleRetreatCmdDeligate.class.getName(), new BattleRetreatCmdHandler());
        //put(BattleRouteCmdDeligate.class.getName(), new BattleRouteCmdHandler());
        put(mot.common.command_delegates.CraftAttackCmdDeligate.class.getName(), new CraftAttackCmdHandler());
        put(CraftBombardPlanetCmdDeligate.class.getName(), new CraftBombardPlanetCmdHandler());
        put(CraftColoniseCmdDeligate.class.getName(), new CraftColoniseCmdHandler());
        put(MooDeleteCmdDeligate.class.getName(), new MooDeleteCmdHandler());
        put(CraftLeaveFleetCmdDeligate.class.getName(), new CraftLeaveFleetCmdHandler());
        put(EndTurnCmdDeligate.class.getName(), new EndTurnCmdHandler());
        put(IncreaseDevelopmentCmdDeligate.class.getName(), new IncreaseDevelopmentCmdHandler());
        put(IncreaseEcologyCmdDeligate.class.getName(), new IncreaseEcologyCmdHandler());
        put(JoinFleetCmdDeligate.class.getName(), new JoinFleetCmdHandler());
        put(LoadCmdDeligate.class.getName(), new LoadCmdHandler());
        put(MooMoveCmdDeligate.class.getName(), new MooMoveCmdHandler());
        put(NewGameCmdDeligate.class.getName(), new NewGameCmdHandler());
        put(NewGameUserPlayerCmdDeligate.class.getName(), new NewGameUserPlayerCmdHandler());
        put(PurchaseProjectCmdDeligate.class.getName(), new PurchaseProjectCmdHandler());
        put(RegisterProxyCmdDeligate.class.getName(), new RegisterProxyCmdHandler());
        put(RemoveCraftDesignDeligate.class.getName(), new RemoveCraftDesignHandler());
        put(SaveCmdDeligate.class.getName(), new SaveCmdHandler());
        put(SetPlanetAutoPercentsCmdDeligate.class.getName(), new SetPlanetAutoPercentsCmdHandler());
        put(SetPlanetAutoPercentsCmdDeligate.class.getName(), new SetPlanetAutoPercentsCmdHandler());
        put(SetPlanetPercentsCmdDeligate.class.getName(), new SetPlanetPercentsCmdHandler());
        put(SetPlanetWantsNoProjectCmdDeligate.class.getName(), new SetPlanetWantsNoProjectCmdHandler());
        put(SetPlayerCharacterPercentsDeligate.class.getName(), new SetPlayerCharacterPercentsHandler());
        put(SetProjectCmdDeligate.class.getName(), new SetProjectCmdHandler());
        put(SetRecruiteSpyEffortCmdDeligate.class.getName(), new SetRecruiteSpyEffortCmdHandler());
        put(SetResearchProjectCmdDeligate.class.getName(), new SetResearchProjectCmdHandler());
        put(SpyRoleAddEspionageCmdDeligate.class.getName(), new SpyRoleAddEspionageCmdHandler());
        put(SpyRoleAddPlayerCmdDeligate.class.getName(), new SpyRoleAddPlayerCmdHandler());
        put(SpyRoleAddSabotageCmdDeligate.class.getName(), new SpyRoleAddSabotageCmdHandler());
        put(SpyRoleAddStellarObjectCmdDeligate.class.getName(), new SpyRoleAddStellarObjectCmdHandler());
        put(SpyRoleSetEspionageTargetCmdDeligate.class.getName(), new SpyRoleSetEspionageTargetCmdHandler());
        put(TransportLoadCmdDeligate.class.getName(), new TransportLoadCmdHandler());
        put(AcceptLeaderCmdDeligate.class.getName(), new AcceptLeaderCmdHandler());
        put(AcceptMoralChoiceCmdDeligate.class.getName(), new AcceptMoralChoiceCmdHandler());
        put(StartNextBattleInQueueCmdDeligate.class.getName(), new StartNextBattleInQueueCmdHandler());
        put(FetchDelegateStateCmdDelegate.class.getName(), new FetchDelegateStateCmdHandler());
        put(DesignMillitaryCraftCmdDeligate.class.getName(), new DesignMilitaryCraftCmdHandler());
        put(DesignColonyCraftCmdDeligate.class.getName(), new DesignColonyCraftCmdHandler());
        put(SpyStealableTechnologiesCmdDelegate.class.getName(), new SpyStealableTechnologiesCmdHandler());
        put(FetchPlayerDetailsCmdDelegate.class.getName(), new FetchPlayerDetailsCmdHandler());
        put(SellSalvageCmdDeligate.class.getName(), new SellSalvageCmdHandler());
        put(SetFleetWayPointCmdDelegate.class.getName(), new SetFleetWayPointCmdHandler());
        put(ClientClosesWindowCmdDeligate.class.getName(), new ClientClosesWindowCmdHandler());
        put(GetGraphCmdDeligate.class.getName(), new FetchGraphCmdHandler());
        put(FetchTechnologiesCmdDelegate.class.getName(), new FetchTechnologiesCmdHandler());
        put(MooRenameCmdDeligate.class.getName(), new MooRenameCmdDeligateHandler());
        put(FetchRegisteredPlayersCmdDelegate.class.getName(), new FetchRegisteredPlayersHandler());
        
    }

    private void put(String key, Object handler) {
        handlers.put(key, handler);
    }

    public CommandResult process(CommandDeligate command, ClientEventProcessor clientEventProcessor) {
		try {
			if (Logger.isDebug()) {
				Logger.logDebug("RequestHandler.processQueuedCommands() Engine run command "+command);
			}
			if (command instanceof NotificationCommandDelegate) {
				try {					
					_process(command, clientEventProcessor);
				} catch (Throwable e) {
					Logger.logError("RequestHandler.processQueuedCommands() Engine discards error", e);
				}
			} else {
				CommandResult cr = _process(command, clientEventProcessor);
				if (command.getSequence() < 0) {
					// This command was issued by the server
					if (Logger.isDebug()) {
						Logger.logDebug("RequestHandler.processQueuedCommands() Engine command response not returned to client: "+cr);
					}
				} else {
					if (Logger.isDebug()) {
						Logger.logDebug("RequestHandler.processQueuedCommands() Engine command response: "+cr);
					}
					return cr;
				}
			}
		} catch (Throwable t) {
			Logger.logError("RequestHandler.processQueuedCommands() Command Failed: ",t);
			return new ApplicationErrorCR(new ApplicationError(t.getMessage()), command == null ? -1 : command.getSequence());
		}
		return null;
    }
    
    private CommandResult _process(CommandDeligate command, ClientEventProcessor clientEventProcessor) {
        try {
            String className = command.getClass().getName();
            MessageHandler handler = (MessageHandler)handlers.get(className);
            if (handler == null) {
                throw new ApplicationError("RequestHandler.process() No handler registered for "+className);
            }
            String playerName = clientEventProcessor.getOwnerName();
            CommandResult response = handler.process(command, playerName, clientEventProcessor);
            if (command instanceof NewGameUserPlayerCmdDeligate) {
            	clientEventProcessor.setOwnerName( ((NewGameUserPlayerCmdDeligate)command).getRaceName() );
            } else if (command instanceof RegisterProxyCmdDeligate) {
            	clientEventProcessor.setOwnerName( ((RegisterProxyCmdDeligate)command).getPlayerName() );
            }
            if (response == null) {
                response = newOKResponse(command);
            }
            response.setSequence(command.getSequence());
            return response;
        } catch (ValidationError ve) {
            return new ValidationErrorCR(ve, command.getSequence());
        } catch (ApplicationError ae) {
            Logger.logError("", ae);
            return new ApplicationErrorCR(ae, command.getSequence());
        } catch (Throwable t) {
            Logger.logError("", t);
            return new ApplicationErrorCR(new ApplicationError(t.getMessage()), command.getSequence());
        }
    }

    private CommandResult newOKResponse(Request r) {
        return new RequestResponseCR(r.getSequence());
    }

}