/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine;

import java.io.IOException;
import java.net.SocketException;

import mot.common.command_delegates.CommandDeligate;
import mot.common.command_results.CommandResult;
import mot.common.coms.protocols.ClientEventProcessor;
import mot.common.coms.protocols.MotSocket;
import mot.common.event.MotEvent;
import mot.common.util.ApplicationError;
import mot.common.util.Logger;
import mot.common.util.ValidationError;

public class SocketHandlerThreadEngine extends Thread implements ClientEventProcessor {

	private RequestHandler requestHandler;
	private MotSocket socket;
	private String ownerName;
	
	public SocketHandlerThreadEngine(MotSocket socket, RequestHandler requestHandler) throws ApplicationError, ValidationError {
    	super("SocketHandlerThreadEngine");
		this.socket = socket;
		this.requestHandler = requestHandler;
    }

    public void run() {
    	ConnectionList.addRemoteServerConnection(this);
        while (true) {
            try {
            	CommandDeligate requestObject = (CommandDeligate) socket._read();
            	CommandResult cr = requestHandler.process(requestObject, this);
            	if (cr != null) {
            		socket._write(cr);
            	}
            } catch (Throwable e) {
            	if (!socket.isConnected() || socket.isClosed() || e instanceof SocketException) {
            		Logger.logDebug("SocketHandlerThreadEngine closing due to error "+e);
            		ConnectionList.removeRemoteServerConnection(this);
            		return;
            	}
           		Logger.logError("SocketHandlerThreadEngine.run() Failure", e);
            }
        }
    }

	@Override
	public void process(MotEvent event) throws ApplicationError {
		try {
			socket._write(event);
		} catch (IOException e) {
			try { Thread.sleep(250); } catch (InterruptedException e1) { }
			try {
				socket._write(event);
			} catch (IOException e2) {
	       		Logger.logError("SocketHandlerThreadEngine.run() Failure", e2);
	       		throw new ApplicationError(e.getMessage());
			}
		}
	}

    public String getOwnerName() {
		return ownerName;
	}

	public void setOwnerName(String ownerName) {
		this.ownerName = ownerName;
	}


}