/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.adapter;

import mot.common.util.ApplicationError;
import mot.common.util.Logger;
import mot.common.vo.CraftVO;
import mot.common.vo.NavigatorVO;
import mot.engine.common.Orbit;
import mot.engine.crafts.Craft;
import mot.engine.crafts.CraftDesignAdapter;
import mot.engine.crafts.Fleet;
import mot.engine.crafts.Navigator;
import mot.engine.players.Player;

public class CraftVOAdapter extends CraftVO {

	private static NavigatorVO getNavigator(Craft a) throws ApplicationError {
        NavigatorVO navigator = null;
        Navigator n = a.getNavigator();
        if (n != null) {
        	if (n.getObjectReference() == null) {
            	Logger.logError("Invalid Navigator "+n, new Exception());
            	return null;
        	} else {
        		navigator = new NavigatorVO(new OrbitVOAdapter(n.getDestination()), n.getETA());
        	}
        }
        return navigator;
	}

	public CraftVOAdapter() {
	}

	public CraftVOAdapter(Craft a, Player viewer) throws ApplicationError {
		this(a,
			 viewer,
			 getNavigator(a),
			 a.getOrbit(),
			 a.getFleet(),
			 false
			);
	}

	public CraftVOAdapter(Craft a, Player viewer, boolean temporaryCraft) throws ApplicationError {
		this(a,
			 viewer,
			 getNavigator(a),
			 a.getOrbit(),
			 a.getFleet(),
			 temporaryCraft
			);
	}

	public CraftVOAdapter(Craft a, Player viewer, NavigatorVO navigator) throws ApplicationError {
		this(a, viewer, navigator, a.getOrbit(), a.getFleet(), false);
	}
	
	public CraftVOAdapter(Craft a, Player viewer, NavigatorVO navigator, Orbit orbit, Fleet fleet, boolean temporaryCraft) throws ApplicationError {
		super(
				a.getName(), 
				a.getOwner().getName(), 
				a.getLocation(), 
				navigator, 
				orbit == null ? null : new OrbitVOAdapter(orbit),
				a.getVisibility(viewer),
				a.getMaxTravelDistance(),
				a.isSleeping(),
				a.getOrigin().getName(),
				fleet == null ? null : fleet.getName(),
				new CraftDesignAdapter(a),
				a.getMaintenanceCost(),
				a.getDamageAsPercent(),
                a.getBuildQuality(),
                temporaryCraft,
   			    a.hasMoved()
              );
	}
	
	  protected String getClassAttribute() {
		  return "mot.common.vo.CraftVO";
	  }
	  
}
