/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.adapter;

import mot.common.util.ApplicationError;
import mot.common.vo.FleetVO;
import mot.common.vo.NavigatorVO;
import mot.engine.common.Orbit;
import mot.engine.crafts.Fleet;
import mot.engine.crafts.Navigator;
import mot.engine.players.Player;

public class FleetVOAdapter extends FleetVO {

	private static NavigatorVO getNavigator(Fleet a) throws ApplicationError {
        NavigatorVO navigator = null;
        Navigator n = a.getNavigator();
        if (n != null) {
            navigator = new NavigatorVO(new OrbitVOAdapter(n.getDestination()), n.getETA());
        }
        return navigator;
	}
	
	public FleetVOAdapter(Fleet a, Player viewer) throws ApplicationError {
		this(a,
			 viewer,
			 getNavigator(a),
			 a.getOrbit()
			);
	}

	private FleetVOAdapter(Fleet a, Player viewer, NavigatorVO navigator, Orbit orbit) throws ApplicationError {
		super(  
				a.getName(), 
				a.getOwner().getName(), 
				a.getLocation(), 
                navigator, 
                orbit == null ? null : new OrbitVOAdapter(orbit),
                a.getCraftNames(),
                a.getVisibility(viewer),
                a.getMaxTravelDistance(),
                a.isSleeping(),
                a.hasMoved()
             );
	}

}
