/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.adapter;

import mot.common.designs.Orbital;
import mot.common.technology.Scanners;
import mot.common.technology.Shields;
import mot.common.technology.Weapons;
import mot.common.util.ApplicationError;
import mot.common.vo.PlanetCrisisVO;
import mot.common.vo.PlanetVO;
import mot.engine.common.EngineVoFactory;
import mot.engine.planets.Planet;
import mot.engine.players.Player;

public class PlanetVOAdapter extends PlanetVO {

	public PlanetVOAdapter(Planet a, Player viewer) throws ApplicationError {
        Player owner = a.getOwner();
        setName(a.getName());
        Player origin = a.getOrigin();
		if (origin != null) setOrigin(origin.getName());
        setOwner(owner == null ? null : owner.getName());
        setSolarSystem(a.getSolarSystem().getName());
        
        setSize(a.getSize());
        setMoneyBonus(a.getMoneyBonus());
        setMaxPopulation(a.getMaxPopulation());
        setMinimumEcologyOutput(a.getMinimumEcologyOutput());
        setProductionBonus(a.getProductionBonus());
        setReproductionBonus(a.getReproductionBonus());
        setResearchBonus(a.getResearchBonus());
        
        boolean visible = a.getSolarSystem().isVisible(viewer);

        setPopulation(a.getPopulation());
        setQtyFactories(a.getQtyFactories());
        setTeraforming(a.getTeraforming());
        setQtyColonistsOnrouteTo(a.getQtyColonistsOnrouteTo());
        setColonistsEtaOnrouteTo(a.getColonistsEtaOnrouteTo());
        setQtyGroundDefense(a.getQtyGroundDefense());
        setInfluence(a.getInfluence());
        setHasAsteroids(a.getHasAsteroids());
        setHasNatives(a.hasNatives());
        
        setViewable(a.isViewableBy(viewer));
        
        setPercentDevelopment(a.getPercentDevelopment());
        setPercentEcology(a.getPercentEcology());
        setPercentProduction(a.getPercentProduction());
        setPercentResearch(a.getPercentResearch());

        setAutoDevelopment(a.getAutoDevelopment());
        setAutoEcology(a.getAutoEcology());
        setVaryProduction(a.getVaryProduction());
        setVaryResearch(a.getVaryResearch());
        
        setFactoriesGrowth(a.getFactoriesGrowth());
        setPopulationGrowth(a.getPopulationGrowth());
        setProduction(a.getProduction());
        setEcologyOutput(a.getEcologyOutput());

//        if (a.getName().equals("Ormiston-A")) {
//        	Logger.logDebug("");
//        }

        if (!a.isMiningColony()) {
            setProductionOutput(a.getProductionOutput(true));
            setLostProductionOutput(a.getProductionOutput(false) - getProductionOutput());
            
            setResearchOutput(a.getResearchOutput(true));
            setLostResearchOutput(a.getResearchOutput(false) - getResearchOutput());
            
            setMoneyOutput(a.getMoneyOutput());
            if (getMoneyOutput() > 1) {
            	setMoneyWasted(a.getMoneyWasted());
            } else {
            	setMoneyWasted(0);
            }
            
            setMiningPopulation(a.getMiningStationPopulation());
        } else {
        	Planet miner = a.getMiner();
        	if (miner != null) {
	            setProductionOutput(miner.getMiningStationProduction());
	            setLostProductionOutput(miner.getLostMiningStationProduction());
	            
	            setResearchOutput(miner.getMiningStationResearch());
	            setLostResearchOutput(miner.getLostMiningStationResearch());
	            
	            setMoneyOutput(miner.getMiningStationMoney());
	            setMoneyWasted(miner.getLostMiningStationMoney());
	            setMiningPopulation(0);
        	}      	
        }

        setDevelopmentOutput(a.getDevelopmentOutput());
        setTeraformingGrowth(a.getTeraformingGrowth());

        setResource((a.getResource() == null) ? null : a.getResource().getName());
        
        setMinimumEcologyPercent(a.getMinimumEcologyPercent());

        boolean blockaded = visible ? a.isBlockaded() : false;        
        boolean dominated = visible ? a.isDominated() : false;        
        setBlockaded(blockaded);
        setDominated(dominated);
        
        Scanners scanners = a.getScanners();
        Shields shields = a.getShields();
        Weapons weapons = a.getWeapons();
        Orbital orbital = a.getOrbital();
        
        setScanners(scanners == null ? null : scanners.getNamesAsArray());
        setShields(shields == null ? null : shields.getNamesAsArray());
        setWeapons(weapons == null ? null : weapons.getNamesAsArray());
        setOrbital(orbital);
        setMiningColony((a.getMiningStation() == null) ? null : a.getMiningStation().getPlanet().getName());

        setNotifiedFactoriesComplete(a.getNotifiedFactoriesComplete());
        setNotifiedTerraformComplete(a.getNotifiedTerraformComplete());
        setOwnerWantsNoProject(a.ownerWantsNoProject);
        
        setRepeatProject(a.getRepeatProject());
        setProject(EngineVoFactory.getPlanetProject(a, a.getProject()));

        if (a.getCrisis() != null) setCrisis(new PlanetCrisisVO(a.getCrisis().getName(), a.getCrisis().getDescription()));

	}
}
