/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.adapter;

import mot.common.util.ApplicationError;
import mot.common.vo.PlayerDetailsVO;
import mot.common.vo.StrategistEventVO;
import mot.engine.MotEngine;
import mot.engine.players.ComputerPlayer;
import mot.engine.players.Player;
import mot.engine.players.UserPlayer;
import mot.engine.spies.Spies;

public class PlayerDetailsVOAdapter extends PlayerDetailsVO {

	public PlayerDetailsVOAdapter() {
	}
	
    public PlayerDetailsVOAdapter(Player player) throws ApplicationError {
    	super(player.getName(),
    		  player.getTotalIncome(true), 
    		  player.getTotalIncome(false), 
    		  player.getTradeIncome(),
    		  player.getTotalMaintenanceCost(),
    		  player.getSpiesMaintenanceCost(),
    		  MotEngine.instance.getSpiesNotNull().getSpyRolesEspionageSuccessChance(player),
    		  MotEngine.instance.getSpiesNotNull().getSpyRolesSabotageSuccessChance(player),
    		  MotEngine.instance.getSpiesNotNull().getSpyRolesEspionageTargets(player));
    	
    	setTotalProduction(player.getTotalProduction());
    	setTotalPopulation(player.getTotalPopulation());
    	setMoralChoices(player.getMoralChoiceNameList());
    	
    	StrategistEventVO[] diplomaticEvents = null;
        Player [] pa = player.getPlayerWithDiplomaticRelations();
        if (pa != null) {
        	for (int i = 0; i < pa.length; i++) {
        		if ((pa[i] instanceof ComputerPlayer)) {
        			StrategistEventVO[] dea = ((ComputerPlayer)pa[i]).getStratagist().getStrategistEvents(player);
        			addStrategistEvents(dea);
        		}
			}
        }
		
    	
        Spies spies = MotEngine.instance.getSpiesNotNull();
        setQtySpiesEspionage(spies.getQtySpiesEspionage(player));
        setQtySpiesSabotage(spies.getQtySpiesSabotage(player));

    	if (player instanceof UserPlayer) {
    		UserPlayer up = (UserPlayer) player;
    		setSpyRecruitCosts(up.getSpyRecruitEffortPerTurn());
    		setSpyRecruitTotal(up.getSpyCenter().getTotalEffort());
    		setSpyRecruitChance(up.getSpyCenter().getChanceToRecuite(up));
    	}
    }
    
	protected String getClassAttribute() {
		  return "mot.common.vo.PlayerDetailsVOAdapter";
	  }
	  

}
