/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.adapter;

import mot.common.util.ApplicationError;
import mot.common.vo.RelationVO;
import mot.engine.players.ComputerPlayer;
import mot.engine.players.Player;
import mot.engine.relations.Relation;

public class RelationVOAdapter extends RelationVO {

	public RelationVOAdapter(Relation a, Player viewer) throws ApplicationError {
	    super(a.getPlayerName1(), 
	    	 a.getPlayerName2(),
	    	 getStrategistEventRating(a.getPlayer1(), a.getPlayer1()),
	    	 getStrategistEventRating(a.getPlayer2(), a.getPlayer1()),
	         a.isAliance(),
	         a.isNonAgression(),
	         a.isPeace(),
	         a.isWar(),
	         a.getResearchAgreementTreaty() == null ? null : new RelationResearchAgreementVOAdapter(a.getResearchAgreementTreaty(), viewer), 
	         a.getTradeAgreementTreaty() == null ? null : new RelationTradeAgreementVOAdapter(a.getTradeAgreementTreaty(), viewer),
	         a.getValue(),
	         a.getDiplomaticHistory());
	}
	
	private static int getStrategistEventRating(Player p1, Player p2) throws ApplicationError {
		if (p1 == null || p2 == null) return 0;
		if (p1 instanceof ComputerPlayer) {
			return ((ComputerPlayer)p1).getStratagist().getEventManagerNotNull().getRelationshipEffect(p2);
		} else {
			return 0;
		}
	}
}
