/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.adapter;

import mot.common.util.ApplicationError;
import mot.common.vo.NavigatorVO;
import mot.common.vo.TransportVO;
import mot.engine.crafts.Navigator;
import mot.engine.transports.Transport;
import mot.engine.transports.TransportTask;
import mot.engine.transports.TransportTaskCreateTradeRoute;
import mot.engine.transports.TransportTaskDeployStation;
import mot.engine.transports.TransportTaskInvade;
import mot.engine.transports.TransportTaskMoveColonists;

public class TransportVOAdapter extends TransportVO {
	
	private static NavigatorVO getNavigator(Transport a) throws ApplicationError {
        NavigatorVO navigator = null;
        Navigator n = a.getNavigator();
        if (n != null) {
            navigator = new NavigatorVO(new OrbitVOAdapter(n.getDestination()), n.getETA());
        }
        return navigator;
	}
	
	public TransportVOAdapter(Transport a) throws ApplicationError {
		this(a, getNavigator(a));
	}

	public TransportVOAdapter(Transport a, NavigatorVO navigator) throws ApplicationError {
		super(  
				a.getName(), 
                a.getOwner().getName(),
                a.getLocation(),
                navigator, 
                a.getOrbit() == null ? null : new OrbitVOAdapter(a.getOrbit()),
                a.getVisibility(),
                a.getMaxTravelDistance(),
                a.isSleeping(),
                0,
                null
            );
		TransportTask task = a.getTask();
		if (task instanceof TransportTaskMoveColonists) {
			setTaskContent(CONTENT_TYPE_COLONISTS);
			setQty(((TransportTaskMoveColonists)task).getQty());
		} else if (task instanceof TransportTaskInvade) {
			setTaskContent(CONTENT_TYPE_TROOPS);
			setQty(((TransportTaskInvade)task).getQtyAttackers());
		} else if (task instanceof TransportTaskDeployStation) {
			setTaskContent(CONTENT_TYPE_SPACE_STATION);
			setOrbitalHull(((TransportTaskDeployStation)task).getOrbitalHullName());
			setOrigin(((TransportTaskDeployStation)task).getOriginName());
		} else if (task instanceof TransportTaskCreateTradeRoute) {
			setTaskContent(CONTENT_TYPE_TRADE_ROUTE);
			setQty(a.getOwner().getMaxSolarSystemTradeRouteDistance());
			setOrigin(((TransportTaskCreateTradeRoute)task).getOriginName());
		}
	}

}
