/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.adapter;

import mot.common.bean.SalvageList;
import mot.common.util.ApplicationError;
import mot.common.vo.UserPlayerVO;
import mot.engine.MotEngine;
import mot.engine.common.EngineVoFactory;
import mot.engine.common.Orbit;
import mot.engine.planets.Planet;
import mot.engine.players.UserPlayer;
import mot.engine.spies.SpyCenter;

public class UserPlayerVOAdapter extends UserPlayerVO {

	public UserPlayerVOAdapter(UserPlayer p) throws ApplicationError {
		super(p.getName());

        if (p.getGeneralLeader() != null) {
        	setGeneralName(p.getGeneralLeader().getName());
        	setGeneralExperience(p.getGeneralLeader().getExperience());
        }
        if (p.getGovenorLeader() != null) {
        	setGovenorName(p.getGovenorLeader().getName());
        	setGovenorExperience(p.getGovenorLeader().getExperience());
        }
		SpyCenter sc = p.getSpyCenter();
		String [] playerSpies = null;
		if (sc != null) {
			playerSpies = sc.getPlayerSpiesAsArray();
		}
		setPlayerSpies(playerSpies);
		Orbit fleetWayPoint = p.getFleetWayPoint();
		if (fleetWayPoint != null) {
			setFleetWayPoint(new OrbitVOAdapter(fleetWayPoint));
		}
		setResearchProject(EngineVoFactory.getResearchProject(p.getResearchProject()));
		Planet homePlanet = p.getCapitol();
		if (homePlanet != null) setHomePlanet(homePlanet.getName());
		setPlayerResources(p.getResourceCache());
        SalvageList salvage = p.getSalvage();
        String[] salvageNames = null;
        if (salvage != null) {
        	salvageNames = salvage.getFullNamesAsArray();
        	setSalvage(salvageNames);
        }
        setNetIncome(p.getNetIncome());
        int qtyFreeTransports = p.getTransportManagerNotNull().getQtyFreeTransport();
        setQtyFreeTransport(qtyFreeTransports);
        
        setFunds(p.getFunds());
        setBoralium(p.getBoralium());
        setChanceToDiscoverSalvaged(p.getChanceToDiscoverSalvagedTechnology());
        
        setQtySpiesDefending(MotEngine.instance.getSpiesNotNull().getQtySpiesDefending(p));
        setTotalResearch(p.getTotalResearch());
    }
}
