/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.battles;

import mot.common.util.ApplicationError;

public abstract class BattleCraftControllerBase implements BattleCraftController {

	/**
	 * This is the craft that is being commanded by this controller.
	 */
	protected BattleCraft targetCraft;

	/**
	 * This is the quantity of turns this Controller will control the target.
	 */
	private int qtyTurns;
	
	/**
	 * This is the turn number this Controller is up to now.
	 */
	private int turn;

	
	public BattleCraftControllerBase(BattleCraft targetCraft, int qtyTurns) {
		this.targetCraft = targetCraft;
		this.qtyTurns = qtyTurns;
		this.turn = 0;
	}

	/**
	 * Increment the quanity of turn this controller has controlled the craft
	 * targetCraft. If all all turns have been used then remove this controller
	 * from the targetCraft (delete this controller).
	 * @throws ApplicationError
	 */
	public void incrementTurns() throws ApplicationError {
		turn++;
		if (turn >= qtyTurns) {
			targetCraft.setControllerDetails(null);
		}
	}	

	public int getQtyTurns() {
		return qtyTurns;
	}

	public void setQtyTurns(int qtyTurns) {
		this.qtyTurns = qtyTurns;
	}

	public int getTurn() {
		return turn;
	}

	public void setTurn(int turn) {
		this.turn = turn;
	}
	
}
