/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.battles;

import mot.common.bean.Decorator;
import mot.common.bean.DecoratorBerserker;
import mot.common.util.ApplicationError;
import mot.engine.players.Player;

public class BattleCraftControllerBerserker extends BattleCraftControllerBase {

	public BattleCraftControllerBerserker(BattleCraft targetCraft, int qtyTurns) {
		super(targetCraft, qtyTurns);
	}

	public boolean canBeComandedBy(Player p) {
		return false;
	}

	public boolean controlIsAutomated() throws ApplicationError {
		return true;
	}

	public void setNextBattleOrders() throws ApplicationError {
		incrementTurns();
		Battle battle = targetCraft.getBattle();
		BattleCraft closestCraft = battle.getClosestCraft(targetCraft);
		if (closestCraft != null) {
			targetCraft.moveTo(closestCraft);
			targetCraft.fireAllWeapons(closestCraft);
		}
		targetCraft.endTurn();
	}

	public Decorator getDecorator() {
		return DecoratorBerserker.getInstance();
	}

	public Player getController() {
		return null;
	}

	public String getControllerName() {
		return null;
	}
}
