/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.battles;

import mot.common.bean.Decorator;
import mot.common.bean.DecoratorCowardice;
import mot.common.bean.Location;
import mot.common.bean.LocationAndDirection;
import mot.common.util.ApplicationError;
import mot.engine.players.Player;

public class BattleCraftControllerCowardice extends BattleCraftControllerBase {

	public BattleCraftControllerCowardice(BattleCraft targetCraft, int qtyTurns) {
		super(targetCraft, qtyTurns);
	}

	public boolean canBeComandedBy(Player p) {
		return false;
	}

	public boolean controlIsAutomated() throws ApplicationError {
		return true;
	}

	public void setNextBattleOrders() throws ApplicationError {
		incrementTurns();
		Battle battle = targetCraft.getBattle();
		Player owner = targetCraft.getOwner();
		BattleCraft closestEnemyCraft = battle.getClosestEnemyCraft(owner, targetCraft, false, null);
		if (closestEnemyCraft != null) {
			Location loc = targetCraft.getLocation();
			int direction = loc.getDirectionFor(closestEnemyCraft.getLocation());
			direction = (direction + 180) % 360;
			Location dest = new Location(loc);
			dest.shiftInDirection(direction, targetCraft.getSpeed());
			targetCraft.moveTo(new LocationAndDirection(dest), 1.0, null, null, false);
			targetCraft.dischargeWeapons();
		}
		targetCraft.endTurn();
	}

	public Decorator getDecorator() {
		return DecoratorCowardice.getInstance();
	}

	public Player getController() {
		return null;
	}

	public String getControllerName() {
		return null;
	}
}
