/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.battles;

import mot.common.bean.Decorator;
import mot.common.bean.DecoratorMindControl;
import mot.common.util.ApplicationError;
import mot.engine.players.Player;

public class BattleCraftControllerMindControl extends BattleCraftControllerBase {

	private Player owner;
	
	public BattleCraftControllerMindControl(Player owner, BattleCraft targetCraft, int qtyTurns) {
		super(targetCraft, qtyTurns);
		this.owner = owner;
	}

	public boolean canBeComandedBy(Player p) {
		return (p == owner);
	}

	public boolean controlIsAutomated() throws ApplicationError {
		return owner.isComputerPlayer();
	}

	public void setNextBattleOrders() throws ApplicationError {
		incrementTurns();
		owner.setNextBattleOrders(targetCraft);
	}

	public Decorator getDecorator() {
		return DecoratorMindControl.getInstance();
	}

	public Player getController() {
		return owner;
	}

	public String getControllerName() {
		return owner.getName();
	}
}
