/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.battles;

import java.util.ArrayList;
import java.util.Iterator;

import mot.common.util.ApplicationError;
import mot.engine.crafts.Craft;
import mot.engine.players.Player;

public class BattleCraftList {

    private ArrayList list;

    public void add(BattleCraft craft) {
        if (list == null) list = new ArrayList();
        list.add(craft);
    }

    public BattleCraft [] getAllCraft() {
        if (list == null) {
            return null;
        } else {
            return (BattleCraft []) list.toArray(new BattleCraft [list.size()]);           
        }
    }

    public boolean contains(Craft craft) {
        if (list == null) return false;
        Iterator i = list.iterator();
        if (i == null) return false;
        while (i.hasNext()) {
            BattleCraft bc = (BattleCraft) i.next();
            if (bc.getCraft() == craft) return true;
        }
        return false;
    }

	public BattleCraft [] getOwnedBy(Player owner) throws ApplicationError {
        if (list == null) return null;
        Iterator i = list.iterator();
        if (i == null) return null;
        BattleCraftList r = new BattleCraftList();
        while (i.hasNext()) {
            BattleCraft bc = (BattleCraft) i.next();
            if (bc.isOwnedBy(owner)) {
            	r.add(bc);
            }
        }
        if (r.getQty() > 0) {
        	return r.getAllCraft();
        } else {
        	return null;
        }
	}

	private int getQty() {
        if (list == null) {
        	return 0;
        } else {
        	return list.size();
        }
	}

}
