/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.battles;

import mot.common.bean.GalaxyDefinitions;
import mot.common.util.ApplicationError;

/**
 * Interface for layout managers to layout crafts and planets in a battle field.
 */
public interface BattleLayoutManager  {
    
    int LOCATION_TYPE_LEFT = 0;
    int LOCATION_TYPE_RIGHT = 1;
    int LOCATION_TYPE_TOP = 2;
    int LOCATION_TYPE_BOTTOM = 3;

    int my = (GalaxyDefinitions.BATTLE_BOUNDARY.getBottom() - GalaxyDefinitions.BATTLE_BOUNDARY.getTop()) / 2;
    int mx = (GalaxyDefinitions.BATTLE_BOUNDARY.getRight() - GalaxyDefinitions.BATTLE_BOUNDARY.getLeft()) / 2;

    int tenPercentLeft = (GalaxyDefinitions.BATTLE_BOUNDARY.getRight() - GalaxyDefinitions.BATTLE_BOUNDARY.getLeft()) / 10;
    int tenPercentRight = GalaxyDefinitions.BATTLE_BOUNDARY.getRight() - tenPercentLeft;
    int tenPercentTop = (GalaxyDefinitions.BATTLE_BOUNDARY.getBottom() - GalaxyDefinitions.BATTLE_BOUNDARY.getTop()) / 10;
    int tenPercentBottom = GalaxyDefinitions.BATTLE_BOUNDARY.getBottom() - tenPercentTop;

    /**
     * Returns the next free location on the battle field suitable for placing the craft.
     */
    public void setNextFreeLocation(BattleCraft craft) throws ApplicationError;

    /**
     * Returns the next free location on the battle field suitable for placing the planet.
     */
    public void setPlanetLocation(BattlePlanet planet) throws ApplicationError;
}