/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.battles;

import mot.common.bean.Location;
import mot.common.util.ApplicationError;
import mot.common.util.Comp;
import mot.common.util.Logger;
import mot.common.util.Utils;
import mot.engine.MotEngine;
import mot.engine.players.Player;

public class BattleMineFactory {
	
	private static final double BUFFER_PERCENT = 0.1;
	private static final int MAX_MINES = 8;
	
	//
	// Define the rectangle in which mines are randomly located
	//
	private static final int TOP = 100;
	private static final int LEFT = 400;
	private static final int WIDTH = 400;
	private static final int HEIGHT = 800;
	
	private static final String NAME_PREFIX = "Mine";

	public static void create(Player owner, Battle battle, int range, int qty) throws ApplicationError {
		qty = Comp.min(MAX_MINES, qty);
		int verticalSpace = HEIGHT/qty;
		int buffer = (int)(verticalSpace*BUFFER_PERCENT);
		for (int i=0; i<qty; i++) {
			int rx = LEFT + Utils.random(WIDTH);
			int ry = TOP + verticalSpace*i + Utils.random(verticalSpace-2*buffer) + buffer;
			Location loc = new Location(rx, ry);
			create(owner, battle, range, loc);
		}
	}
	
	public static void create(Player owner, Battle battle, int range, Location loc) throws ApplicationError {
		String name = MotEngine.getInstance().getNameGenerator().getNextName(NAME_PREFIX);
		if (Logger.isDebug()) {
			Logger.logDebug("BattleMineFactory() create mine "+name+" at "+loc);
		}
		BattleMine mine = new BattleMine(owner, battle, name, loc, range);
		battle.add(mine);
	}
}
