/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.battles;

import mot.common.bean.NamedObject;
import mot.common.util.ApplicationError;
import mot.common.util.BasicNameValueList;
import mot.common.util.NameValuePair;
import mot.common.xml.XMLWriter;
import mot.engine.MotEngine;

public class BattleReference extends NamedObject {

	private transient Battle battle;

	public Battle getBattle() {
		if (battle == null) {
			battle = MotEngine.getInstance().getBattles().getBattle(getName());
		}
		return battle;
	}

	public void setBattle(Battle v) {
		battle = v;
		setName(battle.getName());
	}

	public BattleReference() {
	}

	public BattleReference(Battle battle) {
		super(battle.getName());
		this.battle = battle;
	}

	protected void encode(XMLWriter writer) throws ApplicationError {
		// does not have a bean body
	}

    protected BasicNameValueList getAttributes(boolean generateClassAttribute, boolean generateSchemaAttribute) throws ApplicationError {
		if (getBattle() == null) {
			return null;
		}

		BasicNameValueList params = getAttributesNotNull(generateClassAttribute);
		params.add( new NameValuePair("name", battle.getName()) );

		return params;
	}

	protected String getElementName() { return "battle-reference"; }
    protected boolean beanHasBody() { return false; }
}