/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.battles;
import java.util.ArrayList;
import java.util.Iterator;

import mot.common.util.ApplicationError;
import mot.engine.crafts.Craft;

/**
 * This is a list object used to collect all bombardments scheduled to take place at the 
 * end of the this turn.
 * CURRENTLY BOMBARDMENTS ARE NOT SAVED - ONLY USERS ADD THESE AND THEY ARE LOST ON SAVE!
 */
public class Bombardments  {

    private ArrayList list = new ArrayList();

    public Bombardments() {
    }
    
    public void add(Bombardment bom) {
        list.add(bom);
    }
    
    public Bombardment getFor(Craft craft) {
        for (Iterator i = list.iterator(); i.hasNext(); ) {
            Bombardment bom = (Bombardment) i.next();
            if (bom.contains(craft)) {
                return bom;
            }
        }
        return null;
    }
    
    public Bombardment getFor(Craft [] crafts) {
        for (Iterator i = list.iterator(); i.hasNext(); ) {
            Bombardment bom = (Bombardment) i.next();
            if (bom.containsAny(crafts)) {
                return bom;
            }
        }
        return null;
    }
    
    public void run() throws ApplicationError {
        for (Iterator i = list.iterator(); i.hasNext(); ) {
            Bombardment bom = (Bombardment) i.next();
            bom.run();
            i.remove();
        }
    }
}