/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.battles;

import mot.common.bean.Location;

/**
 * This represents an area that the owner of this craft recommends not sending other craft to attack in.
 * This is used by the Commander for crafts containing weapons like the detonator. 
 *  
 * @author Paul Davis
 */
public class ExclusionZone {

	private Location location;
	private int radius;

	public ExclusionZone(Location location, int radius) {
		this.location = location;
		this.radius = radius;
	}

	public boolean contains(Location loc) {
		return location.getDistanceTo(loc) <= radius;
	}

	public int getDistanceTo(Location loc) {
		return location.getDistanceTo(loc);
	}

	public Location getLocation() {
		return location;
	}
	
	public int getRadius() {
		return radius;
	}
	
}
