/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.battles;
import mot.common.designs.CraftDesign;
import mot.common.technology.Shield;
import mot.common.technology.Technologies;
import mot.common.technology.Weapon;
import mot.common.util.ApplicationError;
import mot.engine.MotEngine;
import mot.engine.common.Orbit;
import mot.engine.crafts.Craft;

/**
 * This is a factory for creating holo crafts.
 * A Holo Craft is a fake craft used as a decoy. See HoloCraft for details.
 */
public class HoloCraftFactory  {

    /**
     * @return An instance of HoloCraft being a 'fake' craft in the battle. 
     * @param parent This is the object that contains a holo emiter and it generating the holo craft.
     * @param battle This is the battle the holo craft is being created in.
     */
    public static void create(Battle battle, BattleCraft parent, boolean attacker) throws ApplicationError {
        int qty = parent.getSpecials().getQtyHoloEmiter();
        while (qty > 0) {
			HoloCraft craft = _create(battle, parent, attacker);
            qty--;
        }
    }

    public static HoloCraft _create(Battle battle, BattleCraft parent, boolean attacker) throws ApplicationError {
    	Orbit orbit = battle.getOrbit();
		String prefix = parent.getName();
		Craft parentCraft = parent.getCraft();
		CraftDesign cd = new CraftDesign(MotEngine.getInstance().getNameGenerator().getNextName(prefix));
		cd.setHull(parentCraft.getHull());
		cd.setEngine(parentCraft.getEngine());
		cd.setShield(Technologies.getShield(Shield.HOLO_SHIELD));
		cd.setWeapon(Technologies.getWeapon(Weapon.HOLO_WEAPON));
		HoloCraft craft = new HoloCraft(battle, parentCraft, attacker, cd);
        battle.addToCraftList(craft);
        return craft;
    }
}