/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.battles;
import mot.common.util.ApplicationError;
import mot.engine.event.MotLinkedEventFactory;

/**
 * A movement linked object is an object in a battle whose movement is linked to the movement 
 * of another object. If this battle object moves 0.8 percent of its move then all linked 
 * object will move 0.8 percent of their move at the same time. Note however, linked objects 
 * can still move independently from their link. At the end of a turn linked objects may use 
 * any remaining movement.
 */
public interface MoveLinkedObject  {

    /**
     * Move the linked object. 
     * @param percent The amount of this objects move should be used.
     * @throws ApplicationError
     */
    public void move(double percent, MotLinkedEventFactory rootEvent) throws ApplicationError;

    /**
     * Instruct automaton to move to target and strike. 
     * @throws ApplicationError
     */
	public void strike(MotLinkedEventFactory rootEvent) throws ApplicationError;
	
    /**
     * @return The percentage of this object will have to perform of a move before it strikes its 
     * target. A missile with speed 300, of distance 200 from its target would return 0.66666.
     */
    public double getPercentMoveBeforeStrike() throws ApplicationError;

    /**
     * @return If this object has been destroyed.
     */
	public boolean isDestroyed();

}