/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.battles;

import java.util.HashMap;
import java.util.Set;

import mot.common.bean.SalvageList;
import mot.engine.players.Player;

public class PlayerSalvageMap {

	private HashMap<Player, SalvageList> playerToSalageMap = new HashMap<Player, SalvageList>();

	public void add(Player player, SalvageList salvage) {
		if (salvage == null) return;
		SalvageList salvageList = playerToSalageMap.get(player);
		if (salvageList == null) {
			SalvageList sl = new SalvageList(salvage);
			playerToSalageMap.put(player, sl);
		} else {
			salvageList.add(salvage);
		}
	}
	
	public Player [] getPlayersWithSalavge() {
		Set<Player> keys = playerToSalageMap.keySet();
		if (keys != null && keys.size() > 0) {
			return keys.toArray(new Player[keys.size()]);
		} else {
			return null;
		}
	}

	public SalvageList getSalvage(Player player) {
		return playerToSalageMap.get(player);
	}
	
}
