/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.battles;

import mot.common.bean.Rectangle;
import mot.common.bean.SalvageList;
import mot.common.util.ApplicationError;

/**
 * This is an animated field of debris on a battle field marking the position where
 * a craft was destroyed.
 */
public class WreckageCraft implements Wreckage {

	/**
	 * The turn this wreckage was created in
	 */
	private int turnCreated;
	
	/**
	 * The craft that was destroyed causing this wreckage.
	 */
	private BattleCraft battleCraft;
	
	/**
	 * A list of technology that is available for salvage in this wreckage.
	 */
	private SalvageList salvage;
	

	public WreckageCraft(BattleCraft battleCraft, int battleTurn, SalvageList salvage) {
		this.battleCraft = battleCraft;
		this.setTurnCreated(battleTurn);
		this.setSalvage(salvage);
	}

	public void setBattleCraft(BattleCraft craft) {
		this.battleCraft = craft;
	}

	public BattleCraft getBattleCraft() {
		return battleCraft;
	}

	public Rectangle getRectangle() throws ApplicationError {
		return battleCraft.getRectangle();
	}

	public void setTurnCreated(int battleTurn) {
		this.turnCreated = battleTurn;
	}

	public int getTurnCreated() {
		return turnCreated;
	}

	public void setSalvage(SalvageList salvage) {
		this.salvage = salvage;
	}

	public SalvageList getSalvage() {
		return salvage;
	}

	public void removeSalvage() {
		salvage = null;
	}
	
	public String toString() {
		return battleCraft.getName();
	}

	public String getName() {
		return battleCraft.getName();
	}
	
}
