/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.battles;

import java.util.ArrayList;

import mot.common.bean.AnimatedBattleAreaDetails;
import mot.common.bean.Location;
import mot.common.util.ApplicationError;

/**
 * Maintains a list of all crafts wreckages in a battle.
 * At the start of a battle this is empty, but each time a craft is destroyed
 * a new craft sweckage is created.
 */
public class Wreckages {

	private transient Wreckage [] list;
	
	private ArrayList _list;
	
	public Wreckage [] getWrecks() {
		if (list == null) {
			if (_list == null || _list.size() == 0) {
				return null;
			}
			list = (Wreckage[]) _list.toArray(new Wreckage[_list.size()]);
		}
		return list;
	}
	
	public void add(WreckageCraft wreckage) {
		list = null;
		if (_list == null) _list = new ArrayList();
		_list.add(wreckage);
	}
	
	public ArrayList<AnimatedBattleAreaDetails> add(ArrayList<AnimatedBattleAreaDetails> r) throws ApplicationError {
		Wreckage[] wrecks = getWrecks();
		if (wrecks != null) {
			for (int i = 0; i < wrecks.length; i++) {
				if (r == null) r = new ArrayList();
				r.add(WreckageDetailsFactory.create(wrecks[i]));
			}
		}
		return r;
	}

	public WreckageCraft getWreckage(BattleCraft craft) {
		Wreckage[] wrecks = getWrecks();
		if (wrecks != null) {
			for (int i = 0; i < wrecks.length; i++) {
				if (wrecks[i] instanceof WreckageCraft) {
					if (((WreckageCraft)wrecks[i]).getBattleCraft() == craft) {
						return (WreckageCraft) wrecks[i];
					}
				}
			}
		}
		return null;
	}

	public Wreckage getWreckageAt(Location target) throws ApplicationError {
		Wreckage[] wrecks = getWrecks();
		if (wrecks != null) {
			for (int i = 0; i < wrecks.length; i++) {
				if (wrecks[i].getRectangle().contains(target)) {
					return wrecks[i];
				}
			}
		}
		return null;
	}

	public BattleCraft [] getWreckageCraft() {
		Wreckage[] wrecks = getWrecks();
		ArrayList r = null;
		if (wrecks != null) {
			for (int i = 0; i < wrecks.length; i++) {
				if (wrecks[i] instanceof WreckageCraft) {
					WreckageCraft wreckageCraft = (WreckageCraft) wrecks[i];
					if (r == null) {
						r = new ArrayList();
					}
					r.add(wreckageCraft.getBattleCraft());
				}
			}
		}
		if (r == null) {
			return null;
		} else {
			return (BattleCraft[]) r.toArray(new BattleCraft [r.size()]);
		}
	}

	public void remove(Wreckage wreckage) {
		list = null;
		if (_list != null) {
			_list.remove(wreckage);
		}
	}

}
