/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.battles.incumbants;

import mot.common.bean.Geometry;
import mot.common.bean.IntersectionLocations;
import mot.common.bean.Location;
import mot.common.bean.Rectangle;

abstract public class IncumbantCircle implements Incumbent {
	
	private Location center;
	private int radius;
	
	public IncumbantCircle(Location center, int radius) {
		this.center = center;
		this.radius = radius;
	}

	public IntersectionLocations getIntersections(Location source, Location destination) {
		return null;
	}

    public Location getClosestPointToCenter(Location source, Location destination) {
		return Geometry.getClosestPoint(
				source.getX(),
				source.getY(),
				destination.getX(),
				destination.getY(),
				center.getX(),
				center.getY());
    }

    public boolean inside(Location loc) {
    	return loc.getDistanceTo(center) < radius;
    }

	public Location getCenter() {
		return center;
	}

	public void setCenter(Location center) {
		this.center = center;
	}

	public int getRadius() {
		return radius;
	}

    public boolean overlaps(Rectangle rect) {
    	int dist = center.getDistanceTo(rect.getCenterLocation());
    	return (dist < radius + (rect.getHeight()/2+rect.getWidth()/2)/2);
    }
	
}
