/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.battles.incumbants;

import mot.common.bean.Geometry;
import mot.common.bean.IntersectionLocations;
import mot.common.bean.Location;
import mot.common.bean.Rectangle;

abstract public class IncumbantRectangle implements Incumbent {
	
	private Rectangle rectangle;
	
	public IncumbantRectangle(Rectangle rectangle) {
		this.rectangle = rectangle;
	}
	
	public IntersectionLocations getIntersections(Location source, Location destination) {
		return Geometry.getIntersections(rectangle, source, destination);
	}

    public Location getClosestPointToCenter(Location source, Location destination) {
    	Location center = rectangle.getCenterLocation();
		return Geometry.getClosestPoint(
				source.getX(),
				source.getY(),
				destination.getX(),
				destination.getY(),
				center.getX(),
				center.getY());
    }

    public boolean inside(Location loc) {
    	return rectangle.contains(loc);
    }

	public Rectangle getRectangle() {
		return rectangle;
	}

    public boolean overlaps(Rectangle rect) {
    	return rectangle.contains(rect.getLeft(), rect.getTop()) ||
    	       rectangle.contains(rect.getLeft()+rect.getWidth(), rect.getTop()) ||
    	       rectangle.contains(rect.getLeft()+rect.getWidth(), rect.getTop()+rect.getHeight()) ||
    	       rectangle.contains(rect.getLeft(), rect.getTop()+rect.getHeight());
    }
	
}
