/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.battles.incumbants;

import mot.common.bean.Location;
import mot.common.util.ApplicationError;
import mot.engine.battles.BattleCraft;
import mot.engine.battles.BattleObject;
import mot.engine.players.Player;

/**
 * This is a general use class that provides notifcation to any object that implements 
 * the perimeter notification interface that an object has entered its peremeter. 
 * These are incumbents on the battle field and may be used to halt a crafts movement.
 * 
 * These are used mine mines to stop craft when they activate a mine and then receive 
 * notification and explode (see BattleMine).
 */
public class PerimeterAlarm extends IncumbantCircle {

	/**
	 * This is the owner of this alarm that would like notification when its
	 * Perimeter is violoated (entered) by ANY craft. 
	 */
	private PerimeterNotification client;
	
	public PerimeterAlarm(PerimeterNotification client, Location location, int radius) {
		super(location, radius);
		this.client = client;
	}
	
	public boolean effectsMovement() {
		return false;
	}

	public boolean effectsWeapons() {
		return false;
	}

	public double getWeaponEffect() {
		return 0.0;
	}

	public double getMovementEffect() {
		return 0.0;
	}

	public double getMovementDamageEffect() {
		return 0.0;
	}
	
	public void activate(BattleCraft craft) throws ApplicationError {
		client.perimeterNotification(craft);
	}

    public boolean isActive(BattleObject bo) throws ApplicationError {
    	return true;
    }
    
    public boolean isVisible(Player player) throws ApplicationError {
    	if (client == null) {
    		return false;
    	} else {
    		return client.isVisible(player);
    	}
    }
    
    public String toString() {
    	return "PerimeterAlarm @ "+getCenter()+" radius "+getRadius();
    }
}
