/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.battles.incumbants;

import mot.common.bean.Rectangle;
import mot.common.bean.SpaceDistortionDetails;
import mot.engine.battles.BattleCraft;
import mot.engine.battles.BattleObject;
import mot.engine.players.Player;

/**
 * A rift in space-time that is spread out across a battle field. 
 * It incumbers weapons fire and craft movement. They are created
 * using special weapons that can only be deployed on planets. 
 */
public class SpaceDistortion extends IncumbantRectangle {

	/**
	 * The damage percentage of movement a craft receives while passing 
	 * through this field.
	 */
	private double movementEffect;

	/**
	 * The player that owns this mine
	 */
	private Player owner;

	public SpaceDistortion(Player owner, Rectangle rectangle, double movementEffect) {
		super(rectangle);
		this.owner = owner;
		this.movementEffect = movementEffect;
	}

	public boolean effectsMovement() {
		return true;
	}

	public boolean effectsWeapons() {
		return true;
	}

	public double getWeaponEffect() {
		return 0.0;
	}

	public double getMovementEffect() {
		return movementEffect;
	}

	public double getMovementDamageEffect() {
		return 0.0;
	}
	
	
	public void activate(BattleCraft craft) {
	}

    public boolean isActive(BattleObject bo) {
    	return false;
    }
    
    public SpaceDistortionDetails getSpaceDistortionDetails() {
    	return new SpaceDistortionDetails(getRectangle());
    }
    
}
