/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.battles.triggers;

import mot.common.bean.Decorator;
import mot.common.lang.L;
import mot.common.technology.Weapon;
import mot.common.util.ApplicationError;
import mot.common.util.Logger;
import mot.engine.MotEngine;
import mot.engine.battles.Battle;
import mot.engine.battles.BattleObject;
import mot.engine.battles.CraftStateFactory;
import mot.engine.event.BattleObjectTriggerEF;
import mot.engine.players.Player;

public class DamageBot extends CraftTriggerBase {

	/**
	 * The quantity of damage done each turn to the craft
	 */
    private int damage;
    
	public DamageBot(Player owner, Battle battle, BattleObject craft, int life, int damage) {
		super(owner, battle, craft, life);
		this.damage = damage;
	}

	public void execute() throws ApplicationError {
		if (battleObject == null || battleObject.isDestroyed()) {
			return;
		}
		CraftStateFactory originalState = battleObject.getCraftState();
		BattleObjectTriggerEF event = new BattleObjectTriggerEF(battleObject, Weapon.GROUP_DAMAGE_BOT, originalState, null, null);
        MotEngine.instance.getProxyManager().scheduleMulticast(event, battle.getStartingUserPlayers());
        if (damage > 0.0) {
        	battleObject.damage(damage, owner, originalState, null);
        }
		if (Logger.isDebug()) {
			Logger.logDebug("DamageBot.execute() on craft "+battleObject.getName());
		}
		super.execute();
		CraftStateFactory newState = battleObject.getCraftState();
		event.setNewState(newState);
		String message = L.DAMAGE_BOT+damage;
		event.setDescription(message);
        MotEngine.instance.getProxyManager().sendScheduledEvent(event);
	}

	public void postExecute() {
	}

	public String toString() { return "Damage Bots on craft "+battleObject.getName(); }

	public int getDamage() {
		return damage;
	}

	public void setDamage(int damage) {
		this.damage = damage;
	}

	public Decorator getDecotator() {
		return null;
	}

}
