/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.battles.triggers;

import mot.common.bean.Decorator;
import mot.common.bean.DecoratorSleep;
import mot.common.technology.Weapon;
import mot.common.util.ApplicationError;
import mot.common.util.Logger;
import mot.engine.MotEngine;
import mot.engine.battles.Battle;
import mot.engine.battles.BattleCraft;
import mot.engine.battles.CraftStateFactory;
import mot.engine.event.BattleObjectTriggerEF;
import mot.engine.players.Player;

public class Sleep extends CraftTriggerBase {

	/**
	 * The quantity of people to kill each turn
	 */
    private int qtyTurnsMissed;
    private int qtyTurnsToMiss;
    
	public Sleep(Player owner, Battle battle, BattleCraft craft, int qtyTurnsToMiss) {
		super(owner, battle, craft, CraftTriggerBase.INFINATE_LIFE);
		this.qtyTurnsToMiss = qtyTurnsToMiss;
	}

	public void execute() throws ApplicationError {
		if (battleObject == null || battleObject.isDestroyed() || !battleObject.isOperating()) {
			return;
		}
		CraftStateFactory originalState = battleObject.getCraftState();
		if (Logger.isDebug()) {
			Logger.logDebug("Sleep.execute() on craft "+battleObject.getName());
		}
		qtyTurnsMissed++;
		((BattleCraft)battleObject).setMoveRemaining(0.0);
		CraftStateFactory newState = battleObject.getCraftState();
		String message = "Sleep : Miss Turn";
		BattleObjectTriggerEF event = new BattleObjectTriggerEF(battleObject, Weapon.GROUP_SLEEP, originalState, newState, message);
        MotEngine.instance.multicast( event, battle.getStartingUserPlayers() );
	}

	public void postExecute() {
	}

	public boolean isComplete() throws ApplicationError {
		return qtyTurnsMissed >= qtyTurnsToMiss;
	}
	
	public String toString() { return "Sleep on craft "+battleObject.getName(); }

	public int getQtyTurnsToMiss() {
		return qtyTurnsToMiss;
	}

	public void setQtyTurnsToMiss(int qtyTurnsToMiss) {
		this.qtyTurnsToMiss = qtyTurnsToMiss;
	}
	
	public void increaseQtyTurnsMissed(int qty) {
		qtyTurnsMissed = qtyTurnsMissed + qty;
	}

	public Decorator getDecotator() {
		return DecoratorSleep.getInstance();
	}
}
