/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.command;

import mot.common.command_results.CommandResult;
import mot.common.command_results.StateUpdateCommandResult;
import mot.common.morals.MoralChoice;
import mot.common.morals.MoralChoices;
import mot.common.util.ApplicationError;
import mot.common.util.Comp;
import mot.common.util.ValidationError;
import mot.engine.adapter.PlayerDetailsVOAdapter;
import mot.engine.common.EngineVoFactory;
import mot.engine.players.Player;
import mot.engine.players.morals.MoralPolicyAdvisor;

/**
 * This is a command issued by a user to the engine.
 * This command causes the engine to add the Leader with name leader to
 * player.
 **/
public class AcceptMoralChoiceCmd extends Command {

    private String moralPolicyName;

    public AcceptMoralChoiceCmd(Player player, String moralPolicyName) {
        super(player);
        this.moralPolicyName = moralPolicyName;
	}

    /**
     * Each command in the system must implement this method. Its implementation
     * must execute the command.
     */
	protected CommandResult execute()  throws ApplicationError, ValidationError {
        Player owner = getOwner();
        MoralPolicyAdvisor moralPolicyAdvisor = owner.getMoralPolicyAdvisorNotNull();
		if (!Comp.same(moralPolicyName, moralPolicyAdvisor.getLastPolicyRecommnded())) {
            throw new ValidationError("Moral Policy "+moralPolicyName+" was not offered to you");
        }
		MoralChoice moralChoice = MoralChoices.getMoralChoice(moralPolicyName);
		if (moralChoice == null) {
            throw new ValidationError("Moral Policy "+moralPolicyName+" does not exist");
        }
		owner.add(moralChoice);
        return new StateUpdateCommandResult(EngineVoFactory.getPlayer(owner), new PlayerDetailsVOAdapter(owner));
	}


}