/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.command;

import mot.common.command_results.CommandResult;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;
import mot.engine.MotEngine;
import mot.engine.battles.Battle;
import mot.engine.battles.BattleCraft;
import mot.engine.battles.BattleObject;
import mot.engine.event.BattleCraftUpdateEF;
import mot.engine.players.Player;

/**
 * This is a command issued by a user to the engine.
 **/
public abstract class BattleCommand extends Command {

	/**
     * The battle this command is being issues in.
     */
    protected Battle battle;

    public Battle getBattle() {return battle; }
    public void setBattle(Battle battle) { this.battle = battle; }


	public BattleCommand(Player owner, Battle battle) {
        super(owner);
        this.battle = battle;
	}

	protected abstract CommandResult executeBattleCommand()  throws ApplicationError, ValidationError;
	
	protected CommandResult execute()  throws ApplicationError, ValidationError {
		CommandResult cr = executeBattleCommand();
		return cr;
	}
	
	
    public void validateCanGiveCommand(BattleObject source) throws ApplicationError, ValidationError {
        if (!source.isControlledBy(owner)) {
            if (!source.isOwnedBy(owner)) {
   	        	throw new ValidationError(L.THIS_DOES_NOT_BELONG_TO_YOU);
            } else {
               	throw new ValidationError(L.YOU_ARE_NOT_IN_CONTROL_OF_THIS);
            }
        }
        if (source instanceof BattleCraft) {
        	BattleCraft craft = (BattleCraft) source;
            if (!battle.canMoveNext(craft)) {
            	throw new ValidationError(L.THERE_ARE_OTHER_CRAFTS_OF_A_HIGHET_INITIATIVE_WAITING_TO_MOVE);
            }
	        if (battle.hasRetreated(craft)) throw new ValidationError(L.NOT_OPERATING);
        }
    }
    
    public void cleanup(BattleObject source) throws ApplicationError {
    	if (source instanceof BattleCraft) {
    		BattleCraft craft = (BattleCraft) source;
    		if (craft.hasMoved() && craft.getControllerDetails() != null) {
    			craft.setControllerDetails(null);
    			BattleCraftUpdateEF updateEvent = new BattleCraftUpdateEF(craft, craft.getCraftState());
    			MotEngine.instance.multicast(updateEvent, battle.getStartingUserPlayers());
    		}
    	}
    }

}