/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.command;

import mot.common.command_results.CommandResult;
import mot.common.command_results.StateUpdateCommandResult;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;
import mot.engine.battles.Battle;
import mot.engine.battles.BattleCraft;
import mot.engine.players.Player;

/**
 * This command causes the source craft to postpone its move. The owner of this craft does not
 * want to move it straight away - and instead, would like a craft of lower initiative to move 
 * first.
 **/
public class BattleCraftWaitCmd extends BattleCommand {

    /**
     * The source of this command.
     */
    protected BattleCraft source;

    public BattleCraft getSource() { return source; }
    public void setSource(BattleCraft v) { source = v; }

    /**
     * @param owner The player who has submitted this command.
     * @param battle The battle this attack is taking place in.
     * @param source The object to attack.
     */
	public BattleCraftWaitCmd(Player owner, Battle battle, BattleCraft source) {
        super(owner, battle);
        this.source = source;
	}

    /**
     * Each command in the system must implement this method. Its implementation
     * must execute the command.
     */
	protected CommandResult executeBattleCommand()  throws ApplicationError, ValidationError {
        validateCanGiveCommand(source);
        if (battle.getNextToMove(false) != source) {
            throw new ValidationError("This is not the next craft to move");
        }
        if (battle.isWaitingCraft(source)) {
            throw new ValidationError("This is already waiting");
        }
        battle.addToWaitList(source);
        StateUpdateCommandResult cr = new StateUpdateCommandResult();
		battle.getNextObjectToMoveCache().checkForUpdates(cr, owner);
        return cr;
	}
}