/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.command;

import mot.common.command_results.CommandResult;
import mot.common.command_results.NameCR;
import mot.common.command_results.StateUpdateCommandResult;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;
import mot.common.vo.BattleNextObjectToMoveVO;
import mot.common.vo.BattleObjectWeaponStateUpdateVO;
import mot.engine.adapter.BattleObjectWeaponStateVOAdapter;
import mot.engine.battles.Battle;
import mot.engine.battles.BattlePrimaryObject;
import mot.engine.battles.NextObjectToMoveCache;
import mot.engine.players.Player;

/**
 * Get the next object that can move in the battle.
 **/
public class BattleGetNextObjectCmd extends BattleCommand {

    public BattleGetNextObjectCmd(Player owner, Battle battle) throws ApplicationError {
        super(owner, battle);
	}

    /**
     * Each command in the system must implement this method. Its implementation
     * must execute the command.
     */
	protected CommandResult executeBattleCommand()  throws ApplicationError, ValidationError {

        Battle battle = getBattle();
        BattlePrimaryObject next = battle.getNextToMove(true);
        
        NextObjectToMoveCache cache = battle.getNextObjectToMoveCache();
        
        StateUpdateCommandResult cr = null;
        if (next != null) {
        	cr = new NameCR(next.getName());
        	cr.addStateUpdate( new BattleNextObjectToMoveVO(battle.getName(), next.getName()) );
        	cache.setLastNextObject(next);
        } else {
        	cr = new StateUpdateCommandResult();
        }
        if (next != null) {
        	BattleObjectWeaponStateUpdateVO wsu = new BattleObjectWeaponStateUpdateVO(battle.getName(), next.getName(), new BattleObjectWeaponStateVOAdapter(next));
        	cr.addStateUpdate(wsu);
        }
		cache.checkForUpdates(cr, owner);
        return cr;
	}

}