/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.command;

import mot.common.command_results.CommandResult;
import mot.common.command_results.StateUpdateCommandResult;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;
import mot.engine.battles.Battle;
import mot.engine.battles.BattleObject;
import mot.engine.battles.BattlePrimaryObject;
import mot.engine.players.Player;

/**
 * This command causes the source craft get its next orders in the battle.
 * This is used for user crafts when battle mode is automatic or for computer
 * crafts when it is their turn to move.
 **/
public class BattleGetNextOrdersCmd extends BattleCommand {

    /**
     * The source of this command - The craft of planet requiring new orders.
     */
    protected BattleObject source;

    public BattleObject getSource() { return source; }
    public void setSource(BattleObject v) { source = v; }

    public BattleGetNextOrdersCmd(Player owner, Battle battle, BattleObject source) throws ApplicationError {
        super(owner, battle);
        this.source = source;
	}

    /**
     * Each command in the system must implement this method. Its implementation
     * must execute the command.
     */
	protected CommandResult executeBattleCommand()  throws ApplicationError, ValidationError {

		validateCanGiveCommand(source);
		
        Battle battle = source.getBattle();
        BattlePrimaryObject next = battle.getNextToMove(false);
        if (source == next && source instanceof BattlePrimaryObject) {
        	((BattlePrimaryObject)source).getNextOrders();
        }
        
        cleanup(source);
        
        StateUpdateCommandResult cr = new StateUpdateCommandResult();
		battle.getNextObjectToMoveCache().checkForUpdates(cr, owner);
        return cr;
	}

}