/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.command;

import mot.common.command_results.CommandResult;
import mot.common.command_results.StateUpdateCommandResult;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;
import mot.engine.battles.Battle;
import mot.engine.battles.BattleCraft;
import mot.engine.battles.BattleObject;
import mot.engine.battles.HoloCraft;
import mot.engine.players.Player;

/**
 * This command causes the source craft to retreat from this battle.
 **/
public class BattleRetreatCmd extends BattleCommand {

	/**
     * The source of this command.
     */
    protected BattleObject source;

    public BattleObject getSource() { return source; }
    public void setSource(BattleObject v) { source = v; }

    public BattleRetreatCmd(Battle battle, BattleObject source, Player owner) throws ApplicationError {
        super(owner, battle);
        this.source = source;
	}

    /**
     * Each command in the system must implement this method. Its implementation
     * must execute the command.
     */
	protected CommandResult executeBattleCommand()  throws ApplicationError, ValidationError {
        if (source instanceof BattleCraft) {
            BattleCraft selectedCraft = (BattleCraft) source;
            if (!selectedCraft.isOwnedBy(owner)) throw new ValidationError(L.THIS_DOES_NOT_BELONG_TO_YOU);
            if (!selectedCraft.hasNotMoved()) throw new ValidationError(L.THIS_HAS_ALREADY_MOVED);
            if (!battle.canMoveNext(selectedCraft)) {
            	throw new ValidationError(L.THERE_ARE_OTHER_CRAFTS_OF_A_HIGHET_INITIATIVE_WAITING_TO_MOVE);
            }
//            BattlePrimaryObject bestInitiative = battle.getNextToMove(false);
//            if (bestInitiative != null && bestInitiative instanceof BattleCraft) {
//            	BattleCraft bc = (BattleCraft) bestInitiative;
//            	if (selectedCraft.getInitiative() < bc.getInitiative()) {
//            		throw new ValidationError(L.THERE_ARE_OTHER_CRAFT_WITH_HIGHER_INITIATIVE_THAT_HAVE_NOT_MOVED_YET);
//            	}
//            }
            if (selectedCraft.getMovementDamage() > 0) {
            	throw new ValidationError(L.THIS_CRAFT_CANNOT_RETREAT_DUE_TO_MOVEMENT_DAMAGE);
            }
            if (selectedCraft instanceof HoloCraft) {
                selectedCraft.destroy(null, selectedCraft.getCraftState(), null);
            } else {
                selectedCraft.retreat();
            }
        }
        cleanup(source);

        StateUpdateCommandResult cr = new StateUpdateCommandResult();
		battle.getNextObjectToMoveCache().checkForUpdates(cr, owner);
        return cr;
	}

}