/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.command;

import mot.common.command_results.CommandResult;
import mot.common.util.ApplicationError;
import mot.common.util.Logger;
import mot.common.util.ValidationError;
import mot.engine.MotEngine;
import mot.engine.battles.Battle;
import mot.engine.players.Player;

public class ClientCloseWindowCmd extends Command {

	/**
	 * If a battle window has been closed this is the battle that was contained in the battle window.
	 */
    protected Battle battle;

    public Battle getBattle() {return battle; }
    public void setBattle(Battle battle) { this.battle = battle; }


	public ClientCloseWindowCmd(Player owner, Battle battle) {
        super(owner);
        this.battle = battle;
	}

	protected CommandResult execute() throws ApplicationError, ValidationError {
		
		if (MotEngine.getInstance() == null) {
			return null;
		}
		
		MotEngine.getInstance().getProxyManager().broadcastQueue();
		

		// Check that the battle has been completed
		
		if (battle != null) {
			if (Logger.isDebug()) {
				Logger.logDebug("ClientCloseWindowCmd() "+battle.getName()+" hasSentEndBattleEvent "+battle.hasSentEndBattleEvent());
			}
			if (battle.hasEnded()) {
				if (!battle.hasSentEndBattleEvent()) {
					Logger.logWarning("ClientCloseWindowCmd.execute() Client driving engine - Calling endBattle()"); 
					battle.endBattle();
					MotEngine.getInstance().getProxyManager().broadcastQueue();
				}		
			} else {
				Logger.logWarning("ClientCloseWindowCmd.execute() Battle window has closed but battle has not finished"); 
				return null;
			}
						
		}
		
		
		return null;
	}

}
