/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.command;

import mot.common.command_results.CommandResult;
import mot.common.command_results.StateUpdateCommandResult;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;
import mot.engine.MotEngine;
import mot.engine.common.EngineVoFactory;
import mot.engine.crafts.Craft;
import mot.engine.crafts.CraftBase;
import mot.engine.planets.Planet;
import mot.engine.players.Player;


/**
 * This is a issues to instruct a craft/fleet by a player in the game (on the galaxy map)
 * to bombard a planet.
 **/
public class CraftBombardPlanetCmd extends CraftCmd {

	private Planet planet;

    public CraftBombardPlanetCmd(CraftBase craft, Planet planet, Player owner) {
        super(craft, owner);
        this.planet = planet;
	}

    /**
     * Each command in the system must implement this method. Its implementation
     * must execute the command.
     */
	protected CommandResult execute()  throws ApplicationError, ValidationError {
        MotEngine engine = MotEngine.getInstance();
        CraftBase craft = (CraftBase) getCraft();
        if (craft.getOwner() != owner) {
            throw new ValidationError(L.THIS_DOES_NOT_BELONG_TO_YOU);
        }
        if (planet.getOwner() == null) {
            throw new ValidationError(L.INVALID_COMMAND_THIS_PLANET_HAS_NO_OWNER);
        }
        if (!engine.getRelations().isWar(getOwner(), planet.getOwner())) {
            throw new ValidationError(L.INVALID_COMMAND_YOU_ARE_NOT_AT_WAR_WITH_PLAYER+planet.getOwner().getName());
        }
        if (planet.hasWeapons()) {
            throw new ValidationError(L.INVALID_COMMAND_CANNOT_BOMBARD_A_PLANET_THAT_HAS_DEFENSES);
        }
        Craft [] enemies = getOwner().getEnemyCraftAt(planet.getStellarObject(), false);
        if (enemies != null && enemies.length > 0) {
            throw new ValidationError(L.INVALID_COMMAND_CANNOT_BOMBARD_A_PLANET_WHEN_ENEMY_CRAFTS_ARE_IN_ORBIT_WITH_YOU);
        }
        if (craft.hasMoved()) {
            throw new ValidationError(L.THIS_HAS_ALREADY_MOVED);
        }
        
        craft.bombard(planet);
        craft.setHasMoved(true);
        
        // Bombard events send update information for bombing details        
    	return new StateUpdateCommandResult(EngineVoFactory.getMoo(craft, getOwner()));
	}

}