/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.command;

import mot.common.command_results.CommandResult;
import mot.common.command_results.StateUpdateCommandResult;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;
import mot.common.vo.RemoveMooVO;
import mot.engine.adapter.PlanetVOAdapter;
import mot.engine.common.StellarObject;
import mot.engine.crafts.Craft;
import mot.engine.crafts.CraftBase;
import mot.engine.planets.Planet;
import mot.engine.players.Player;


/**
 * This is a issues to request a craft colonise a planet (on the galaxy map).
 **/
public class CraftColoniseCmd extends CraftCmd {

	private Planet planet;

    public CraftColoniseCmd(CraftBase craft, Planet planet, Player owner) {
        super(craft, owner);
        this.planet = planet;
	}

    /**
     * Each command in the system must implement this method. Its implementation
     * must execute the command.
     */
	protected CommandResult execute()  throws ApplicationError, ValidationError {
        Craft craft = (Craft) getCraft();
        if (craft.getOwner() != owner) {
            throw new ValidationError(L.THIS_DOES_NOT_BELONG_TO_YOU);
        }
        if (planet.getOwner() != null) {
            throw new ValidationError(L.PLANET+" "+planet.getName()+L._IS_ALREADY_COLONISED);
        }
        StellarObject so = planet.getStellarObject();
        if ( so.hasOwner() && !so.isOwnedBy(craft.getOwner()) ) {
            throw new ValidationError(L.SOLAR_SYSTEM_+so.getName()+L._IS_ALREADY_OWNED_BY_ANOTHER_PLAYER);
        }
        int qtyEnemies = getOwner().getQtyEnemyCraftAt(so);
        if (qtyEnemies > 0) {
            throw new ValidationError(L.YOU_CANNOT_COLONISE_A_PLANET_WITH_ENEMY_CRAFT_IN_ORBIT);
        }
        if (!craft.canColonise(planet)) {
            throw new ValidationError(L.CRAFT_+craft.getName()+L._IS_NOT_CAPABLE_OF_COLONISING_+planet.getName());
        }
        craft.colonise(planet);
        return new StateUpdateCommandResult(new RemoveMooVO(craft.getName()), new PlanetVOAdapter(planet, owner));
	}

}