/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.command;

import mot.common.command_results.CommandResult;
import mot.common.command_results.StateUpdateCommandResult;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;
import mot.common.vo.RemoveMooVO;
import mot.engine.adapter.CraftVOAdapter;
import mot.engine.adapter.FleetVOAdapter;
import mot.engine.crafts.Craft;
import mot.engine.crafts.Fleet;
import mot.engine.players.Player;

/**
 * Removes this craft from the fleet.
 */
public class CraftLeaveFleetCommand extends Command {

	private Craft craft;

    public CraftLeaveFleetCommand(Craft craft, Player owner) {
        super(owner);
        this.craft = craft;
    }

    /**
     * Each command in the system must implement this method. Its implementation
     * must execute the command.
     */
	protected CommandResult execute()  throws ApplicationError, ValidationError {
        Fleet fleet = craft.getFleet();
        if (!craft.isOwnedBy(owner)) {
            throw new ValidationError(L.THIS_DOES_NOT_BELONG_TO_YOU);
        }
        if (fleet == null) {
            throw new ValidationError(L.CRAFT_IS_NOT_IN_A_FLEET);
        }
        if (fleet.getOrbit() == null) {
            throw new ValidationError(L.FLEET_IS_NOT_IN_ORBIT);
        }
        fleet.setSleeping(false);
        craft.setSleeping(false);
        fleet.remove(craft);
        if (fleet.getSize() < 1) {
        	fleet.destroy();
        	return new StateUpdateCommandResult(new RemoveMooVO(fleet.getName()), new CraftVOAdapter(craft, owner));
        } else {        	
        	return new StateUpdateCommandResult(new FleetVOAdapter(fleet, owner), new CraftVOAdapter(craft, owner));
        }
    }

}