/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.command;

import mot.common.command_results.CommandResult;
import mot.common.command_results.CraftDesignCR;
import mot.common.designs.Orbital;
import mot.common.technology.Hull;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;
import mot.engine.battles.BattleStationFactory;
import mot.engine.common.Orbit;
import mot.engine.common.StellarObject;
import mot.engine.common.StellarObjectOrbital;
import mot.engine.planets.Planet;
import mot.engine.players.UserPlayer;
import mot.engine.players.mayor.CraftDesignerMilitary;

/**
 * Removes the craft design with name name from the the user player owner.
 */
public class DesignMilitaryCraftCmd extends Command {

	private UserPlayer owner;
	private Hull hull;
	private Orbit orbit;

    public DesignMilitaryCraftCmd(UserPlayer owner, Hull hull, Orbit orbit) {
        super(owner);
        this.owner = owner;
		this.hull = hull;
		this.orbit = orbit;
    }

    protected CommandResult execute() throws ApplicationError, ValidationError {
    	if (hull == null) {
            return new CraftDesignCR(new CraftDesignerMilitary().designCraft(owner, CraftDesignerMilitary.SIZE_LARGE, 0.2, 0.0));
    	} else if (hull.isOutpost()) {
    		return new CraftDesignCR(BattleStationFactory.createBattleStationDesign(hull, owner, false, false, true, 0));
    	} else if (hull.isStation()) {
    		int qtyFighterBays = 0;
    		if (orbit != null) {
    			Planet planet = orbit.getPlanet();
    			StellarObject so = orbit.getStellarObject();
    			if (planet != null) {
    				Orbital o = planet.getOrbital();
    				if (o != null) {
    					qtyFighterBays = o.getQtyFighterBays();
    				}
    			} else if (so != null) { 
    				StellarObjectOrbital o = so.getOrbital();
    				if (o != null) {
    					qtyFighterBays = o.getQtyFighterBays();
    				}
    			}
    		}
    		return new CraftDesignCR(BattleStationFactory.createBattleStationDesign(hull, owner, true, true, true, qtyFighterBays));
    	} else {
    		return new CraftDesignCR(new CraftDesignerMilitary().designCraft(owner, hull, CraftDesignerMilitary.SIZE_LARGE, 0.2, 0.0));
    	}
    }

   
}