/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.command;

import mot.common.command_results.CommandResult;
import mot.common.command_results.StateUpdateCommandResult;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;
import mot.common.vo.FlushCraftCacheVO;
import mot.common.vo.RemoveMooVO;
import mot.engine.MotEngine;
import mot.engine.common.EngineVoFactory;
import mot.engine.common.MoveableOwnedObject;
import mot.engine.crafts.Craft;
import mot.engine.crafts.Fleet;
import mot.engine.players.Player;
import mot.engine.transports.Transport;


/**
 * This is a issues to delete a craft by a player in the game (on the galaxy map).
 **/
public class MooDeleteCmd extends Command {

	private mot.engine.common.MoveableOwnedObject craft;

	public MooDeleteCmd(MoveableOwnedObject craft, Player owner) {
        super(owner);
		this.craft = craft;
	}

    /**
     * Each command in the system must implement this method. Its implementation
     * must execute the command.
     */
	protected CommandResult execute()  throws ApplicationError, ValidationError {
		if (craft == null) {
            throw new ValidationError(L.INVALID_COMMAND_PLEASE_SELECT_A_CRAFT_FIRST);
		}
        if (craft.getOwner() != getOwner()) {
            throw new ValidationError(L.THIS_DOES_NOT_BELONG_TO_YOU);
        }
        if (craft.isInABattle()) {
			throw new ValidationError(L.THIS_OBJECT_IS_UNDER_ATTACK);
        }
        if (craft instanceof Craft) {        	
        	craft.destroy();
            owner.addFunds(((Craft)craft).getValue());
        	StateUpdateCommandResult cr = new StateUpdateCommandResult(EngineVoFactory.getPlayer(owner));
        	// Visible craft in the galaxy may have changed due to loss of scanners
			cr.addStateUpdate(new FlushCraftCacheVO());
        	cr.addStateUpdate(EngineVoFactory.getMoos(MotEngine.instance.getMoveableOwnedObjects().getMOOs(owner, true, true), owner));
			return cr;
        } else if (craft instanceof Fleet) {
        	Fleet fleet = (Fleet) craft;
        	Craft[] crafts = fleet.getCrafts();
        	fleet.destroy();
        	StateUpdateCommandResult cr = new StateUpdateCommandResult(new RemoveMooVO(craft.getName()));
    		cr.addStateUpdate(EngineVoFactory.getCrafts(crafts, owner));
			return cr;
        } else if (craft instanceof Transport) {
        	craft.destroy();
        	return new StateUpdateCommandResult(new RemoveMooVO(craft.getName()), EngineVoFactory.getPlayer(owner));
        } else {
            throw new ValidationError(L.INVALID_COMMAND_PLEASE_SELECT_A_CRAFT_FIRST);
        }
	}

}