/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.command;

import mot.common.command_results.CommandResult;
import mot.common.command_results.StateUpdateCommandResult;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;
import mot.engine.MotEngine;
import mot.engine.common.EngineVoFactory;
import mot.engine.common.MoveableOwnedObject;
import mot.engine.players.Player;


/**
 * This is a issues to deploy the contents of a transport to the stellar object or
 * planet the transport is currently in orbit at.
 **/
public class MooSleepCmd extends Command {

	private MoveableOwnedObject moo;
    
    public MooSleepCmd(MoveableOwnedObject moo, Player owner) {
        super(owner);
        this.moo = moo;
	}

    /**
     * Each command in the system must implement this method. Its implementation
     * must execute the command.
     */
	protected CommandResult execute()  throws ApplicationError, ValidationError {
		StateUpdateCommandResult cr = new StateUpdateCommandResult();
		
		if (moo == null) {
			MoveableOwnedObject[] moos = MotEngine.instance.getMoveableOwnedObjects().getMOOs(owner, false);
			if (moos != null) {
				if (allSleeping(moos)) {
					for (int i = 0; i < moos.length; i++) {
						moos[i].setSleeping(false);
					}
				} else {
					for (int i = 0; i < moos.length; i++) {
						if (moos[i].getNavigator() == null) {
							moos[i].setSleeping(true);
						}
					}
				}
				EngineVoFactory.addMooDeepStateUpdate(moos, owner, cr);
			}
		} else {
			if (moo.getOwner() != getOwner()) {
				throw new ValidationError(L.THIS_DOES_NOT_BELONG_TO_YOU);
			}
			
			moo.setSleeping(!moo.isSleeping());
			
			EngineVoFactory.addMooDeepStateUpdate(moo, owner, cr);
		}
		
		return cr;
	}

	private boolean allSleeping(MoveableOwnedObject[] moos) {
		for (int i = 0; i < moos.length; i++) {
			if (!moos[i].isSleeping()) return false;
		}
		return true;
	}	
}