/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.command;

import mot.common.command_results.CommandResult;
import mot.common.command_results.StateUpdateCommandResult;
import mot.common.coms.protocols.ClientEventProcessor;
import mot.common.lang.L;
import mot.common.proxy.UserPlayerProxy;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;
import mot.engine.ClientProxyManager;
import mot.engine.MotEngine;
import mot.engine.players.UserPlayer;


/**
 * This is a command is used to register a proxy with this server for a client. Note - all
 * clients need to register a proxy with the server and the server uses this proxy to communicate
 * with the client.
 **/
public class RegisterProxyCmd extends Command {

    private UserPlayer player;
    private boolean updateClient;
	private ClientEventProcessor eventProcessor;

    public RegisterProxyCmd(UserPlayer player, boolean updateClient, ClientEventProcessor eventProcessor) {
    	super(player);
        this.player = player;
		this.updateClient = updateClient;
		this.eventProcessor = eventProcessor;
	}

    /**
     * Each command in the system must implement this method. Its implementation
     * must execute the command.
     */
	protected CommandResult execute()  throws ApplicationError, ValidationError {
		ClientProxyManager proxyManager = MotEngine.instance.getProxyManager();
		if (proxyManager.getProxy(player) != null) {
			throw new ValidationError(L.THIS_NAME_IS_ALREADY_IN_USE);
		}
		proxyManager.add(new UserPlayerProxy(eventProcessor, player));
        StateUpdateCommandResult cr = new StateUpdateCommandResult();
        if (updateClient) {
        	MotEngine.instance.addStateUpdate(cr, player, true, true, true, true, true, true, true, true, true, true, true);
        }
		return cr;
	}

}