/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.command;

import java.io.File;

import mot.common.command_results.CommandResult;
import mot.common.command_results.ReloadCR;
import mot.common.command_results.StateUpdateCommandResult;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;
import mot.engine.MotEngine;
import mot.engine.players.Player;
import mot.engine.players.UserPlayer;

/**
 * This is a command issued by a user to the engine.
 **/
public class ReloadCmd extends Command {

	private File file;
    private UserPlayer player;

	public ReloadCmd(Player player, File file) {
        super(player);
        this.file = file;
	}

    /**
     * Each command in the system must implement this method. Its implementation
     * must execute the command.
     */
	protected CommandResult execute()  throws ApplicationError, ValidationError {
        if (file == null) {
            throw new ValidationError(L.YOU_MUST_SELECT_A_FILE_TO_LOAD);
        }
        MotEngine.load(file);
        String playerName = MotEngine.instance.getUserPlayerName();
        if (playerName == null) {
            MotEngine.instance = null;
            throw new ValidationError(L.THIS_IS_NOT_A_SINGLE_USER_GAME);
        }
        Player p = MotEngine.instance.getPlayers().getPlayer(playerName);
        if (p == null || !(p instanceof UserPlayer)) {
            MotEngine.instance = null;
            throw new ValidationError(L.THIS_IS_A_LOST_USER_GAME_NO_SUCH_PLAYER_+playerName);
        }
        player = (UserPlayer) p;
        StateUpdateCommandResult cr = new ReloadCR(player.getName());
        MotEngine.instance.addStateUpdate(cr, player, true, true, true, true, true, true, true, true, true, true, true);
		return cr;
	}

    public void setFile(File file) {
        this.file = file;
    }


    public File getFile() {
        return file;
    }


    public void setPlayer(UserPlayer player) {
        this.player = player;
    }


    public UserPlayer getPlayer() {
        return player;
    }
}