/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.command;

import mot.common.command_results.CommandResult;
import mot.common.command_results.StateUpdateCommandResult;
import mot.common.designs.CraftDesign;
import mot.common.designs.CraftDesigns;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;
import mot.common.vo.CraftDesignsVO;
import mot.engine.common.EngineVoFactory;
import mot.engine.players.UserPlayer;

/**
 * Removes the craft design with name name from the the user player owner.
 */
public class RemoveCraftDesign extends Command {

	private UserPlayer owner;
    private String name;

    public RemoveCraftDesign(String name, UserPlayer owner) {
        super(owner);
        this.owner = owner;
        this.name = name;
    }

    protected CommandResult execute() throws ApplicationError, ValidationError {
        if (name == null) {
            throw new ValidationError(L.NO_CRAFT_DESIGN_SPECIFIED);
        }
        
        CraftDesigns p = owner.getCraftDesigns();
        if ( p == null ) {
            throw new ValidationError(L.YOU_DO_NOT_HAVE_ANY_CRAFT_DESIGNS);
        }
        CraftDesign cd = p.get(name);
        if ( cd == null ) {
            throw new ValidationError(L.YOU_DO_NOT_HAVE_ANY_CRAFT_DESIGN_FOR_NAME_+name);
        }
        p.remove(cd);
        
        // Delegate cache manager removes craft design
        CraftDesignsVO r = EngineVoFactory.getCraftDesigns(p, owner);
        return new StateUpdateCommandResult(r);
    }

   
}