/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.command;

import mot.common.command_results.CommandResult;
import mot.common.command_results.StateUpdateCommandResult;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;
import mot.common.vo.RemoveMooVO;
import mot.engine.common.EngineVoFactory;
import mot.engine.players.Player;
import mot.engine.transports.Transport;
import mot.engine.transports.TransportTask;


/**
 * This is issued to remove the current task from a transport.
 **/
public class RemoveTaskFromTransportCmd extends Command {

	private Transport transport;

    public RemoveTaskFromTransportCmd(Transport transport, Player owner) {
        super(owner);
        this.transport = transport;
	}

    /**
     * Each command in the system must implement this method. Its implementation
     * must execute the command.
     */
	protected CommandResult execute()  throws ApplicationError, ValidationError {
        if (transport.getOwner() != getOwner()) {
            throw new ValidationError(L.THIS_TRANSPORT_DOES_NOT_BELONG_TO_YOU);
        }
        TransportTask task = transport.getTask();
        if (task == null) {
            throw new ValidationError(L.THIS_DOES_NOT_HAVE_ANYTHING_TO_DEPLOY);
        }
        if (transport.getOrbit() == null) {
            throw new ValidationError(L.TRANSPORT_MUST_BE_IN_ORBIT_TO_DEPLOY);
        }
        transport.setTask(null);
        
        return new StateUpdateCommandResult(new RemoveMooVO(transport.getName()), EngineVoFactory.getPlayer(owner));
	}

}