/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.command;

import mot.common.bean.SalvageList;
import mot.common.command_results.CommandResult;
import mot.common.command_results.IntegerCR;
import mot.common.lang.L;
import mot.common.technology.Technology;
import mot.common.technology.TechnologyBundle;
import mot.common.technology.TechnologyList;
import mot.common.util.ApplicationError;
import mot.common.util.Comp;
import mot.common.util.Logger;
import mot.common.util.ValidationError;
import mot.engine.adapter.PlayerDetailsVOAdapter;
import mot.engine.common.EngineVoFactory;
import mot.engine.players.Player;

public class SellSalvageCmd extends Command {

	private TechnologyList salvage;

	public SellSalvageCmd(TechnologyList salvage, Player owner) {
		super(owner);
		this.salvage = salvage;
	}

	@Override
	protected CommandResult execute() throws ApplicationError, ValidationError {
		TechnologyBundle[] techsToSell = salvage.getDistinct();
		if (Logger.isDebug()) {
			Logger.logDebug("SellSalvageCmd "+Comp.toString(techsToSell));
		}
		if (techsToSell == null || techsToSell.length == 0) {
			throw new ValidationError(L.NO_EFFECT);
		}
		for (int i = 0; i < techsToSell.length; i++) {
			canSell(techsToSell[i].getTechnology(), techsToSell[i].getQty());
		}
		int amount = 0;
		for (int i = 0; i < techsToSell.length; i++) {
			amount += sell(techsToSell[i].getTechnology(), techsToSell[i].getQty());
		}
		IntegerCR cr = new IntegerCR(amount);
		cr.addStateUpdate(EngineVoFactory.getPlayer(owner));
		cr.addStateUpdate(new PlayerDetailsVOAdapter(owner));
		return cr;
	}

	private void canSell(Technology technology, int qty) throws ValidationError {
		SalvageList ownedSalvage = owner.getSalvage();
		if (ownedSalvage.getQuantity(technology) < qty) {
			throw new ValidationError(L.YOU_DO_NOT_OWN_ALL_TECHNOLOGY_IN_THIS_SALVAGE_LIST);
		}
	}
	
	private int sell(Technology technology, int qty) {
		SalvageList ownedSalvage = owner.getSalvage();
		int amount = owner.sell(technology) * qty;
		while (qty > 0) {
			ownedSalvage.remove(technology);
			qty--;
		}
		return amount;
	}
}
