/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.command;

import mot.common.command_results.CommandResult;
import mot.common.command_results.StateUpdateCommandResult;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;
import mot.engine.common.EngineVoFactory;
import mot.engine.common.Orbit;
import mot.engine.players.Player;
import mot.engine.players.UserPlayer;

/**
 * This is used for a user's planets and informs the planet AI that
 * the user does not wish to have any projects on this planet so do not
 * generate NoProject events.
 **/
public class SetFleetWayPointCmd extends Command {

    private Orbit orbit;

    public SetFleetWayPointCmd(Orbit orbit, Player owner) throws ApplicationError {
        super(owner);
		this.orbit = orbit;
	}

	protected CommandResult execute()  throws ApplicationError, ValidationError {
		if (orbit != null) {
			if (!owner.canTravelTo(orbit.getStellarObject())) {
				throw new ValidationError(L.INVALID_COMMAND_DESTINATION_IS_OUT_OF_RANGE);
			}
		}
		
		if (owner instanceof UserPlayer) {			
			((UserPlayer)owner).setFleetWayPoint(orbit);
		}
        return new StateUpdateCommandResult(EngineVoFactory.getPlayer(owner));
    }

}