/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.command;

import mot.common.command_results.CommandResult;
import mot.common.command_results.StateUpdateCommandResult;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;
import mot.engine.adapter.PlanetVOAdapter;
import mot.engine.common.EngineVoFactory;
import mot.engine.planets.Planet;
import mot.engine.players.Player;

/**
 * This is used for a user's planets and informs the planet AI that
 * the user does not wish to have any projects on this planet so do not
 * generate NoProject events.
 **/
public class SetPlanetWantsNoProjectCmd extends PlanetCmd {

    private boolean wantsNoProject;

    public SetPlanetWantsNoProjectCmd(Planet planet, boolean wantsNoProject, Player owner) throws ApplicationError {
        super(planet, owner);
        this.wantsNoProject = wantsNoProject;
	}

    /**
     * Each command in the system must implement this method. Its implementation
     * must execute the command.
     */
	protected CommandResult execute()  throws ApplicationError, ValidationError {
        Planet planet = getPlanet();
        if (!planet.isOwnedBy(owner)) {
			throw new ValidationError(L.INVALID_COMMAND_THIS_PLANET_THAT_DOES_NOT_BELONG_TO_YOU);
        }
        if (wantsNoProject) {
            planet.setProject(null);
        }
        planet.ownerWantsNoProject = wantsNoProject;
        return new StateUpdateCommandResult(new PlanetVOAdapter(planet, owner), EngineVoFactory.getPlayer(owner));
    }

    public void setWantsNoProject(boolean wantsNoProject) {
        this.wantsNoProject = wantsNoProject;
    }

    public boolean isWantsNoProject() {
        return wantsNoProject;
    }

}