/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.command;
import mot.common.command_results.CommandResult;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;
import mot.engine.players.PlayerCharacter;
import mot.engine.players.UserPlayer;

public class SetPlayerCharacterPercents extends Command {

    private Double ecology;
    private Double development;
    private Double research;
    private Double production;
    private Double money;
    private Double improveEcology;
    private Double improveDevelopment;
    private UserPlayer owner;

    public SetPlayerCharacterPercents(Double ecology, Double development, Double research, Double production, Double money, Double improveEcology, Double improveDevelopment, UserPlayer owner) {
    	super(owner);
        this.ecology = ecology;
        this.development = development;
        this.research = research;
        this.production = production;
        this.money = money;
        this.improveEcology = improveEcology;
        this.improveDevelopment = improveDevelopment;
        this.owner = owner;
    }

    protected CommandResult execute() throws ApplicationError, ValidationError {
        PlayerCharacter pc = owner.getPlayerCharacter();
        if (ecology != null) {
            pc.setPlayerEcologyPercent(ecology.doubleValue());
        }
        if (development != null) {
            pc.setPlayerDevelopmentPercent(development.doubleValue());
        }
        if (research != null) {
            pc.setPlayerResearchPercent(research.doubleValue());
        }
        if (production != null) {
            pc.setPlayerProductionPercent(production.doubleValue());
        }
        if (money != null) {
            pc.setPlayerMoneyPercent(money.doubleValue());
        }
        if (improveEcology != null) {
            pc.setPlayerEcologyPercent(improveEcology.doubleValue());
        }
        if (improveDevelopment != null) {
            pc.setPlayerDevelopmentPercent(improveDevelopment.doubleValue());
        }
        return null;
    }
}