/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.command;

import mot.common.command_results.CommandResult;
import mot.common.command_results.StateUpdateCommandResult;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;
import mot.engine.adapter.PlayerDetailsVOAdapter;
import mot.engine.common.EngineVoFactory;
import mot.engine.players.Player;
import mot.engine.players.UserPlayer;

/**
 * This allocates the amount of money allocated each turn to recruit spies
 * for this player.
 **/
public class SetRecruiteSpyEffortCmd extends Command {

	/**
     * The amount of effort per turn to allocate.
     */
    private int amount;

    public SetRecruiteSpyEffortCmd(Player owner, int amount) {
        super(owner);
        this.amount = amount;
	}

    /**
     * Each command in the system must implement this method. Its implementation
     * must execute the command.
     */
	protected CommandResult execute()  throws ApplicationError, ValidationError {
        UserPlayer player = (UserPlayer) getOwner();
        if (amount < 0) {
            throw new ValidationError(L.CANNOT_ALLOCATE_NEGATIVE_VALUES);
        }
        if (amount > player.getFunds()) {
            throw new ValidationError(L.IT_IS_UNWISE_TO_SPEND_MORE_MONEY_THAN_YOU_HAVE);        	
        }
        player.setSpyRecruitEffortPerTurn(amount);
        StateUpdateCommandResult r = new StateUpdateCommandResult(EngineVoFactory.getPlayer(owner), new PlayerDetailsVOAdapter(owner));
        r.addStateUpdate( new PlayerDetailsVOAdapter(player) );
		return r;
	}
}