/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.command;

import mot.common.bean.SalvageList;
import mot.common.command_results.CommandResult;
import mot.common.command_results.StateUpdateCommandResult;
import mot.common.technology.Technology;
import mot.common.util.ApplicationError;
import mot.common.util.Comp;
import mot.common.util.ValidationError;
import mot.engine.common.EngineVoFactory;
import mot.engine.players.Player;
import mot.engine.players.ResearchProject;

/**
 * This is a command issued by a user to the engine.
 **/
public class SetResearchProjectCmd extends Command {

    private Technology tech;

    public SetResearchProjectCmd(Technology tech, Player player) {
        super(player);
        this.tech = tech;
	}

    /**
     * Each command in the system must implement this method. Its implementation
     * must execute the command.
     */
	protected CommandResult execute() throws ApplicationError, ValidationError {
        Player player = getOwner();
        
        boolean fromSalvage = false;
        
        Technology[] available = player.getTechnologyAvailableForResearch();
        if (!Comp.in(tech, available)) {
        	SalvageList salvage = owner.getSalvage();
            if (salvage == null || !salvage.contains(tech)) {
            	throw new ValidationError("Cannot Research Technology "+tech.getName()+" - Not available for research");
            }
            fromSalvage = true;
            salvage.remove(tech);
        }
        
        ResearchProject rp = new ResearchProject(tech, player, fromSalvage);
        player.setResearchProject(rp);
        return new StateUpdateCommandResult(EngineVoFactory.getPlayer(owner));
	}
}