/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.command;

import mot.common.command_results.CommandResult;
import mot.common.event.ShutdownEvent;
import mot.common.proxy.ClientProxy;
import mot.common.proxy.UserPlayerProxy;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;
import mot.engine.ConnectionList;
import mot.engine.MotEngine;
import mot.engine.players.Player;

/**
 * This is a command issued by a user to the engine.
 **/
public class ShutdownCmd extends Command {

	private String playerName;

	public ShutdownCmd(String playerName) {
        super(null);
		this.playerName = playerName;
	}

    /**
     * Each command in the system must implement this method. Its implementation
     * must execute the command.
     */
	protected CommandResult execute()  throws ApplicationError, ValidationError {

		if (MotEngine.instance != null) {
			Player player = MotEngine.instance.getPlayers().getPlayer(playerName);
			if (player != null) {
				ClientProxy ownerProxy = MotEngine.instance.getProxyManager().getProxy(player);
				if (ownerProxy != null && ownerProxy instanceof UserPlayerProxy) {
					UserPlayerProxy upp = (UserPlayerProxy) ownerProxy;
					if (!upp.isLocalProxy()) {
						throw new ValidationError("Invalid Command - Remote clients cannot shutdown an existing game");
					}
				}
				// Send message to any players playing a replaced game but have not joined the new game
				ClientProxy[] originalProxies = MotEngine.instance.getProxyManager().getProxies(player);
				if (originalProxies != null) {
					for (int i = 0; i < originalProxies.length; i++) {
						if (originalProxies[i] instanceof UserPlayerProxy) {
							UserPlayerProxy upp = (UserPlayerProxy) originalProxies[i];
							upp.notify(new ShutdownEvent());
						}
					}
				}
			}
		}
    	
    	ConnectionList.removeRemoteServerConnections();
    	
		return null;
	}


}