/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.command;

import mot.common.command_results.CommandResult;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;
import mot.engine.MotEngine;

/**
 * This is a command issued by the server when a battle in the server ends.
 * It means there is another battle to be fought at the end of this turn.
 * We do not start the next battle because we want to lose down the other battle before starting the next.
 * NB - Battles.end() is called deep inside a stack trace usually inside a weapon.fire() call..... This should
 * not be the location to chain onto the next battle from! 
 **/
public class StartNextBattleInQueueCmd extends Command {

	public StartNextBattleInQueueCmd() {
        super(null);
	}

    /**
     * Each command in the system must implement this method. Its implementation
     * must execute the command.
     */
	protected CommandResult execute()  throws ApplicationError, ValidationError {
		MotEngine.instance.startNextBattleInQueue();
        return null;
	}

}