/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.command;

import mot.common.command_results.CommandResult;
import mot.common.command_results.StateUpdateCommandResult;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;
import mot.engine.MotEngine;
import mot.engine.adapter.CraftVOAdapter;
import mot.engine.adapter.FleetVOAdapter;
import mot.engine.common.EngineVoFactory;
import mot.engine.crafts.Craft;
import mot.engine.crafts.CraftBase;
import mot.engine.crafts.Crafts;
import mot.engine.crafts.Fleet;
import mot.engine.players.Player;

/**
 * This is a command issued by a user to upgrade all the engines on all crafts
 * owned by this player.
 **/
public class UpgradeEngineCmd extends CraftCmd {

    public UpgradeEngineCmd(CraftBase craft, Player owner) throws ApplicationError {
        super(craft, owner);
	}

    /**
     * Each command in the system must implement this method. Its implementation
     * must execute the command.
     */
	protected CommandResult execute()  throws ApplicationError, ValidationError {
		CraftBase craftBase = getCraft();
		if (craftBase != null) {
			if (!craftBase.isOwnedBy(owner)) {
				throw new ValidationError(L.THIS_DOES_NOT_BELONG_TO_YOU);
			}
	        StateUpdateCommandResult r = new StateUpdateCommandResult();
			if (craftBase instanceof Fleet) {
				Fleet fleet = (Fleet) craftBase;
		        Craft [] crafts = fleet.getCrafts();
		        if (crafts != null && owner.getEngines() != null) {
		        	for (int i = 0; i < crafts.length; i++) {						
		        		crafts[i].upgradeEngine(owner.getEngines().getFastestEngine());
					}
		        }
		        r.addStateUpdate(new FleetVOAdapter(fleet, owner));
		        r.addStateUpdate(EngineVoFactory.getMoos(crafts, owner));
			} else if (craftBase instanceof Craft) {
				Craft craft = (Craft) craftBase;
				if (owner.getEngines() != null) {
					craft.upgradeEngine(owner.getEngines().getFastestEngine());
				}
		        r.addStateUpdate(new CraftVOAdapter(craft, owner));
			}
			return r;
		} else {
	        Crafts crafts = MotEngine.instance.getCrafts();
	        if (crafts != null && owner.getEngines() != null) {
	            crafts.upgradeEngines(owner, owner.getEngines().getFastestEngine());
	        }
	        return new StateUpdateCommandResult(EngineVoFactory.getMoos(owner.getCraftAndFleetObjects(), owner));
		}
	}
}