/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.command_handlers;

import mot.common.bean.DiplomaticProposal;
import mot.common.command_delegates.DiplomaticRequestCmdDeligate;
import mot.common.command_delegates.Request;
import mot.common.command_results.CommandResult;
import mot.common.coms.protocols.ClientEventProcessor;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;
import mot.engine.MotEngine;
import mot.engine.command.DiplomaticRequestCmd;
import mot.engine.players.Player;
import mot.engine.players.UserPlayer;

/**
 * This command causes the owning player to send a diplomatic request to the
 * target player. Note a response does not come back immediately - An event 
 * will be sent some time soon containing the response.
 */
public class DiplomaticRequestCmdHandler extends CommandHandler {

    public CommandResult process(Request o, String playerName, ClientEventProcessor connection) throws ApplicationError, ValidationError {
    	DiplomaticRequestCmdDeligate d = (DiplomaticRequestCmdDeligate) o;
        UserPlayer player = MotEngine.instance.getPlayersNotNull().getUserPlayer(playerName);
        Player reveiver = getPlayer(d.getReceiver());
		DiplomaticProposal proposal = d.getProposal();
		return new DiplomaticRequestCmd(player, reveiver, proposal, d.getMessage()).run();
    }

}