/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.command_handlers;

import mot.common.bean.CraftDesignStatistics;
import mot.common.command_delegates.GetCraftDesignStatistics;
import mot.common.command_delegates.Request;
import mot.common.command_results.CommandResult;
import mot.common.coms.protocols.ClientEventProcessor;
import mot.common.designs.CraftDesign;
import mot.common.lang.L;
import mot.common.technology.Weapons;
import mot.common.util.ApplicationError;
import mot.common.util.Formatter;
import mot.engine.MotEngine;
import mot.engine.battles.BattleCraft;
import mot.engine.crafts.Craft;
import mot.engine.players.Player;
import mot.engine.players.UserPlayer;


public class FetchCraftDesignStatisticsHandler extends MessageHandlerBase {
    
    public CommandResult process(Request o, String playerName, ClientEventProcessor connection) throws ApplicationError {
        GetCraftDesignStatistics p = (GetCraftDesignStatistics)o;
        Player origin = getPlayer(p.getOrigin());
        CraftDesign design = p.getCraftDesign();
        UserPlayer player = MotEngine.instance.getPlayersNotNull().getUserPlayer(playerName);
        return process(design, player, origin);
    }
    
    public CommandResult process(CraftDesign design, Player player, Player origin) throws ApplicationError {
        Craft craft = new Craft(player, origin, design, null);
        BattleCraft bc = new BattleCraft(null, craft, false);
        
        CraftDesignStatistics r = new CraftDesignStatistics();
        
        r.setBattleSpeed(bc.getSpeed(false));
        r.setWarpSpeed(craft.getWarpSpeed());
        r.setManouverability(bc.getManoeuvrability());
        r.setMaxDamage(craft.getMaxDamage());
        r.setCloak(craft.getCloak());
        r.setPsi(bc.getPsiLevel());
    	double assault = 0.0;
    	Weapons weapons = player.getWeapons();
    	if (weapons != null && weapons.getBestGroundWeaponDamage() != null) {
    		assault = weapons.getBestGroundWeaponDamage().getDamage();
    	}
        r.setAssaultBonus(assault * (1.0+player.getAssaultBonus()));
        r.setInitiative(bc.getInitiative());
        double attackBonusPlayer = player.getOwnerDamageBonus();
        double attackBonusSpecials = 0.0;
        double defendBonusSpecials = 0.0;
        if (craft.getSpecials() != null) {
            attackBonusSpecials = craft.getSpecials().getAttackerModification();
            defendBonusSpecials = craft.getSpecials().getDefenderModification();

        }
        r.setAttackBonus(attackBonusPlayer + attackBonusSpecials);

        r.setBattleSpeedDescription(bc.getSpeedDescription());
        r.setWarpSpeedDescription(craft.getWarpSpeedDescription());
        r.setManouverabilityDescription(bc.getManoeuvrabilityDescription());
        r.setMaxDamageDescription(craft.getMaxDamageDescription());
        r.setCloakDescription(craft.getCloakDescription());
        r.setPsiDescription(bc.getPsiLevelDescription());
        r.setAssaultBonusDescription(craft.getOwner().getAssaultBonusDescription());
        r.setInitiativeDescription(bc.getInitiativeDescription());
        r.setAttackBonusDescription(L.ATTACK_BONUS+" = "+L.WEAPON_DAMAGE_CAPS+" + "+L.SPECIALS_BONUS+" "+Formatter.percentLabelNoSign(attackBonusSpecials)+" + "+L.PLAYER_BONUS+" "+Formatter.percentLabelNoSign(attackBonusPlayer));
        r.setDefenceBonusDescription(L.DEFENCE_BONUS+" = "+L.WEAPON_DAMAGE_CAPS+" - "+L.SPECIALS_BONUS+" "+Formatter.percentLabelNoSign(defendBonusSpecials));
        
        return r;
    }
}