/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.command_handlers;

import mot.common.bean.UserPlayerSummary;
import mot.common.command_delegates.Request;
import mot.common.command_results.CommandResult;
import mot.common.command_results.UserPlayerSummaryCR;
import mot.common.coms.protocols.ClientEventProcessor;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;
import mot.engine.ConnectionList;
import mot.engine.MotEngine;
import mot.engine.SocketHandlerThreadEngine;
import mot.engine.players.UserPlayer;

/**
 * This is a command issued by a user to the engine.
 **/
public class FetchRegisteredPlayersHandler extends MessageHandlerBase {

    public FetchRegisteredPlayersHandler() {
	}

	public CommandResult process(Request o, String playerName, ClientEventProcessor connection) throws ApplicationError, ValidationError {
		if (MotEngine.instance == null) {
			throw new ValidationError("No Game has been started");
		}
		UserPlayer[] pa = MotEngine.instance.getPlayersNotNull().getUserPlayers();
		if (pa == null) {
			throw new ValidationError("No Game has been started");
		}
		UserPlayerSummary [] r = new UserPlayerSummary[pa.length];
		for (int i = 0; i < r.length; i++) {
			String name = pa[i].getName();
			SocketHandlerThreadEngine rsc = ConnectionList.getRemoteServerConnectionFor(name);
			r[i] = new UserPlayerSummary(name, pa[i].getColor(), pa[i].getAlignment(), rsc != null); 
		}
		return new UserPlayerSummaryCR(r);
	}

}