/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.command_handlers;

import java.io.File;
import java.io.FileFilter;
import java.text.SimpleDateFormat;

import mot.common.bean.SavedGameFile;
import mot.common.command_delegates.Request;
import mot.common.command_results.CommandResult;
import mot.common.command_results.FileNamesCR;
import mot.common.coms.protocols.ClientEventProcessor;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;
import mot.engine.validators.SavedGameFileNameValidator;

/**
 * This is a command issued by a user to the engine.
 **/
public class FetchSavedGameFilesCmdHandler extends MessageHandlerBase {

    public FetchSavedGameFilesCmdHandler() {
        super();
	}

	public CommandResult process(Request o, String playerName, ClientEventProcessor connection) throws ApplicationError, ValidationError {
        File folder = SavedGameFileNameValidator.getSavesFolder();
        FileFilter gameFilter = new FileFilter() {
			public boolean accept(File pathname) {
				return pathname.getName().endsWith(SavedGameFileNameValidator.SAVED_GAME_EXTENSION);
			}
        };
        File [] files = folder.listFiles(gameFilter);
        if (files == null) {
            return null;
        }
        SavedGameFile [] fileNames = new SavedGameFile [files.length];
        for (int i = 0; i < files.length; i++) {
			SimpleDateFormat sdf = new SimpleDateFormat("dd MMM : HH mm");
			String date =  sdf.format(files[i].lastModified());
			fileNames[i] = new SavedGameFile(files[i].getName(), date);
		}
        return new FileNamesCR(fileNames);
	}

}