/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.command_handlers;

import mot.common.command_delegates.FetchTechnologiesCmdDelegate;
import mot.common.command_delegates.Request;
import mot.common.command_results.CommandResult;
import mot.common.command_results.TechnologyListCR;
import mot.common.coms.protocols.ClientEventProcessor;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;
import mot.engine.MotEngine;
import mot.engine.players.Player;
import mot.engine.players.UserPlayer;
import mot.engine.spies.SpyCenter;

/**
 * This is a command issued by a user to the engine.
 **/
public class FetchTechnologiesCmdHandler extends MessageHandlerBase {

    public FetchTechnologiesCmdHandler() {
        super();
	}

	public CommandResult process(Request o, String playerName, ClientEventProcessor connection) throws ApplicationError, ValidationError {
		FetchTechnologiesCmdDelegate c = (FetchTechnologiesCmdDelegate) o;
		String p = c.getPlayer();
		if (p == null) throw new ValidationError("Must specify a player");
		Player player = MotEngine.instance.getPlayersNotNull().getPlayer(p);
		if (player == null) throw new ValidationError("Player "+p+" does not exist");
		
        UserPlayer owner = MotEngine.instance.getPlayersNotNull().getUserPlayer(playerName);
        SpyCenter sc = owner.getSpyCenter();
        if (sc == null || !sc.canViewDetailsOf(player)) {
        	throw new ValidationError(L.YOU_CANNOT_VIEW_THE_ESPIONAGE_REPORT_FOR_THIS_PLAYER_BECUASE_YOU_HAVE_NOT_ALLOCATED_ANY_SPIES_TO_THIS_PLAYER);
        }
        
		return new TechnologyListCR(player.getTechnologies());
	}

}