/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.command_handlers;

import mot.common.bean.NewGameUserPlayerData;
import mot.common.command_delegates.NewGameUserPlayerCmdDeligate;
import mot.common.command_delegates.Request;
import mot.common.command_results.CommandResult;
import mot.common.coms.protocols.ClientEventProcessor;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;
import mot.engine.command.NewGameUserPlayerCmd;


/**
 * This is a command issued by a user to the engine.
 * It stores up the options selected by a user players as they register for a new game, then
 * when a NewGameCmd is fired, the accumulated options for all the users are consumed to create
 * a game.
 **/
public class NewGameUserPlayerCmdHandler extends CommandHandler {

    public CommandResult process(Request o, String playerName, ClientEventProcessor connection) throws ApplicationError, ValidationError {
        NewGameUserPlayerCmdDeligate d = (NewGameUserPlayerCmdDeligate) o;
        NewGameUserPlayerData userData = d.getUserData();
        return new NewGameUserPlayerCmd(d.getClientId(), userData).run();
    }


}