/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.command_handlers;

import mot.common.command_delegates.Request;
import mot.common.command_delegates.SetPlanetPercentsCmdDeligate;
import mot.common.command_results.CommandResult;
import mot.common.coms.protocols.ClientEventProcessor;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;
import mot.engine.MotEngine;
import mot.engine.command.SetPlanetPercentsCmd;
import mot.engine.players.UserPlayer;

/**
 * If development is not null, then planet auto development percent is set to development.
 * If ecology is not null, then planet auto ecology percent is set to ecology.
 * If planet auto development percent is set to automatic, this command causes development
 * on a planet allocated to be calculated automatically.
 * If planet auto ecology percent percent is set to automatic, this command causes ecology
 * on a planet allocated to be calculated automatically.
 **/
public class SetPlanetPercentsCmdHandler extends CommandHandler {

    public CommandResult process(Request o, String playerName, ClientEventProcessor connection) throws ApplicationError, ValidationError {
        SetPlanetPercentsCmdDeligate d = (SetPlanetPercentsCmdDeligate) o;
        UserPlayer player = MotEngine.instance.getPlayersNotNull().getUserPlayer(playerName);
        return new SetPlanetPercentsCmd(getPlanet(d.getPlanet()),
                                 d.getDevelopmentPercent(),
                                 d.getEcologyPercent(),
                                 d.getProductionPercent(),
                                 d.getResearchPercent(),
                                 player).run();
    }

}