/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.command_handlers;

import mot.common.command_delegates.Request;
import mot.common.command_delegates.SpyRoleAddEspionageCmdDeligate;
import mot.common.command_results.CommandResult;
import mot.common.coms.protocols.ClientEventProcessor;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;
import mot.engine.MotEngine;
import mot.engine.command.SpyRoleAddEspionageCmd;
import mot.engine.players.UserPlayer;

/**
 * Moves a spy from the defend pool belonging to player to an espionage spy role
 * owned by player and targetting player other..
 */
public class SpyRoleAddEspionageCmdHandler extends CommandHandler {

    public CommandResult process(Request o, String playerName, ClientEventProcessor connection) throws ApplicationError, ValidationError {
        SpyRoleAddEspionageCmdDeligate d = (SpyRoleAddEspionageCmdDeligate) o;
        UserPlayer player = MotEngine.instance.getPlayersNotNull().getUserPlayer(playerName);
        return new SpyRoleAddEspionageCmd(player, getPlayer(d.getTarget()), d.getQty()).run();
    }

}