/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.command_handlers;

import mot.common.command_delegates.Request;
import mot.common.command_delegates.SpyRoleAddStellarObjectCmdDeligate;
import mot.common.command_results.CommandResult;
import mot.common.coms.protocols.ClientEventProcessor;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;
import mot.engine.MotEngine;
import mot.engine.command.SpyRoleAddStellarObjectCmd;
import mot.engine.players.UserPlayer;

/**
 * Allocates some spies from owner to spy on the target planet. This will allow the owner
 * to view the details of the planets production etc.
 */
public class SpyRoleAddStellarObjectCmdHandler extends CommandHandler {

    public CommandResult process(Request o, String playerName, ClientEventProcessor connection) throws ApplicationError, ValidationError {
        SpyRoleAddStellarObjectCmdDeligate d = (SpyRoleAddStellarObjectCmdDeligate) o;
        UserPlayer player = MotEngine.instance.getPlayersNotNull().getUserPlayer(playerName);
        return new SpyRoleAddStellarObjectCmd(player, getStellarObject(d.getTarget())).run();
    }

}