/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.common;

import mot.client.proxy.CompletedCallback;
import mot.client.proxy.MotServerProxy;
import mot.common.util.ApplicationError;
import mot.common.util.Logger;
import mot.common.util.ValidationError;

public class CompletedServerCallbackSyncroniser implements CompletedCallback {
	
	private boolean complete = false;
	private Object result = null;

	@Override
	public void complete(Object result) throws ApplicationError, ValidationError {
		this.result = result;
		complete = true;
	}
	
	public Object waitTillComplete() {
		while (!complete) {
			try {
				Thread.sleep(5);
			} catch (InterruptedException e) {	}
		}
		complete = false;
		return result;
	}
	
	public Object waitTillCompleteAndProcessCommandResponse(MotServerProxy serverProxy) {
		while (!complete) {
			try {
				Thread.sleep(5);
				try {
					serverProxy._processCommandResponse();
				} catch (Exception e) {
					Logger.logError("", e);
				}
			} catch (InterruptedException e) {	}
		}
		complete = false;
		return result;
	}
}
