/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.common;

import mot.common.designs.Orbital;
import mot.common.util.PropertyManager;
import mot.engine.players.Player;

/**
 * An outpost is an orbital that is associated with a stellar object instead of a
 * planet and is used to extend the range of crafts and a players scanners.
 */
public class SpaceStation extends StellarObjectOrbital {

    private static final int INFLUENCE = PropertyManager.getMandatoryNoErrorAsInt("influence.space_station",1);

	private transient String image;
    
    public SpaceStation(Orbital orbital, Player owner) {
        super(orbital, owner);
    }

    public SpaceStation() {
    }

    protected String getElementName() {
        return "space-station";
    }

	public int getInfluence() {
		return INFLUENCE;
	}
}