/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.common;

import mot.common.util.ApplicationError;
import mot.common.xml.XMLBean;
import mot.common.xml.XMLWriter;
import mot.engine.players.Player;
import mot.engine.players.PlayerReference;

/**
 * This a visitors to an object. A player can see details of a solar system once
 * that player has visited it. This object keeps a record of when a player has visited
 * a stellar object.
 */
public class Visitor extends  XMLBean {

    /**
     * This is the player that ownes this visited object.
     */
    private Player player;

    /**
     * This is the date the player last visited the object.
     * @see mot.engine.MotEngine for details.
     */
    private int date;
    
    /**
     * The quantity of spies allocated to this planet by this player.
     */
    private int qtySpies;

    public Visitor() {
    }

    public Visitor(Player player, int date) {
        this.player = player;
        this.date = date;
    }

    public int getDate() {
        return date;
    }

    public void setDate(int date) {
        this.date = date;
    }

    public Player getPlayer() {
        return player;
    }

    public void setPlayer(Player player) {
        this.player = player;
    }

    public void setPlayerReference(PlayerReference p) throws ApplicationError {
        player = p.getPlayer();
    }

	protected void encode(XMLWriter writer) throws ApplicationError {
        new PlayerReference(player).toXML(writer);
        writer.addElement("date", date);
        if (qtySpies > 0) {
            writer.addElement("qty-spies", qtySpies);
        }
	}

	protected String getElementName() { return "visitor"; }


    public void setQtySpies(int qtySpies) {
        this.qtySpies = qtySpies;
    }

    public void addSpies(int qtySpies) {
        this.qtySpies = +qtySpies;
    }


    public int getQtySpies() {
        return qtySpies;
    }


}