/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.crafts;

import mot.common.util.ApplicationError;
import mot.engine.common.MoveableOwnedObject;
import mot.engine.planets.Planet;
import mot.engine.planets.SolarSystem;

/**
 * These are factories that define a logic to allocate a 
 * craft to an orbit around a planet. A user can use the
 * getOrbit() method to receive the recommended planet this
 * craft should orbit.
 */
public interface CraftOrbitFactory {
	
	/**
	 * Return the planet that this factory would recommend as an orbit for the craft
	 * passed in. Not this may return null. If a solar system does not have any planets
	 * it will return null.
	 * @param ss The solar system we need an orbit recommendation in
	 * @param craft The craft that requires a planetary orbit in a solar system
	 * @return The planet this craft os recommended to orbit or null
	 * @throws ApplicationError 
	 */
	public Planet getOrbit(SolarSystem ss, MoveableOwnedObject moo) throws ApplicationError;
}
