/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.crafts;

import mot.common.bean.Location;
import mot.common.util.ApplicationError;
import mot.engine.common.Orbit;
import mot.engine.players.Player;

public class FleetFactory  {

    public static Fleet create(Craft [] crafts) throws ApplicationError {
        if (crafts == null || crafts.length == 0) {
            return null;
        }
        Fleet fleet = create(crafts[0].getOwner(), crafts[0].getOrbit());
        for (int i=0; i<crafts.length; i++) {
            fleet.add(crafts[i]);
        }
        return fleet;
    }
    
    public static Fleet create(Craft craft) throws ApplicationError {
        Orbit orbit = craft.getOrbit();
		Fleet fleet = create(craft.getOwner(), orbit);
		if (orbit == null) {
			// Players can only create a fleet in orbit, but a kaan is added to a fleet in a nebula!
			if (craft.getLocation() != null) {
				fleet.setLocation(new Location(craft.getLocation()));
			}
		}
        fleet.add(craft);
        return fleet;
    }

    public static Fleet create(Craft craft1, Craft craft2) throws ApplicationError {
    	Fleet f = create(craft1);
    	f.add(craft2);
    	return f;
    }
    
    public static Fleet create(Player owner, Orbit orbit) {
        Fleet fleet = new Fleet(owner, orbit);
        owner.setFleet(fleet);
        return fleet;
    } 

}