/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.crafts;

import mot.common.util.ApplicationError;
import mot.common.xml.XMLWriter;
import mot.engine.common.MoveableOwnedObject;
import mot.engine.common.MoveableOwnedObjectReference;
import mot.engine.players.Player;
import mot.engine.players.PlayerReference;

public class FleetReference extends MoveableOwnedObjectReference {

	/**
	 * The fleet which this references refers to.
	 * This can be determined from the name and the owner.
	 */
	private transient Fleet fleet;

	/**
	 * The player to whom this fleet belongs.
	 */
	private PlayerReference playerReference;

	public Fleet getFleet() throws ApplicationError {
		if (fleet == null) {
			Player owner = getOwner();
			if (owner == null) {
				return null;
			} else {
				fleet = owner.getFleet(getName());
			}
		}
		return fleet;
	}

	public void setFleet(Fleet v) {
		fleet = v;
		setName(fleet.getName());
	}

	public Player getOwner() throws ApplicationError {	return playerReference.getPlayer(); }
	public PlayerReference getPlayerReference() {	return playerReference; }

	public void setOwner(Player v) { playerReference = new PlayerReference(v, v.getName()); }
	public void setPlayerReference(PlayerReference v) {	playerReference = v; }

	public FleetReference() {
	}

	public FleetReference(Fleet fleet) throws ApplicationError {
        this(fleet, fleet.getOwner());
    }
    
	public FleetReference(Fleet fleet, Player owner) {
		super(fleet.getName());
		this.fleet = fleet;
        setOwner(owner);
	}

	protected void encode(XMLWriter writer) throws ApplicationError {
        Fleet f = getFleet();
        if (f == null) {
            throw new ApplicationError("FleetReference.encode() No fleet for name "+getName()+" player "+playerReference.getName());
        }
		writer.addElement("name", f.getName());
		playerReference.toXML(writer);
	}

	protected String getElementName() { return "fleet-reference"; }

	public MoveableOwnedObject getObject() throws ApplicationError {
		return getFleet();
	}

	public boolean contains(Craft c) throws ApplicationError {
		Fleet f = getFleet();
		if (f == null) {
			return false;
		} else {
			return f.contains(c);
		}
	}
}