/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.event;

import mot.common.event.BattleAutomateEvent;
import mot.common.event.MotEvent;
import mot.common.util.ApplicationError;
import mot.engine.battles.Battle;
import mot.engine.players.Player;

/**
 * Notifies user players that that the battle has been automated.
 * This is sent to all user players except the last to request automate and should cause
 * them the close their battle window.
 * The last user to automate proceeds like in the single player game (closes the window
 * upon successful command result). 
 */
public class BattleAutomatedEF implements MotEventFactory {

    private Battle battle;

    public BattleAutomatedEF(Battle battle) {
        this.battle = battle;
	}

    public MotEvent createEvent(Player owner) throws ApplicationError {
    	BattleAutomateEvent e = new BattleAutomateEvent( battle.getName() );
		return e;
    }

}