/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.event;

import mot.common.bean.CraftState;
import mot.common.bean.ObjectMovement;
import mot.common.event.BattleCraftMoveEvent;
import mot.common.event.MotEvent;
import mot.common.util.ApplicationError;
import mot.engine.battles.BattleCraft;
import mot.engine.battles.CraftStateFactory;
import mot.engine.players.Player;

/**
 * This event is sent to all when a craft has moved on the battle map. This gives UIs a
 * chance to animate craft movement.
 *
 * Note percentTurn + percentMove does not have to be equal to one because not all of the
 * crafts turn may have been taken.
 */
public class BattleCraftMoveEF extends LinkedEventFactoryBase {

    private BattleCraft craft;
    private ObjectMovement [] movements;
    private CraftStateFactory craftState;

    public BattleCraftMoveEF(BattleCraft craft, ObjectMovement [] movements, CraftStateFactory craftState) {
        this.craft = craft;
        this.movements = movements;
        this.craftState = craftState;
    }


    public MotEvent createEvent(Player owner) throws ApplicationError {
    	CraftState cs = (craftState != null) ? craftState.getCraftState(owner) : null;
    	BattleCraftMoveEvent event = new BattleCraftMoveEvent(craft.getBattle().getName(), craft.getName(), cs, movements);
        setLinkedEvents(event, owner);
        return event;
    }


	public void setMovements(ObjectMovement [] movements, CraftStateFactory craftState) {
		this.movements = movements;
        this.craftState = craftState;
	}


}