/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.event;

import mot.common.event.BattleCraftNewEvent;
import mot.common.event.MotEvent;
import mot.common.util.ApplicationError;
import mot.common.vo.BattleCraftVO;
import mot.engine.adapter.CraftVOAdapter;
import mot.engine.battles.BattleCraft;
import mot.engine.common.EngineVoFactory;
import mot.engine.crafts.Craft;
import mot.engine.players.Player;

/**
 * Caused when a craft materialises in a battle.
 */
public class BattleCraftNewEF extends LinkedEventFactoryBase {

	/**
	 * The new craft that is to materialise.
	 */
	private BattleCraft battleCraft;
	
	/**
	 * If false = Crafts just appear on battle map
	 * If true = Craft materialise using an animation
	 */
	private boolean useMaterialiseAnimation;


    public BattleCraftNewEF(BattleCraft craft, boolean useMaterialiseAnimation) {
		this.battleCraft = craft;
		this.useMaterialiseAnimation = useMaterialiseAnimation;
	}

    public MotEvent createEvent(Player owner) throws ApplicationError {
    	BattleCraftVO vo = EngineVoFactory.getBattleCraft(battleCraft, owner);
    	BattleCraftNewEvent event = new BattleCraftNewEvent(battleCraft.getBattle().getName(), vo, useMaterialiseAnimation);
        setLinkedEvents(event, owner);
    	Craft craft = battleCraft.getCraft();
    	CraftVOAdapter cvo = new CraftVOAdapter(craft, owner, true);
    	event.addStateUpdate(cvo);
		return event;
    }
}