/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.event;

import mot.common.bean.CraftState;
import mot.common.event.BattleCraftSurrenderEvent;
import mot.common.event.MotEvent;
import mot.common.util.ApplicationError;
import mot.engine.battles.BattleCraft;
import mot.engine.battles.CraftStateFactory;
import mot.engine.players.Player;

/**
 * Caused when a craft surrenders in a battle.
 * This occurs when a craft attacks this craft and has a much higher psi rating.
 */
public class BattleCraftSurrenderEF implements MotEventFactory {

	public BattleCraft craft;
	private CraftStateFactory oldState;
	private CraftStateFactory newState;

    public BattleCraftSurrenderEF(BattleCraft craft, CraftStateFactory oldState, CraftStateFactory newState) {
		this.craft = craft;
		this.oldState = oldState;
		this.newState = newState;
	}

    public MotEvent createEvent(Player owner) throws ApplicationError {
    	CraftState os = (oldState != null) ? oldState.getCraftState(owner) : null;
    	CraftState ns = (newState != null) ? newState.getCraftState(owner) : null;
        return new BattleCraftSurrenderEvent(craft.getBattle().getName(), craft.getName(), os, ns);
    }

}