/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.event;

import mot.common.bean.CraftState;
import mot.common.event.BattleCraftTeleportEvent;
import mot.common.event.MotEvent;
import mot.common.util.ApplicationError;
import mot.engine.battles.BattleCraft;
import mot.engine.battles.CraftStateFactory;
import mot.engine.players.Player;

/**
 * This event is sent to all when a craft has moved on the battle map. This gives UIs a
 * chance to animate craft movement.
 *
 * Note percentTurn + percentMove does not have to be equal to one because not all of the
 * crafts turn may have been used.
 */
public class BattleCraftTeleportEF extends LinkedEventFactoryBase {

    private BattleCraft craft;
    private CraftStateFactory oldState;
    private CraftStateFactory newState;
    private double percentMove;


    public BattleCraftTeleportEF(BattleCraft craft, CraftStateFactory oldState, double percentMove) {
		this.craft = craft;
		this.oldState = oldState;
		this.percentMove = percentMove;
	}

    public BattleCraftTeleportEF(BattleCraft craft, CraftStateFactory oldState, CraftStateFactory newState, double percentMove) {
		this.craft = craft;
		this.oldState = oldState;
		this.newState = newState;
		this.percentMove = percentMove;
	}

    public MotEvent createEvent(Player owner) throws ApplicationError {
        // The locations are copies incase the craft is moved after this animation is created
    	CraftState os = (oldState != null) ? oldState.getCraftState(owner) : null;
    	CraftState ns = (newState != null) ? newState.getCraftState(owner) : null;
    	BattleCraftTeleportEvent event = new BattleCraftTeleportEvent(craft.getBattle().getName(), craft.getName(), os, ns, percentMove);
        setLinkedEvents(event, owner);
        return event;
    }

	public CraftStateFactory getOldState() {
		return oldState;
	}

	public void setOldState(CraftStateFactory oldState) {
		this.oldState = oldState;
	}

	public CraftStateFactory getNewState() {
		return newState;
	}

	public void setNewState(CraftStateFactory newState) {
		this.newState = newState;
	}

	public double getPercentMove() {
		return percentMove;
	}

	public void setPercentMove(double percentMove) {
		this.percentMove = percentMove;
	}

}