/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.event;

import mot.common.bean.CraftState;
import mot.common.bean.Damage;
import mot.common.event.BattleDamageEvent;
import mot.common.event.MotEvent;
import mot.common.util.ApplicationError;
import mot.engine.battles.BattleObject;
import mot.engine.battles.CraftStateFactory;
import mot.engine.players.Player;

/**
 * This event is caused when a craft is damaged - and causes the damage animation to be
 * destroyed. This event is not used when an object is damaged by weapon fire - A Weapon
 * FireEvent is created for damage inflicted by a weapon - This is used for things like
 * a warp core breach or any explosion.
 *
 * NOTE - Using WeaponFireEvent reduces the total quantity of events sent to the client.
 */
public class BattleDamageEF implements MotEventFactory {

    private BattleObject target;
	private String damageDescription;
	private double damage;
	private double shieldBlockedDamage;
	private boolean destroyed;
	private CraftStateFactory oldTargetState;
	private CraftStateFactory newTargetState;

    public BattleDamageEF(BattleObject target, String damageDescription, double damage, double shieldBlockedDamage, boolean destroyed, CraftStateFactory oldTargetState, CraftStateFactory newTargetState) throws ApplicationError {
        this.target = target;
		this.damageDescription = damageDescription;
		this.damage = damage;
		this.shieldBlockedDamage = shieldBlockedDamage;
		this.destroyed = destroyed;
		this.oldTargetState = oldTargetState;
		this.newTargetState = newTargetState;
	}

    public BattleDamageEF(BattleObject target) {
        this.target = target;
	}

    public MotEvent createEvent(Player owner) throws ApplicationError {
        if (target != null && oldTargetState == null) oldTargetState = target.getCraftState();
        CraftState ots = (oldTargetState != null) ? oldTargetState.getCraftState(owner) : null;
        CraftState nts = (newTargetState != null) ? newTargetState.getCraftState(owner) : null;
        Damage d = new Damage(damageDescription, damage, shieldBlockedDamage, destroyed, ots, nts);
    	BattleDamageEvent event = new BattleDamageEvent(target.getBattle().getName(), target.getName(), d);
        return event;
    }


	public void setDamage(String damageDescription, double damage, double shieldBlockedDamage, boolean destroyed, CraftStateFactory oldTargetState, CraftStateFactory newTargetState) {
		this.damageDescription = damageDescription;
		this.damage = damage;
		this.shieldBlockedDamage = shieldBlockedDamage;
		this.destroyed = destroyed;
		this.oldTargetState = oldTargetState;
		this.newTargetState = newTargetState;
	}


}