/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.event;

import mot.common.bean.CraftState;
import mot.common.event.BattleDestroyedEvent;
import mot.common.event.MotEvent;
import mot.common.util.ApplicationError;
import mot.common.util.Logger;
import mot.engine.battles.BattleObject;
import mot.engine.battles.CraftStateFactory;
import mot.engine.players.Player;

/**
 * Caused when a craft is destroyed, either in a battle or on the main map
 * due to some other event.
 */
public class BattleDestroyedEF extends LinkedEventFactoryBase {

    /**
     * This is the state before the craft was destroyed.
     * Note if this event is being sent in conjunction with a WeaponFireEvent then this may be null
     * because any animation based on this will not be required to maintain old state.
     */
	public CraftStateFactory oldState;
    
    /**
     * This is the craft that has been destroyed.
     */
	private BattleObject target;

    /**
     * True if this craft was a hologram.
     */
    private boolean hologram;

    public BattleDestroyedEF(BattleObject target, CraftStateFactory oldState, boolean isHologram) {
		this.target = target;
        this.oldState = oldState;
        this.hologram = isHologram;
	}

    public MotEvent createEvent(Player owner) throws ApplicationError {
        if (target != null && oldState == null) {
        	Logger.logWarning("DestroyedEF No Old State "+target);
        	oldState = target.getCraftState();
        }
    	CraftState os = (oldState != null) ? oldState.getCraftState(owner) : null;
        BattleDestroyedEvent r = new BattleDestroyedEvent(target.getBattle().getName(), target.getName(), os, hologram);
        setLinkedEvents(r, owner);
        r.setState(getState());
		return r;
    }


	public BattleObject getTarget() {
		return target;
	}

	public void setTarget(BattleObject target) {
		this.target = target;
	}


}