/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.event;

import mot.common.event.BattleDroidMineLaunchEvent;
import mot.common.event.MotEvent;
import mot.common.util.ApplicationError;
import mot.common.util.Logger;
import mot.engine.adapter.DroidMineVOAdapter;
import mot.engine.battles.DroidMine;
import mot.engine.players.Player;

/**
 * Caused when a craft fires a droid mine in a battle.
 * There should now be an automaton object in the battle being the droid mine.
 */
public class BattleDroidMineLaunchEF implements MotEventFactory {

    private DroidMine droidMine;

    public BattleDroidMineLaunchEF(DroidMine droidMine) {
        this.droidMine = droidMine;
        if (Logger.isDebug()) {
        	Logger.logDebug("BattleDroidMineLaunchEF() "+droidMine);
        }
	}

    public MotEvent createEvent(Player owner) throws ApplicationError {
    	BattleDroidMineLaunchEvent event = new BattleDroidMineLaunchEvent(droidMine.getBattle().getName(), new DroidMineVOAdapter(droidMine, owner));
		return event;
    }

}