/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.event;

import mot.common.bean.CraftState;
import mot.common.bean.Location;
import mot.common.event.BattleDroidMineMoveEvent;
import mot.common.event.MotEvent;
import mot.common.util.ApplicationError;
import mot.common.util.Logger;
import mot.engine.battles.CraftStateFactory;
import mot.engine.battles.DroidMine;
import mot.engine.players.Player;

/**
 * This event is sent to all when a missile has moved on the battle map.
 * This gives UIs a change to animate missile movement.
 */
public class BattleDroidMineMoveEF implements MotEventFactory {

    private DroidMine droidMine;
    private Location from;
    private Location to;

    /**
     * The craft damage at the point this animations is taking place.
     * This will usually be different from the crafts damage at this point in time!!
     */
    private CraftStateFactory targetState;


    public BattleDroidMineMoveEF(DroidMine droidMine, Location from, Location to, CraftStateFactory targetState) {
        this.droidMine = droidMine;
        this.from = from;
        this.to = to;
        this.targetState = targetState;
        if (Logger.isDebug()) {
        	Logger.logDebug("BattleDroidMineMoveEF() "+droidMine+" "+from+"->"+to);
        }
    }

    public MotEvent createEvent(Player owner) throws ApplicationError {
        // The locations are copies incase the craft is moved after this animation is created
    	CraftState ts = (targetState != null) ? targetState.getCraftState(owner) : null;
        return new BattleDroidMineMoveEvent(droidMine.getBattle().getName(), droidMine.getName(), new Location(from), new Location(to), droidMine.getCraftStateForGenericPlayer(), ts);
    }


}