/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.event;

import mot.common.event.BattleEndEvent;
import mot.common.event.MotEvent;
import mot.common.util.Comp;
import mot.engine.battles.Battle;
import mot.engine.battles.BattleCraft;
import mot.engine.players.Player;

/**
 * Notifies player that a battle has completed. This will cause the next battle in the
 * queue to start (if one exists).
 * @see mot.proxy.eventNewBattleEvent for more details.
 */
public class BattleEndEF extends StatefulEventFactory {

    private Battle battle;
	private BattleCraft [] craftDestroyed;

    public BattleEndEF(Battle battle, BattleCraft[] craftDesrtoyed) {
        this.battle = battle;
		this.craftDestroyed = craftDesrtoyed;
	}

    public MotEvent createEvent(Player owner) {
    	BattleEndEvent r = new BattleEndEvent(battle.getName(), Comp.toStrings(craftDestroyed));
        r.setState(getState());
		return r;
    }

	public Battle getBattle() {
		return battle;
	}

	public BattleCraft [] getCraftDestroyed() {
		return craftDestroyed;
	}

	public String toString() {
		return "BattleEndEF: battle="+battle;
	}


}