/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.event;

import mot.common.bean.Location;
import mot.common.event.BattleFearEvent;
import mot.common.event.MotEvent;
import mot.engine.battles.BattleCraft;
import mot.engine.players.Player;

/**
 * Caused when a craft attempts fires a weapon in a battle but the target
 * craft has a higher psi ability and has caused the source craft to lose
 * their chance to fire (weapons discharged).
 */
public class BattleFearEF implements MotEventFactory {

    private BattleCraft source;
    private BattleCraft target;
	private Location location;

    public BattleFearEF(BattleCraft source, Location location, BattleCraft target) {
        this.source = source;
		this.location = location;
        this.target = target;
	}

    public MotEvent createEvent(Player owner) {
        return new BattleFearEvent(source.getBattle().getName(), source.getName(), new Location(location), target.getName());
    }
}