/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.event;

import mot.common.event.BattleMissileLaunchEvent;
import mot.common.event.MotEvent;
import mot.common.util.ApplicationError;
import mot.engine.adapter.MissilesVOAdapter;
import mot.engine.battles.Missiles;
import mot.engine.players.Player;

/**
 * Caused when a craft fires a missile in a battle.
 * The battle craft source has fired on battle craft target using weapon weapon.
 * There should now be an automaton object in the battle being the missile.
 */
public class BattleMissileLaunchEF implements MotEventFactory {

    private Missiles missile;

    public BattleMissileLaunchEF(Missiles missile) {
        this.missile = missile;
	}

    public MotEvent createEvent(Player owner) throws ApplicationError {
    	BattleMissileLaunchEvent event = new BattleMissileLaunchEvent(missile.getBattle().getName(), new MissilesVOAdapter(missile, owner));
		return event;
    }
}