/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.event;

import mot.common.event.BattleNewTurnEvent;
import mot.common.event.MotEvent;
import mot.common.util.ApplicationError;
import mot.engine.adapter.BattleCraftVOAdapter;
import mot.engine.adapter.BattlePlanetVOAdapter;
import mot.engine.adapter.BattleStateVOAdapter;
import mot.engine.battles.Battle;
import mot.engine.battles.BattleCraft;
import mot.engine.battles.BattlePlanet;
import mot.engine.players.Player;

/**
 * Notifies player that a new turn is about to start in the battle.
 * This is not really a significant event, but I am generating a notification
 * in case any user interface would like to do a particular action.
 */
public class BattleNewTurnEF implements MotEventFactory {

    private Battle battle;

    public BattleNewTurnEF(Battle battle) {
        this.battle = battle;
	}

    public MotEvent createEvent(Player owner) throws ApplicationError {
        BattleNewTurnEvent e = new BattleNewTurnEvent( battle.getName() );
        e.addStateUpdate(new BattleStateVOAdapter(battle));
        BattleCraft[] bca = battle.getCrafts();
        if (bca != null) {
        	for (int i = 0; i < bca.length; i++) {
        		e.addStateUpdate(new BattleCraftVOAdapter(bca[i], owner));
			}
        }
        BattlePlanet bp = battle.getPlanet();
        if (bp != null) {
        	e.addStateUpdate(new BattlePlanetVOAdapter(bp, owner));
        }
		return e;
    }

}