/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.event;

import mot.common.bean.CraftState;
import mot.common.event.BattleObjectNotificationEvent;
import mot.common.event.BattleObjectNotificationType;
import mot.common.event.MotEvent;
import mot.common.util.ApplicationError;
import mot.engine.battles.BattleObject;
import mot.engine.battles.CraftStateFactory;
import mot.engine.players.Player;

/**
 * This is a generic message to be animated on the battle field for
 * BattleObject. It should appear as text moving above the object.
 */
public class BattleObjectNotificationEF implements MotEventFactory {

    private BattleObject target;

    /**
     * Generic message intended for display above the target
     */
    private String message;

    /**
     * The name of an icon that should be used with this notification.
     * This icon may also connect to a sound.
     */
    private BattleObjectNotificationType type;
    
    /**
     * The target craft state before this animations is taking place.
     */
    private CraftStateFactory oldTargetState;

    /**
     * The target craft state while this animations is taking place.
     */
    private CraftStateFactory newTargetState;


    public BattleObjectNotificationEF(BattleObject target, String message, BattleObjectNotificationType type, CraftStateFactory oldTargetState, CraftStateFactory newTargetState) {
        this.target = target;
        this.message = message;
		this.type = type;
        this.oldTargetState = oldTargetState;
        this.newTargetState = newTargetState;
	}

    public MotEvent createEvent(Player owner) throws ApplicationError {
    	CraftState os = (oldTargetState != null) ? oldTargetState.getCraftState(owner) : null;
    	CraftState ns = (newTargetState != null) ? newTargetState.getCraftState(owner) : null;
    	BattleObjectNotificationEvent event = new BattleObjectNotificationEvent(
        								    target.getBattle().getName(),
                                            target.getName(),
                                            message,
                                            type,
                                            os,
                                            ns);
        return event;
    }


}