/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.event;

import mot.common.bean.CraftState;
import mot.common.event.BattleObjectTriggerEvent;
import mot.common.event.MotEvent;
import mot.common.util.ApplicationError;
import mot.engine.battles.BattleObject;
import mot.engine.battles.CraftStateFactory;
import mot.engine.players.Player;

/**
 * Caused when a trigger executes that has an effect on a craft.
 */
public class BattleObjectTriggerEF extends LinkedEventFactoryBase {

	/**
	 * The object this trigger effects
	 */
    private BattleObject battleObject;
    
    /**
     * This is the group name of the weapon that generated this bot.
     * @see mot.common.technology.Weapon for details
     */
    private String type;
    
    /**
     * The state before this event
     */
    private CraftStateFactory originalState;

    /**
     * The state after this event
     */
    private CraftStateFactory newState;

    /**
     * Some weapon fire animations have special messages for the user.
     */
    private String description;

    
    
    public BattleObjectTriggerEF(BattleObject battleObject, String type, CraftStateFactory originalState, CraftStateFactory newState, String description) {
		this.battleObject = battleObject;
		this.type = type;
		this.originalState = originalState;
		this.newState = newState;
		this.description = description;
	}



    public MotEvent createEvent(Player owner) throws ApplicationError {
    	CraftState os = (originalState != null) ? originalState.getCraftState(owner) : null;
    	CraftState ns = (newState != null) ? newState.getCraftState(owner) : null;
    	BattleObjectTriggerEvent event = new BattleObjectTriggerEvent(
    			battleObject.getBattle().getName(),
    			battleObject.getName(),
    			type,
    			os,
    			ns,
    			description);
        return event;
    }

	public void setNewState(CraftStateFactory newState) {
		this.newState = newState;
	}

	public void setDescription(String description) {
		this.description = description;
	}



}