/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.event;

import mot.common.bean.Location;
import mot.common.event.BattleWeaponMissEvent;
import mot.common.event.MotEvent;
import mot.common.technology.Weapon;
import mot.common.util.ApplicationError;
import mot.engine.battles.BattleObject;
import mot.engine.common.ServerImageObject;
import mot.engine.players.Player;

/**
 * Caused when a craft attempts fires a weapon in a battle at a target
 * craft but it missed entirely. This is usually because the craft is cloaked.
 */
public class BattleWeaponMissEF implements MotEventFactory {

    private ServerImageObject source;
    private BattleObject target;
    private Weapon weapon;
	private Location sourceLocation;
	private Location targetLocation;
	private int sourceDirection;

    public BattleWeaponMissEF(ServerImageObject source, BattleObject target, Weapon weapon, Location sourceLocation, int sourceDirection, Location targetLocation) {
        this.source = source;
        this.target = target;
        this.weapon = weapon;
		this.sourceLocation = sourceLocation;
		this.sourceDirection = sourceDirection;
		this.targetLocation = targetLocation;
	}

    public MotEvent createEvent(Player owner) throws ApplicationError {
        return new BattleWeaponMissEvent(target.getBattle().getName(), source.getName(), target.getName(), weapon.getName(), new Location(sourceLocation), sourceDirection, new Location(targetLocation));
    }
}