/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.event;

import mot.common.event.BattleWeaponStateUpdateEvent;
import mot.common.event.MotEvent;
import mot.common.vo.BattleObjectWeaponStateVO;
import mot.engine.adapter.BattleObjectWeaponStateVOAdapter;
import mot.engine.battles.Battle;
import mot.engine.battles.BattleObject;
import mot.engine.players.Player;

/**
 * When the weapon status of a battle object changes, this event is sent to the clients to
 * update the delegates. It contains information about what weapon are ready to fire or have 
 * already been fired.
 */
public class BattleWeaponStateUpdateEF implements MotEventFactory {

    private Battle battle;
	private BattleObject object;

    public BattleWeaponStateUpdateEF(Battle battle, BattleObject object) {
        this.battle = battle;
		this.object = object;
	}

    public MotEvent createEvent(Player owner) {
    	BattleObjectWeaponStateVO vo = new BattleObjectWeaponStateVOAdapter(object);
        return new BattleWeaponStateUpdateEvent( battle.getName(), object.getName(), vo );
    }

}