/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.event;

import mot.common.bean.DiplomaticProposal;
import mot.common.event.DiplomaticRequestEvent;
import mot.common.event.MotEvent;
import mot.engine.players.Player;

/**
 * Caused when a player requests to swap assets (exchange technology, money and or a planet).
 * This is sent to a single player who is the player that is receiving the request to swap
 * assets. This event contains the details of the player requesting the swap as well as the
 * assets this player is offering and wants in exchange. 
 */
public class DiplomaticRequestEF extends DiplomaticEF implements MotEventFactory {

    private DiplomaticProposal proposal;

    /**
     * @param wantedAssets The assets that the player who made this swap request is offering
     * @param offeredAssets The assets that the player who made this swap request is wants in exchange
     * @param player The player who request the swap.
     */
    public DiplomaticRequestEF(Player player, DiplomaticProposal proposal) {
		super(player, null);
        this.proposal= proposal;
    }

    public MotEvent createEvent(Player owner) {
    	DiplomaticRequestEvent r = new DiplomaticRequestEvent(getPlayer().getName(), proposal, getMessage());
        r.setState(getState());
		return r;
    }

	public DiplomaticProposal getProposal() {
		return proposal;
	}

	public void setProposal(DiplomaticProposal proposal) {
		this.proposal = proposal;
	}
}