/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.event;

import mot.common.bean.DiplomaticProposal;
import mot.common.event.DiplomaticResponseEvent;
import mot.common.event.MotEvent;
import mot.engine.players.Player;

/**
 * Caused when a player requests to swap assets (exchange technology, money and or a planet).
 * This is sent to a single player who is the player that that made the request to swap
 * assets. This event contains the details of the player responding to the swap as well as the
 * assets this player is offering and wants in exchange AND the response - a true indicated 
 * the offer is accepted. 
 */
public class DiplomaticResponseEF extends DiplomaticEF implements MotEventFactory {

    private DiplomaticProposal proposal;
    private boolean accept;

    /**
     * @param accept True if the sending player accepts the request and false otherwise
     * @param wantedAssets The assets that the player who made this swap request is offering
     * @param offeredAssets The assets that the player who made this swap request is wants in exchange
     * @param player The player who received the swap request and is sending this response.
     */
    public DiplomaticResponseEF(Player player, DiplomaticProposal proposal, boolean accept, String response) {
		super(player, response);
        this.proposal= proposal;
        this.accept = accept;
    }

    public MotEvent createEvent(Player owner) {
    	DiplomaticResponseEvent e = new DiplomaticResponseEvent(getPlayer().getName(), proposal, accept, getMessage());
        e.setState(getState());
		return e;
    }

	public DiplomaticProposal getProposal() {
		return proposal;
	}

	public void setProposal(DiplomaticProposal proposal) {
		this.proposal = proposal;
	}

  }