/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.event;

import mot.common.event.EndTurnEvent;
import mot.common.event.MotEvent;
import mot.engine.players.Player;
import mot.engine.players.UserPlayer;

/**
 * Sent after each user player has called endTurn() causing the current game turn the end.
 * All computer players, crafts and planets have moved before this event is sent.
 * A new turn starts after all battles have completed and will be announced by a NewTurnEvent.
 * 
 * @see mot.engine.event.StartTurnEF
 */
public class EndTurnEF extends StatefulEventFactory {

    private UserPlayer player;

	public EndTurnEF(UserPlayer player) {
		this.player = player;
	}

    public MotEvent createEvent(Player owner) {
    	EndTurnEvent r = new EndTurnEvent();
        r.setState(getState());
		return r;
    }

	public UserPlayer getPlayer() {
		return player;
	}

}