/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.event;
import mot.common.event.MotEvent;
import mot.common.util.ApplicationError;
import mot.engine.players.Player;

/**
 * This is not an actual event - it is a wrapper for another event. It is used as a 
 * place holder for an actual event.
 * 
 * This is useful for scheduling an event before it has been created. Schedule an 
 * a container event for dispatch, perform some processing (that may cause other events 
 * that must be after our scheduled events) then set the actual event in this container
 * and dispatch it.
 * 
 * This event factory generated the correct event for its container.
 */
public class EventContainerEF extends StatefulEventFactory {

    /**
     * The event that this container holds.
     */
    private MotEventFactory event;
    
    /**
     * A player this event has been scheduled to be sent to (optional)
     */
    private Player target;

    public EventContainerEF() {	
    }
    
    public EventContainerEF(MotEventFactory event) {
    	this.event = event;
    }
    
    public MotEvent createEvent(Player owner) throws ApplicationError {
        if (event == null) {
            return null;
        } else {
            return event.createEvent(owner);
        }
    }

    public void setEvent(MotEventFactory event) {
        this.event = event;
    }


    public MotEventFactory getEvent() {
        return event;
    }

	public Player getTarget() {
		return target;
	}

	public void setTarget(Player target) {
		this.target = target;
	}

}