/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.event;

import mot.common.bean.NamedObject;
import mot.common.event.FundsGoneEvent;
import mot.common.event.MotEvent;
import mot.engine.planets.Planet;
import mot.engine.players.Player;

/**
 * If a player has no money to pay for the upkeep of his/her/its fleet then
 * one of the players items are sold and the money credited to the players
 * account. Then this event is sent to the player informing them of the situation.
 */
public class FundsGoneEF extends StatefulEventFactory {

    public NamedObject object;
    private Planet location;
    public int money;

    public FundsGoneEF(NamedObject object, Planet location, int money) {
        this.object = object;
		this.location = location;
        this.money = money;
	}

    public MotEvent createEvent(Player owner) {
        FundsGoneEvent e = new FundsGoneEvent(object.getName(), location == null ? null : location.getName(), money);
        e.setState(getState());
		return e;
    }


}