/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.event;

import java.util.ArrayList;

import mot.common.event.LinkedEventBase;
import mot.common.event.MotEvent;
import mot.common.util.ApplicationError;
import mot.common.util.Logger;
import mot.engine.players.Player;

/**
 * This is the base class for all events that may contain other linked events.
 */
public abstract class LinkedEventFactoryBase extends StatefulEventFactory implements MotLinkedEventFactory {

    private ArrayList linkedEvents;

    public void link(MotEventFactory event) {
        if (linkedEvents == null) linkedEvents = new ArrayList();
        linkedEvents.add(event);
    }

    public void link(MotEventFactory event, int index) {
        if (linkedEvents == null) linkedEvents = new ArrayList();
        if (linkedEvents.size() > index) {
        	linkedEvents.add(index, event);
        } else if (linkedEvents.size() == index) {
        	linkedEvents.add(event);
        } else {
        	Logger.logWarning("LinkedEventFactory.link() Invalid index "+index+" size "+linkedEvents.size());
        	linkedEvents.add(event);
        }
    }

    public MotEventFactory [] getLinkedEvents() {
        if (linkedEvents == null) return null;
        return (MotEventFactory []) linkedEvents.toArray(new MotEventFactory[linkedEvents.size()]);
    }

    public boolean containsLinkedEvent(MotEventFactory event) {
        if (linkedEvents == null) return false;
        MotEventFactory [] linked = getLinkedEvents();
        if (linked != null) {
            for (int i=0; i<linked.length; i++) {
                if (linked[i] == event) return true;
            }
        }
        return false;
    }

    protected void setLinkedEvents(LinkedEventBase event, Player owner) throws ApplicationError {
        MotEventFactory [] linked = getLinkedEvents();
        if (linked != null) {
            for (int i=0; i<linked.length; i++) {
                MotEvent linkedEvent = linked[i].createEvent(owner); 
                event.link(linkedEvent);
            }
        }
    }
    
    public int getQtyLinkedEvents() {
    	if (linkedEvents == null) {
    		return 0;
    	} else {
    		return linkedEvents.size();
    	}
    }

    /**
     * @return Returns true if this event would like have the event in the event factory linked
     * to its while this event is queued.
     * @param event The event that may be linked to this event
     */
    public boolean wantsToLink(MotEventFactory event) {
        return false;
    }


}