/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.event;

import mot.common.bean.MessageType;
import mot.common.event.MessageEvent;
import mot.common.event.MotEvent;
import mot.engine.players.Player;

/**
 * This is an event caused when the engine wishes to send a message to a user
 * player.
 */
public class MessageEF extends StatefulEventFactory {

	/**
	 * Causes a message to be displayed to user players while computer players
     * ignore it.
	 */
 	protected String message;

	/**
	 * If true this message flashes when it is displayed. Otherwise it does not.
	 */
 	private MessageType messageType;

	/**
	 * If not null the sound that should play when this message is displayed
	 */
 	protected String sound;

    public MessageEF(String message) {
        this.message = message;
        messageType = MessageType.flashing;
    }

    public MessageEF(String message, MessageType messageType, String sound) {
        this.message = message;
        this.messageType = messageType;
        this.sound = sound;
    }

    public MotEvent createEvent(Player owner) {
    	MessageEvent vo = new MessageEvent(message, messageType, sound);
        vo.setState(getState());
        return vo;
    }


}