/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.event;

import mot.common.event.MotEvent;
import mot.common.util.ApplicationError;
import mot.engine.players.Player;

/**
 * Each type of event is generated from an event factory for that type of event.
 * For Example a FearEvent would be created from a FearEventEF. This event factory
 * generates the required type of fear events for each client's proxy.
 *
 * For details see MotEngine.broadcast(MotEventFactory ef);
 *
 * This is the base class for all event factories.
 */
public interface MotEventFactory {

    /**
     * Creates the event object to be sent to a client.
     * Some events requires a different object containing different information for each player.
     * e.g. PlanetColonisedEvent - Event sent to planet owner will contains more information than for other players.
     */
    public MotEvent createEvent(Player owner) throws ApplicationError;

}