/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.event;

import mot.common.event.MotEvent;
import mot.common.event.PlanetColonisedEvent;
import mot.common.util.ApplicationError;
import mot.engine.adapter.PlanetVOAdapter;
import mot.engine.planets.Planet;
import mot.engine.players.Player;

/**
 * Caused when a craft colonises a new planet.
 * Tells a GUI to open a planet window and a computer player to set a project etc.
 */
public class PlanetColonisedEF implements MotEventFactory {

	/**
	 * This is the planet that has just been colonised.
	 */
	private Planet planet;

    public PlanetColonisedEF(Planet planet) {
		this.planet = planet;
	}

    public MotEvent createEvent(Player owner) throws ApplicationError {
    	PlanetColonisedEvent r = new PlanetColonisedEvent(planet.getName());
        r.addStateUpdate(new PlanetVOAdapter(planet, owner));
		return r;
    }


}