/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.event;

import mot.common.event.MotEvent;
import mot.common.event.PlanetConqueredEvent;
import mot.engine.planets.Planet;
import mot.engine.players.Player;
import mot.engine.transports.Transport;

/**
 * Caused when a craft has invaded a planet during a battle and conquered.
 * This planet now belongs to the same player as the craft that conquered it
 * but it used to belong to oldOwner.
 */
public class PlanetConqueredEF extends StatefulEventFactory {

    private Transport source;
    private Planet target;
 	private Player oldOwner;

    public Player getOldOwner() { return oldOwner; }

    public PlanetConqueredEF(Transport source, Planet target, Player oldOwner) {
        this.source = source;
        this.target = target;
        this.oldOwner = oldOwner;
    }

    public MotEvent createEvent(Player owner) {
        PlanetConqueredEvent event = new PlanetConqueredEvent(source.getName(),
                                         target.getName(),
                                         oldOwner.getName());
        event.setState(getState());
		return event;
    }


}