/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.event;

import mot.common.event.MotEvent;
import mot.common.event.PlanetInvadeEvent;
import mot.common.util.ApplicationError;
import mot.engine.planets.Planet;
import mot.engine.players.Player;
import mot.engine.transports.Transport;

/**
 * Caused when a transport attempts to invade a planet.
 * This opens the troop battle window in the client.
 */
public class PlanetInvadeEF extends StatefulEventFactory {

    private Transport source;
    private Planet target;

    private int qtyAttackers;
    private int qtyDefenders;
    private double attackerAdvantage;
    private int remainingAttackers;
    private int remainingDefenders;

    public PlanetInvadeEF(Transport source, Planet target, int qtyAttackers, int qtyDefenders, double attackerAdvantage, int remainingAttackers, int remainingDefenders) {
        this.source = source;
        this.target = target;

        this.qtyAttackers = qtyAttackers;
        this.qtyDefenders = qtyDefenders;
        this.attackerAdvantage = attackerAdvantage;
        this.remainingAttackers = remainingAttackers;
        this.remainingDefenders = remainingDefenders;
    }

    public MotEvent createEvent(Player owner) throws ApplicationError {
        PlanetInvadeEvent event = new PlanetInvadeEvent((source == null || source.getOwner() == null) ? "Unknown" :  source.getOwner().getName(),
        							 (target == null || target.getOwner() == null) ? "Unknown" :  target.getOwner().getName(),
        							 (target == null) ? "Unknown" :  target.getName(),
                                     qtyAttackers,
                                     qtyDefenders,
                                     attackerAdvantage,
                                     remainingAttackers,
                                     remainingDefenders);
        event.setState(getState());
		return event;
    }

}