/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.event;

import mot.common.event.MotEvent;
import mot.common.event.PrizeGiftEvent;
import mot.engine.players.Player;

/**
 * This event is sent to a player when that player has released a prize. The description contains
 * details of the prize to display to the user. For details on prizes see the class Prize.
 */
public class PrizeGiftEF extends StatefulEventFactory {

    private String description;
	private String imageConfigName;
	private String techFullName;
	private boolean isPrize;

    public PrizeGiftEF(boolean isPrize, String imageConfigName, String techFullName, String description) {
		this.isPrize = isPrize;
		this.imageConfigName = imageConfigName;
		this.techFullName = techFullName;
        this.description = description;
	}

    public MotEvent createEvent(Player owner) {
        PrizeGiftEvent event = new PrizeGiftEvent(isPrize, imageConfigName, techFullName, description);
        event.setState(getState());
        return event;
    }

}