/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.event;

import mot.common.bean.NameList;
import mot.common.event.MotEvent;
import mot.common.event.RoutedEvent;
import mot.engine.common.Orbit;
import mot.engine.players.Player;

/**
 * Caused when a player refuses to fight a battle. When a player refuses to fight a
 * battle (by retreating all craft or closing the battle window) then all crafts at
 * that stellar object are destroyed owned by this player.
 */
public class RoutedEF implements MotEventFactory {

    private Player player;
    private Orbit orbit;
	private NameList craftDestroyed;

    public RoutedEF(Player player, Orbit orbit, NameList craftDestroyed) {
        this.player = player;
        this.orbit = orbit;
		this.craftDestroyed = craftDestroyed;
	}

    public RoutedEF(Player player, Orbit orbit) {
        this.player = player;
        this.orbit = orbit;
		this.craftDestroyed = new NameList();
	}

	public void addCraftName(String craftName) {
		craftDestroyed.add(craftName);
	}

    public MotEvent createEvent(Player owner) {
        return new RoutedEvent(player.getName(), orbit.getShortDescription(), craftDestroyed.getNamesAsArray());
    }


}