/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.event;

import mot.common.event.MotEvent;
import mot.common.event.SabotageEvent;
import mot.engine.planets.Planet;
import mot.engine.players.Player;

/**
 * Caused when a player sabotages another players planet.
 */
public class SabotageEF implements MotEventFactory {

	/**
	 * This is the planet that has just been sabotaged.
	 */
	private Planet planet;

    private int qtyProductionSabotaged;
    private int qtyFactoriesSabotaged;
    private int qtyPopulationSabotaged;

    /**
     * The player who performed the sabotage
     */
    private Player player;

    public SabotageEF(Planet planet, Player player) {
		this.planet = planet;
        this.player = player;
	}

    /**
     * Creates a version of this event for local clients.
     * Local clients are those in the same JVM so no RPC is required.
     */
    public MotEvent createEvent(Player owner) {
        return new SabotageEvent(planet.getName(), player.getName(), qtyFactoriesSabotaged, qtyPopulationSabotaged, qtyProductionSabotaged);
    }

    public void setQtyProductionSabotaged(int qtyProductionSabotaged) {
        this.qtyProductionSabotaged = qtyProductionSabotaged;
    }


    public int getQtyProductionSabotaged() {
        return qtyProductionSabotaged;
    }


    public void setQtyFactoriesSabotaged(int qtyFactoriesSabotaged) {
        this.qtyFactoriesSabotaged = qtyFactoriesSabotaged;
    }


    public int getQtyFactoriesSabotaged() {
        return qtyFactoriesSabotaged;
    }


    public void setQtyPopulationSabotaged(int qtyPopulationSabotaged) {
        this.qtyPopulationSabotaged = qtyPopulationSabotaged;
    }


    public int getQtyPopulationSabotaged() {
        return qtyPopulationSabotaged;
    }

}