/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.event;

import java.util.ArrayList;

import mot.common.event.StateContainer;
import mot.common.event.StateUpdateContainerEvent;
import mot.common.util.ApplicationError;
import mot.common.util.Comp;
import mot.common.vo.NamedValueObject;
import mot.common.vo.ValueObject;
import mot.common.vo.ValueObjectList;


/**
 * 
 */
public abstract class StatefulEventFactory implements MotEventFactory, StateContainer {

	private ArrayList<ValueObject> state;
	
	public void addStateUpdate(ValueObjectList vol) {
		if (vol == null) return;
		ValueObject[] l = vol.getStateUpdates();
		for (int i = 0; i < l.length; i++) {
			addStateUpdate(l[i]);
		}
	}
	
	public void addStateUpdate(ValueObject v) {
		if (state == null) state = new ArrayList<ValueObject>();
		state.add(v);
	}
	
	public void addStateUpdate(ValueObject [] vol) {
		if (vol == null) return;
		for (int i = 0; i < vol.length; i++) {
			addStateUpdate(vol[i]);
		}
		
	}
	
	public ValueObject [] getStateUpdates() {
		if (state == null) return null;
		return state.toArray(new ValueObject[state.size()]);
	}
	
	public ValueObject getState(String name) {
		if (state == null) return null;
		for (ValueObject vo : state) {
			if (vo instanceof NamedValueObject && Comp.same(((NamedValueObject)vo).getName(), name)) {
				return vo;
			}
		}
		return null;
	}
	
	public ValueObject getType(Class clazz) {
		if (state == null) return null;
		for (ValueObject vo : state) {
			if (vo.getClass() == clazz) {
				return vo;
			}
		}
		return null;
	}

	
	public void addStateUpdates(StateUpdateContainerEvent event) throws ApplicationError {
		if (state == null) return;
		for (ValueObject s : state) {
			event.addStateUpdate(s);
		}
	}

	public ArrayList<ValueObject> getState() {
		return state;
	}

	public void setState(ArrayList<ValueObject> state) {
		this.state = state;
	}
	
	
}