/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.event;

import mot.common.event.MotEvent;
import mot.common.event.TechnologyDiscoveredEvent;
import mot.common.technology.Technology;
import mot.engine.players.Player;

/**
 * Caused when a player has discovered a new piece of technology.
 * Note - It will be followed by a NoResearchProjectEvent.
 */
public class TechnologyDiscoveredEF extends StatefulEventFactory {

	/**
	 * This is the technology that has just been discovered.
	 */
	private Technology technology;
	
	/**
	 * True if this tech was discovered from salvage after a battle
	 * False if this tech was discovered by research effort in the game
	 */
	private boolean fromSalvage;

    public TechnologyDiscoveredEF(Technology technology, boolean fromSalvage) {
		this.technology = technology;
		this.fromSalvage = fromSalvage;
	}

    public MotEvent createEvent(Player owner) {
    	TechnologyDiscoveredEvent vo = new TechnologyDiscoveredEvent(technology.getFullName(), fromSalvage);
        vo.setState(getState());
		return vo;
    }


	public void setFromSalvage(boolean fromSalvage) {
		this.fromSalvage = fromSalvage;
	}

	public boolean isFromSalvage() {
		return fromSalvage;
	}


}