/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.event;

import mot.common.event.MotEvent;
import mot.common.event.TechnologyStolenEvent;
import mot.common.technology.Technology;
import mot.engine.players.Player;

/**
 * Caused when a player has stolen a technology from another player.
 * This event is sent to both players.
 */
public class TechnologyStolenEF extends StatefulEventFactory implements MotEventFactory {

	/**
	 * This is the technology that has just been discovered.
	 */
	private Technology technology;

    private Player giver;
    private Player receiver;

    public TechnologyStolenEF(Technology technology, Player receiver, Player giver) {
		this.technology = technology;
        this.receiver = receiver;
        this.giver = giver;
	}

     public MotEvent createEvent(Player owner) {
        TechnologyStolenEvent vo = new TechnologyStolenEvent(technology.getFullName(), receiver.getName(), giver.getName());
        vo.setState(getState());
        return vo;
    }


 }