/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.event;

import mot.common.event.MotEvent;
import mot.common.event.TradeRouteInvalidEvent;
import mot.common.util.ApplicationError;
import mot.engine.players.Player;

/**
 * Sent at the end of a turn when a trade route is found to be invalid (usually sector between the
 * planets of a trade route is controlled by another player)
 */
public class TradeRouteInvalidEF implements MotEventFactory {

	private String solarSystem1;
	private String solarSystem2;

	public TradeRouteInvalidEF(String solarSystem1, String solarSystem2) {
		this.solarSystem1 = solarSystem1;
		this.solarSystem2 = solarSystem2;
	}

	@Override
	public MotEvent createEvent(Player owner) throws ApplicationError {
		TradeRouteInvalidEvent r = new TradeRouteInvalidEvent(solarSystem1, solarSystem2);
		return r;
	}

	public String getSolarSystem1() {
		return solarSystem1;
	}

	public void setSolarSystem1(String solarSystem1) {
		this.solarSystem1 = solarSystem1;
	}

	public String getSolarSystem2() {
		return solarSystem2;
	}

	public void setSolarSystem2(String solarSystem2) {
		this.solarSystem2 = solarSystem2;
	}

}
