/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.leaders;

import mot.common.leaders.GeneralDetails;
import mot.common.leaders.GeneralLeader;
import mot.common.util.ApplicationError;
import mot.engine.MotEngine;
import mot.engine.event.LeaderGainLevelEF;
import mot.engine.players.Player;

/**
 * @see mot.common.leaders.GeneralLeader for details of Leaders.
 * This is a extension to a general that provides functionality specific to the engine. 
 */
public class EngineGeneralLeader extends GeneralLeader  {
    public EngineGeneralLeader() {
    }

    public EngineGeneralLeader(GeneralDetails details) {
        super(details);
    }

    private static final int EXPERIENCE_WHEN_WIN_BATTLE = 50;
    private static final int EXPERIENCE_WHEN_LOSE_BATTLE = 100;
    
    /**
     * Called to notify this general that its owner has finished a battle.
     * This must be called so that the Leaders experience can be updated.
     * @param winner True if the owner won he battle and false otherwise
     */
    public void notifyBattleEnded(boolean winner, Player owner) throws ApplicationError {
        if (winner) {
            addExperience(EXPERIENCE_WHEN_WIN_BATTLE, owner);
        } else {
            addExperience(EXPERIENCE_WHEN_LOSE_BATTLE, owner);
        }
    }
    

    public void addExperience(int qty, Player owner) throws ApplicationError {
        int oldLevel = getLevel();
        addExperience(qty);
        int newLevel = getLevel();
        if (newLevel > oldLevel) {
     		MotEngine.instance.broadcast( new LeaderGainLevelEF(this), owner );
        }
    }
}