/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.leaders;

import mot.common.leaders.GovenorDetails;
import mot.common.leaders.GovenorLeader;
import mot.common.util.ApplicationError;
import mot.engine.MotEngine;
import mot.engine.event.LeaderGainLevelEF;
import mot.engine.players.Player;
import mot.engine.relations.Relations;

/**
 * @see mot.common.leaders.GovenorLeader for details of Leaders.
 * This is a extension to a general that provides functionality specific to the engine. 
 */
public class EngineGovenorLeader extends GovenorLeader  {
    public EngineGovenorLeader() {
    }

    public EngineGovenorLeader(GovenorDetails details) {
        super(details);
    }

    private static final int EXPERIENCE_WHEN_END_TURN = 1;
    private static final int EXPERIENCE_PER_TRADE_ROUTE = 3;
    private static final int EXPERIENCE_WHEN_COLONISE_PLANET = 50;

    /**
     * Called to notify this govenor that a turn has ended.
     * This must be called so that the Leaders experience can be updated.
     * @param winner True if the owner won he battle and false otherwise
     */
    public void notifyEndTurn(Player owner) throws ApplicationError {
        addExperience(EXPERIENCE_WHEN_END_TURN, owner);
        Relations rels = MotEngine.instance.getRelationsNotNull();
        int qtyTraders = rels.getQtyTradersWith(owner);
        if (qtyTraders > 0) {
            addExperience(qtyTraders*EXPERIENCE_PER_TRADE_ROUTE, owner);
        }
    }
    
    /**
     * Called to notify this govenor that a its owner has colonised a planet.
     * This must be called so that the Leaders experience can be updated.
     * @param winner True if the owner won he battle and false otherwise
     */
    public void notifyColonisePlanet(Player owner) throws ApplicationError {
        addExperience(EXPERIENCE_WHEN_COLONISE_PLANET, owner);
    }
    

    public void addExperience(int qty, Player owner) throws ApplicationError {
        int oldLevel = getLevel();
        addExperience(qty);
        int newLevel = getLevel();
        if (newLevel > oldLevel) {
     		MotEngine.instance.broadcast( new LeaderGainLevelEF(this), owner );
        }
    }
}