/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.planets;

import mot.common.bean.Location;
import mot.common.util.ApplicationError;
import mot.common.util.NameGenerator;
import mot.engine.MotEngine;

public class BlackHoleFactory {
	
	/**
	 * Create a new black hole on a random edge of the galaxy map heading in a random direction
	 * that represents a direction directly towards the opposite side of the galaxy +/- 90
	 * degrees. It has already been added to the list of stellar objects.
	 * @return A new Black Hole
	 * @throws ApplicationError 
	 */
	public static BlackHole createBlackHole(Location loc) throws ApplicationError {
		MotEngine engine = MotEngine.getInstance();
		NameGenerator ng = engine.getNameGenerator();
		String name = ng.getNextName("Black Hole");
		BlackHole r = new BlackHole(name, loc.getX(), loc.getY(), 0.1f, false);
		engine.getStellarObjects().add(r);
		return r;
	}

	public static BlackHole createWormHole(Location loc) throws ApplicationError {
		MotEngine engine = MotEngine.getInstance();
		NameGenerator ng = engine.getNameGenerator();
		String name = ng.getNextName("Worm Hole");
		BlackHole r = new BlackHole(name, loc.getX(), loc.getY(), 0.0f, true);
		engine.getStellarObjects().add(r);
		return r;
	}

}
