/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.planets;

/**
 * This is a singleton object that represents a blockade on a planet.
 * @see Planet.blockade for details.
 */
public interface Blockade  {
    public boolean isBlockaded();
}

class BlockadeFactory {
    public static Blockade create(boolean isBlockaded) {
        if (isBlockaded) {
            return BlockadeOn.getInstance();
        } else {
            return BlockadeOff.getInstance();
        }
    }
}

class BlockadeOn implements Blockade {

    private static final Blockade instance = new BlockadeOn();
    
    public static Blockade getInstance() { return instance; }

    private BlockadeOn() {
    }

    public boolean isBlockaded() { return true; }
}

class BlockadeOff implements Blockade {

    private static final Blockade instance = new BlockadeOff();
    
    public static Blockade getInstance() { return instance; }

    private BlockadeOff() {
    }

    public boolean isBlockaded() { return false; }
}