/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.planets;

import mot.common.util.ApplicationError;
import mot.common.xml.XMLBean;
import mot.common.xml.XMLWriter;

/**
 * 
 * This is the base for a crisis on a planet.
 * 
 * @author Paul Davis
 *
 */
public abstract class Crisis extends XMLBean {
	
	private int dateStarted;
	
	public Crisis() {
	}

	public Crisis(int dateStarted) {
		this.dateStarted = dateStarted;
	}
	
	/**
	 * @return The name of this Crisis. Its unique and suitable for display to the user.
	 */
	public abstract String getName();
	
	/**
	 * @return The description of this Crisis suitable for display to the user.
	 */
	public abstract String getDescription();

	/**
	 * @return TRUE iff this crisis has expired and should be removed.
	 */
	public abstract boolean hasExpired();

	/**
	 * @return A value between 0.0 and 1.0 representing the chance of a successful espionage 
	 * attempt on this planet per turn during the crisis. A value of 0.0 implies no chance, and
	 * a value of 1.0 implies certainty.
	 * A value of NULL implies not used
	 */
	public Double espionageEffect() {
		return null;
	}

	/**
	 * @return A value between 0.0 and 1.0 representing the change in population on this planet per 
	 * turn during the crisis. A value of 0.0 implies remove no population a value of 1.0 implies 
	 * remove all population.
	 * A value of NULL implies not used
	 */
	public Double populationEffect() {
		return null;
	}

	/**
	 * @return A value bonus percentage to modify production on this planet.
	 * A value of NULL implies not used
	 * A value of 1.0 implies 100% increase
	 */
	public Double productionEffect() {
		return null;
	}

	public void endTurn() {
	}

	@Override
	protected void encode(XMLWriter writer) throws ApplicationError {
        writer.addElement("date-started", dateStarted);
	}

	public int getDateStarted() {
		return dateStarted;
	}

	public void setDateStarted(int dateStarted) {
		this.dateStarted = dateStarted;
	}


}
