/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.planets;

import mot.engine.MotEngine;

/**
 * Caused by a non fatal attack on a planet (when a planet is attacked it motivates its people
 * to work harder to defend themselves). This crisis doubles production on the planet.
 * 
 * @author Paul Davis
 *
 */
public class CrisisEmergency extends Crisis {

	public CrisisEmergency() {
	}

	public CrisisEmergency(int dateStarted) {
		super(dateStarted);
	}

	private static final int DURATION = 10;

	@Override
	public String getName() {
		return "Emergency";
	}

	@Override
	public String getDescription() {
		return "Planetary Emergency causing production to double";
	}
	
	@Override
	protected String getElementName() {
		return "crisis-emergency";
	}

	@Override
	public boolean hasExpired() {
		int dateStarted = getDateStarted();
	    return MotEngine.instance.getDate() > dateStarted + DURATION;
	}

	@Override
	public Double productionEffect() {
		return 1.0;
	}

}
