/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.planets;

import mot.engine.MotEngine;

/**
 * Caused by the plague weapon when deployed on a planet. Population on the 
 * planet die to a set number of turns.
 * 
 * @author Paul Davis
 *
 */
public class CrisisPlague extends Crisis {

	public CrisisPlague() {
	}

	public CrisisPlague(int dateStarted) {
		super(dateStarted);
	}

	private static final int DURATION = 10;

	@Override
	public String getName() {
		return "Plague";
	}

	@Override
	public String getDescription() {
		return "Planetary Plague killing 5% of the population per turn";
	}
	
	@Override
	protected String getElementName() {
		return "crisis-plague";
	}

	@Override
	public boolean hasExpired() {
		int dateStarted = getDateStarted();
	    return MotEngine.instance.getDate() > dateStarted + DURATION;
	}

	@Override
	public Double populationEffect() {
		return 0.05;
	}

}
