/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.planets;

import mot.engine.MotEngine;

/**
 * Caused by the psi weapon when deployed on a planet. Population morale drops
 * causing easy access for spies (makes sabotage and espionage more successful 
 * for a set number of turns).
 * 
 * @author Paul Davis
 *
 */
public class CrisisPsi extends Crisis {

	public CrisisPsi() {
	}

	public CrisisPsi(int dateStarted) {
		super(dateStarted);
	}

	private static final int DURATION = 10;

	@Override
	public String getName() {
		return "Psi Assault";
	}

	@Override
	public String getDescription() {
		return "Planetary Psi Assault reducing the population's ability to defend against enemy spies";
	}
	
	@Override
	protected String getElementName() {
		return "crisis-psi";
	}

	@Override
	public boolean hasExpired() {
		int dateStarted = getDateStarted();
	    return MotEngine.instance.getDate() > dateStarted + DURATION;
	}

	@Override
	public Double espionageEffect() {
		return 0.15;
	}
	
}
