/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.planets;

import mot.common.util.ApplicationError;
import mot.engine.MotEngine;
import mot.engine.common.MoveableOwnedObject;
import mot.engine.common.StellarObject;
import mot.engine.players.Player;

/**
 * This is a stellar object (something visible on the galaxy map) that effects the 
 * movement of crafts in the galaxy.  
 */
public abstract class GalacticIncumbent extends StellarObject {

	private int width;
	private int height;

	public GalacticIncumbent() {
	}

	public GalacticIncumbent(String name, int x, int y, int width, int height) {
		super(name, x, y);
		this.width = width;
		this.height = height;
	}
    
//	public int getInfluence(Player p) throws ApplicationError {
//		return 0;
//	}

	public Player[] getOwners() throws ApplicationError {
		return null;
	}

	public boolean hasOwner() throws ApplicationError {
		return false;
	}

	public boolean isOwnedBy(Player player) throws ApplicationError {
		return false;
	}
	
	/**
	 * This method does the whatever this incumbent does when this object enters it.
	 * This will handle any notification the user interfaces require.
	 * @param moo The craft or fleet that has entered into this incumbent.
	 * @return True if entry into this incumbent has resulted in the objects destruction.
	 */
	public abstract boolean handleEntry(MoveableOwnedObject moo) throws ApplicationError;
	
	/**
	 * @param moo The craft or fleet that may be commanded to enter this incumbent.
	 * @return True if the owner of this moo can instruct them to pass through or enter this
	 * incumbent.
	 */
	public abstract boolean canCommandEntry(MoveableOwnedObject moo) throws ApplicationError;
	
	/**
	 * Removes this object from the game - No events are generated and users are not informed.
	 * It is simply removed from the list of stellar objects.
	 */
	public void destroy() {
		StellarObjects sos = MotEngine.getInstance().getStellarObjects();
		sos.remove(this);
	}

	public int getWidth() {
		return width;
	}

	public void setWidth(int width) {
		this.width = width;
	}

	public int getHeight() {
		return height;
	}

	public void setHeight(int height) {
		this.height = height;
	}
}