/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.planets;

import mot.common.bean.NamedObject;
import mot.common.bean.Nebula;
import mot.common.util.ApplicationError;
import mot.common.util.BasicNameValueList;
import mot.common.util.NameValuePair;
import mot.common.xml.XMLWriter;
import mot.engine.MotEngine;

/**
 * This is a reference to a solar system. It uses the name of the solar system to locate
 * the solar system in the list of solar systems in the game  and then caches it for 
 * future use. If it cannot find a solar system for the given name, it searches all 
 * the solar systems for old names of this given name.
 */
public class NebulaReference extends NamedObject {

	private transient Nebula nebula;

    /**
     * @return The solar system for this reference 
     */
	public Nebula getNebula() {
		if (nebula == null) {
			nebula = MotEngine.instance.getStellarObjects().getNebula(getName());
		}
		return nebula;
	}
    
	public NebulaReference() {
	}

	public NebulaReference(Nebula nebula) {
		super(nebula.getName());
		this.nebula = nebula;
	}

	protected void encode(XMLWriter writer) throws ApplicationError {
		// does not have a bean body
	}

    protected BasicNameValueList getAttributes(boolean generateClassAttribute, boolean generateSchemaAttribute) throws ApplicationError {
		if (getNebula() == null) {
			return null;
		}

		BasicNameValueList params = getAttributesNotNull(generateClassAttribute);
		params.add( new NameValuePair("name", nebula.getName()) );

		return params;
	}

	protected String getElementName() { return "nebula-reference"; }
    protected boolean beanHasBody() { return false; }
}