/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.planets;

import mot.common.designs.Orbital;
import mot.common.technology.Hull;
import mot.common.technology.Modules;
import mot.common.technology.Scanner;
import mot.common.util.ApplicationError;
import mot.engine.players.Player;

/**
 * This is an adapter class that converts an orbital to an influence generator.
 */
public class OrbitalInfluenceGeneratorAdapter extends Orbital implements InfluenceGenerator {

	private Planet planet; 

	public OrbitalInfluenceGeneratorAdapter(Planet planet, Hull hull, Scanner scanner, Modules modules) {
		super(hull, scanner, modules);
		this.planet = planet;
	}

	public OrbitalInfluenceGeneratorAdapter(Planet planet, Orbital orbital) throws ApplicationError {
		super(orbital.getHullTech(), orbital.getScannerTech(), orbital.getModuleTechs());
		this.planet = planet;
	}


	public Player getOwner() throws ApplicationError {
		return planet.getOwner();
	}

	public int getInfluence() {
		return super.getInfluence(planet.getResource());
	}
}
