/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.planets;

import mot.common.designs.AsteroidDesign;
import mot.common.designs.ProjectDesign;
import mot.common.technology.AsteroidFieldConstruction;
import mot.common.util.ApplicationError;
import mot.common.xml.XMLBean;
import mot.common.xml.XMLWriter;
import mot.engine.common.ProjectBuilder;

/**
 * This is a planetary project to build an asteroid belt around a planet.
 */
public class ProjectAsteroids extends XMLBean implements Project {

	private AsteroidDesign asteroidDesign;
	
    public ProjectAsteroids() {
    }

    public ProjectAsteroids(AsteroidDesign design) {
    	this.asteroidDesign = design;
    }

    public ProjectAsteroids(AsteroidFieldConstruction afc) {
    	this.asteroidDesign = new AsteroidDesign(afc);
    }

    public boolean canBuildProjectNow(ProjectBuilder builder) { return true; }

    /**
     * This method is called when the project has been completed to build the object.
     * @param builder The planet/thing which has built the object.
     */
    public void build(ProjectBuilder builder) throws ApplicationError {
        if (builder instanceof Planet) {
            Planet planet = (Planet) builder;
          	planet.setHasAsteroids(!planet.getHasAsteroids());
        }
    }
    
    public int getCostToBuildOnPlanet() throws ApplicationError {
        return asteroidDesign.getCostToBuildOnPlanet();
    }

    public String getName() {
        return asteroidDesign.getName();
    }

    protected String getElementName() {
        return "asteroid-project";
    }

    protected void encode(XMLWriter writer) throws ApplicationError {
        asteroidDesign.toXML(writer);
    }
    
	public String getProjectElementName() {
        return getElementName();
    }

	public ProjectDesign getProjectDesign() {
		return asteroidDesign;
	}

	public AsteroidDesign getAsteroidDesign() {
		return asteroidDesign;
	}

	public void setAsteroidDesign(AsteroidDesign design) {
		this.asteroidDesign = design;
	}
}