/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.planets;

import mot.common.designs.ProjectDesign;
import mot.common.designs.TransportDesign;
import mot.common.technology.TechnologyReference;
import mot.common.util.ApplicationError;
import mot.common.util.Logger;
import mot.common.xml.XMLBean;
import mot.common.xml.XMLWriter;
import mot.engine.common.ProjectBuilder;
import mot.engine.transports.Transport;

/**
 * This is a project to build a transport on a planet.
 * Transports may be used to move colonists between planets.
 */
public class ProjectTransport extends XMLBean implements Project {

	private TransportDesign design;
	
    public ProjectTransport() {
    	design = new TransportDesign();
    }

    public boolean canBuildProjectNow(ProjectBuilder builder) { return true; }

    /**
     * This method is called when the project has been completed to build the object.
     * @param builder The planet/thing which has built the object.
     */
    public void build(ProjectBuilder builder) throws ApplicationError {
        if (Logger.isInfo()) {
            Logger.logInfo("Transport.build() Build Transport "+getName()+" on planet "+builder.getName());
        }
        builder.getOwner().getTransportManagerNotNull().setTransport(new Transport(builder.getOwner()));
    }

	public ProjectDesign getProjectDesign() {
		return design;
	}
	
	public String getName() {
		return design.getName();
	}

	public int getCostToBuildOnPlanet() throws ApplicationError {
		return design.getCostToBuildOnPlanet();
	}

	protected String getElementName() { return "transport-project"; }
	
    protected void encode(XMLWriter writer) throws ApplicationError {
		//design.toXML(writer);
    }

	public TransportDesign getDesign() {
		return design;
	}

	public void setDesign(TransportDesign design) {
		this.design = design;
	}
    
	
	public void setTechnologyReference(TechnologyReference v) throws ApplicationError {
		if (design == null) {
			design = new TransportDesign();
		}
	}

}