/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.planets;

/**
 * A trade imbalance is created when one planet owned by a player with
 * lots of influence is close to another planet owned by a different player
 * with less influence. The player with high influence exerts influence over
 * the less influential player's population to create a trade imbalance.
 * 
 * When a trade imbalance is defined between two planets, the influencing
 * planet receives a percentage of the production of the influenced planet.
 * @see Planet for details of how production is tranfered between the two.
 */
public class TradeImbalance {

	/**
	 * This is the planet that is benefitting from the trade imbalance.
	 */
	private Planet master;

	/**
	 * This is the planet that is suffering from the trade imbalance.
	 */
	private Planet slave;
	
	/**
	 * A value between 0 and 1 representing the quantity of production
	 * that should be transfered from the slave to the master.
	 */
	private double percentage;

	public TradeImbalance(Planet master, Planet slave, double percentage) {
		this.master = master;
		this.slave = slave;
		this.percentage = percentage;
	}
	
	public void remove() {
		//master.getTradeImbalanceIn().remove(this);
		//slave.setTradeImbalanceOut(null);
	}

	public Planet getMaster() {
		return master;
	}

	public void setMaster(Planet master) {
		this.master = master;
	}

	public Planet getSlave() {
		return slave;
	}

	public void setSlave(Planet slave) {
		this.slave = slave;
	}

	public double getPercentage() {
		return percentage;
	}

	public void setPercentage(double percentage) {
		this.percentage = percentage;
	}

	public String toString() {
		return "Trade Imbalance "+slave+" -> "+master+" @ "+percentage;
	}	
	
	
}
