/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.planets;

import mot.common.util.PropertyManager;

public class TradeImbalanceFactory {

	/**
	 * This is the quantity of influence more then the other planet required on 
	 * a planet before it created a 10% trade imbalance.
	 */
	private static int TRADE_IMBALANCE_10;

	/**
	 * This is the quantity of influence more then the other planet required on 
	 * a planet before it created a 20% trade imbalance.
	 */
	private static int TRADE_IMBALANCE_20;

	/**
	 * This is the quantity of influence more then the other planet required on 
	 * a planet before it created a 30% trade imbalance.
	 */
	private static int TRADE_IMBALANCE_30;

	static {
		try {
			TRADE_IMBALANCE_10 = PropertyManager.getMandatoryAsInt("influence.create_trade_imbalance.10");
			TRADE_IMBALANCE_20 = PropertyManager.getMandatoryAsInt("influence.create_trade_imbalance.20");
			TRADE_IMBALANCE_30 = PropertyManager.getMandatoryAsInt("influence.create_trade_imbalance.30");
		} catch (Exception e) {
			TRADE_IMBALANCE_10 = 100;
			TRADE_IMBALANCE_20 = 200;
			TRADE_IMBALANCE_30 = 400;
		}
	}
	
	public static void create(Planet master, int influenceMaster, Planet slave, int influenceSlave) {
		TradeImbalance ti = _create(master, influenceMaster, slave, influenceSlave);
		if (ti != null) {
// TRADE IMBALANCE IS NOT USED ANY MORE!
			//TradeImbalanceList til = master.getTradeImbalanceInNotNull();
			//til.add(ti);
			//slave.setTradeImbalanceOut(ti);
		}
	}
	
	public static TradeImbalance _create(Planet master, int influenceMaster, Planet slave, int influenceSlave) {
		int dif = influenceMaster-influenceSlave;
		if (dif > TRADE_IMBALANCE_30) {
			return new TradeImbalance(master, slave, 0.3);
		} else if (dif > TRADE_IMBALANCE_20) {
			return new TradeImbalance(master, slave, 0.2);
		} else if (dif > TRADE_IMBALANCE_10) {
			return new TradeImbalance(master, slave, 0.1);
		}
		return null;
	}
}
