/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.planets;

import java.util.ArrayList;

/**
 * A List of TradeImbalance objects
 */
public class TradeImbalanceList {

	private ArrayList list;
	private transient TradeImbalance [] cache;
	
	private void flush() {
		cache = null;
	}
	
	public void add(TradeImbalance v) {
		if (list == null) list = new ArrayList();
		list.add(v);
		flush();
	}
	
	public void remove(TradeImbalance ti) {
		if (list != null) list.remove(ti);
		flush();
	}
	
	public TradeImbalance [] getAll() {
		if (list == null || list.size() < 1) {
			return null;
		}
		if (cache == null) {
			cache = (TradeImbalance []) list.toArray(new TradeImbalance [list.size()]);
		}
		return cache;
	}
	
	/**
	 * The trade lost for each planet is the Production Output * the Trade Imbalance Percentage
	 * @return The amount of production gained by the trade imbalance from all the planets in this list
	 */
//	public double getProduction() throws ApplicationError {
//		TradeImbalance [] til = getAll();
//		if (til == null) return 0.0;
//		double sum = 0.0;
//		for (int i = 0; i < til.length; i++) {
//			sum += til[i].getSlave().getIndustryWork(false) * til[i].getPercentage();
//		}
//		return sum;
//	}
}
