/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.players;

import mot.common.util.ApplicationError;
import mot.common.xml.XMLBean;
import mot.common.xml.XMLWriter;
import mot.engine.common.StellarObject;
import mot.engine.common.StellarObjectReference;
import mot.engine.planets.SolarSystemReference;

public class AncientPlayer extends XMLBean {

    /**
     * This is the name of the race alignment for races who are 
     * aligned to this player.
     */
    private String name;
    
    /**
     * This is the hold solar system of this ancient race.
     */
    private StellarObjectReference home;

    public AncientPlayer() {
    }

    public AncientPlayer(String name, StellarObject home) {
        this.name = name;
        setHome(home);
    }


    public void setName(String name) {
        this.name = name;
    }


    public String getName() {
        return name;
    }

    protected String getElementName() {
        return "ancient-player";
    }

    protected void encode(XMLWriter writer) throws ApplicationError {
        writer.addElement("name", name);
        if (home != null) {
            home.toXML(writer, "home");
        }
    }


    public void setHome(StellarObject home) {
        if (home == null) {
            home = null;
        } else {
            this.home = home.getObjectReference();
        }
    }

    public void setHome(StellarObjectReference home) {
        this.home = home;
    }
    public void setHome(SolarSystemReference home) {
        this.home = home;
    }


    public StellarObject getHome() {
        if (home == null) {
            return null;
        } else {
            return home.getStellarObject();
        }
    }
}