/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.players;

import mot.common.bean.stats.GameScore;
import mot.common.bean.stats.GameScoreData;
import mot.common.util.ApplicationError;

public class GameScoreFactory {

	public static GameScore create(UserPlayer userPlayer) throws ApplicationError {
		GameScoreData gsd = userPlayer.getGameScoreDataNotNull();
		double craftsBuiltScore = gsd.getTotalQtyCraftsBuilt() * 25;
		double craftsDestroyedScore = gsd.getTotalQtyCraftsDestroyed() * 25;
		double craftsInvadedScore = gsd.getTotalQtyCraftsInvaded() * 100;
		double ancientsDefeatScore = gsd.isAncientsConquered() ? 500 : 0;
		int qtyPopulation = userPlayer.getTotalPopulation();
		double populationScore = qtyPopulation;
		int qtyTechnology = userPlayer.getTechnologies().getQuantity();
		double technologyScore = qtyTechnology / 2.0;
		return new GameScore(gsd, craftsBuiltScore, craftsDestroyedScore, craftsInvadedScore, ancientsDefeatScore, qtyPopulation, populationScore, qtyTechnology, technologyScore);
	}

}
