/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.players;

import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;
import mot.engine.common.OwnedObject;

/**
 * Manages a player's spies.
 * It assignes a players spies to defend the player as well as attack enemy players
 * or keep an eye on friendly players.
 */
public abstract class Intelligence extends OwnedObject {

	protected static final int CALCULATE_INTERVAL = 9;

	/**
	 * The date of the last time this player calculates its priorities.
	 */
	protected int dateOfLastCalculation;

	public int getDateOfLastCalculation() { return dateOfLastCalculation; }
	public void setDateOfLastCalculation(int v) { dateOfLastCalculation = v; }

	public Intelligence() {
	}

	public Intelligence(Player owner) throws ApplicationError {
		super(owner);
		dateOfLastCalculation = 0;
	}

	/**
	 * Checks that all spies are currently in use AND assigns a task to each spy based 
     * upon the players position.
	 */
	public abstract void assignSpies() throws ApplicationError, ValidationError;

}