/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.players;

import mot.common.bean.NamedObject;
import mot.common.util.ApplicationError;
import mot.common.util.BasicNameValueList;
import mot.common.util.NameValuePair;
import mot.common.xml.XMLWriter;
import mot.engine.MotEngine;

public class PlayerReference extends NamedObject {

	private transient Player player;

	public Player getPlayer() throws ApplicationError {
		if (player == null) {
            Player monsterPlayer = MotEngine.instance.getMonsterPlayer();
            if (monsterPlayer.sameName(getName())) {
                player = monsterPlayer;
            } else {
                player = MotEngine.instance.getPlayers().getPlayer(getName());
                if (player == null) {
                    // This player no longer exists - Check dead players!
                	player = MotEngine.instance.getDeadPlayersNotNull().getPlayer(getName());
                }
            }
		}
		return player;
	}

	public PlayerReference() {
	}

	public PlayerReference(Player player) {
		this(player, player.getName());
	}

	public PlayerReference(Player player, String name) {
		super(name);
		this.player = player;
	}

	public PlayerReference(String name) {
		super(name);
	}

	protected void encode(XMLWriter writer) throws ApplicationError {
		// does not have a bean body
	}

    protected BasicNameValueList getAttributes(boolean generateClassAttribute, boolean generateSchemaAttribute) throws ApplicationError {
		if (getPlayer() == null) {
			return null;
		}

		BasicNameValueList params = getAttributesNotNull(generateClassAttribute);
		params.add( new NameValuePair("name", player.getName()) );

		return params;
	}

	protected String getElementName() { return "player-reference"; }
    protected boolean beanHasBody() { return false; }
}