/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.players;

import mot.common.technology.Technology;
import mot.common.util.Comp;
import mot.common.xml.XMLBean;
import mot.common.xml.XMLWriter;

public class ResearchScriptOption extends XMLBean {

    /**
     * The name of this technology
     */
    String name;
    
    /**
     * The field of research this technology is in. e.g. computer.
     * See Technologies for a valid list of fields.
     */
    String type;

    public ResearchScriptOption(String name, String type) {
        this.name = name;
        this.type = type;
    }

    public ResearchScriptOption(Technology tech) {
        name = tech.getName();
        type = tech.getTechType();
    }

    public ResearchScriptOption() {
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }
    
    public boolean same(ResearchScriptOption o) {
        return (o != null && Comp.same(o.getName(), getName()) && Comp.same(o.getType(), getType()));
    }

    protected String getElementName() {
        return "research-script-option";
    }

	protected void encode(XMLWriter writer) {
        writer.addElement("type", type);
        writer.addElement("name", name);
	}
    
    public String toString() {
        return "name="+name+" type="+type;
    }
}