/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.players;
import mot.common.util.ApplicationError;
import mot.engine.battles.BattleObject;

/**
 * This interface defines the operation of a Resourceful Processor. Any player that
 * is resourceful (@see PlayerCharacter) must contains a resourceful processor that 
 * implements the resourcefulness of the player.
 */
public interface ResourcefulProcessor {

    /**
     * Execute the resourcefulness of this processor on the battle object.
     * Note - Its operation depends on the type of resourcefulness.
     * @throws mot.common.util.ApplicationError
     * @param bo The battle object owned by a resourceful player
     */
    public void execute(BattleObject bo) throws ApplicationError; 
}