/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.players.commanders;

import mot.common.util.ApplicationError;
import mot.engine.battles.BattleCraft;
import mot.engine.battles.BattlePlanet;
import mot.engine.common.OwnedObject;
import mot.engine.planets.Planet;
import mot.engine.players.Player;

/**
 * A commander manages a players crafts while in battle. It selects the next target to attack, and 
 * gives a craft orders to move to a particular target and attack it.
 */
public abstract class Commander extends OwnedObject {

    public Commander() {
    }

	protected Commander(Player owner) {
		super(owner);
	}

    
	/**
	 * This assigns tasks to a computer controlled craft in a battle situation.
	 */
	public abstract void assignTaskToCraft(BattleCraft craft) throws ApplicationError;
    
	/**
	 * This assigns tasks to a computer controlled planets in a battle situation. Currently a
	 * craft simply attacks the closest enemy craft in the battle.
	 */
	public abstract void assignTaskToPlanet(BattlePlanet planet) throws ApplicationError;
    
    
    /**
     * Returns true if this commander would like to attack this planet. Even if a general chooses
     * a particular planet for conquering the fleet/crafts may have attack the previous turn and
     * may not want to attack again but wait for troops. Alternatively this general might want to 
     * bombard planets to destroy the colony. The commander chooses because it must know when to
     * retreat its fighters during a battle.
     * This must be a deterministic algorithm (must not contain a random determinanent).
     */
    public abstract boolean wantToAttack(Planet planet) throws ApplicationError;

}