/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.players.generals;

import mot.common.bean.NamedObject;
import mot.common.util.ApplicationError;
import mot.common.util.BasicNameValueList;
import mot.common.util.NameValuePair;
import mot.engine.MotEngine;
import mot.engine.players.ComputerPlayer;
import mot.engine.players.MonsterPlayer;

public class CraftTaskReference extends NamedObject {

    /**
     * The craft task - It is generated by the task name!
     */
	private transient CraftTask task;

	public CraftTaskReference() {
	}

	public CraftTaskReference(CraftTask task) {
		this(task, task.getName());
	}

	public CraftTaskReference(CraftTask task, String name) {
		super(name);
		this.task = task;
	}

	public CraftTaskReference(String name) {
		super(name);
	}

    protected BasicNameValueList getAttributes(boolean generateClassAttribute, boolean generateSchemaAttribute) throws ApplicationError {
		if (getTask() == null) {
			return null;
		}

		BasicNameValueList params = getAttributesNotNull(generateClassAttribute);
		params.add( new NameValuePair("name", getName()) );

		return params;
	}

	protected String getElementName() { return "craft-task-reference"; }
    protected boolean beanHasBody() { return false; }

	public CraftTask getTask() throws ApplicationError {
		if (task == null) {
			ComputerPlayer [] players = MotEngine.instance.getPlayers().getComputerPlayers();
            if (players != null) {
                for (int i=0; i<players.length && task == null; i++) {
                    if (players[i].getGeneral() != null) {
                        CraftTask t = players[i].getGeneral().getTaskForName(getName());
                        if (t != null) {
                            task = t;
                        }
                    }
                }
            }
            if (task == null) {
                MonsterPlayer mp = MotEngine.instance.getMonsterPlayer();
                if (mp != null) {
                    if (mp.getGeneral() != null) {
                        CraftTask t = mp.getGeneral().getTaskForName(getName());
                        if (t != null) {
                            task = t;
                        }
                    }
                }
            }
		}
		return task;
	}


}