/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.players.mayor;

import mot.common.designs.CraftDesign;
import mot.common.util.ApplicationError;
import mot.engine.MotEngine;
import mot.engine.players.Player;

/**
 * Base class for objects the create craft designs from the technology a player 
 * has discovered.
 */
public abstract class CraftDesigner  {
    public CraftDesigner() {
    }

    /**
     * Uses the technology discovered by player p to design a new craft.
     * @param p Player for which it will design a new craft. All technology on 
     * the craft will restricted to techs researched by this player.
     * @return A new Craft Design.
     */
    public abstract CraftDesign designCraft(Player p) throws ApplicationError;

    /**
     * Generates new unique names for craft designs. The name will consist of the
     * prefix passed in followed by a number.
     */
	protected String getNewName(String prefix) {
		return MotEngine.getInstance().getNameGenerator().getNextName(prefix);
	}
}