/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.players.morals;

import java.util.ArrayList;

import mot.common.morals.MoralChoice;
import mot.common.morals.MoralChoiceList;
import mot.common.util.ApplicationError;
import mot.common.xml.XMLBean;
import mot.common.xml.XMLWriter;
import mot.engine.MotEngine;
import mot.engine.players.ComputerPlayer;
import mot.engine.players.Player;

/**
 * This is a list of moral choices that also contains a event listener
 * design pattern implementation so other objects can listen for changes.
 */
public class MoralChoiceListenerList extends XMLBean {
	
	private MoralChoiceList list;
	private ArrayList listsners;
	
	public MoralChoiceListenerList() {
		list = new MoralChoiceList();
	}
	
	public void addListsner(MoralChoiceListener listener) {
		if (listsners == null) listsners = new ArrayList();
		listsners.add(listener);
	}

    /**
     * Adds a new moral choice item to the list of items.
     * @param p The player that has just made the decision v
     * @param mc The moral choice that has just been made 
     * @throws ApplicationError 
     */
	public void add(Player p, MoralChoice mc) throws ApplicationError {
		list.add(mc);
		//for (Iterator i = listsners.iterator(); i.hasNext();) {
		//	MoralChoiceListener mcl = (MoralChoiceListener) i.next();
		//	mcl.newMoralDecision(v);
		//}
		// I have not used the event listener design pattern throughout the game
		// becuase wiring the listsners is to difficult. What happens on save / load?
		// What is order of objects saved changes? To do this you must have a seperate
		// wiring step after a load but without technologies like spring it is just too
		// ugly and this was started long before Spring was well known.
		Player [] players = MotEngine.getInstance().getPlayers().getPlayers();
		for (int i = 0; i < players.length; i++) {
			if (players[i] != p && players[i] instanceof ComputerPlayer) {
				ComputerPlayer cp = (ComputerPlayer) players[i];
				cp.getStratagist().notifyOfMoralChoice(p, mc);
			}
		}
	}

	protected String getElementName() {
		return "moral-choice-listener-list";
	}

	public MoralChoiceList getList() {
		return list;
	}

	public void setList(MoralChoiceList list) {
		this.list = list;
	}
	
	public double getProductionBonus() {
		return list. getProductionBonus();
	}
	
	public double getInfluenceBonus() {
		return list. getInfluenceBonus();
	}
	
	public double getDamageBonus() {
		return list. getDamageBonus();
	}
	
	public int getRelationsBonus() {
		return list. getRelationsBonus();
	}

	protected void encode(XMLWriter writer) throws ApplicationError {
		list.referenceToXML(writer, "list");
	}
		
}
