/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.players.morals;

import mot.common.util.ApplicationError;
import mot.engine.players.Player;

/**
 * A Moral Policy Advisor is a AI module that proposes the adoption of a moral 
 * policies to players (human and computer). NOTE - These do not create MoralChoices
 * they call the recommendMoralChoice() method on player and give the player
 * the option of accepting or rejecting the policy. 
 */
public interface MoralPolicyAdvisor {
	
	/**
	 * This should be called at the end of every turn so that the moral policy
	 * advisor is given the option to propose the adoption of a moral policy
	 * to the player.
	 * @param owner
	 */
	public void endTurn(Player owner) throws ApplicationError;

	/**
	 * NOTE this value need not persist between saves, it is intended purly for
	 * validation of user policy adoption!
	 * @return The name of the last moral policy recomended by this manager!
	 */
	public String getLastPolicyRecommnded();
	
}
