/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.players.morals;

import mot.common.morals.MoralChoice;
import mot.common.morals.MoralChoiceList;
import mot.common.morals.MoralChoices;
import mot.common.util.ApplicationError;
import mot.common.util.Utils;
import mot.engine.players.Player;

/**
 * Basic implementation of the MoralPolicyAdvisor interface.
 * Recommends the adoption of moral policy using randomly.
 */
public class MoralPolicyAdvisorBasic implements MoralPolicyAdvisor {

	private static final int QTY_BETWEEN_POLICY_ADVICE = 10;
	private static final int QTY_BETWEEN_POLICY_ADVIVE_VARIANCE = 40;
	
	private int turnToAdvisePolicy;
	
	private String lastPolicyRecomended;

	public MoralPolicyAdvisorBasic() {
		turnToAdvisePolicy = 10 + Utils.random(QTY_BETWEEN_POLICY_ADVICE);
	}

	public void endTurn(Player owner) throws ApplicationError {
		turnToAdvisePolicy--;
		if (turnToAdvisePolicy <= 0) {
			createNewAdvice(owner);
			turnToAdvisePolicy = QTY_BETWEEN_POLICY_ADVICE + Utils.random(QTY_BETWEEN_POLICY_ADVIVE_VARIANCE);
		}
	}

	public void createNewAdvice(Player owner) throws ApplicationError {
		MoralChoice [] all = MoralChoices.getMoralChoices().getAllAsArray();
		MoralChoiceList available = new MoralChoiceList(all);
		if (owner.getMoralChoices() != null) {
			available.remove(owner.getMoralChoices().getList());
		}
		if (available.getQuantity() > 0) {
			MoralChoice choice = (MoralChoice) Utils.random(available.getAllAsArray());
			lastPolicyRecomended = choice.getName();
			owner.recommendMoralChoice(choice);
		}
	}

	public String getLastPolicyRecommnded() {
		return lastPolicyRecomended;
	}
	
	public int getTurnToAdvisePolicy() {
		return turnToAdvisePolicy;
	}

	public void setTurnToAdvisePolicy(int turnToAdvisePolicy) {
		this.turnToAdvisePolicy = turnToAdvisePolicy;
	}

	public void setLastPolicyRecomended(String lastPolicyRecomended) {
		this.lastPolicyRecomended = lastPolicyRecomended;
	}

}
