/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.players.strategists;
import mot.engine.MotEngine;
import mot.engine.players.Player;

/**
 * The player has annoyed the owner of this strategist event by requesting the same
 * thing over and over again.
 * A strategist remembers this so it know when it has just given assets from a
 * previous demand..
 */
public class StrategistEventAnnoy extends StratagistEvent {

    private static final int RELATION_EFFECT = -1;
    private static final int EXPIRY_INTERVAL = 5;
    
    public StrategistEventAnnoy() {
    }

    public StrategistEventAnnoy(Player player) {
        super(player, MotEngine.instance.getDate() + EXPIRY_INTERVAL);
    }

    protected int getRelationshipEffect() { return RELATION_EFFECT; }

    public String getDescription() {
    	if (hasExpired()) {
    		return "Annoying behaviour (effects expired)";
    	} else {
    		return "Annoying behaviour (-1)";
    	}
    }

}