/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.players.strategists;
import mot.common.util.ApplicationError;
import mot.common.xml.XMLWriter;
import mot.engine.MotEngine;
import mot.engine.players.Player;

/**
 * This is a treaty offered by this player to another player has been rejected.
 */
public class StrategistEventBrokeNonAggression extends StratagistEvent {

    private static final int EXPIRY_INTERVAL = 150;
    private static final int RELATION_EFFECT = -3;
    
	private String treatyName;

    public StrategistEventBrokeNonAggression() {
    }
    
    public StrategistEventBrokeNonAggression(Player player, String treatyName) {
        super(player, MotEngine.instance.getDate() + EXPIRY_INTERVAL);
		this.treatyName = treatyName;
    }

    public String getDescription() {
    	if (hasExpired()) {
    		return "Broke "+treatyName+" treaty (effects expired)";
    	} else {
    		return "Broke "+treatyName+" treaty (-3)";
    	}
    }

    protected int getRelationshipEffect() { return RELATION_EFFECT; }
    
    protected void encode(XMLWriter writer) throws ApplicationError {
        writer.addElement("treaty-name", treatyName);
        super.encode(writer);
    }

	public String getTreatyName() {
		return treatyName;
	}

	public void setTreatyName(String treatyName) {
		this.treatyName = treatyName;
	}


}