/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.players.strategists;
import mot.engine.MotEngine;
import mot.engine.players.Player;

/**
 * The player has declared war the owner of this strategist event. This has a negative 
 * effect on the relationship between player and the owner of this event.
 */
public class StrategistEventCaughtSabotaging extends StratagistEvent {

    private static final int EXPIRY_INTERVAL = 100;
    private static final int RELATION_EFFECT = -5;

    public StrategistEventCaughtSabotaging() {
    }
    
    public StrategistEventCaughtSabotaging(Player player) {
        super(player, MotEngine.instance.getDate() + EXPIRY_INTERVAL);
    }

    public String getDescription() {
    	if (hasExpired()) {
    		return "Acts of sabotage (effects expired)";
    	} else {
    		return "Acts of sabotage (-5)";
    	}
    }

    protected int getRelationshipEffect() { return RELATION_EFFECT; }
}