/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.players.strategists;
import mot.common.technology.Technology;
import mot.common.util.ApplicationError;
import mot.common.xml.XMLWriter;
import mot.engine.MotEngine;
import mot.engine.players.Player;

/**
 * The player has declared war the owner of this strategist event. This has a negative 
 * effect on the relationship between player and the owner of this event.
 */
public class StrategistEventCaughtSpying extends StratagistEvent {

    private static final int EXPIRY_INTERVAL = 100;
    private static final int RELATION_EFFECT = -5;

    private String techDescription;
    
    public StrategistEventCaughtSpying() {
    }
    
    public StrategistEventCaughtSpying(Player player, Technology tech) {
        super(player, MotEngine.instance.getDate() + EXPIRY_INTERVAL);
        if (tech != null) techDescription = tech.getFullName();
    }

    public String getDescription() {
    	String effect = hasExpired() ? "(effects expired)" : "(-5)";
   		return "<html>Act of spying "+effect+"<br/>"+getPlayerName()+" stole "+techDescription+"</html>";
    }

    protected int getRelationshipEffect() { return RELATION_EFFECT; }

    protected void encode(XMLWriter writer) throws ApplicationError {
        writer.addElement("tech-description", techDescription);
        super.encode(writer);
    }

	public String getTechDescription() {
		return techDescription;
	}

	public void setTechDescription(String techDescription) {
		this.techDescription = techDescription;
	}

}