/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.players.strategists;
import mot.common.util.ApplicationError;
import mot.common.xml.XMLWriter;
import mot.engine.MotEngine;
import mot.engine.players.Player;

/**
 * The player has invaded (taken) or destroyed a planet that belonged to the owner of this strategist 
 * event. This has a negative effect on the relationship between player and the owner of this event.
 */
public class StrategistEventColonyLost extends StratagistEvent {

    private static final int EXPIRY_INTERVAL = 100;
    private static final int RELATION_EFFECT_INVADE = -10;
    private static final int RELATION_EFFECT_BOMBARD = -15;
    
	private String planetName;
	private boolean genocide;

    public StrategistEventColonyLost() {
    }
    
    public StrategistEventColonyLost(Player player, String planetName, boolean genocide) {
        super(player, MotEngine.instance.getDate() + EXPIRY_INTERVAL);
		this.planetName = planetName;
		this.genocide = genocide;
    }

    public String getDescription() {
    	if (genocide) {
        	String effect = hasExpired() ? "(effects expired)" : "(-15)";
            return "Destruction of my colony on "+planetName+" Genocide "+effect;
    	} else {
        	String effect = hasExpired() ? "(effects expired)" : "(-10)";
            return "Invasion of my colony on "+planetName+" "+effect;
    	}
    }

    protected int getRelationshipEffect() { return genocide ? RELATION_EFFECT_BOMBARD : RELATION_EFFECT_INVADE; }

	public String getPlanetName() {
		return planetName;
	}

	public void setPlanetName(String planetName) {
		this.planetName = planetName;
	}

    protected void encode(XMLWriter writer) throws ApplicationError {
        writer.addElement("planet-name", planetName);
        writer.addElement("genocide", genocide);
        super.encode(writer);
    }

	public boolean isGenocide() {
		return genocide;
	}

	public void setGenocide(boolean genocide) {
		this.genocide = genocide;
	}

}