/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.players.strategists;
import mot.common.util.ApplicationError;
import mot.common.xml.XMLWriter;
import mot.engine.MotEngine;
import mot.engine.players.Player;
import mot.engine.players.PlayerReference;

/**
 * The player has declared war on a enemy of the owner of this strategist event.
 * This has a positive effect of the relationship between player and the owner of 
 * this event.
 */
public class StrategistEventDeclareWarOnEnemy extends StratagistEvent {

    private static final int EXPIRY_INTERVAL = 25;
    private static final int RELATION_EFFECT = 5;
    
    private PlayerReference commonEnemy;

    public StrategistEventDeclareWarOnEnemy() {
    }
    
    public StrategistEventDeclareWarOnEnemy(Player player, Player commonEnemy) {
        super(player, MotEngine.instance.getDate() + EXPIRY_INTERVAL);
        this.commonEnemy = new PlayerReference(commonEnemy);
    }

    public String getDescription() {
    	String effect = hasExpired() ? " (effects expired)" : " (+5)";
    	if (commonEnemy != null) {
			return "declaration of war on "+commonEnemy.getName()+effect;
    	} else {
    		return "declaration of war on UNKNOWN PLAYER"+effect;
    	}
    }

    protected int getRelationshipEffect() { return RELATION_EFFECT; }

    protected void encode(XMLWriter writer) throws ApplicationError {
        super.encode(writer);
        if (commonEnemy != null) {
            commonEnemy.toXML(writer, "common-enemy");
        }
    }

    public void setCommonEnemy(PlayerReference commonEnemy) {
        this.commonEnemy = commonEnemy;
    }


    public PlayerReference getCommonEnemy() {
        return commonEnemy;
    }

}