/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.players.strategists;
import mot.common.util.ApplicationError;
import mot.common.xml.XMLWriter;
import mot.engine.MotEngine;
import mot.engine.players.Player;

/**
 * This event's player has demanded from the owner of this strategist and the demand
 * has been agreed to.
 * A strategist remembers this so it know when it has just given assets from a
 * previous demand.
 */
public class StrategistEventDemandAssets extends StratagistEvent {

    private static final int RELATION_EFFECT = -5;
    private static final int EXPIRY_INTERVAL = 50;

    /**
     * This is the assert score of the assets given to the player in the demand.
     */
    private int assetScore;

    private String assetsDescription;

    public StrategistEventDemandAssets() {
    }

    public StrategistEventDemandAssets(Player player, int assetScore, boolean accepted, String assetsDescription) {
        super(player, MotEngine.instance.getDate() + EXPIRY_INTERVAL);
        this.assetScore = assetScore;
		this.assetsDescription = assetsDescription;
    }

    protected int getRelationshipEffect() { return RELATION_EFFECT; }

    public String getDescription() {
    	String effect = hasExpired() ? "(effects expired)" : "(-5)";
    	if (hasExpired()) {
    		return "<html>Demanded assets "+effect+"<br/>Wanted: "+assetsDescription+"</html>";
    	} else {
    		return "<html>Demand for assets "+effect+"<br/>Wanted: "+assetsDescription+"</html>";
    	}
    }


    public void setAssetScore(int assetScore) {
        this.assetScore = assetScore;
    }


    public int getAssetScore() {
        return assetScore;
    }

    protected void encode(XMLWriter writer) throws ApplicationError {
        writer.addElement("asset-score", assetScore);
        writer.addElement("assets-description", assetsDescription);
        super.encode(writer);
    }

	public String getAssetsDescription() {
		return assetsDescription;
	}

	public void setAssetsDescription(String assetsDescription) {
		this.assetsDescription = assetsDescription;
	}
}