/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.players.strategists;
import mot.common.util.ApplicationError;
import mot.common.xml.XMLWriter;
import mot.engine.MotEngine;
import mot.engine.players.Player;

/**
 * The player has demanded from the owner of this strategist event and the demand
 * has been agreed to.
 * A strategist remembers this so it know when it has just given assets from a
 * previous demand..
 */
public class StrategistEventGiveAssets extends StratagistEvent {

    private static final int EXPIRY_INTERVAL = 20;
    private static final int HALF_EXPIRY_INTERVAL = 10;
    
    /**
     * The effect this gift will have on relations.
     */
    private int relationEffect;
    
	private String assetsDescription;
    
    public StrategistEventGiveAssets() {
    }

    public StrategistEventGiveAssets(Player player, int relationEffect, String assetsDescription) {
        super(player, MotEngine.instance.getDate() + EXPIRY_INTERVAL);
        this.relationEffect = relationEffect;
		this.assetsDescription = assetsDescription;
    }

    protected int getRelationshipEffect() {
        int timeToExpire = getExpiryDate() - MotEngine.instance.getDate();
        if (timeToExpire < 0) {
            return 0; 
        } else if (timeToExpire < HALF_EXPIRY_INTERVAL) {
            return relationEffect/2; 
        } else {
            return relationEffect; 
        }
    }

    public String getDescription() {
    	String effect = hasExpired() ? "(effects expired)" : "(+"+getRelationshipEffect() +")";
		return "<html>Gift of assets "+effect+"<br/>Given: "+assetsDescription+"</html>";
    }


    protected void encode(XMLWriter writer) throws ApplicationError {
        writer.addElement("relation-effect", relationEffect);
        writer.addElement("assets-description", assetsDescription);
        super.encode(writer);
    }


    public void setRelationEffect(int relationEffect) {
        this.relationEffect = relationEffect;
    }


    public int getRelationEffect() {
        return relationEffect;
    }

	public String getAssetsDescription() {
		return assetsDescription;
	}

	public void setAssetsDescription(String assetsDescription) {
		this.assetsDescription = assetsDescription;
	}
}