/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.players.strategists;
import mot.common.util.ApplicationError;
import mot.common.xml.XMLWriter;
import mot.engine.MotEngine;
import mot.engine.players.Player;

/**
 * The player has bombarded a planet killing the entire population. The planet did NOT belong to this strategist.
 */
public class StrategistEventInvasion extends StratagistEvent {

    private static final int EXPIRY_INTERVAL = 10;
    private static final int RELATION_EFFECT = -2;
    
    /**
     * The planet that was invaded
     */
	private String planetName;
	
	/**
	 * The name of the player who owned this planet before it was invaded.
	 */
	private String victim;

    public StrategistEventInvasion() {
    }
    
    public StrategistEventInvasion(Player owner, Player player, String planetName, String victim) {
        super(owner, player, MotEngine.instance.getDate() + EXPIRY_INTERVAL);
		this.planetName = planetName;
		this.victim = victim;
    }

    public String getDescription() throws ApplicationError {
    	Player v = MotEngine.instance.getPlayersNotNull().getPlayer(victim);
    	Player owner = getOwner();
    	if (v != null && owner != null && v.isEnemy(owner)) {
        	String effect = hasExpired() ? "(effects expired)" : "(+2)";
            return "Invasion of my enemy's planet "+planetName+" "+effect;
    	} else {
        	String effect = hasExpired() ? "(effects expired)" : "(-2)";
            return "Expansionist Behaviour - Your invasion of "+planetName+" "+effect;
    	}
    }

    protected int getRelationshipEffect() throws ApplicationError { 
    	Player v = MotEngine.instance.getPlayersNotNull().getPlayer(victim);
    	Player owner = getOwner();
    	if (v != null && owner != null && v.isEnemy(owner)) {
    		return -RELATION_EFFECT;
    	} else {
    		return RELATION_EFFECT;
    	}
    }

	public String getPlanetName() {
		return planetName;
	}

	public void setPlanetName(String planetName) {
		this.planetName = planetName;
	}

    protected void encode(XMLWriter writer) throws ApplicationError {
        writer.addElement("planet-name", planetName);
        super.encode(writer);
    }

}