/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.players.strategists;
import mot.common.morals.MoralChoice;
import mot.common.morals.MoralChoices;
import mot.common.util.ApplicationError;
import mot.common.xml.XMLWriter;
import mot.engine.players.Player;

/**
 * The player has declared war the owner of this strategist event. This has a negative 
 * effect on the relationship between player and the owner of this event.
 */
public class StrategistEventMoralDecision extends StratagistEvent {

	private static final int DEFAULT_RELATION_EFFECT = -10;
    private MoralChoice moralChoice;

    public StrategistEventMoralDecision() {
    }
    
    public StrategistEventMoralDecision(Player player, MoralChoice moralChoice) {
        super(player, NEVER_EXPIRE);
        this.moralChoice = moralChoice;
    }

    public String getDescription() {
    	if (moralChoice.getRelationsBonus() != null) {
            return "Your use of "+moralChoice.getName()+" ("+moralChoice.getRelationsBonus()+")";
    	} else {
            return "Your use of "+moralChoice.getName();
    	}
    }

    protected int getRelationshipEffect() {
    	if (moralChoice.getRelationsBonus() == null) {
        	return DEFAULT_RELATION_EFFECT; 
    	} else {
        	return moralChoice.getRelationsBonus().intValue(); 
    	}
    }

    
	protected void encode(XMLWriter writer) throws ApplicationError {
		super.encode(writer);
        writer.addElement("moral-choice-name", moralChoice.getName());
	}

    public void setMoralChoiceName(String name) throws ApplicationError {
        setMoralChoice(MoralChoices.getMoralChoice(name));
    }
	
	public MoralChoice getMoralChoice() {
		return moralChoice;
	}

	public void setMoralChoice(MoralChoice moralChoice) {
		this.moralChoice = moralChoice;
	}

}