/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.players.strategists;
import mot.common.util.ApplicationError;
import mot.common.xml.XMLWriter;
import mot.engine.MotEngine;
import mot.engine.players.Player;

/**
 * This event's player has requested a swap assets from the strategists owner and
 * the swap has been rejected.
 * A strategist remembers this so it can spot a user asking for the same swap over 
 * and over again.
 */
public class StrategistEventRejectSwapAssets extends StratagistEvent {

    private static final int EXPIRY_INTERVAL = 2;

    /**
     * This is the assert score of the assets wanted from the player in the swap.
     */
    private int wantedAssetScore;
    
    /**
     * This is the assert score of the assets offered to the player in the swap.
     */
    private int offeredAssetScore;

    public StrategistEventRejectSwapAssets() {
    }

    public StrategistEventRejectSwapAssets(Player player, int wantedAssetScore, int offeredAssetScore) {
        super(player, MotEngine.instance.getDate() + EXPIRY_INTERVAL);
        this.wantedAssetScore = wantedAssetScore;
        this.offeredAssetScore = offeredAssetScore;
    }

    protected void encode(XMLWriter writer) throws ApplicationError {
        writer.addElement("wanted-asset-score", wantedAssetScore);
        writer.addElement("offered-asset-score", offeredAssetScore);
        super.encode(writer);
    }

	public int getOfferedAssetScore() {
		return offeredAssetScore;
	}

	public void setOfferedAssetScore(int offeredAssetScore) {
		this.offeredAssetScore = offeredAssetScore;
	}

	public int getWantedAssetScore() {
		return wantedAssetScore;
	}

	public void setWantedAssetScore(int wantedAssetScore) {
		this.wantedAssetScore = wantedAssetScore;
	}
	
}