/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.players.strategists;
import mot.common.util.ApplicationError;
import mot.common.xml.XMLWriter;
import mot.engine.MotEngine;
import mot.engine.players.Player;

/**
 * The player has annoyed the owner of this strategist event by requesting the same
 * thing over and over again.
 * A strategist remembers this so it know when it has just given assets from a
 * previous demand..
 */
public class StrategistEventRelationsEstablished extends StratagistEvent {

    private static final int RELATION_EFFECT = 0;
	private boolean starting;
     
    public StrategistEventRelationsEstablished() {
    }

    public StrategistEventRelationsEstablished(Player player, boolean starting) {
        super(player, MotEngine.instance.getDate());
		this.starting = starting;
    }

    protected int getRelationshipEffect() { return RELATION_EFFECT; }

    public String getDescription() throws ApplicationError {
    	if (starting) {
    		return "Relations Established";
    	} else {
    		return "Relations Broken";
    	}
    		
    }
    
    protected void encode(XMLWriter writer) throws ApplicationError {
        writer.addElement("starting", starting);
        super.encode(writer);
    }

	public boolean isStarting() {
		return starting;
	}

	public void setStarting(boolean starting) {
		this.starting = starting;
	}

}