/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.players.strategists;
import mot.engine.MotEngine;
import mot.engine.players.Player;

/**
 * This is a treaty offered by this player to another player has been rejected.
 */
public class StrategistEventTreatyRejected extends StratagistEvent {

    private static final int EXPIRY_INTERVAL = 25;
    private static final int RELATION_EFFECT = -1;
	private String message;

    public StrategistEventTreatyRejected() {
    }
    
    public StrategistEventTreatyRejected(Player player, String message) {
        super(player, MotEngine.instance.getDate() + EXPIRY_INTERVAL);
		this.message = message;
    }

    public String getDescription() {
    	String effect = hasExpired() ? "(effects expired)" : "(-1)";
    	if (message != null) {
    		return message+" "+effect;
    	} else {    		
    		return "Treaty Rejected "+effect;
    	}
    }

    protected int getRelationshipEffect() { return RELATION_EFFECT; }

}