/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.prizes;

import mot.common.designs.CraftDesign;
import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.Logger;
import mot.common.xml.XMLWriter;
import mot.engine.MotEngine;
import mot.engine.common.StellarObject;
import mot.engine.crafts.Craft;
import mot.engine.crafts.CraftFactory;
import mot.engine.event.PrizeGiftEF;
import mot.engine.players.Player;
import mot.engine.players.mayor.CraftDesignerMilitary;

/**
 * This prize gives a new craft when released.
 * The craft will be designed using the players discovered technology and will be a small 
 * craft using the best techs available for the player.
 */
public class CraftPrize extends Prize {


	public CraftPrize() {
    }
    
    public void release(Player player, StellarObject so) throws ApplicationError {
        CraftDesignerMilitary cdm = new CraftDesignerMilitary();
        CraftDesign cd = cdm.designCraft(player, CraftDesignerMilitary.SIZE_SMALL, 0.15, 0.0);
        if (cd == null) {
            Logger.logWarning("CraftPrize.release() No craft design at "+so.getName());
            return;
        }
        cd.setName("Prize");
        Craft craft = CraftFactory.getCraftInstance(cd, player, player, so.getOrbit(), true, false);
        if (Logger.isDebug()) {
            Logger.logDebug("CraftPrize.release() player "+player.getName()+" given "+craft.getName());
            //cd.log(player.getName());
        }
        String text = L.YOU_HAVE_DISCOVERED_AN_ABANDONED_CRAFT+craft.getName();
        MotEngine.instance.broadcast(new PrizeGiftEF(true, "PrizeCraft", null, text), player);
    }
    
	protected void encode(XMLWriter writer) throws ApplicationError {
    }

	protected String getElementName() { return "craft-prize"; }


}