/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.prizes;

import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.util.Logger;
import mot.common.xml.XMLWriter;
import mot.engine.MotEngine;
import mot.engine.common.StellarObject;
import mot.engine.event.PrizeGiftEF;
import mot.engine.players.Player;

/**
 * This prize gives a player a money when it is released.
 */
public class MoneyPrize extends Prize {

	/**
     * The amount of money that will be given when released.
     */
    private int amount;

    public MoneyPrize() {
    }
    
    public MoneyPrize(int amount) {
        this.amount = amount;
    }
    
    public void release(Player player, StellarObject so) throws ApplicationError {
        if (Logger.isDebug()) {
            Logger.logDebug("MoneyPrize.release() player "+player.getName()+" given "+amount);
        }
        player.addFunds(amount);
        String text = L.YOU_HAVE_DISCOVERED_A_PIRATE_S_CACHE_OF_MONEY+amount;
        MotEngine.instance.broadcast(new PrizeGiftEF(true, "PrizeGold", null, text), player);
    }
    
	protected void encode(XMLWriter writer) throws ApplicationError {
        writer.addElement("amount", amount);
    }

	protected String getElementName() { return "money-prize"; }



    public void setAmount(int amount) {
        this.amount = amount;
    }

    public long getAmount() {
        return amount;
    }


}