/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.prizes;

import mot.common.util.ApplicationError;
import mot.common.xml.XMLBean;
import mot.engine.common.StellarObject;
import mot.engine.players.Player;

/**
 * This is the base class for all prize objects. A Prize is an event that is triggered when 
 * a player arrives at a stellar object. One it is triggered the prize is removed. At the start
 * of a game variouse solar system are seeded with random prizes and the first visitor to
 * the solar system gets the prizes.
 * 
 * To give the prize to a player call execute(Player, StellarObject) and the prize will be given 
 * to player at the stellar object passed in.
 */
public abstract class Prize extends XMLBean {
    protected Prize() {
    }
    
    public abstract void release(Player player, StellarObject so) throws ApplicationError;
}