/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.prizes;

import mot.common.lang.L;
import mot.common.setup.RelicsFactory;
import mot.common.setup.SetupOption;
import mot.common.util.ApplicationError;
import mot.common.util.Logger;
import mot.common.xml.XMLWriter;
import mot.engine.MotEngine;
import mot.engine.common.StellarObject;
import mot.engine.event.PrizeGiftEF;
import mot.engine.players.Player;

/**
 * This prize gives a player a new technology when it is released.
 */
public class RelicPrize extends Prize {

	/**
     * The technology that will be given to the player who releases this prize.
     */
    private SetupOption relic;

    public RelicPrize() {
    }
    
    public RelicPrize(SetupOption relic) {
        this.relic = relic;
    }
    
    public void release(Player player, StellarObject so) throws ApplicationError {
        if (Logger.isDebug()) {
            Logger.logDebug("RelicPrize.release() player "+player.getName()+" given "+relic.getName());
        }
        if (relic != null) {
            String text = L.YOU_HAVE_DISCOVERED_RELICS_CONTAINING_SECRETS_OF_ANCIENT_TECHNOLOGY+relic.getDescription();
            MotEngine.instance.broadcast(new PrizeGiftEF(true, null, null, text), player);
            player.getPlayerCharacter().increasesBonusesFromOptions(relic);
        }
    }
    
	protected void encode(XMLWriter writer) throws ApplicationError {
		writer.addElement("relic", relic.getName());
    }

	protected String getElementName() { return "relic-prize"; }


    public void setRelic(SetupOption relic) {
        this.relic = relic;
    }

    public void setRelic(String relicName) throws ApplicationError {
        this.relic = RelicsFactory.getRelic(relicName);
    }

    public SetupOption getRelic() {
        return relic;
    }


}