/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.prizes;

import mot.common.lang.L;
import mot.common.technology.Technology;
import mot.common.technology.TechnologyReference;
import mot.common.util.ApplicationError;
import mot.common.util.Logger;
import mot.common.xml.XMLWriter;
import mot.engine.MotEngine;
import mot.engine.common.StellarObject;
import mot.engine.event.PrizeGiftEF;
import mot.engine.players.Player;

/**
 * This prize gives a player a new technology when it is released.
 */
public class TechnologyPrize extends Prize {

	/**
     * The technology that will be given to the player who releases this prize.
     */
    private Technology tech;

    public TechnologyPrize() {
    }
    
    public TechnologyPrize(Technology tech) {
        this.tech = tech;
    }
    
    public void release(Player player, StellarObject so) throws ApplicationError {
        if (Logger.isDebug()) {
            Logger.logDebug("TechnologyPrize.release() player "+player.getName()+" given "+tech.getFullName());
        }
        if (tech != null) {
            String text = L.YOU_HAVE_DISCOVERED_DETAILS_OF_THE_TECHNOLOGY+tech.getFullName();
            MotEngine.instance.broadcast(new PrizeGiftEF(true, null, tech.getFullName(), text), player);
            player.addTechnology(tech);
            player.notifyTechnologyDiscovered(tech, false);            
        }
    }
    
	protected void encode(XMLWriter writer) throws ApplicationError {
        if (tech != null) {
            new TechnologyReference(tech).toXML(writer);
        }
    }

	protected String getElementName() { return "technology-prize"; }


    public void setTech(Technology tech) {
        this.tech = tech;
    }

    public void setTechnologyReference(TechnologyReference tech) throws ApplicationError {
        this.tech = tech.getTechnology();
    }

    public Technology getTech() {
        return tech;
    }


}