/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.relations;

import mot.common.lang.L;
import mot.common.util.ApplicationError;
import mot.common.xml.XMLWriter;
import mot.engine.MotEngine;

public class AllianceTreaty extends Treaty  {
	public static final int MIN_TIME = 50;
	
    /**
     * The date this trade route was started.
     */
    private int dateStarted;
    
    public int getDateStarted() { return dateStarted; }
    public void setDateStarted(int v) { dateStarted = v; }

    public AllianceTreaty() {
    }

    public AllianceTreaty(int dateStarted) {
		this.dateStarted = dateStarted;
    }

	protected void encode(XMLWriter writer) throws ApplicationError {
        writer.addElement("date-started", dateStarted);
	}

	protected String getElementName() { return "alliance-treaty"; }

    public String getName() {
        return L.TREATY_ALLIANCE;
    }
    
	public boolean isOutOfDate() {
		int date = MotEngine.instance.getDate();
		return date > dateStarted + MIN_TIME;
	}
}