/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.setup;

import mot.common.bean.RaceGraphics;
import mot.common.technology.Technologies;
import mot.common.technology.Weapon;
import mot.common.util.ApplicationError;
import mot.common.util.Logger;
import mot.engine.MotEngine;
import mot.engine.crafts.Craft;
import mot.engine.crafts.CraftFactory;
import mot.engine.planets.Planet;
import mot.engine.players.AncientPlayer;
import mot.engine.players.MonsterPlayer;
import mot.engine.prizes.TechnologyPrize;

/**
 * Creates an ancient race - Ancient races are actually the monster player but they do 
 * need a planet as their base with a very powerful monster defending it.
 */
public class AncientFactory {

    public AncientFactory() {
    }

    /**
     * This method actually creates the monster and converts the planet into a desirable 
     * planet guarded by the monster.
     * @param planet The planet to be guarded by the monster.
     */
    public static  void createAncient(Planet planet, RaceGraphics raceGraphics) throws ApplicationError {
        MonsterPlayer player = MotEngine.instance.getMonsterPlayer();
        String name = raceGraphics.getName();
        Craft craft1 = CraftFactory.create("large_"+name, player, player, planet.getOrbit(), false, false);
        Craft craft2 = CraftFactory.create("medium_"+name, player, player, planet.getOrbit(), false, false);
        Craft craft3 = CraftFactory.create("medium_"+name, player, player, planet.getOrbit(), false, false);
        Craft craft4 = CraftFactory.create("medium_"+name, player, player, planet.getOrbit(), false, false);
        planet.setSize(150);
        planet.setTeraforming(1.0);
        planet.setProductionBonus(3.0);
        planet.setReproductionBonus(1.0);
        planet.setResearchBonus(2.0);
        planet.setMoneyBonus(0);
        Weapon ancientWeapon = Technologies.getWeapon("ancient");
        if (ancientWeapon == null) {
            Logger.logWarning("AncientFactory.createAncient() Ancient Technolgies Missing");
        } else {
            planet.getStellarObject().setPrize(new TechnologyPrize(ancientWeapon));
        }
        player.addAncient(new AncientPlayer(name, planet.getStellarObject()));
    }
}