/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.setup;

import mot.common.bean.PlayerAiSettings;
import mot.common.bean.PlayerColor;
import mot.common.proxy.ComputerPlayerProxy;
import mot.common.setup.RaceOptions;
import mot.common.util.ApplicationError;
import mot.engine.MotEngine;
import mot.engine.players.ComputerPlayer;
import mot.engine.players.Player;

public class ComputerPlayerFactory extends PlayerFactory  {

    /**
     * Creates a new Player with the parameters passed in. The player type is unknown and
     * dependent on the implementation of this interface.
     * @param name The name of the new Player
     * @param character The Player character for the new Player
     * @param color The colour this new player will use.
     * @return The new Player.
     */
    public Player create(RaceOptions raceOptions, String name, Double level, PlayerColor color, String alignment, PlayerAiSettings playerAiSettings, String [] playerNames) throws ApplicationError {
        SetupPlayerCharacter character = new SetupPlayerCharacter(name, raceOptions, level, playerAiSettings, playerNames);
		ComputerPlayer cp = new ComputerPlayer(name, character, color, alignment);
        MotEngine.instance.getProxyManager().add(new ComputerPlayerProxy(cp));
        return cp;
    }

}