/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.setup;

import mot.common.util.ApplicationError;
import mot.engine.MotEngine;
import mot.engine.crafts.Craft;
import mot.engine.crafts.CraftFactory;
import mot.engine.planets.Planet;
import mot.engine.players.MonsterPlayer;

/**
 * For details of Monster Factories see the MonsterFactory base class.
 * This factory performs the following;
 *  Makes the planet desirable - size 110, Terraform 1.0, Production bonus +100%.
 *  Create a new craft - Size Hull large.
 */
public class MonsterFactoryMedium extends MonsterFactory  {
    public MonsterFactoryMedium() {
    }

    /**
     * This method actually creates the monster and converts the planet into a desirable 
     * planet guarded by the monster.
     * @param planet The planet to be guarded by the monster.
     */
    protected void doCreate(Planet planet) throws ApplicationError {
        MonsterPlayer player = MotEngine.instance.getMonsterPlayer();
        Craft craft = CraftFactory.create("monster", player, player, planet.getOrbit(), false, false);
        planet.setSize(110);
        planet.setTeraforming(1.0);
        planet.setProductionBonus(2.0);
        planet.setReproductionBonus(1.0);
        planet.setResearchBonus(1.0);
        planet.setMoneyBonus(0);
        planet.setHasNatives(false);
    }
}