/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.setup;

import mot.common.resources.ResourceAntiMatter;
import mot.common.resources.ResourceBoralium;
import mot.common.resources.ResourceCloakPalm;
import mot.common.resources.ResourceEnergySpores;
import mot.common.resources.ResourcePsiFungus;
import mot.common.resources.ResourceTritanOre;
import mot.common.resources.ResourceWarpCrystal;
import mot.common.util.ApplicationError;
import mot.common.util.Utils;
import mot.engine.planets.Planet;

/**
 * Resources are scare sources of bonuses that if located in a player's empire bestow empire wide
 * benefits to the owner.
 */
public class ResourceFactory {

    public ResourceFactory() {
    }

    /**
     * Assigns a random resource to the planet.
     * @param planet The planet to be assigned a resource.
     */
    public static  void createResource(Planet planet) throws ApplicationError {
        int r = Utils.random(7);
        if (r == 0) {
            planet.setResource(new ResourceAntiMatter());
        } else if (r == 1) {
            planet.setResource(new ResourceCloakPalm());
        } else if (r == 2) {
            planet.setResource(new ResourcePsiFungus());
        } else if (r == 3) {
            planet.setResource(new ResourceTritanOre());
        } else if (r == 4) {
            planet.setResource(new ResourceWarpCrystal());
        } else if (r == 5) {
            planet.setResource(new ResourceBoralium());
        } else if (r == 6) {
            planet.setResource(new ResourceEnergySpores());
        }
    }


}