/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.setup;

import mot.common.bean.PlayerAiSettings;
import mot.common.setup.RaceOptions;
import mot.common.util.ApplicationError;
import mot.engine.players.PlayerCharacter;

/**
 * This is a PlayerCharacter that is used only while creating a new instances of a game
 * Restricted use of Player Character in MotFactory!
 */
public class SetupPlayerCharacter extends PlayerCharacter {
	/**
	 * Contains the set of options used to generate this character
	 * (when the map was originally created).
	 * NOTE - These are only stored in the character while generating a new game. They are not saved
	 * and this value will usually be null. It is only set to avoid reloading the options for this player.
	 */
	public transient RaceOptions raceOptions;
    
	public SetupPlayerCharacter(String myName, RaceOptions options, Double level, PlayerAiSettings playerAiSettings, String [] playerNames) throws ApplicationError {
        super(myName, options, level, playerAiSettings, playerNames);
        this.raceOptions = options;
    }

    /**
     * We only use SetupPlayerCharacter while creating a new game so we do not persist its details.
     * @return Returns the name of the super class of this class. We do not want to save this class.
     */
    protected String getClassAttribute() {
        return getClass().getSuperclass().getName();
    }

}