/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.technology;

import mot.common.technology.TechnologyBundle;
import mot.common.technology.Weapon;
import mot.common.technology.WeaponBayDetails;
import mot.common.util.ApplicationError;

public class WeaponInstanceFactory  {

    public static WeaponInstance create(Weapon weapon, int qty, boolean heavy, boolean infiniteShots, WeaponBayDetails weaponBayDetails) throws ApplicationError {
        String group = weapon.getGroup();
        if (group == null || group.equals(Weapon.GROUP_BEAM) || group.equals(Weapon.GROUP_PROJECTILE)) {
            return new WeaponInstanceBeam(weapon, qty, heavy, infiniteShots, weaponBayDetails);
        } else if (group.equals(Weapon.GROUP_MISSILE)) {
            return new WeaponInstanceMissile(weapon, qty, heavy, infiniteShots);
        } else if (group.equals(Weapon.GROUP_GIRATOR)) {
            return new WeaponInstanceGirator(weapon,qty, heavy, infiniteShots, weaponBayDetails);
        } else if (group.equals(Weapon.GROUP_IMMOBILISER)) {
            return new WeaponInstanceImmobiliser(weapon, qty, heavy, infiniteShots, weaponBayDetails);
        } else if (group.equals(Weapon.GROUP_PSI)) {
            return new WeaponInstancePsi(weapon, qty, heavy, infiniteShots, weaponBayDetails);
        } else if (group.equals(Weapon.GROUP_TRANSPORT)) {
            return new WeaponInstanceTransport(weapon, qty, heavy, infiniteShots, weaponBayDetails);
        } else if (group.equals(Weapon.GROUP_DETONATOR)) {
            return new WeaponInstanceDetonator(weapon, qty, heavy, infiniteShots, weaponBayDetails);
        } else if (group.equals(Weapon.GROUP_TROOP_TRANSPORT)) {
            return new WeaponInstanceTroopTransport(weapon, qty, heavy, infiniteShots, weaponBayDetails);
        } else if (group.equals(Weapon.GROUP_BIO)) {
            return new WeaponInstanceBio(weapon, qty, heavy, infiniteShots, weaponBayDetails);
        } else if (group.equals(Weapon.GROUP_SPACIAL_DESTORTION)) {
            return new WeaponInstanceSpacialDistortion(weapon, qty, weaponBayDetails);
        } else if (group.equals(Weapon.GROUP_PLAGUE)) {
            return new WeaponInstancePlague(weapon, qty, weaponBayDetails);
        } else if (group.equals(Weapon.GROUP_TIME_WARP)) {
            return new WeaponInstanceTimeWarp(weapon);
        } else if (group.equals(Weapon.GROUP_TIME_WARP_BEAM)) {
            return new WeaponInstanceTimeWarpBeam(weapon);
        } else if (group.equals(Weapon.GROUP_DAMAGE_BOT)) {
            return new WeaponInstanceDamageBot(weapon, qty, weaponBayDetails);
        } else if (group.equals(Weapon.GROUP_MIND_CONTROL)) {
            return new WeaponInstanceMindControl(weapon, qty, weaponBayDetails);
        } else if (group.equals(Weapon.GROUP_BERSERKER)) {
            return new WeaponInstanceMindControlBerserker(weapon, qty, weaponBayDetails);
        } else if (group.equals(Weapon.GROUP_COWARDICE)) {
            return new WeaponInstanceMindControlCowardice(weapon, qty, weaponBayDetails);
        } else if (group.equals(Weapon.GROUP_DROID_MINE)) {
            return new WeaponInstanceDroidMine(weapon, qty, infiniteShots, weaponBayDetails);
        } else if (group.equals(Weapon.GROUP_RETARGET)) {
            return new WeaponInstanceRetarget(weapon, qty, infiniteShots, weaponBayDetails);
        } else if (group.equals(Weapon.GROUP_SALVAGE_BEAM)) {
            return new WeaponInstanceSalvageBeam(weapon, qty, infiniteShots, weaponBayDetails);
        } else if (group.equals(Weapon.GROUP_REPLICA_BEAM)) {
            return new WeaponInstanceReplicaBeam(weapon, weaponBayDetails);
        } else if (group.equals(Weapon.GROUP_SHIELD_BURST)) {
            return new WeaponInstanceShieldBurst(weapon, weaponBayDetails);
        } else if (group.equals(Weapon.GROUP_TELEPORT)) {
            return new WeaponInstanceTeleporter(weapon, weaponBayDetails);
        } else if (group.equals(Weapon.GROUP_SLEEP)) {
            return new WeaponInstanceSleep(weapon, qty, weaponBayDetails);
        } else if (group.equals(Weapon.GROUP_PULSE)) {
            return new WeaponInstancePulse(weapon, qty, weaponBayDetails);
        } else {
            return new WeaponInstanceBeam(weapon, qty, heavy, infiniteShots, weaponBayDetails);
        }
    }

    public static WeaponInstance create(TechnologyBundle bundle, boolean heavy, boolean infiniteShots, WeaponBayDetails weaponBayDetails) throws ApplicationError {
        String group = bundle.getTechnology().getGroup();
        if (group == null || group.equals(Weapon.GROUP_BEAM) || group.equals(Weapon.GROUP_PROJECTILE)) {
            return new WeaponInstanceBeam((Weapon)bundle.getTechnology(), bundle.getQty(), heavy, infiniteShots, weaponBayDetails);
        } else if (group.equals(Weapon.GROUP_MISSILE)) {
            return new WeaponInstanceMissile((Weapon)bundle.getTechnology(), bundle.getQty(), heavy, infiniteShots);
        } else if (group.equals(Weapon.GROUP_SHIELD_DRAIN)) {
            return new WeaponInstanceShieldDrain((Weapon)bundle.getTechnology(), bundle.getQty(), heavy, infiniteShots, weaponBayDetails);
        } else if (group.equals(Weapon.GROUP_GIRATOR)) {
            return new WeaponInstanceGirator((Weapon)bundle.getTechnology(), bundle.getQty(), heavy, infiniteShots, weaponBayDetails);
        } else if (group.equals(Weapon.GROUP_IMMOBILISER)) {
            return new WeaponInstanceImmobiliser((Weapon)bundle.getTechnology(), bundle.getQty(), heavy, infiniteShots, weaponBayDetails);
        } else if (group.equals(Weapon.GROUP_PSI)) {
            return new WeaponInstancePsi((Weapon)bundle.getTechnology(), bundle.getQty(), heavy, infiniteShots, weaponBayDetails);
        } else if (group.equals(Weapon.GROUP_TRANSPORT)) {
            return new WeaponInstanceTransport((Weapon)bundle.getTechnology(), bundle.getQty(), heavy, infiniteShots, weaponBayDetails);
        } else if (group.equals(Weapon.GROUP_DETONATOR)) {
            return new WeaponInstanceDetonator((Weapon)bundle.getTechnology(), bundle.getQty(), heavy, infiniteShots, weaponBayDetails);
        } else if (group.equals(Weapon.GROUP_TROOP_TRANSPORT)) {
            return new WeaponInstanceTroopTransport((Weapon)bundle.getTechnology(), bundle.getQty(), heavy, infiniteShots, weaponBayDetails);
        } else if (group.equals(Weapon.GROUP_BIO)) {
            return new WeaponInstanceBio((Weapon)bundle.getTechnology(), bundle.getQty(), heavy, infiniteShots, weaponBayDetails);
        } else if (group.equals(Weapon.GROUP_SPACIAL_DESTORTION)) {
            return new WeaponInstanceSpacialDistortion((Weapon)bundle.getTechnology(), bundle.getQty(), weaponBayDetails);
        } else if (group.equals(Weapon.GROUP_PLAGUE)) {
            return new WeaponInstancePlague((Weapon)bundle.getTechnology(), bundle.getQty(), weaponBayDetails);
        } else if (group.equals(Weapon.GROUP_TIME_WARP)) {
            return new WeaponInstanceTimeWarp((Weapon)bundle.getTechnology());
        } else if (group.equals(Weapon.GROUP_TIME_WARP_BEAM)) {
            return new WeaponInstanceTimeWarpBeam((Weapon)bundle.getTechnology());
        } else if (group.equals(Weapon.GROUP_DAMAGE_BOT)) {
            return new WeaponInstanceDamageBot((Weapon)bundle.getTechnology(), bundle.getQty(), weaponBayDetails);
        } else if (group.equals(Weapon.GROUP_MIND_CONTROL)) {
            return new WeaponInstanceMindControl((Weapon)bundle.getTechnology(), bundle.getQty(), weaponBayDetails);
        } else if (group.equals(Weapon.GROUP_BERSERKER)) {
            return new WeaponInstanceMindControlBerserker((Weapon)bundle.getTechnology(), bundle.getQty(), weaponBayDetails);
        } else if (group.equals(Weapon.GROUP_COWARDICE)) {
            return new WeaponInstanceMindControlCowardice((Weapon)bundle.getTechnology(), bundle.getQty(), weaponBayDetails);
        } else if (group.equals(Weapon.GROUP_DROID_MINE)) {
            return new WeaponInstanceDroidMine((Weapon)bundle.getTechnology(), bundle.getQty(), infiniteShots, weaponBayDetails);
        } else if (group.equals(Weapon.GROUP_RETARGET)) {
            return new WeaponInstanceRetarget((Weapon)bundle.getTechnology(), bundle.getQty(), infiniteShots, weaponBayDetails);
        } else if (group.equals(Weapon.GROUP_SALVAGE_BEAM)) {
            return new WeaponInstanceSalvageBeam((Weapon)bundle.getTechnology(), bundle.getQty(), infiniteShots, weaponBayDetails);
        } else if (group.equals(Weapon.GROUP_REPLICA_BEAM)) {
            return new WeaponInstanceReplicaBeam((Weapon)bundle.getTechnology(), weaponBayDetails);
        } else if (group.equals(Weapon.GROUP_SHIELD_BURST)) {
            return new WeaponInstanceShieldBurst((Weapon)bundle.getTechnology(), weaponBayDetails);
        } else if (group.equals(Weapon.GROUP_TELEPORT)) {
            return new WeaponInstanceTeleporter((Weapon)bundle.getTechnology(), weaponBayDetails);
        } else if (group.equals(Weapon.GROUP_SLEEP)) {
            return new WeaponInstanceSleep((Weapon)bundle.getTechnology(), bundle.getQty(), weaponBayDetails);
        } else if (group.equals(Weapon.GROUP_PULSE)) {
            return new WeaponInstancePulse((Weapon)bundle.getTechnology(), bundle.getQty(), weaponBayDetails);
        } else {
            return new WeaponInstanceBeam((Weapon)bundle.getTechnology(), bundle.getQty(), heavy, infiniteShots, weaponBayDetails);
        }
    }

}