/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.technology;

import mot.common.bean.Location;
import mot.common.lang.L;
import mot.common.technology.TechnologyBundle;
import mot.common.technology.Weapon;
import mot.common.technology.WeaponBayDetails;
import mot.common.util.ApplicationError;
import mot.common.util.Formatter;
import mot.common.util.Logger;
import mot.engine.MotEngine;
import mot.engine.battles.BattleObject;
import mot.engine.battles.BattlePlanet;
import mot.engine.event.BattleWeaponFireEF;

public class WeaponInstanceGirator extends WeaponInstance {

    public WeaponInstanceGirator(TechnologyBundle tb, boolean heavy, boolean infiniteShots, WeaponBayDetails weaponBayDetails) {
        super(tb, heavy, infiniteShots, weaponBayDetails);
    }

    public WeaponInstanceGirator(Weapon weapon, int qty, boolean heavy, boolean infiniteShots, WeaponBayDetails weaponBayDetails) {
        super(weapon, qty, heavy, infiniteShots, weaponBayDetails);
    }

	/**
     * Fires this Girator weapon located on the source craft at the target craft.
     * This causes damage by this weapon to be inflicted on the target by passing all shields.
     *
     * @param source The craft firing this weapon
     * @param target The craft this weapon is being fired at.
     * @param qtyToFire The quantity of weapons in this weapon instance to fire.
     * @throws mot.common.util.ApplicationError
	 */
	public void fire(BattleObject source, BattleObject target, int qtyToFire) throws ApplicationError {
		dirty = true;
		
		if (handleEncumbants(source, target, qtyToFire)) {
			return;
		}
		
        boolean imune = isImune(target) || target instanceof BattlePlanet ;

        qtyToFire = updateQtyFired(qtyToFire, true);
        
        double damage = 0.0;
        if (!imune) {
            damage = getDamage(source, target);
            if (damage <= 0.0)  {
            	damage = 0.0;
            	imune = true;
            } else {
            	damage = damage*qtyToFire;
            }
        }

        if (Logger.isDebug()) {
            Logger.logDebug("Girator.fire() "+source.getName()+" fires "+weapon.getName()+"X"+qtyToFire+" at "+target.getName()+" damage="+damage);
        }

        String damageDescription = Formatter.getDamageDescription(damage, 0.0);
        BattleWeaponFireEF event = new BattleWeaponFireEF(source, target, getWeapon(), damage, 0.0, null, damageDescription, false, source.getCraftState(), target.getCraftState(), null, null);
        MotEngine.instance.getProxyManager().scheduleMulticast(event, source.getBattle().getStartingUserPlayers());

        if (damage > 0.0) {
            target.damage(damage, source.getOwner(), target.getCraftState(), null);
        }

        event.setNewTargetState(target.getCraftState());
        event.setDestroyed(target.isDestroyed());
        if (imune) event.setTargetDescription(weapon.getName() + " " + L.IMMUNE);
        MotEngine.instance.getProxyManager().sendScheduledEvent(event);
    }

	public void fire(BattleObject source, Location target, int qtyToFire) { }
	public boolean canMiss() { return false; }
	public boolean canAttackLocationAndHasCharge() { return false; }

}