/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.technology;

import mot.common.bean.Location;
import mot.common.technology.TechnologyBundle;
import mot.common.technology.Weapon;
import mot.common.util.ApplicationError;
import mot.engine.MotEngine;
import mot.engine.battles.Automaton;
import mot.engine.battles.Battle;
import mot.engine.battles.BattleCraft;
import mot.engine.battles.BattleObject;
import mot.engine.battles.Missiles;
import mot.engine.event.BattleMissileLaunchEF;

public class WeaponInstanceMissile extends WeaponInstance {

    public WeaponInstanceMissile(TechnologyBundle tb, boolean heavy, boolean infiniteShots) {
        super(tb, heavy, infiniteShots, null);
    }

    public WeaponInstanceMissile(Weapon weapon, int qty, boolean heavy, boolean infiniteShots) {
        super(weapon, qty, heavy, infiniteShots, null);
    }

	/**
	 * This method fires this missile from the source craft at the target craft. The quantity 
     * of shots this weapon has used is increased by one and the weapon is discharged.
     * If the target is out of range or is an Automaton then no action is taken.
     * 
     * Once the missile has been launched a MissileLaunchEvent is sent to all players proxies.
     * 
     * @param source The craft firing this weapon
     * @param target The craft this weapon is being fired at.
     * @param qtyToFire Ignored. All missiles are always fired.
     * @throws mot.common.util.ApplicationError
	 */
	public void fire(BattleObject source, BattleObject target, int qtyToFire) throws ApplicationError {
		dirty = true;
		
		// check we are in range
		int distance = source.getLocation().getDistanceTo( target.getLocation() );
		if (distance > getRange()) {
            return;
        }
        if (target instanceof Automaton) {
            return;
        }
        
        qtyToFire = updateQtyFired(qtyToFire, true);
                
        Battle battle = source.getBattle();
        Missiles missiles = null;
        if (target instanceof BattleCraft) {
            missiles = new Missiles(source, target, this, target);
            target.add(missiles);
        } else {
            missiles = new Missiles(source, target, this, null);
        }
        battle.add(missiles);
        MotEngine.instance.multicast( new BattleMissileLaunchEF(missiles), battle.getStartingUserPlayers() );
    }
	
	public void fire(BattleObject source, Location target, int qtyToFire) { }
	public boolean canAttackLocationAndHasCharge() { return false; }

	public boolean usesWeaponBayFireAngle() { return false;	}

}