/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.technology;

import mot.common.bean.Location;
import mot.common.lang.L;
import mot.common.technology.TechnologyBundle;
import mot.common.technology.Weapon;
import mot.common.technology.WeaponBayDetails;
import mot.common.util.ApplicationError;
import mot.common.util.Logger;
import mot.engine.MotEngine;
import mot.engine.battles.Battle;
import mot.engine.battles.BattleCraft;
import mot.engine.battles.BattleObject;
import mot.engine.battles.CraftStateFactory;
import mot.engine.battles.triggers.Sleep;
import mot.engine.battles.triggers.Triggers;
import mot.engine.event.BattleWeaponFireEF;
import mot.engine.players.Player;

public class WeaponInstanceSleep extends WeaponInstance {

	public WeaponInstanceSleep(TechnologyBundle tb, WeaponBayDetails weaponBayDetails) {
        super(tb, false, false, weaponBayDetails);
    }

	public WeaponInstanceSleep(Weapon weapon, int qty, WeaponBayDetails weaponBayDetails) {
        super(weapon, qty, false, false, weaponBayDetails);
    }

	public void fire(BattleObject source, BattleObject target, int qtyToFire) throws ApplicationError {
		dirty = true;
		
		if (handleEncumbants(source, target, qtyToFire)) {
			return;
		}
		
		if (handleShields(source, target, qtyToFire)) {
			return;
		}
		
        boolean imune = isImune(target);
        String damageDescription = getDefaultFailMessage();
        
        CraftStateFactory originalTargetState = target.getCraftState();

        qtyToFire = updateQtyFired(qtyToFire, true);
        
        if (imune || !(target instanceof BattleCraft)) {
        	damageDescription = weapon.getName() + " " + L.IMMUNE;
        } else {
    		BattleCraft targetCraft = (BattleCraft) target;
        	double crewToSleep = getDamage(source, false) * qtyToFire;
        	int qtyCrew = targetCraft.getCrew();
    		if (crewToSleep > qtyCrew) {
    			damageDescription = null;
    			Player owner = source.getOwner();
				Battle battle = targetCraft.getBattle();
				Triggers triggers = battle.getTriggersNotNull();
				Sleep trigger = (Sleep) triggers.getBattleObjectTriggerOn(target, Sleep.class);
				if (trigger != null) {
					trigger.setQtyTurnsToMiss(trigger.getQtyTurnsToMiss()+qtyToFire);
				} else {
					trigger = new Sleep(source.getOwner(), battle, targetCraft, qtyToFire);
					battle.getTriggers().add(trigger);
				}
				targetCraft.getDecorators().update();
				if (targetCraft.getMoveRemaining() > 0.0 || targetCraft.hasWeaponsToFire()) {
					targetCraft.setMoveRemaining(0.0);
					targetCraft.dischargeWeapons();
					trigger.increaseQtyTurnsMissed(1);
				}
    		}
        }

        if (Logger.isDebug()) {
            Logger.logDebug(weapon.getName()+".fire() "+source.getName()+" fires "+weapon.getName()+"X"+qtyToFire+" at "+target.getName()+" success="+damageDescription);
        }

        BattleWeaponFireEF event = new BattleWeaponFireEF(source, target, getWeapon(), 0.0, 0.0, null, damageDescription, false, source.getCraftState(), originalTargetState, null, target.getCraftState());
        MotEngine.instance.multicast( event, source.getBattle().getStartingUserPlayers() );
    }
	
	public void fire(BattleObject source, Location target, int qtyToFire) { }
	public boolean canAttackLocationAndHasCharge() { return false; }
}
