/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.technology;

import mot.common.bean.Location;
import mot.common.technology.Weapon;
import mot.common.util.ApplicationError;
import mot.engine.MotEngine;
import mot.engine.battles.BattleCraft;
import mot.engine.battles.BattleObject;
import mot.engine.event.BattleWeaponFireEF;

/**
 * This is a weapon that sends this craft back in time to start its turn again. This weapon
 * should be used at the end of a turn (after the craft has fired and moved). When this weapon
 * fires it will recharge all other weapons and set move remaining to 1.0 so the craft can move 
 * again. This allows the craft to move twice in a single turn.
 * 
 * A craft can only have a single instance of this weapon.
 */
public class WeaponInstanceTimeWarp extends WeaponInstance {
	
	private boolean hasFiredTimeWarpThisCommand = false;
	
    public WeaponInstanceTimeWarp(Weapon weapon) {
        super(weapon, 1, false, false, null);
    }
    
	public boolean notifyStartCommand() {
		hasFiredTimeWarpThisCommand = false;
        return false;
	}

	public boolean hasFiredTimeWarpThisCommand() {
		return hasFiredTimeWarpThisCommand;
	}

	public void fire(BattleObject source, BattleObject target, int qtyToFire) throws ApplicationError {
		dirty = true;
		
		if (source instanceof BattleCraft) {
			BattleCraft bc = (BattleCraft) source;
			bc.setMoveRemaining(1.0);
		}
		source.rechargeWeapons();
        discharge();
        qtyShots++;
        BattleWeaponFireEF event = new BattleWeaponFireEF(source, target, getWeapon(), 0.0, 0.0, null, "", false, source.getCraftState(), null, null, null);
        MotEngine.instance.multicast( event, source.getBattle().getStartingUserPlayers() );
        hasFiredTimeWarpThisCommand = true;
	}
	
	public void fire(BattleObject source, Location target, int qtyToFire) throws ApplicationError { 
		fire(source, (BattleObject)null, qtyToFire);
	}
	
	public boolean canAttackLocationAndHasCharge() { 
		return hasWeaponsToFire(); 
	}

    public boolean inRange(BattleObject source, Location loc) {
    	return true;
    }
    
	public boolean canMiss() {
		return false;
	}

}
