/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.trace;

import java.util.ArrayList;
import java.util.Iterator;

import mot.common.util.ApplicationError;
import mot.common.xml.XMLBean;
import mot.common.xml.XMLWriter;
import mot.engine.command.Command;

/**
 * This class 
 */
public class Trace extends XMLBean {

    /**
     * This is the seed the game was started with.
     * In order to reproduce a game we need to know the seed the random number 
     * generator was started with so random events re-produce the same outcomes.
     */
    private long seed;
    
    /**
     * This is the list of commands that was issued to this trace to reach the 
     * final state.
     * See the package mot.proxy.command for details.
     */
    private ArrayList commands = new ArrayList();

    public Trace(long seed) {
        this.seed = seed;
    }
    
    public void add(Command command) {
        commands.add(command);
    }

    protected void encode(XMLWriter writer) throws ApplicationError {
        writer.addElement("seed", seed);
        Iterator i = commands.iterator(); 
        while (i != null && i.hasNext()) {
            Command c = (Command) i.next();
            //c.toXML(writer);
        }
    }
    
    protected String getElementName() { return "trace"; }
}