/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.transports;

import mot.common.util.ApplicationError;
import mot.common.util.BasicNameValueList;
import mot.common.util.NameValuePair;
import mot.common.xml.XMLWriter;
import mot.engine.MotEngine;
import mot.engine.common.MoveableOwnedObject;
import mot.engine.common.MoveableOwnedObjectReference;

public class TransportReference extends MoveableOwnedObjectReference {

	private transient Transport transport;

	public Transport getTransport() {
		if (transport == null) {
			transport = MotEngine.instance.getPlayers().getTransport(getName());
		}
		return transport;
	}

	public void setTransport(Transport v) {
		transport = v;
		setName(transport.getName());
	}

	public TransportReference() {
	}

	public TransportReference(Transport craft) {
		super(craft.getName());
		this.transport = craft;
	}

	protected void encode(XMLWriter writer) throws ApplicationError {
		// does not have a bean body
	}

    protected BasicNameValueList getAttributes(boolean generateClassAttribute, boolean generateSchemaAttribute) throws ApplicationError {
		if (getTransport() == null) {
			return null;
		}

		BasicNameValueList params = getAttributesNotNull(generateClassAttribute);
		params.add( new NameValuePair("name", getName()) );

		return params;
	}

	protected String getElementName() { return "transport-reference"; }
    protected boolean beanHasBody() { return false; }

	public MoveableOwnedObject getObject() {
		return getTransport();
	}
}