/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.transports;

import java.util.ArrayList;
import java.util.Iterator;

/**
 * This is a list of transports. This may be used for a player to maintain a list of discovered 
 * transports for the eng game engine to maintain a list of all transports defined in the system.
 */
public class Transports {

	private ArrayList list = null;
    private transient Transport [] transports = null;

    
    public Transports() {
    }

    public Transports(Transport w) {
        add(w);
    }

    /**
     * Adds a new transport to this list of transports.
     * @param v The new transport to add.
     */
	public void add(Transport v) {
        if (v == null) return;
		if (list == null) list = new ArrayList();
		list.add(v);
	}
    
    /**
     * @return The shield in the list
     */
    public Transport [] getTransports() {
        if (transports == null) {
			if (list == null) return null;
            transports = new Transport[list.size()];
			Iterator i = list.iterator();
            int index = 0;
			while (i.hasNext()) {
                Transport v = (Transport) i.next();
                transports[index++] = v;
			}
		}
        return transports;
	}
    
    public int getQuantity() {
        if (list == null) {
            return 0;
        } else {
            return list.size();
        }
    }

    protected String getElementName() { return "transports"; }

    public Transport getBestTransport() {
        getTransports();
        if (transports == null) {
            return null;
        } else {
            return transports[transports.length-1];
        }
	}

    public void setTransport(Transport v) {
        add(v);
    }

    public Transport getTransportAtIndex(int index) {
        getTransports();
        if (transports == null) {
            return null;
        } else {
            return transports[index];
        }
    }
}