/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.engine.validators;

import java.io.File;

import mot.common.util.ApplicationError;
import mot.common.util.PropertyManager;
import mot.common.util.ValidationError;

public class SavedGameFileNameValidator {

    public static final String SAVES_FOLDER = PropertyManager.getMandatoryNoError("directory.save");
    public static final String SAVED_GAME_EXTENSION = PropertyManager.getMandatoryNoError("saved.game.extension");

    public static File getSavesFolder() throws ApplicationError {
		File folder = new File(SAVES_FOLDER);
        if (folder.exists() && !folder.isDirectory()) {
            throw new ApplicationError("Unable to locate folder to save games ["+SAVES_FOLDER+"]");
        }
        if (!folder.exists()) {
       		folder.mkdir();
        }
        return folder;
    }

    public static File validate(String fileName, boolean mustExist) throws ValidationError, ApplicationError {
        if (fileName == null || fileName.length() == 0) {
            throw new ValidationError("You must enter a file name");
        }
        int extensionIndex = fileName.indexOf('.');
        if (extensionIndex == 0) {
            throw new ValidationError("You must enter a file name");
        }
        if (fileName.indexOf('/') >= 0 || fileName.indexOf('\\') >= 0 || fileName.indexOf(':') >= 0) {
            throw new ValidationError("Your save file not not contain any path elements");
        }
        if (fileName.substring(extensionIndex+1).indexOf('.') >= 0) {
            throw new ValidationError("Can only have a single . character");
        }
        getSavesFolder();
		String name = SAVES_FOLDER + fileName;
        if (!fileName.endsWith(SAVED_GAME_EXTENSION)) {
            name += SAVED_GAME_EXTENSION;
        }
        File file = new File(name);
		if (mustExist && !file.exists()) {
            throw new ValidationError("File "+fileName+" does not exist");
		}
		return file;
	}
	
}
