/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.mp;

import java.io.IOException;
import java.net.ServerSocket;
import java.net.Socket;

import mot.client.proxy.RemoteConnectionServerProxy;
import mot.common.coms.protocols.MotSocket;
import mot.common.util.ApplicationError;
import mot.common.util.Logger;
import mot.common.util.PropertyManager;
import mot.engine.RequestHandler;
import mot.engine.SocketHandlerThreadEngine;

public class ServerSocketThread extends Thread implements RemoteConnectionServerProxy {

	public static ServerSocketThread instance;
	
    private ServerSocket socket;
	private RequestHandler requestHandler;
	
	private boolean running = false;

    public ServerSocketThread() throws ApplicationError, IOException {
    	super("ServerSocketThread");
    	instance = this;
    }
    
	public void setRequestHandler(RequestHandler requestHandler) throws ApplicationError {
		this.requestHandler = requestHandler;
        String portString = PropertyManager.getMandatory("server.port");
        int port = Integer.parseInt(portString);
        try {
			socket = new ServerSocket(port);
		} catch (IOException e) {
			Logger.logError("Unable to create server socket", e);
			throw new ApplicationError(e.toString());
		}
    }
	

    public synchronized void start() {
    	if (running) return;
    	running = true;
    	super.start();
    }

    public void run() {
        while (running) {
            try {
                Socket client = socket.accept();
                Logger.logInfo("MainThread.run() receive client connection from "+client.getRemoteSocketAddress().toString());
                new SocketHandlerThreadEngine(new MotSocket(client), requestHandler).start();
            } catch (Exception e) {
                Logger.logError("Failure", e);
            }
        }
    }

	@Override
	public boolean isListeningForConnections() {
		return running;
	}

	@Override
	public void stopListingForConnections() {
		running = false;
	}

	@Override
	public void startListingForConnections() {
		start();
	}

}