/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.test;

import mot.client.proxy.ProxyStore;
import mot.client.swing.window.main.MainWindow;
import mot.common.designs.CraftDesign;
import mot.common.designs.Orbital;
import mot.common.technology.Engine;
import mot.common.technology.Hull;
import mot.common.technology.Module;
import mot.common.technology.Modules;
import mot.common.technology.Scanner;
import mot.common.technology.Scanners;
import mot.common.technology.Technologies;
import mot.common.technology.Weapon;
import mot.common.technology.Weapons;
import mot.common.util.ApplicationError;
import mot.common.util.ValidationError;
import mot.engine.MotEngine;
import mot.engine.crafts.Fleet;
import mot.engine.planets.Planet;
import mot.engine.planets.SolarSystem;
import mot.engine.players.ComputerPlayer;
import mot.engine.players.UserPlayer;


public class BattleGraphicsTest extends TestBase  {

	public BattleGraphicsTest(String name) {
		super(name);
	}

	public void runInGame(MotEngine engine, MainWindow mainWindow) throws ApplicationError, ValidationError {
		UserPlayer p1 = engine.getPlayers().getUserPlayers()[0];
		ComputerPlayer p2 = engine.getPlayers().getComputerPlayers()[0];
		engine.getRelations().setWar(p1, p2);
		
		SolarSystem ss = newSolarSystem("TestSS", 500, 500);
		Planet p = newPlanet("TestSS-A", ss, p1, 100, 1.0);

		Hull defender45 = Technologies.getHull("Defender45");
		Hull defender75 = Technologies.getHull("Defender75");
		Engine fusion40 = Technologies.getEngine("Fusion40");
		Weapon fusionBeam = Technologies.getWeapon("FusionBeam");
		Weapon detonator = Technologies.getWeapon("Detonator");
		Weapon droidMine = Technologies.getWeapon("Droid Mine");
		Weapon missile15 = Technologies.getWeapon("Missile15");
		Scanner scanner200 = Technologies.getScanner("Photon200");
		Module sentinels = Technologies.getModules().getBestSentinels();
		Hull battleStation = Technologies.getHulls().getBiggestBattleStationHull();

		p.setWeapons(new Weapons(missile15));
		p.setScanners(new Scanners(scanner200));
		
		p.setOrbital(new Orbital(battleStation, scanner200, new Modules(sentinels)));
		
		p1.addTechnology(Technologies.getSpecials().getStationFighterBays());
		p1.addTechnology(Technologies.getSpecials().getFighterBays());
		p1.addTechnology(Technologies.getMiscTechnologies().getMineField());
		p1.addTechnology(Technologies.getMiscTechnologies().getKamikaziTechnology());
		
		CraftDesign cd = new CraftDesign("Fighter", defender75, fusion40, scanner200, tech_electronic25, tech_energy20, droidMine, fusionBeam, fusionBeam, fusionBeam, fusionBeam, missile15);
		CraftDesign cd_suicide = new CraftDesign("Suicide", defender45, fusion40, scanner200, tech_electronic25, tech_energy10, droidMine, detonator);

        Fleet fleet1 = newFleet(p1, p, cd, 2);
        Fleet fleet2 = newFleet(p2, p, cd, 1, cd_suicide, 3);
        fleet2.attack(p);
        
        ProxyStore.getInstance().endTurnCmd(null, mainWindow);
	}

}
