/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.test;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;
import mot.common.util.Logger;

public class GameTest extends TestCase {
    public GameTest() {
    }

    /**
     * Need this or run like - java junit.textui.TestRunner ShoppingCartTest
     */
    public static void main(String args[]) {
        Logger.clearContents();
        Logger.setInMemory(false);
        junit.textui.TestRunner.run(suite());
    }

    public static Test suite() {
        TestSuite suite = new TestSuite();

        suite.addTest(TechnologyTest.suite());
        suite.addTest(TechnologyTreeTest.suite());
        suite.addTest(GeometryTest.suite());
        suite.addTest(NameGeneratorTest.suite());
        suite.addTest(GalaxyTest.suite());
        suite.addTest(RelationsTest.suite());
        suite.addTest(CraftTest.suite());
        suite.addTest(PrizeTest.suite());
        suite.addTest(GiftTest.suite());
        suite.addTest(GeneralTest.suite());
        suite.addTest(AncientsTest.suite());
        suite.addTest(KaanTest.suite());
        suite.addTest(TransportTest.suite());
        suite.addTest(PlanetsTest.suite());
        suite.addTest(PlanetTest.suite());
        suite.addTest(PlayerTest.suite());
        suite.addTest(MayorTest.suite());
        suite.addTest(StratagistTest.suite());
        suite.addTest(BankerAndTradeTest.suite());
        suite.addTest(SpyTest.suite());
        suite.addTest(CraftDesignTest.suite());
        suite.addTest(MoneyTest.suite());
        suite.addTest(BattleStationFactoryTest.suite());
        suite.addTest(BattleTest.suite());
        suite.addTest(BattleCommandTest.suite());
        suite.addTest(BattleIncumbentTest.suite());
        suite.addTest(SalvageFactoryTest.suite());
        suite.addTest(TroopTransportTest.suite());
        suite.addTest(SetupTest.suite());
        suite.addTest(LeaderTest.suite());
        suite.addTest(ResourceTest.suite());
        suite.addTest(InfluenceTest.suite());
        suite.addTest(MoralChoiceTest.suite());
        suite.addTest(SaveLoadTest.suite());
        suite.addTest(DeligateGalaxyTest.suite());
        suite.addTest(DeligateBattleTest.suite());
        suite.addTest(SerialisabilityTest.suite());
        suite.addTest(AnimationTest.suite());
        suite.addTest(GalaxyEditorTest.suite());
        suite.addTest(ResearchTest.suite());
        suite.addTest(ResearchTestOnLiveXML.suite());
        return suite;
    }

    
    protected void tearDown() throws Exception {
    	super.tearDown();
    }
 
}