/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.test;

import java.util.ArrayList;

import junit.framework.Test;
import junit.framework.TestSuite;
import mot.client.deligates.ComputerPlayerDelegate;
import mot.client.deligates.UserPlayerDelegate;
import mot.client.deligates.cache.DeligateCacheManager;
import mot.client.event.MotEventConsumer;
import mot.client.proxy.CompletedClientCallbackSyncroniser;
import mot.client.proxy.MotServerProxy;
import mot.client.proxy.ProxyStore;
import mot.client.swing.window.main.MainWindow;
import mot.client.swing.window.main.TestGalaxyWindowConfig;
import mot.common.event.LinkedEventBase;
import mot.common.event.MotEvent;
import mot.common.setup.SetupOption;
import mot.common.util.ApplicationError;
import mot.common.util.Logger;
import mot.common.util.ValidationError;
import mot.engine.MotEngine;
import mot.engine.planets.Planet;
import mot.engine.planets.SolarSystem;
import mot.engine.players.ComputerPlayer;
import mot.engine.players.UserPlayer;

/**
 * This test harness tests that players can use spies to steal technology
 * sabotage planets and hide. It also tests that spies stationed at home
 * find an kill enemy spies.
 */

public class MultiPlayerTest extends TestBase {

    private static final String REMOTE_SERVER_URL = "http://localhost:7999/main";

    public static Test suite() {
        Logger.clearContents();
        Logger.setInMemory(false);
        TestSuite suite = new TestSuite(mot.test.MultiPlayerTest.class);
        return suite;
    }

    public MultiPlayerTest(String name) {
        super(name);
    }
    
    private UserPlayer p1,p2;
    private ComputerPlayer p3;
    private SolarSystem ss1, ss2, ss3, ss4;
    private Planet h1, h2, h3, h4, h3b;

    private UserPlayerDelegate player1, player2;
    private ComputerPlayerDelegate player3;
    
    private MotEventConsumer player1EventConsumer;
    private MotEventConsumer player2EventConsumer;

	private CompletedClientCallbackSyncroniser callbackSync = new CompletedClientCallbackSyncroniser();
    
    protected void setUp() throws ApplicationError, ValidationError {
        Logger.setDebug();
        MotEngine.newInstance();
        DeligateCacheManager.flush();
        setupConfigs();
        MainWindow.__createTestMainWindow(new TestGalaxyWindowConfig());
        player1EventConsumer = new TestEventConsumer();
        player2EventConsumer = new TestEventConsumer();
       	new ProxyStore(new MotServerProxy(true, MainWindow.getExestingInstance(), player1EventConsumer));
    }
    
    protected void tearDown() throws Exception {
    	super.tearDown();
    	Logger.flushLog();
    	if (ProxyStore.hasInstance()) ProxyStore.getInstance().disconnect();
    }

    public void createMap() throws Exception {
    	createMap(null);
    }
    
    public void createMap(SetupOption option) throws Exception {
//    	DeligateCacheManager.flush();
//    	
//    	setupOneTierTechTree();
//    	
//        String [] playerNames = { "Humans", "Bears" };
//        RaceOptions options = OptionsFactory.getRaceOptions(playerNames[0]);
//        if (option != null) options.getRaceOptions().setOption(option);
//        p1 = newUserPlayer(playerNames[0], blue, null, options);
//        p2 = newPlayer(playerNames[1], green, options, playerNames);
//
//        ss1 = newSolarSystem("SS1", 100, 100);
//        h1 = newPlanet("SS1-A", ss1, p1);
//
//        ss2 = newSolarSystem("SS2", 200, 100);
//        h2 = newPlanet("SS2-A", ss2, p2);
//        
//        ss3 = newSolarSystem("SS3", 150, 100);
//        h3 = newPlanet("SS3-A", ss3, null, 100, 0.9);
//        
//        ss4 = newSolarSystem("SS4", 50, 100);
//        
//        // Events for p1 will come through the server connection (MotEventHandler interface)
//        // while events for p2 will come directly from the server (ClientProxy interface).
//        owner = p2;
//
//        serverProxy = (MotServerProxy) ProxyStore.getInstance();
//        CompletedServerCallbackSyncroniser callback = new CompletedServerCallbackSyncroniser();
//        serverProxy.register("Humans", true, callback, null);
//        callback.waitTillCompleteAndProcessCommandResponse(serverProxy);
//        
//        player1 = (UserPlayerDelegate) DeligateCacheManager.getPlayer("Humans");
//        player2 = (ComputerPlayerDelegate) DeligateCacheManager.getPlayer("Bears");
//        
//        MainWindow.getExestingInstance()._setWindowOwner(player1);
//        MainWindow.getExestingInstance().toGalaxyWindow();
//        
//        assertEquals("Player Human is correct", "Humans", player1.getName());
//        assertEquals("Player Bears is correct", "Bears", player2.getName());
//
//        PlayerDelegate [] players = (PlayerDelegate[]) order(DeligateCacheManager.getPlayers(), new PlayerDelegate [2], "Humans", "Bears");
    }

    
    /**
     * Test create new game works and that the following factions work in a game with
     * two players (one computer and one human);
     */
    public void testNewGame() throws Exception {
        Logger.logDebug("*******************************  DeligateTest.testNewGame() *************************");
//        serverProxy = (MotServerProxy) ProxyStore.getInstance();
//        Double level = new Double(1.0);
//        int qtyComputerPlayers = 1;
//        int qtyPlanets = 5;
//        int qtyNebula = 1;
//        Size galaxySize = new Size(800,800);
//        String player1Name = "Humans";
//        SetupOptions userOptions = OptionsFactory.getSetupOptions(player1Name);
//        NewGameUserPlayerData userPlayerData = new NewGameUserPlayerData(player1Name, userOptions, playerColourBlue, ANCIENT_WATER_MAN);
//        serverProxy.newGameUserPlayer(userPlayerData, null, null);
//        serverProxy._processCommandResponse();
//        NewGameDataComputerPlayerDetails[] cpd = new NewGameDataComputerPlayerDetails[1];
//        cpd[0] = new NewGameDataComputerPlayerDetails("Bears", level);
//        NewGameData gameData = new NewGameData(cpd, level, false, qtyPlanets, qtyNebula, galaxySize);
//        serverProxy.newGame(userPlayerData, gameData, null, null);
//        serverProxy._processCommandResponse();
//        player1 = (UserPlayerDelegate) DeligateCacheManager.getPlayer(player1Name);
//        assertEquals("Player Human is correct", player1Name, player1.getName());
//        
//        PlayerDelegate [] players = DeligateCacheManager.getPlayers();
//        assertEquals("Have two players", 2, players.length);
//        player2 = (ComputerPlayerDelegate) (players[1] instanceof ComputerPlayerDelegate ? players[1] : players[0]);
//
//        PlanetDelegate [] planets = DeligateCacheManager.getPlanets();
//        assertEquals("Have 6 planets players", 6, planets.length);
//
//        PlanetDelegate [] player1Planets = DeligateCacheManager.getPlanets(player1);
//        assertEquals("Have 1 planets players", 1, player1Planets.length);
//        SolarSystemDelegate player1SS = player1Planets[0].getSolarSystem();
//        assertEquals("Solar System has correct owner", player1Name, player1SS.getOwners()[0]);
//        assertEquals("Solar System has correct owner", true, player1SS.isOwnedBy(player1));
//
//        PlanetDelegate [] player2Planets = DeligateCacheManager.getPlanets(player2);
//        assertEquals("Have 1 planets players", 1, player2Planets.length);
//        SolarSystemDelegate player2SS = player1Planets[0].getSolarSystem();
//        assertEquals("Solar System has correct owner", player1Name, player2SS.getOwners()[0]);
//        assertEquals("Solar System has correct owner", true, player2SS.isOwnedBy(player1));
//
//        CraftDelegate [] player1Crafts = DeligateCacheManager.getCrafts(player1); 
//        assertEquals("Have 2 crafts", 2, player1Crafts.length);
//        assertEquals("Have 2 crafts", player1.getName(), player1Crafts[0].getOwner());
//        assertEquals("Have 2 crafts", player1SS.getName(), player1Crafts[0].getOrbit().getStellarObject());
//
//        assertEquals(false, player1.isAutomated());
//        assertEquals(true, player2.isAutomated());
//
//        Planet homePlanet = MotEngine.getInstance().getPlayersNotNull().getPlayer(player1Name).getHomePlanet();
//        assertEquals("Player has home planet", homePlanet.getName(), player1.getHomePlanet().getName());
//        
//        Nebula[] nebulae = DeligateCacheManager.getGalaxyDetails().getNebulaeAsArray();
//        assertEquals("Have 1 Nebula players", 1, nebulae.length);
//        
//        CraftDesign[] cda = player1.getCraftDesigns().getCraftDesigns();
//		assertEquals(2, cda.length);
//		assertEquals("Coloniser", cda[0].getName());
//		assertEquals("Scout", cda[1].getName());
    }


    class TestEventConsumer implements MotEventConsumer {

        private ArrayList events = new ArrayList();
        private MotEvent lastEvent;
        
		@Override
		public void process(MotEvent e, LinkedEventBase parent) throws ApplicationError, ValidationError {
	        lastEvent = e;
	        events.add(e);
		}
    	
	    
	    private void clearEvents() {
	        Logger.logDebug("DeligateTest.notify() Clear Events ");
	        events.clear();
	        lastEvent = null;
	    }

	    private MotEvent getEvent(Class c) {
	        for (int i=events.size()-1; i>=0; i--) {
	            MotEvent e = (MotEvent) events.get(i);
	            if (e.getClass() == c) {
	                return e;
	            }
	        }
	        return null;
	    }
    }
    
    public static void main(String args[]) {
        Logger.clearContents();
        junit.textui.TestRunner.run(suite());
        if (!ProxyStore.hasInstance()) {
        	try {
				ProxyStore.getInstance().disconnect();
			} catch (ApplicationError e) {
				Logger.logError("", e);
			}
        }
    }

}