/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.test;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.io.Serializable;

import junit.framework.Test;
import junit.framework.TestSuite;
import mot.common.bean.AsteroidFieldDetails;
import mot.common.bean.Damage;
import mot.common.bean.DecoratorBerserker;
import mot.common.bean.DecoratorCommandCenter;
import mot.common.bean.DecoratorCowardice;
import mot.common.bean.DecoratorDamageBot;
import mot.common.bean.DecoratorDisabled;
import mot.common.bean.DecoratorHologram;
import mot.common.bean.DecoratorList;
import mot.common.bean.DecoratorMindControl;
import mot.common.bean.DecoratorPlague;
import mot.common.bean.DecoratorSleep;
import mot.common.bean.DiplomaticProposal;
import mot.common.bean.GalaxyDetails;
import mot.common.bean.ImmunityBio;
import mot.common.bean.ImmunityGravity;
import mot.common.bean.ImmunityMindControl;
import mot.common.bean.ImmunityMoveCraft;
import mot.common.bean.ImmunityPsi;
import mot.common.bean.ImmunityReplicaBeam;
import mot.common.bean.ImmunityTroopTransport;
import mot.common.bean.Location;
import mot.common.bean.LocationAndDirection;
import mot.common.bean.MessageType;
import mot.common.bean.NameList;
import mot.common.bean.Nebula;
import mot.common.bean.NewGameData;
import mot.common.bean.NewGameDataComputerPlayerDetails;
import mot.common.bean.NewGameUserPlayerData;
import mot.common.bean.ObjectMovement;
import mot.common.bean.ObjectShift;
import mot.common.bean.ObjectTurn;
import mot.common.bean.PlayerAiSettings;
import mot.common.bean.PlayerAssets;
import mot.common.bean.PlayerCharacterBasic;
import mot.common.bean.Rectangle;
import mot.common.bean.SalvageList;
import mot.common.bean.Settings;
import mot.common.bean.Size;
import mot.common.bean.SpaceDistortionDetails;
import mot.common.bean.TroopBattleResult;
import mot.common.bean.WreckageDetails;
import mot.common.bean.stats.GameScore;
import mot.common.bean.stats.GameScoreData;
import mot.common.bean.stats.Graph;
import mot.common.bean.stats.GraphState;
import mot.common.command_delegates.AbandonCmdDeligate;
import mot.common.command_delegates.AcceptLeaderCmdDeligate;
import mot.common.command_delegates.AcceptMoralChoiceCmdDeligate;
import mot.common.command_delegates.AddCraftDesignDeligate;
import mot.common.command_delegates.BattleAttackCmdDeligate;
import mot.common.command_delegates.BattleAttackLocationCmdDeligate;
import mot.common.command_delegates.BattleAutomateCmdDeligate;
import mot.common.command_delegates.BattleCraftLaunchFightersCmdDeligate;
import mot.common.command_delegates.BattleCraftMoveToCmdDeligate;
import mot.common.command_delegates.BattleCraftWaitCmdDeligate;
import mot.common.command_delegates.BattleEndTurnCmdDeligate;
import mot.common.command_delegates.BattleFetchCraftMoveActualLocCmdDeligate;
import mot.common.command_delegates.BattleGetNextObjectCmdDeligate;
import mot.common.command_delegates.BattleGetNextOrdersCmdDeligate;
import mot.common.command_delegates.BattleRetreatCmdDeligate;
import mot.common.command_delegates.ClientClosesWindowCmdDeligate;
import mot.common.command_delegates.CraftAttackCmdDeligate;
import mot.common.command_delegates.CraftBombardPlanetCmdDeligate;
import mot.common.command_delegates.CraftColoniseCmdDeligate;
import mot.common.command_delegates.CraftLeaveFleetCmdDeligate;
import mot.common.command_delegates.DesignColonyCraftCmdDeligate;
import mot.common.command_delegates.DesignMillitaryCraftCmdDeligate;
import mot.common.command_delegates.DiplomaticRequestCmdDeligate;
import mot.common.command_delegates.DiplomaticResponseCmdDeligate;
import mot.common.command_delegates.EndTurnCmdDeligate;
import mot.common.command_delegates.FetchDelegateStateCmdDelegate;
import mot.common.command_delegates.FetchGalaxyPreview;
import mot.common.command_delegates.FetchRegisteredPlayersCmdDelegate;
import mot.common.command_delegates.FetchSavedGameFiles;
import mot.common.command_delegates.FetchTechnologiesCmdDelegate;
import mot.common.command_delegates.GetCraftDesignStatistics;
import mot.common.command_delegates.GetGraphCmdDeligate;
import mot.common.command_delegates.IncreaseDevelopmentCmdDeligate;
import mot.common.command_delegates.IncreaseEcologyCmdDeligate;
import mot.common.command_delegates.JoinFleetCmdDeligate;
import mot.common.command_delegates.LoadCmdDeligate;
import mot.common.command_delegates.MooDeleteCmdDeligate;
import mot.common.command_delegates.MooDeployCmdDeligate;
import mot.common.command_delegates.MooMoveCmdDeligate;
import mot.common.command_delegates.MooRenameCmdDeligate;
import mot.common.command_delegates.MooSleepCmdDeligate;
import mot.common.command_delegates.NewGameCmdDeligate;
import mot.common.command_delegates.NewGameUserPlayerCmdDeligate;
import mot.common.command_delegates.PurchaseProjectCmdDeligate;
import mot.common.command_delegates.RegisterProxyCmdDeligate;
import mot.common.command_delegates.ReloadCmdDeligate;
import mot.common.command_delegates.RemoveCraftDesignDeligate;
import mot.common.command_delegates.RenamePlanetCmdDeligate;
import mot.common.command_delegates.RenameStellarObjectCmdDeligate;
import mot.common.command_delegates.SaveCmdDeligate;
import mot.common.command_delegates.SellSalvageCmdDeligate;
import mot.common.command_delegates.SetFleetWayPointCmdDelegate;
import mot.common.command_delegates.SetPlanetAutoPercentsCmdDeligate;
import mot.common.command_delegates.SetPlanetPercentsCmdDeligate;
import mot.common.command_delegates.SetPlanetWantsNoProjectCmdDeligate;
import mot.common.command_delegates.SetPlayerCharacterPercentsDeligate;
import mot.common.command_delegates.SetProjectCmdDeligate;
import mot.common.command_delegates.SetRecruiteSpyEffortCmdDeligate;
import mot.common.command_delegates.SetResearchProjectCmdDeligate;
import mot.common.command_delegates.SpyRoleAddEspionageCmdDeligate;
import mot.common.command_delegates.SpyRoleAddStellarObjectCmdDeligate;
import mot.common.command_delegates.SpyStealableTechnologiesCmdDelegate;
import mot.common.command_delegates.StartNextBattleInQueueCmdDeligate;
import mot.common.command_delegates.TransportLoadCmdDeligate;
import mot.common.command_results.CraftDesignCR;
import mot.common.command_results.StateUpdateCommandResult;
import mot.common.command_results.TechnologyListCR;
import mot.common.designs.AsteroidDesign;
import mot.common.designs.BattleStationDesign;
import mot.common.designs.ConstructPlanetDesign;
import mot.common.designs.CraftDesign;
import mot.common.designs.Orbital;
import mot.common.designs.OutpostDesign;
import mot.common.designs.ProjectDesign;
import mot.common.designs.ScannerDesign;
import mot.common.designs.ShieldDesign;
import mot.common.designs.SpaceStationDesign;
import mot.common.designs.TransportDesign;
import mot.common.designs.WeaponDesign;
import mot.common.event.BattleCraftLeaveEvent;
import mot.common.event.BattleCraftMoveEvent;
import mot.common.event.BattleCraftNewEvent;
import mot.common.event.BattleCraftSurrenderEvent;
import mot.common.event.BattleCraftTeleportEvent;
import mot.common.event.BattleCraftUpdateEvent;
import mot.common.event.BattleDamageEvent;
import mot.common.event.BattleDamageRingEvent;
import mot.common.event.BattleDestroyedEvent;
import mot.common.event.BattleDroidMineLaunchEvent;
import mot.common.event.BattleDroidMineMoveEvent;
import mot.common.event.BattleEndEvent;
import mot.common.event.BattleFearEvent;
import mot.common.event.BattleMissileLaunchEvent;
import mot.common.event.BattleMissileMoveEvent;
import mot.common.event.BattleNewTurnEvent;
import mot.common.event.BattleObjectNotificationEvent;
import mot.common.event.BattleObjectNotificationType;
import mot.common.event.BattleObjectTriggerEvent;
import mot.common.event.BattleStateUpdateContainerEvent;
import mot.common.event.BattleWeaponFireEvent;
import mot.common.event.BattleWeaponMissEvent;
import mot.common.event.BattleWeaponStateUpdateEvent;
import mot.common.event.ColonisePlanetEvent;
import mot.common.event.DestroyColonyEvent;
import mot.common.event.DiplomaticRequestEvent;
import mot.common.event.DiplomaticResponseEvent;
import mot.common.event.EndTurnEvent;
import mot.common.event.FundsGoneEvent;
import mot.common.event.FundsLowEvent;
import mot.common.event.GameEndEvent;
import mot.common.event.LeaderGainLevelEvent;
import mot.common.event.MessageEvent;
import mot.common.event.NewBattleEvent;
import mot.common.event.NewSpyEvent;
import mot.common.event.NoProjectEvent;
import mot.common.event.NoResearchProjectEvent;
import mot.common.event.OfferLeaderEvent;
import mot.common.event.OfferMoralChoiceEvent;
import mot.common.event.PlanetBombardedEvent;
import mot.common.event.PlanetColonisedEvent;
import mot.common.event.PlanetConqueredEvent;
import mot.common.event.PlanetCrisisEvent;
import mot.common.event.PlanetInvadeEvent;
import mot.common.event.PlayerLoseEvent;
import mot.common.event.PlayerSurrenderEvent;
import mot.common.event.PrizeGiftEvent;
import mot.common.event.RoutedEvent;
import mot.common.event.SabotageEvent;
import mot.common.event.TechnologyDiscoveredEvent;
import mot.common.event.TechnologyStolenEvent;
import mot.common.event.TooManySpiesEvent;
import mot.common.leaders.GeneralDetails;
import mot.common.leaders.GeneralDetailsList;
import mot.common.leaders.GovenorDetails;
import mot.common.leaders.GovenorDetailsList;
import mot.common.morals.MoralChoices;
import mot.common.resources.ResourceAntiMatter;
import mot.common.resources.ResourceBoralium;
import mot.common.resources.ResourceCloakPalm;
import mot.common.resources.ResourceEnergySpores;
import mot.common.resources.ResourcePsiFungus;
import mot.common.resources.ResourceTritanOre;
import mot.common.resources.ResourceWarpCrystal;
import mot.common.resources.Resources;
import mot.common.setup.OptionsFactory;
import mot.common.setup.RaceOptions;
import mot.common.setup.SetupOptions;
import mot.common.technology.AsteroidFieldConstruction;
import mot.common.technology.GeneralTechnologyList;
import mot.common.technology.Modules;
import mot.common.technology.Scanners;
import mot.common.technology.Shields;
import mot.common.technology.Technologies;
import mot.common.technology.Weapons;
import mot.common.util.ApplicationError;
import mot.common.util.Logger;
import mot.common.util.ValidationError;
import mot.common.vo.BattleStateVO;
import mot.common.vo.BattleVO;
import mot.common.vo.BlackHoleVO;
import mot.common.vo.ComputerPlayerVO;
import mot.common.vo.CraftVO;
import mot.common.vo.DroidMineVO;
import mot.common.vo.FleetVO;
import mot.common.vo.MissilesVO;
import mot.common.vo.OrbitVO;
import mot.common.vo.PlanetVO;
import mot.common.vo.PlayerConstantsVO;
import mot.common.vo.PlayerDetailsVO;
import mot.common.vo.PlayerTechnologiesVO;
import mot.common.vo.RelationVO;
import mot.common.vo.SolarSystemVO;
import mot.common.vo.SpaceStationVO;
import mot.common.vo.StellarObjectOrbitalVO;
import mot.common.vo.TechnologyListVO;
import mot.common.vo.TradeRouteListVO;
import mot.common.vo.UserPlayerVO;
import mot.engine.MotEngine;
import mot.engine.adapter.BattleCraftVOAdapter;
import mot.engine.adapter.BattleObjectWeaponStateVOAdapter;
import mot.engine.adapter.BattleVOAdapter;
import mot.engine.adapter.PlayerDetailsVOAdapter;
import mot.engine.battles.Battle;
import mot.engine.battles.BattleCraft;
import mot.engine.command_handlers.FetchGraphCmdHandler;
import mot.engine.common.Orbit;
import mot.engine.common.Outpost;
import mot.engine.common.SpaceStation;
import mot.engine.crafts.Craft;
import mot.engine.crafts.Fleet;
import mot.engine.crafts.FleetFactory;
import mot.engine.leaders.LeaderFactory;
import mot.engine.planets.BlackHole;
import mot.engine.planets.BlackHoleFactory;
import mot.engine.planets.OrbitalReference;
import mot.engine.planets.Planet;
import mot.engine.planets.ProjectAsteroids;
import mot.engine.planets.ProjectBattleStation;
import mot.engine.planets.ProjectConstructPlanet;
import mot.engine.planets.ProjectCraft;
import mot.engine.planets.ProjectOutpost;
import mot.engine.planets.ProjectScanner;
import mot.engine.planets.ProjectShield;
import mot.engine.planets.ProjectSpaceStation;
import mot.engine.planets.ProjectWeapon;
import mot.engine.planets.SolarSystem;
import mot.engine.planets.TradeRouteFactory;
import mot.engine.players.ComputerPlayer;
import mot.engine.players.UserPlayer;
import mot.engine.players.mayor.CraftDesignerMilitary;
import mot.engine.prizes.BoraliumPrize;
import mot.engine.prizes.CraftPrize;
import mot.engine.prizes.MoneyPrize;
import mot.engine.prizes.TechnologyPrize;
import mot.engine.relations.Relation;
import mot.engine.relations.Relations;
import mot.engine.relations.ResearchAgreementTreaty;
import mot.engine.relations.TradeAgreementTreaty;
import mot.engine.transports.Transport;
import mot.engine.transports.TransportTaskDeployStation;
import mot.engine.transports.TransportTaskMoveColonists;

public class SerialisabilityTest extends TestBase {

    public static Test suite() {
        Logger.clearContents();
        Logger.setInMemory(false);
        TestSuite suite = new TestSuite(SerialisabilityTest.class);
        return suite;
    }

    public SerialisabilityTest(String name) {
        super(name);
    	try {
			Settings.getInstance();
		} catch (ApplicationError e) {
			e.printStackTrace();
		}
    }

    protected void setUp() throws ApplicationError {
        MotEngine.newInstance();
        setupConfigs();
        //MotEngine.getInstance().getProxyManager().add(this);
    }
    
    protected void tearDown() throws Exception {
    	super.tearDown();
    	Logger.flushLog();
    }
    
    private UserPlayer player1;
    private ComputerPlayer player2;
    private ComputerPlayer player3;
    private ComputerPlayer deadPlayer;

    private SolarSystem ss1;
    private SolarSystem ss2;
    private SolarSystem ss3;
    private SolarSystem ss4;
    private SolarSystem ss5;
    private SolarSystem ss6;
    private SolarSystem ss7;
    private SolarSystem ss8;
    private SolarSystem ss9;

    private Planet planet1;
    private Planet planet1mine;
    private Planet planet2;
    private Planet planet3;
    private Planet planet4;
    private Planet planet6;
    private Planet planet7a;
    private Planet planet7b;
    private Planet planet7c;
    private Planet planet7d;
    private Planet planet7e;
    private Planet planet7f;
    private Planet planet7g;
    private Planet planet7h;

    private BlackHole blackHole;
	private Craft craft1;
	private Craft craft2;
	private Craft craft3;
	private Fleet fleet1;
	
    private void init() throws ApplicationError, ValidationError {
        MotEngine.newInstance();
        SetupOptions options = OptionsFactory.getGeneralOptions();;
        String [] playerNames = { "Humans", "Bears" };
        RaceOptions ro = OptionsFactory.getRaceOptions(playerNames[0]);
        player1 = newUserPlayer(playerNames[0], blue, null, ro);
        player2 = newPlayer(playerNames[1], green, options, playerNames);

        ss1 = newSolarSystem("SS1", 100, 100);
        planet1 = newPlanet("SS1-A", ss1, player1);

        ss2 = newSolarSystem("SS2", 200, 200);
        planet2 = newPlanet("SS2-A", ss2, player2);

        MotEngine.getInstance().getRelations().setWar(player1, player2);
        
        craft1 = newCraft(fighterDesign, player1, ss1);
        craft2 = newCraft(fighterDesign, player2, ss1);

    }

    public void testCommandDelegates() throws Exception {
        Logger.logDebug("*******************************  GeometryTest.testCommandDelegates() *************************");
        init();
        
        AbandonCmdDeligate r1 = (AbandonCmdDeligate) serialiseDeserialise(new AbandonCmdDeligate("TP"));
        assertEquals("TP", r1.getPlanet());
        
        AcceptLeaderCmdDeligate r2 = (AcceptLeaderCmdDeligate) serialiseDeserialise(new AcceptLeaderCmdDeligate("LDR"));
        assertEquals("LDR", r2.getLeader());
        
        AcceptMoralChoiceCmdDeligate r3 = (AcceptMoralChoiceCmdDeligate) serialiseDeserialise(new AcceptMoralChoiceCmdDeligate("MC"));
        assertEquals("MC", r3.getChoice());
        
        CraftDesign cd1 = new CraftDesign("CraftDesign1", tech_flyer30, tech_fusion25, tech_electronic25, tech_massDriver1, tech_massDriver1, tech_missile6, tech_armour25, tech_photon100, tech_energy10);
        AddCraftDesignDeligate r4 = (AddCraftDesignDeligate) serialiseDeserialise(new AddCraftDesignDeligate(cd1));
        assertEquals(cd1, r4.getCraftDesign());
        
        BattleAttackCmdDeligate r5 = (BattleAttackCmdDeligate) serialiseDeserialise(new BattleAttackCmdDeligate("Battle1", "Source", "Target", true, true, true, new LocationAndDirection(50, 50, 90), "Weapon", 10));
        assertEquals("Battle1", r5.getBattle());
        assertEquals("Source", r5.getSource());
        assertEquals("Target", r5.getTarget());
        assertEquals(true, r5.isDischarge());
        assertEquals(true, r5.isMissileDefence());
        assertEquals(true, r5.isMove());
        assertEquals(50,50,90, r5.getAttackFrom());
        assertEquals("Weapon", r5.getWeapon());
        assertEquals(10, r5.getQtyToFire());

        BattleAttackLocationCmdDeligate r6 = (BattleAttackLocationCmdDeligate) serialiseDeserialise(new BattleAttackLocationCmdDeligate("Battle", "Source", new Location(50, 50), "Weapon", 10));
        assertEquals("Battle", r6.getBattle());
        assertEquals("Source", r6.getSource());
        assertEquals(50,50, r6.getTarget());
        assertEquals("Weapon", r6.getWeapon());
        assertEquals(10, r6.getQtyToFire());
        
        BattleAutomateCmdDeligate r7 = (BattleAutomateCmdDeligate) serialiseDeserialise(new BattleAutomateCmdDeligate("BA"));
        assertEquals("BA", r7.getBattle());
        
        BattleCraftLaunchFightersCmdDeligate r8 = (BattleCraftLaunchFightersCmdDeligate) serialiseDeserialise(new BattleCraftLaunchFightersCmdDeligate("BA", "SFC"));
        assertEquals("BA", r8.getBattle());
        assertEquals("SFC", r8.getSource());
        
        BattleCraftMoveToCmdDeligate r9 = (BattleCraftMoveToCmdDeligate) serialiseDeserialise(new BattleCraftMoveToCmdDeligate("Battle1", "Source", new LocationAndDirection(50, 50, 90), "Target", true, true));
        assertEquals("Battle1", r9.getBattle());
        assertEquals("Source", r9.getSource());
        assertEquals("Target", r9.getTarget());
        assertEquals(true, r9.isMissileDefence());
        assertEquals(true, r9.isStopOnMissileAttack());
        assertEquals(50,50,90, r9.getMoveToDest());
        
        BattleCraftWaitCmdDeligate r10 = (BattleCraftWaitCmdDeligate) serialiseDeserialise(new BattleCraftWaitCmdDeligate("BA", "SFC"));
        assertEquals("BA", r10.getBattle());
        assertEquals("SFC", r10.getSource());
        
        BattleEndTurnCmdDeligate r11 = (BattleEndTurnCmdDeligate) serialiseDeserialise(new BattleEndTurnCmdDeligate("BA", "SFC", true, true, tech_massDriver1.getName(), 10));
        assertEquals("BA", r11.getBattle());
        assertEquals("SFC", r11.getSource());
        assertEquals(true, r11.isDischargeWeapons());
        assertEquals(true, r11.isEndMove());
        assertEquals(tech_massDriver1.getName(), r11.getWeapon());
        assertEquals(10, r11.getQtyWeapons());

        BattleFetchCraftMoveActualLocCmdDeligate r12 = (BattleFetchCraftMoveActualLocCmdDeligate) serialiseDeserialise(new BattleFetchCraftMoveActualLocCmdDeligate("Battle1", "Source", new LocationAndDirection(50, 50, 90), "Target"));
        assertEquals("Battle1", r12.getBattle());
        assertEquals("Source", r12.getSource());
        assertEquals("Target", r12.getTarget());
        assertEquals(50,50,90, r12.getMoveToDest());
        
        BattleGetNextObjectCmdDeligate r13 = (BattleGetNextObjectCmdDeligate) serialiseDeserialise(new BattleGetNextObjectCmdDeligate("BA"));
        assertEquals("BA", r13.getBattle());
        
        BattleGetNextOrdersCmdDeligate r14 = (BattleGetNextOrdersCmdDeligate) serialiseDeserialise(new BattleGetNextOrdersCmdDeligate("BA", "SFC"));
        assertEquals("BA", r14.getBattle());
        assertEquals("SFC", r14.getSource());
        
        BattleRetreatCmdDeligate r15 = (BattleRetreatCmdDeligate) serialiseDeserialise(new BattleRetreatCmdDeligate("BA", "SFC"));
        assertEquals("BA", r15.getBattle());
        assertEquals("SFC", r15.getSource());
        
        ClientClosesWindowCmdDeligate r16 = (ClientClosesWindowCmdDeligate) serialiseDeserialise(new ClientClosesWindowCmdDeligate("BA"));
        assertEquals("BA", r16.getBattle());
        
        CraftAttackCmdDeligate r17 = (CraftAttackCmdDeligate) serialiseDeserialise(new CraftAttackCmdDeligate("Craft", "Planet"));
        assertEquals("Craft", r17.getCraft());
        assertEquals("Planet", r17.getPlanet());
        
        CraftBombardPlanetCmdDeligate r18 = (CraftBombardPlanetCmdDeligate) serialiseDeserialise(new CraftBombardPlanetCmdDeligate("Craft", "Planet"));
        assertEquals("Craft", r18.getCraft());
        assertEquals("Planet", r18.getPlanet());
        
        CraftColoniseCmdDeligate r19 = (CraftColoniseCmdDeligate) serialiseDeserialise(new CraftColoniseCmdDeligate("Craft", "Planet"));
        assertEquals("Craft", r19.getCraft());
        assertEquals("Planet", r19.getPlanet());
        
        CraftLeaveFleetCmdDeligate r21 = (CraftLeaveFleetCmdDeligate) serialiseDeserialise(new CraftLeaveFleetCmdDeligate("Craft"));
        assertEquals("Craft", r21.getCraft());
        
//        DemandAssetsCmdDeligate r22 = (DemandAssetsCmdDeligate) serialiseDeserialise(new DemandAssetsCmdDeligate("Receiver", new PlayerAssets(tech_ancientEngine, 25, "Planet")));
//        assertEquals("Receiver", r22.getReceiver());
//        assertEquals(tech_ancientEngine, r22.getAssets().getTechnologies());
//        assertEquals(25, r22.getAssets().getMoney());
//        assertEquals("Planet", r22.getAssets().getPlanet());
//        
//        DemandAssetsResponseCmdDeligate r23 = (DemandAssetsResponseCmdDeligate) serialiseDeserialise(new DemandAssetsResponseCmdDeligate("Receiver", new PlayerAssets(tech_ancientEngine, 25, "Planet"), true, "Msg"));
//        assertEquals("Receiver", r23.getReceiver());
//        assertEquals(tech_ancientEngine, r23.getAssets().getTechnologies());
//        assertEquals(25, r23.getAssets().getMoney());
//        assertEquals("Planet", r23.getAssets().getPlanet());
//        assertEquals(true, r23.isAccept());
//        assertEquals("Msg", r23.getMessage());
        
        MooDeployCmdDeligate r24 = (MooDeployCmdDeligate) serialiseDeserialise(new MooDeployCmdDeligate("Transport", "SO", "Planet"));
        assertEquals("Transport", r24.getMoo());
        assertEquals("SO", r24.getStellarObject());
        assertEquals("Planet", r24.getPlanet());
        
        MooSleepCmdDeligate r24b = (MooSleepCmdDeligate) serialiseDeserialise(new MooSleepCmdDeligate("Transport"));
        assertEquals("Transport", r24b.getMoo());
        
        DesignColonyCraftCmdDeligate r25 = (DesignColonyCraftCmdDeligate) serialiseDeserialise(new DesignColonyCraftCmdDeligate());

        DesignMillitaryCraftCmdDeligate r26 = (DesignMillitaryCraftCmdDeligate) serialiseDeserialise(new DesignMillitaryCraftCmdDeligate(null, new OrbitVO("SO", "planet")));
        CraftDesignCR r27 = (CraftDesignCR) serialiseDeserialise(new CraftDesignCR(new CraftDesignerMilitary().designCraft(player1, CraftDesignerMilitary.SIZE_LARGE, 0.2, 0.0)));
       
        EndTurnCmdDeligate r28 = (EndTurnCmdDeligate) serialiseDeserialise(new EndTurnCmdDeligate());
        
        FetchDelegateStateCmdDelegate r29 = (FetchDelegateStateCmdDelegate) serialiseDeserialise(new FetchDelegateStateCmdDelegate());
		StateUpdateCommandResult statefulCR = new StateUpdateCommandResult();
        MotEngine.instance.addStateUpdate(statefulCR, player1, true, true, true, true, true, true, true, true, true, true, true);
        StateUpdateCommandResult r30 = (StateUpdateCommandResult) serialiseDeserialise(statefulCR);
        
        FetchGalaxyPreview r31 = (FetchGalaxyPreview) serialiseDeserialise(new FetchGalaxyPreview("FILE"));
        assertEquals("FILE", r31.getFileName());

        FetchRegisteredPlayersCmdDelegate r32 = (FetchRegisteredPlayersCmdDelegate) serialiseDeserialise(new FetchRegisteredPlayersCmdDelegate());

        FetchSavedGameFiles r33 = (FetchSavedGameFiles) serialiseDeserialise(new FetchSavedGameFiles());

        SpyStealableTechnologiesCmdDelegate r34 = (SpyStealableTechnologiesCmdDelegate) serialiseDeserialise(new SpyStealableTechnologiesCmdDelegate("Giver", "Taker", new TechnologyListVO(tech_SalvageAnalyser)));
        assertEquals("Giver", r34.getGiverPlayer());
        assertEquals("Taker", r34.getTakerPlayer());
        TechnologyListCR r35 = (TechnologyListCR) serialiseDeserialise(new TechnologyListCR(new GeneralTechnologyList(tech_armour25)));
        assertEquals(tech_armour25, r35.getResult());

        FetchTechnologiesCmdDelegate r36 = (FetchTechnologiesCmdDelegate) serialiseDeserialise(new FetchTechnologiesCmdDelegate("Player"));
        assertEquals("Player", r36.getPlayer());

        CraftDesign cd2 = new CraftDesign("CraftDesign1", tech_flyer30, tech_fusion25, tech_electronic25, tech_massDriver1, tech_massDriver1, tech_missile6, tech_armour25, tech_photon100, tech_energy10);
        GetCraftDesignStatistics r37 = (GetCraftDesignStatistics) serialiseDeserialise(new GetCraftDesignStatistics(cd2, "Owner", "Origin"));
        assertEquals("Owner", r37.getOwner());
        assertEquals("Origin", r37.getOrigin());
        assertEquals(cd2, r37.getDesign());

        GetGraphCmdDeligate r38 = (GetGraphCmdDeligate) serialiseDeserialise(new GetGraphCmdDeligate());

//        GiveAssetsCmdDeligate r39 = (GiveAssetsCmdDeligate) serialiseDeserialise(new GiveAssetsCmdDeligate("Receiver", new PlayerAssets(tech_ancientEngine, 25, "Planet")));
//        assertEquals("Receiver", r39.getReceiver());
//        assertEquals(tech_ancientEngine, r39.getGift().getTechnologies());
//        assertEquals(25, r39.getGift().getMoney());
//        assertEquals("Planet", r39.getGift().getPlanet());
    
        IncreaseDevelopmentCmdDeligate r40 = (IncreaseDevelopmentCmdDeligate) serialiseDeserialise(new IncreaseDevelopmentCmdDeligate());
        IncreaseEcologyCmdDeligate r41 = (IncreaseEcologyCmdDeligate) serialiseDeserialise(new IncreaseEcologyCmdDeligate());
        
        JoinFleetCmdDeligate r42 = (JoinFleetCmdDeligate) serialiseDeserialise(new JoinFleetCmdDeligate("Craft"));
        assertEquals("Craft", r42.getCraft());
        
        LoadCmdDeligate r43 = (LoadCmdDeligate) serialiseDeserialise(new LoadCmdDeligate("File", "Player"));
        assertEquals("File", r43.getFile());
        assertEquals("Player", r43.getPlayerName());
        
        MooMoveCmdDeligate r44 = (MooMoveCmdDeligate) serialiseDeserialise(new MooMoveCmdDeligate("Craft", "Destination", "Planet", true));
        assertEquals("Craft", r44.getMoo());
        assertEquals("Destination", r44.getDestination());
        assertEquals("Planet", r44.getPlanet());
        assertEquals(true, r44.getGenerateOrbit());
        
        MooDeleteCmdDeligate r44a = (MooDeleteCmdDeligate) serialiseDeserialise(new MooDeleteCmdDeligate("Craft"));
        assertEquals("Craft", r44a.getMoo());
        
        MooRenameCmdDeligate r44b = (MooRenameCmdDeligate) serialiseDeserialise(new MooRenameCmdDeligate("Old", "New"));
        assertEquals("Old", r44b.getMooName());
        assertEquals("New", r44b.getNewName());
        
        NewGameDataComputerPlayerDetails[] cpd = new NewGameDataComputerPlayerDetails[1];
        cpd[0] = new NewGameDataComputerPlayerDetails("Bears", 3.0, new PlayerAiSettings(-1, 1, -1));
        NewGameData gameData = new NewGameData(cpd, 2.0, false, 10, 1, new Size(500,500), false, false);      
        SetupOptions userOptions = OptionsFactory.getSetupOptions("Humans");
        NewGameUserPlayerData userPlayerData = new NewGameUserPlayerData("Humans", userOptions, playerColourBlue, ANCIENT_WATER_MAN);
        NewGameCmdDeligate r45 = (NewGameCmdDeligate) serialiseDeserialise(new NewGameCmdDeligate("ID", userPlayerData, gameData));
        assertEquals(1, r45.getGameData().getQtyNebula());
        assertEquals(10, r45.getGameData().getQtyPlanets());
        assertEquals(2.0, r45.getGameData().getLevel());
        assertEquals(500,500, r45.getGameData().getGalaxySize());
        assertEquals(1, r45.getGameData().getComputerPlayers().length);
        assertEquals("Bears", r45.getGameData().getComputerPlayers()[0].getRaceName());
        assertEquals(1, r45.getGameData().getComputerPlayers()[0].getPlayerAiSettings().getDiplomaticTrade());
        assertEquals(3.0, r45.getGameData().getComputerPlayers()[0].getLevel());
        assertEquals("Humans", r45.getUserData().getRaceName());
        assertEquals(playerColourBlue, r45.getUserData().getPlayerColour());
        assertEquals(userOptions, r45.getUserData().getUserOptions());
        
        NewGameUserPlayerCmdDeligate r46 = (NewGameUserPlayerCmdDeligate) serialiseDeserialise(new NewGameUserPlayerCmdDeligate("ID", userPlayerData));
        assertEquals("Humans", r46.getUserData().getRaceName());
        assertEquals(playerColourBlue, r46.getUserData().getPlayerColour());
        assertEquals(userOptions, r46.getUserData().getUserOptions());
        
        PurchaseProjectCmdDeligate r47 = (PurchaseProjectCmdDeligate) serialiseDeserialise(new PurchaseProjectCmdDeligate("Planet"));
        assertEquals("Planet", r47.getPlanet());
        
        RegisterProxyCmdDeligate r48 = (RegisterProxyCmdDeligate) serialiseDeserialise(new RegisterProxyCmdDeligate("Player", "Password", false));
        
        ReloadCmdDeligate r49 = (ReloadCmdDeligate) serialiseDeserialise(new ReloadCmdDeligate("Player", "File"));
        assertEquals("Player", r49.getPlayer());
        assertEquals("File", r49.getFile());
        
        RemoveCraftDesignDeligate r50 = (RemoveCraftDesignDeligate) serialiseDeserialise(new RemoveCraftDesignDeligate("Name"));
        assertEquals("Name", r50.getName());
        
        RenamePlanetCmdDeligate r51 = (RenamePlanetCmdDeligate) serialiseDeserialise(new RenamePlanetCmdDeligate("Old", "New"));
        assertEquals("Old", r51.getPlanetName());
        assertEquals("New", r51.getNewName());
        
        RenameStellarObjectCmdDeligate r52 = (RenameStellarObjectCmdDeligate) serialiseDeserialise(new RenameStellarObjectCmdDeligate("Old", "New"));
        assertEquals("Old", r52.getSoName());
        assertEquals("New", r52.getNewName());
        
	    SaveCmdDeligate r53 = (SaveCmdDeligate) serialiseDeserialise(new SaveCmdDeligate("File"));
	    assertEquals("File", r53.getFile());
	    
	    SellSalvageCmdDeligate r54 = (SellSalvageCmdDeligate) serialiseDeserialise(new SellSalvageCmdDeligate(new GeneralTechnologyList(tech_ancientComputer)));
		assertEquals(tech_ancientComputer, r54.getSalvage().getAllAsList());
	    
		SetFleetWayPointCmdDelegate r55 = (SetFleetWayPointCmdDelegate) serialiseDeserialise(new SetFleetWayPointCmdDelegate(new OrbitVO("SO", "Planet")));
		assertEquals("SO", "Planet", r55.getOrbit());

		SetPlanetAutoPercentsCmdDeligate r56 = (SetPlanetAutoPercentsCmdDeligate) serialiseDeserialise(new SetPlanetAutoPercentsCmdDeligate("Planet", true, true, true, true));
		assertEquals("Planet", r56.getPlanet());
		assertTrue(r56.getDevelopment());
		assertTrue(r56.getEcology());
		assertTrue(r56.getDevelopment());
		assertTrue(r56.getResearch());

		SetPlanetPercentsCmdDeligate r57 = (SetPlanetPercentsCmdDeligate) serialiseDeserialise(new SetPlanetPercentsCmdDeligate("Planet", 1, 2, 3, 4));
		assertEquals("Planet", r57.getPlanet());
		assertEquals(1.0, r57.getDevelopmentPercent());
		assertEquals(2.0, r57.getEcologyPercent());
		assertEquals(3.0, r57.getProductionPercent());
		assertEquals(4.0, r57.getResearchPercent());
    
		SetPlanetWantsNoProjectCmdDeligate r58 = (SetPlanetWantsNoProjectCmdDeligate) serialiseDeserialise(new SetPlanetWantsNoProjectCmdDeligate("Planet", true));
		assertEquals("Planet", r58.getPlanet());
		assertTrue(r58.isWantsNoProject());

		SetPlayerCharacterPercentsDeligate r59 = (SetPlayerCharacterPercentsDeligate) serialiseDeserialise(new SetPlayerCharacterPercentsDeligate(1.0,2.0,3.0,4.0,5.0,6.0,7.0));
		assertEquals(1.0, r59.getEcology());
		assertEquals(2.0, r59.getDevelopment());
		assertEquals(3.0, r59.getResearch());
		assertEquals(4.0, r59.getProduction());
		assertEquals(5.0, r59.getMoney());
		assertEquals(6.0, r59.getImproveEcology());
		assertEquals(7.0, r59.getImproveDevelopment());

        ProjectDesign project = new WeaponDesign(tech_missile6);
		SetProjectCmdDeligate r60 = (SetProjectCmdDeligate) serialiseDeserialise(new SetProjectCmdDeligate("Planet", project, 1, true, true));
		assertEquals("Planet", r60.getPlanets());
		assertEquals(1, r60.getRepeat());
		assertEquals(tech_missile6, ((WeaponDesign)r60.getProject()).getWeapon());
		assertTrue(r60.isUseSalvage());

        project = new ShieldDesign(tech_energy10);
		SetProjectCmdDeligate r61 = (SetProjectCmdDeligate) serialiseDeserialise(new SetProjectCmdDeligate("Planet", project, 1, true, false));
		assertEquals("Planet", r61.getPlanets());
		assertEquals(1, r61.getRepeat());
		assertEquals(tech_energy10, ((ShieldDesign)r61.getProject()).getShield());
		assertFalse(r61.isUseSalvage());

        project = new ScannerDesign(tech_photon100);
		SetProjectCmdDeligate r62 = (SetProjectCmdDeligate) serialiseDeserialise(new SetProjectCmdDeligate("Planet", project, 1, true, true));
		assertEquals("Planet", r62.getPlanets());
		assertEquals(1, r62.getRepeat());
		assertEquals(tech_photon100, ((ScannerDesign)r62.getProject()).getScanner());

        project = new BattleStationDesign(tech_battleStationI);
		SetProjectCmdDeligate r62a = (SetProjectCmdDeligate) serialiseDeserialise(new SetProjectCmdDeligate("Planet", project, 1, true, true));
		assertEquals("Planet", r62a.getPlanets());
		assertEquals(1, r62a.getRepeat());
		assertEquals(tech_battleStationI, ((BattleStationDesign)r62a.getProject()).getBattleStation());

        project = new AsteroidDesign();
		SetProjectCmdDeligate r67 = (SetProjectCmdDeligate) serialiseDeserialise(new SetProjectCmdDeligate("Planet", project, 1, true, true));
		assertEquals("Planet", r67.getPlanets());
		assertEquals(1, r67.getRepeat());

        project = new ConstructPlanetDesign(tech_planetConstruction, "SolarSystem");
		SetProjectCmdDeligate r68 = (SetProjectCmdDeligate) serialiseDeserialise(new SetProjectCmdDeligate("Planet", project, 1, true, true));
		assertEquals("Planet", r68.getPlanets());
		assertEquals(1, r68.getRepeat());
		assertEquals(tech_planetConstruction, ((ConstructPlanetDesign)r68.getProject()).getPlanetConstructionTech());
		assertEquals("SolarSystem", ((ConstructPlanetDesign)r68.getProject()).getSolarSystem());

        project = new OutpostDesign(tech_outpost);
		SetProjectCmdDeligate r69 = (SetProjectCmdDeligate) serialiseDeserialise(new SetProjectCmdDeligate("Planet", project, 1, true, true));
		assertEquals("Planet", r69.getPlanets());
		assertEquals(1, r69.getRepeat());
		assertEquals(tech_outpost, ((OutpostDesign)r69.getProject()).getOutpost());

        project = new TransportDesign();
		SetProjectCmdDeligate r70 = (SetProjectCmdDeligate) serialiseDeserialise(new SetProjectCmdDeligate("Planet", project, 1, true, true));
		assertEquals("Planet", r70.getPlanets());
		assertEquals(1, r70.getRepeat());

		CraftDesign cd = new CraftDesign("TestCraftDesign");
		SetProjectCmdDeligate r71 = (SetProjectCmdDeligate) serialiseDeserialise(new SetProjectCmdDeligate("Planet", cd, 1, true, true));
		assertEquals("Planet", r71.getPlanets());
		assertEquals(1, r71.getRepeat());
		assertEquals(cd, (CraftDesign)r71.getProject());
		
		SetRecruiteSpyEffortCmdDeligate r72 = (SetRecruiteSpyEffortCmdDeligate) serialiseDeserialise(new SetRecruiteSpyEffortCmdDeligate(8));
		assertEquals(8, r72.getAmount());
		
		SetResearchProjectCmdDeligate r73 = (SetResearchProjectCmdDeligate) serialiseDeserialise(new SetResearchProjectCmdDeligate("Tech"));
		assertEquals("Tech", r73.getTech());
		
		SpyRoleAddEspionageCmdDeligate r74 = (SpyRoleAddEspionageCmdDeligate) serialiseDeserialise(new SpyRoleAddEspionageCmdDeligate("Player", 9));
		assertEquals("Player", r74.getTarget());
		assertEquals(9, r74.getQty());
		
		SpyRoleAddStellarObjectCmdDeligate r75 = (SpyRoleAddStellarObjectCmdDeligate) serialiseDeserialise(new SpyRoleAddStellarObjectCmdDeligate("Player"));
		assertEquals("Player", r75.getTarget());
		
		StartNextBattleInQueueCmdDeligate r76 = (StartNextBattleInQueueCmdDeligate) serialiseDeserialise(new StartNextBattleInQueueCmdDeligate(2));
		assertEquals(2, r76.getSequence());
		
		PlayerAssets offered = new PlayerAssets(tech_ComputerisedLabI, 15, "Planet1");
		offered.setCraftNames(new NameList("A Craft"));
		PlayerAssets wanted = new PlayerAssets(tech_ancientWeapon, 16, "Planet2");
		wanted.setCraftNames(new NameList("A Craft"));
		DiplomaticRequestCmdDeligate r77 = (DiplomaticRequestCmdDeligate) serialiseDeserialise(new DiplomaticRequestCmdDeligate("Player", new DiplomaticProposal(offered, wanted), "A Message"));
		assertEquals("Player", r77.getReceiver());
		assertEquals(offered, r77.getProposal().getOffered());
		assertEquals(wanted, r77.getProposal().getWanted());
		assertEquals("A Message", r77.getMessage());
		
		offered = new PlayerAssets(tech_ComputerisedLabI, 15, "Planet1");
		wanted = new PlayerAssets(tech_ancientWeapon, 16, "Planet2");
		DiplomaticResponseCmdDeligate r78 = (DiplomaticResponseCmdDeligate) serialiseDeserialise(new DiplomaticResponseCmdDeligate("Player", new DiplomaticProposal(offered, wanted), true, "XXX"));
		assertEquals("Player", r78.getReceiver());
		assertEquals(offered, r78.getProposal().getOffered());
		assertEquals(wanted, r78.getProposal().getWanted());
		assertTrue(r78.isAccept());
		assertEquals("XXX", r78.getMessage());
		
		TransportLoadCmdDeligate r79 = (TransportLoadCmdDeligate) serialiseDeserialise(new TransportLoadCmdDeligate(new OrbitVO("SrcS","SrcP"), new OrbitVO(null, "DestP"), 12, 1));
		assertEquals("SrcS", "SrcP", r79.getSource());
		assertEquals(null, "DestP", r79.getDestination());
		assertEquals(12, r79.getQty());
		assertTrue(r79.isTroops());
		
		DiplomaticResponseCmdDeligate r80 = (DiplomaticResponseCmdDeligate) serialiseDeserialise(new DiplomaticResponseCmdDeligate("Player", DiplomaticProposal.getWar(), false, "My Message"));
		assertEquals("Player", r80.getReceiver());
		assertEquals(false, r80.isAccept());
		assertEquals("My Message", r80.getMessage());
		assertEquals(true, r80.getProposal().isWar());
		assertEquals(false, r80.getProposal().isPeace());
		assertEquals(false, r80.getProposal().isNonAggression());
		assertEquals(false, r80.getProposal().isAlliance());
		assertEquals(false, r80.getProposal().isTrade());
		assertEquals(false, r80.getProposal().isResearch());
		
		DiplomaticProposal diplomaticProposal = DiplomaticProposal.getPeace();
		diplomaticProposal.setNonAggression(true);
		diplomaticProposal.setAlliance(true);
		diplomaticProposal.setTrade(true);
		diplomaticProposal.setResearch(true);
		DiplomaticResponseCmdDeligate r81 = (DiplomaticResponseCmdDeligate) serialiseDeserialise(new DiplomaticResponseCmdDeligate("Player", diplomaticProposal, false, "My Message"));
		assertEquals("Player", r81.getReceiver());
		assertEquals(false, r81.isAccept());
		assertEquals("My Message", r81.getMessage());
		assertEquals(false, r81.getProposal().isWar());
		assertEquals(true, r81.getProposal().isPeace());
		assertEquals(true, r81.getProposal().isNonAggression());
		assertEquals(true, r81.getProposal().isAlliance());
		assertEquals(true, r81.getProposal().isTrade());
		assertEquals(true, r81.getProposal().isResearch());
		
    }    

    public void testValueObjects() throws Exception {
        Logger.logDebug("*******************************  GeometryTest.testCommandDelegates() *************************");
        String [] playerNames = { "TestPlayer1", "TestPlayer2", "TestPlayer3", "DeadPlayer" };
        SetupOptions options = mot.common.setup.OptionsFactory.getGeneralOptions();
        RaceOptions ro = OptionsFactory.getRaceOptions("Humans");
        player1 = newUserPlayer(playerNames[0], blue, "WaterMan", ro);
        player2 = newPlayer(playerNames[1], green, options, playerNames);
        player3 = newPlayer(playerNames[2], red, options, playerNames);
        ComputerPlayer deadPlayer = newPlayer(playerNames[3], yellow, options, playerNames);
        deadPlayer.surrendetTo(player1);

        ss1 = newSolarSystem("SS1", 100, 100);
        planet1 = newPlanet("SS1-A", ss1, player1);
        planet1mine = newPlanet("SS1-MINE", ss1, null, 50, 0.1);
        ss1.addVisitor(player1, false);

        ss2 = newSolarSystem("SS2", 150, 100);
        planet2 = newPlanet("SS2-A", ss2, player2);

        ss3 = newSolarSystem("SS3", 200, 100);
        planet3 = newPlanet("SS3-A", ss3, null, 100, 0.8);

        ss4 = newSolarSystem("SS4", 250, 100);
        planet4 = newPlanet("SS4-A", ss4, null, 110, 1.0);

        ss5 = newSolarSystem("SS5", 100, 200);
        
        ss6 = newSolarSystem("SS6", 100, 250);
        planet6 = newPlanet("SS6-A", ss6, player3);
        
        ss7 = newSolarSystem("SS7", 100, 300);
        planet7a = newPlanet("SS7-A", ss7, null, 80, 0.5);
        planet7b = newPlanet("SS7-B", ss7, null, 80, 0.5);
        planet7c = newPlanet("SS7-C", ss7, null, 80, 0.5);
        planet7d = newPlanet("SS7-D", ss7, null, 80, 0.5);
        planet7e = newPlanet("SS7-E", ss7, null, 80, 0.5);
        planet7f = newPlanet("SS7-F", ss7, null, 80, 0.5);
        planet7g = newPlanet("SS7-G", ss7, null, 80, 0.5);
        planet7h = newPlanet("SS7-H", ss7, null, 80, 0.5);
        
        ss2.setPrize(new MoneyPrize(250));
        ss3.setPrize(new TechnologyPrize(tech_massDriver1));
        ss4.setPrize(new CraftPrize());
        ss5.setPrize(new BoraliumPrize(7));
        
        ss8 = newSolarSystem("SS8", 200, 300);
        ss9 = newSolarSystem("SS9", 200, 400);
        
        blackHole = BlackHoleFactory.createBlackHole(new Location(500,500));
        
        // Test player details are saved correctly
        player1.setFunds(700);
        player1.setBoralium(71);
        player1.setLastDateAncientsDefended(3010);
        player1.addEngine(tech_fusion25x);
        player1.addWeapon(tech_massDriver2);
        player1.addShield(tech_energy10);
        player1.addSpecial(tech_armour25);
        player1.addScanner(tech_photon150);
        player1.addBiotechnology(tech_terraforming10);
        player1.addTheory(tech_researchLabI);
        player1.addFactory(tech_basicComputerisedFactory);
        player1.addLaboratory(tech_ComputerisedLabI);
        player1.addModule(tech_habitatI);
        player1.addMiscTechnology(tech_planetConstruction);
        player1.getPlayerCharacter().setBattleSpeedBonus(1.1);
        player1.getPlayerCharacter().setBattleTurningBonus(1.2);
        player1.getPlayerCharacter().setMaxDamageBonus(1.05);
        player1.getPlayerCharacter().setSpeedBonus(1.3);
        player1.getPlayerCharacter().setProductionBonus(1.5);
        player1.getPlayerCharacter().setResearchBonus(1.6);
        player1.getPlayerCharacter().setReproductionBonus(1.7);
        player1.getPlayerCharacter().setAssaultBonus(1.25);
        player1.getPlayerCharacter().setInitiativeBonus(1.8);
        player1.getPlayerCharacter().setSpyDefendPercent(0.5);
        player1.getPlayerCharacter().setSpyBonus(0.9);
        player1.getPlayerCharacter().setTradingBonus(1.9);
        player1.getPlayerCharacter().setEcologyBonus(0.7);
        player1.getPlayerCharacter().setFactoryPerPopulationBonus(2.0);
        player1.getPlayerCharacter().setPsiRating(20);
        player1.getPlayerCharacter().setMaxPlayerTradeRoutes(6);
        player1.getPlayerCharacter().setMaxPlanetTradeRoutes(7);
        player1.getPlayerCharacter().setCharisma(5);
        player1.getPlayerCharacter().setCloakLevel(10);
        player1.getPlayerCharacter().setRelation(new Relation(player1, player2, 55));
        player1.getPlayerCharacter().setCloakLevel(10);
        player1.getPlayerCharacter().setFactoryPerPopulationBonus(2.0);
        player1.getPlayerCharacter().setBlockadeOrAttackProbability(0.4);
        player1.getPlayerCharacter().setAcceptAlianceProbabilityWhenFond(0.1);
        player1.getPlayerCharacter().setAcceptAlianceProbabilityWhenLike(0.2);
        player1.getPlayerCharacter().setAcceptPeaceProbability(0.3);
        player1.getPlayerCharacter().setQtyCraftPerPlanetToDeclareWar(4);
        player1.getPlayerCharacter().setMaxTimeBetweenFleets(30);
        player1.getPlayerCharacter().setCraftsSpecialWeapons((String[])null);
        player1.getPlayerCharacter().setCraftsSpecialWeapons("XXX");
        player1.getPlayerCharacter().setCraftsSpecialWeapons("YYY");
        player1.getPlayerCharacter().setCraftsWantPsiShields(true);
        player1.getPlayerCharacter().setResourceful(true);
        player1.getPlayerCharacter().setImmunity(new ImmunityBio());
        player1.getPlayerCharacter().setImmunity(new ImmunityMindControl());
        player1.getPlayerCharacter().setImmunity(new ImmunityGravity());
        player1.getPlayerCharacter().setImmunity(new ImmunityPsi());
        player1.getPlayerCharacter().setImmunity(new ImmunityReplicaBeam());
        GeneralTechnologyList missed = new GeneralTechnologyList();
        missed.add(tech_ComputerisedLabI);
        missed.add(tech_basicComputerisedFactory);
        player1.getPlayerCharacter().setMissedTechnologies(missed);
        player1.setSalvage(new SalvageList(tech_fusionBeam4));
        player1.getCraftBuildExperienceNotNull().addDesignExperience(tech_flyer60.getName());
        
        GeneralDetails generalDetails = GeneralDetailsList.getInstance().getGeneralDetails("TestGeneral");
        LeaderFactory.addGeneralLeaderTo(player1, generalDetails);
        player1.getGeneralLeader().setExperience(5);
        GovenorDetails govenorDetails = GovenorDetailsList.getInstance().getGovenorDetails("TestGovenor");
        LeaderFactory.addGovenorLeaderTo(player1, govenorDetails);
        player1.getGovenorLeader().setExperience(5);
        
        player1.add(MoralChoices.getMoralChoice(TEST_MORAL_CHOICE));

        player1.setSpyRecruitEffortPerTurn(25);
        player1.getSpyCenter().setQtyBuiltSpies(50);
        player1.getSpyCenter().setTotalEffort(250);
        player1.setFleetWayPoint(new Orbit(planet2));
        
        GameScoreData gsd = new GameScoreData();
        gsd.addCraftBuilt(tech_flyer30, 6);
        gsd.addCraftBuilt(tech_flyer60, 1);
		player1.setGameScoreData(gsd);
        // Test Relations and treaties
        MotEngine engine = MotEngine.instance;
		Relations rels = engine.getRelations();
        Relation r = rels.getRelationshipNotNull(player1, player2);
        r.setValue(65);
        TradeAgreementTreaty tt = new TradeAgreementTreaty(player1, player2);
        tt.setResource1(Resources.energySpores);
        tt.setResource2(Resources.psiFungus);
        tt.setDateStarted(2999);
        r.addTreaty(tt);
        ResearchAgreementTreaty rt = new ResearchAgreementTreaty(player1, player2);
        rt.setMissedTechnologies1(new GeneralTechnologyList(tech_ancientEngine));
        rt.setMissedTechnologies2(new GeneralTechnologyList(tech_ancientShieldLarge, tech_auto_repair_unit));
        rt.setDateStarted(2998);
        r.addTreaty(rt);
        rels.setAliance(player1, player2);

        rels.setWar(player1, player3);
        Relation r3 = rels.getRelationshipNotNull(player1, player3);
        r3.setValue(25);

		player2.setFunds(701);
		player2.setBoralium(99);
		
        rels.setNonAgression(player2, player3);
        MotEngine.instance.getSpies().addDefendingSpies(player1, 3);
        Relation r2 = rels.getRelationshipNotNull(player2, player3);
        r2.setValue(46);

        GalaxyDetails gd = engine.getStellarObjects().getGalaxyDetails();
        gd.setSize(new Size(900,900));
        engine.getStellarObjects().add(new BlackHole("BlackHole1", 500,500, 0.1f, false));
        engine.getStellarObjects().getGalaxyDetails().setNebulae(new Nebula("Nebula1", 600,602, 102));

        // Create Craft in Orbit
        craft1 = newCraft(fighterDesign, player1, ss1);

        // Create Craft at warp between ss1 and ss7
        craft2 = newCraft(fighterDesign, player1, ss1);
        craft2.moveTo(ss7.getOrbit());
        craft2.endTurn();
        craft2.setHasMoved(true);

        // Create fleet containing craft3 in orbit of ss2
        craft3 = newCraft(fighterDesign, player1, ss2);
        fleet1 = FleetFactory.create(craft3);
        
        // Test basic planet characteristics
        planet1.setSize(110);
        planet1.setTeraforming(0.98);
        planet1.setPopulation(25); // 5 colonists moved onto transport!
        planet1.setMoneyBonus(5);
        planet1.setReproductionBonus(1.1);
        planet1.setProductionBonus(1.2);
        planet1.setResearchBonus(1.3);
        planet1.setQtyFactories(15);
        planet1.setQtyGroundDefense(9);
        planet1.setHasAsteroids(true);
        planet1.setInfluence(99.9);
        planet1.setHasNatives(true);
        planet1.setQtyNatives(15);
        planet2.setOrigin(player1);
        planet2.setHasNatives(false);
        
        // Test that planet weapons, shields and scanners are saved correctly
        AsteroidFieldConstruction asteroidField = (AsteroidFieldConstruction) Technologies.getMiscTechnology(TestTechs.MISC_ASTEROIDS);
        Weapons weapons = new Weapons();
        weapons.add(tech_massDriver1);
        weapons.add(tech_massDriver1);
        planet1.setWeapons(weapons);
        planet1.setShields(new Shields(tech_energy10));
        planet1.setScanners(new Scanners(tech_photon100));
        
        // Test planet 1 with mining station on planet 1 mine
        Orbital mine = new Orbital(tech_spaceStation, tech_photon100, null);
        mine.addModule(tech_habitatI);
        mine.addModule(tech_oreExtractor);
        mine.addModule(tech_researchModule);
        planet1mine.setOrbital(mine);
        planet1.setMiningStation(new OrbitalReference(planet1mine));
        
        // Test that planet build craft and build weapon is saved correctly
        planet1.setProject(new ProjectCraft(fighterDesign, planet1, false));
        planet1.setProduction(50);
        planet1.setRepeatProject(5);
        
        planet2.setProject(new ProjectWeapon(new WeaponDesign(tech_massDriver1)));
        planet3.setWeapons(new Weapons(tech_massDriver1));
        //planet3.setProject(new ProjectWeaponUpgrade(new WeaponUpgradeDesign(tech_massDriver1, tech_fusionBeam4, planet3.getWeapons())));
        planet4.setProject(new ProjectShield(new ShieldDesign(tech_energy10)));
        planet6.setShields(new Shields(tech_energy10));
        //planet6.setProject(new ProjectShieldUpgrade(new ShieldUpgradeDesign(tech_energy10, tech_energy20, planet6.getShields())));
        planet7a.setProject(new ProjectBattleStation(new BattleStationDesign(tech_battleStationI)));
        //planet7b.setProject(new ProjectBattleStationUpgrade(new BattleStationUpgradeDesign(tech_battleStationI, tech_battleStationII)));
        planet7c.setProject(new ProjectScanner(new ScannerDesign(tech_photon100)));
        planet7d.setScanners(new Scanners(tech_photon100));
        //planet7d.setProject(new ProjectScannerUpgrade(new ScannerUpgradeDesign(tech_photon100, tech_photon150, planet7d.getScanners())));
        planet7e.setProject(new ProjectOutpost(new OutpostDesign(tech_outpost), ss2));
        planet7f.setProject(new ProjectSpaceStation(new SpaceStationDesign(tech_spaceStation), new Orbit(planet2)));
        planet7g.setProject(new ProjectAsteroids(asteroidField));
        planet7h.setProject(new ProjectConstructPlanet(tech_planetConstruction, "SS1"));
        
        planet1.setOrbital(new Orbital(tech_battleStationI, null, new Modules(tech_habitatI)));
        
        // Test outpost
        Orbital outpostOrbital = new Orbital(tech_outpost, tech_photon150, null);
        ss1.setOutpost(new Outpost(outpostOrbital, player1));
        
        // Test resources
        planet1mine.setResource(new ResourceAntiMatter());
        planet1.setResource(new ResourceWarpCrystal());
        planet2.setResource(new ResourceCloakPalm());
        planet3.setResource(new ResourceTritanOre());
        planet4.setResource(new ResourcePsiFungus());
        planet7a.setResource(new ResourceBoralium());
        planet7b.setResource(new ResourceEnergySpores());
        
        // Test transport enroute to target
        player1.getTransportManagerNotNull().setTransport(new Transport(player1));
        player1.getTransportManager().setTransport(new Transport(player1));
        player1.getTransportManager().setTransport(new Transport(player1));
        player1.getTransportManager().setTransport(new Transport(player1));
        player1.getTransportManager().setTransport(new Transport(player1));
        
        createOutpost(tech_outpost, ss2, planet1);
        Transport outpostTransport = player1.getTransportManager().getTransportsAsArray()[0];
        TransportTaskDeployStation outpostTask = (TransportTaskDeployStation)outpostTransport.getTask();
        outpostTransport.moveTo(ss2.getOrbit());
        outpostTransport.endTurn(); 

        new ProjectSpaceStation(new SpaceStationDesign(tech_spaceStation), new Orbit(planet2)).build(planet1, false);
        Transport stationTransport = player1.getTransportManager().getTransportsAsArray()[1];
        TransportTaskDeployStation stationTask = (TransportTaskDeployStation)stationTransport.getTask();
        stationTransport.moveTo(planet2.getOrbit());
        
        // Test transports
        double tmpPlanet1Pop = planet1.getPopulation();        
        Transport populationTransport = player1.getTransportManager().getFreeTransport();
        new TransportTaskMoveColonists(populationTransport, planet1, planet2, 5);
        planet1.setPopulation(tmpPlanet1Pop);
        
        // test black hole
        blackHole.setOrbital(new SpaceStation(new Orbital(tech_spaceStation, tech_photon100, new Modules(tech_researchModule)), player1));
        
        TradeRouteFactory.create(ss3, ss4);
        
        
        StateUpdateCommandResult cr = new StateUpdateCommandResult();
        engine.addStateUpdate(cr, player1, true, true, true, true, true, true, true, true, true, true, true);
        cr.addStateUpdate(new PlayerDetailsVOAdapter(player1));
        
        cr = (StateUpdateCommandResult) serialiseDeserialise(cr);

        
        PlayerConstantsVO playerconstants1vo = (PlayerConstantsVO) getPlayerConstants(cr, "TestPlayer1");
        assertEquals("player1 is correct", "blue", playerconstants1vo.getColor());
        assertEquals("player1 is correct", "WaterMan", playerconstants1vo.getAlignment());
        assertEquals("player1 is correct", 1.1, playerconstants1vo.getPlayerCharacter().getBattleSpeedBonus(), 0.0);
        assertEquals("player1 is correct", 1.2, playerconstants1vo.getPlayerCharacter().getBattleTurningBonus(), 0.0);
        assertEquals("player1 is correct", 1.05, playerconstants1vo.getPlayerCharacter().getMaxDamageBonus(), 0.0);
        assertEquals("player1 is correct", 1.3, playerconstants1vo.getPlayerCharacter().getSpeedBonus(), 0.0);
        assertEquals("player1 is correct", 1.5, playerconstants1vo.getPlayerCharacter().getProductionBonus(), 0.0);
        assertEquals("player1 is correct", 1.6, playerconstants1vo.getPlayerCharacter().getResearchBonus(), 0.0);
        assertEquals("player1 is correct", 1.7, playerconstants1vo.getPlayerCharacter().getReproductionBonus(), 0.0);
        assertEquals("player1 is correct", 1.25, playerconstants1vo.getPlayerCharacter().getAssaultBonus(), 0.0);
        assertEquals("player1 is correct", 1.8, playerconstants1vo.getPlayerCharacter().getInitiativeBonus(), 0.0);
        assertEquals("player1 is correct", 0.9, playerconstants1vo.getPlayerCharacter().getSpyBonus(), 0.0);
        assertEquals("player1 is correct", 1.9, playerconstants1vo.getPlayerCharacter().getTradingBonus(), 0.0);
        assertEquals("player1 is correct", 0.7, playerconstants1vo.getPlayerCharacter().getEcologyBonus(), 0.0);
        assertEquals("player1 is correct", 2.0, playerconstants1vo.getPlayerCharacter().getFactoryPerPopulationBonus(), 0.0);
        assertEquals("player1 is correct", 20, playerconstants1vo.getPlayerCharacter().getPsiRating());
        assertEquals("player1 is correct", 6, playerconstants1vo.getPlayerCharacter().getMaxPlayerTradeAgreements());
        assertEquals("player1 is correct", 7, playerconstants1vo.getPlayerCharacter().getMaxSolarSystemTradeRoutes());
        assertEquals("player1 is correct", 5, playerconstants1vo.getPlayerCharacter().getCharisma());
        assertEquals("player1 is correct", 10, playerconstants1vo.getPlayerCharacter().getCloakLevel());
        assertEquals("player1 is correct", 2, playerconstants1vo.getPlayerCharacter().getMissedTechnologiesAsList().getQuantity());
        assertEquals("player1 is correct", tech_basicComputerisedFactory, tech_ComputerisedLabI, playerconstants1vo.getPlayerCharacter().getMissedTechnologiesAsList());
        assertEquals("player1 is correct", true, playerconstants1vo.getPlayerCharacter().isResourceful());
        assertEquals("player1 is correct", ImmunityBio.class, playerconstants1vo.getPlayerCharacter().getImmunities()[0].getClass());
        assertEquals("player1 is correct", ImmunityMindControl.class, playerconstants1vo.getPlayerCharacter().getImmunities()[1].getClass());
        assertEquals("player1 is correct", ImmunityGravity.class, playerconstants1vo.getPlayerCharacter().getImmunities()[2].getClass());
        assertEquals("player1 is correct", ImmunityPsi.class, playerconstants1vo.getPlayerCharacter().getImmunities()[3].getClass());
        assertEquals("player1 is correct", ImmunityReplicaBeam.class, playerconstants1vo.getPlayerCharacter().getImmunities()[4].getClass());

        RelationVO relation1 = (RelationVO) getRelation(cr, "TestPlayer1", "TestPlayer2");
        assertEquals("Test relations and treaties", 65, relation1.getValue());
        assertEquals("Test relations and treaties", true, relation1.isAliance());
        assertEquals("Test relations and treaties", false, relation1.isNonAgression());
        assertEquals("Test relations and treaties", false, relation1.isPeace());
        assertEquals("Test relations and treaties", false, relation1.isWar());
        assertEquals("Test relations and treaties", 2999, relation1.getTradeAgreement().getDate());
        assertEquals("Test relations and treaties", 15, relation1.getTradeAgreement().getMoney());
        assertEquals(Resources.psiFungus, relation1.getTradeAgreement().getResourceGiven());
        assertEquals(Resources.energySpores, relation1.getTradeAgreement().getResourceTaken());
        assertEquals("Test relations and treaties", 2998, relation1.getResearchAgreement().getDate());
        assertEquals("Test relations and treaties", 3, relation1.getResearchAgreement().getResearch());
        assertEquals(tech_ancientEngine, relation1.getResearchAgreement().getPlayer1VoidedMissedTechnologies().getAllAsArray());
        assertEquals(tech_ancientShieldLarge, tech_auto_repair_unit, relation1.getResearchAgreement().getPlayer2VoidedMissedTechnologies().getAllAsArray());
        
        RelationVO relation2 = (RelationVO) getRelation(cr, "TestPlayer1", "TestPlayer3");
        assertEquals("Test relations and treaties", 25, relation2.getValue());
        assertEquals("Test relations and treaties", false, relation2.isAliance());
        assertEquals("Test relations and treaties", false, relation2.isNonAgression());
        assertEquals("Test relations and treaties", false, relation2.isPeace());
        assertEquals("Test relations and treaties", true, relation2.isWar());
        assertNull(relation2.getTradeAgreement());
        assertNull(relation2.getResearchAgreement());
        
        UserPlayerVO player1vo = (UserPlayerVO) getPlayer(cr, "TestPlayer1");
        assertEquals("player1 is correct", "TestGeneral", player1vo.getGeneralName());
        assertEquals("player1 is correct", 5, player1vo.getGeneralExperience());
        assertEquals("player1 is correct", "TestGovenor", player1vo.getGovenorName());
        assertEquals("player1 is correct", 5, player1vo.getGovenorExperience());
        assertEquals("player1 is correct", 700, player1vo.getFunds());
        assertEquals("player1 is correct", 2, player1vo.getQtyFreeTransport());
        assertEquals("player1 is correct", 71, player1vo.getBoralium());
        assertEquals("player1 is correct", tech_fusionBeam4.getFullName(), player1vo.getSalvage());
        
        PlayerDetailsVO player1detailsvo = getPlayerDetails(cr, "TestPlayer1");
        assertEquals("player1 is correct", MoralChoices.getMoralChoice(TEST_MORAL_CHOICE), player1detailsvo.getMoralChoices());

        PlayerTechnologiesVO player1techsvo = getPlayerTechnologies(cr, "TestPlayer1");
        assertEquals("player1 is correct", true, player1techsvo.getAllAsList().contains(tech_fusion25));
        assertEquals("player1 is correct", true, player1techsvo.getAllAsList().contains(tech_fusion25x));
        assertEquals("player1 is correct", true, player1techsvo.getAllAsList().contains(tech_massDriver1));
        assertEquals("player1 is correct", true, player1techsvo.getAllAsList().contains(tech_massDriver2));
        assertEquals("player1 is correct", true, player1techsvo.getAllAsList().contains(tech_energy10));
        assertEquals("player1 is correct", true, player1techsvo.getAllAsList().contains(tech_armour25));
        assertEquals("player1 is correct", true, player1techsvo.getAllAsList().contains(tech_photon150));
        assertEquals("player1 is correct", true, player1techsvo.getAllAsList().contains(tech_terraforming10));
        assertEquals("player1 is correct", true, player1techsvo.getAllAsList().contains(tech_researchLabI));
        assertEquals("player1 is correct", true, player1techsvo.getAllAsList().contains(tech_basicComputerisedFactory));
        assertEquals("player1 is correct", true, player1techsvo.getAllAsList().contains(tech_ComputerisedLabI));
        assertEquals("player1 is correct", true, player1techsvo.getAllAsList().contains(tech_habitatI));
        assertEquals("player1 is correct", true, player1techsvo.getAllAsList().contains(tech_planetConstruction));        
        
        ComputerPlayerVO player2vo = (ComputerPlayerVO)getPlayer(cr, "TestPlayer2");
        assertEquals("player1 is correct", 701, player2vo.getFunds());
        assertEquals("player1 is correct", 99, player2vo.getBoralium());
        
        SolarSystemVO solarsystem1vo = (SolarSystemVO) getStellarObject(cr, "SS1");
		assertEquals("SS1", solarsystem1vo.getName());
		assertEquals(100,100, solarsystem1vo.getLocation());
		assertEquals(3000, solarsystem1vo.getLastVisitiedDate());
		//assertEquals("Red", solarsystem1vo.getStarType());
        
        BlackHoleVO blackhole1vo = (BlackHoleVO) getStellarObject(cr, "BlackHole1");
		assertEquals(500,500, blackhole1vo.getLocation());
		assertEquals(0.1f, blackhole1vo.getResearchBonus());
		assertEquals(false, blackhole1vo.isSpaceJumpAbility());

        GalaxyDetails galaxyDetails = (GalaxyDetails) cr.getType(GalaxyDetails.class);
        Nebula[] nebulae = galaxyDetails.getNebulaeAsArray();
		assertEquals(900,900, galaxyDetails.getSize());
		assertEquals(1, nebulae.length);
		assertEquals(600,602, nebulae[0].getLocation());
		assertEquals(102, nebulae[0].getDiameter());
		
        CraftVO craft1vo = getCraft(cr, "TestFighter1");
        assertEquals("craft1 is correct", 100,100, craft1vo.getLocation());
        assertEquals("craft1 is correct", ss1, craft1vo.getOrbit().getStellarObject());
        assertEquals("craft1 is correct", null, craft1vo.getNavigator());
        assertEquals("craft1 is correct", player1, craft1vo.getOwner());
        assertEquals("craft1 is correct", 1.0, craft1vo.getBuildQualityAsPercent());
        assertEquals("craft1 is correct", 0.0, craft1vo.getDamageAsPercent());
        assertEquals("craft1 is correct", 150, craft1vo.getRange());
        assertEquals("craft1 is correct", player1, craft1vo.getOwner());
        assertEquals("craft1 is correct", player1, craft1vo.getOrigin());
        assertEquals("craft1 is correct", craft1, craft1vo.getDesign());

        CraftVO craft2vo = getCraft(cr, "TestFighter2");
        assertEquals("craft2 is correct", "TestFighter2", craft2.getName());
        assertNull(  "craft2 is correct",craft2.getOrbit());
        assertEquals("craft2 is correct", ss7, craft2.getNavigator().getDestination().getStellarObject());
        assertEquals("craft2 is correct", null, craft2.getNavigator().getDestination().getPlanet());
        assertEquals("craft2 is correct", player1, craft2.getOwner());
        assertEquals("craft2 is correct", true, craft2.hasMoved());

        CraftVO craft3vo = getCraft(cr, "TestFighter3");
        assertEquals("fleet1 is correct", "Fleet1", fleet1.getName());
        assertEquals("fleet1 is correct", "TestFighter3", craft3.getName());
        assertEquals("fleet1 is correct", fleet1, craft3.getFleet());
        assertEquals("fleet1 is correct", ss2, craft3.getOrbit().getStellarObject());
        assertEquals("fleet1 is correct", null, craft3.getNavigator());
        assertEquals("fleet1 is correct", player1, craft3.getOwner());

        FleetVO fleetvo = getFleet(cr, "Fleet1");
        assertEquals("fleet1 is correct", 1, fleetvo.getCrafts().length);
        assertEquals("fleet1 is correct", "TestFighter3", fleetvo.getCrafts()[0]);

        PlanetVO planet1vo = getPlanet(cr, "SS1-A");
        assertEquals("Test planet", "SS1", planet1vo.getSolarSystem());
        assertEquals("Test planet", 110, planet1vo.getSize());
        assertEquals("Test planet", 0.98, planet1vo.getTeraforming(), 0.0);
        assertEquals("Test planet", 25, planet1vo.getPopulation(), 0.0);
        assertEquals("Test planet", 5, planet1vo.getMoneyBonus());
        assertEquals("Test planet", 1.1, planet1vo.getReproductionBonus(), 0.0);
        assertEquals("Test planet", 1.2, planet1vo.getProductionBonus(), 0.0);
        assertEquals("Test planet", 1.3, planet1vo.getResearchBonus(), 0.0);
        assertEquals("Test planet", 15, planet1vo.getQtyFactories(), 0.0);
        assertEquals("Test planet", 9, planet1vo.getQtyGroundDefense());
        assertEquals("Test planet", true, planet1vo.hasAsteroids());
        assertEquals("Test planet", true, planet1vo.hasNatives());
        assertEquals("Test planet", player1, planet1vo.getOwner());
        assertEquals("Test planet", player1, planet1vo.getOrigin());

        assertEquals("Test planet installations", tech_massDriver1, tech_massDriver1, planet1vo.getWeapons());
        assertEquals("Test planet installations", tech_energy10, planet1vo.getShields());
        assertEquals("Test planet installations", tech_photon100, planet1vo.getScanners());
        assertEquals("Test planet installations", tech_battleStationI, planet1vo.getOrbital().getHullTech());
        assertEquals("Test planet installations", tech_habitatI, planet1vo.getOrbital().getModuleTechs().getModuleAtIndex(0));

        // Test outpost
        StellarObjectOrbitalVO outpostOrbitalvo = getStellarObject(cr, "SS1").getOrbital();
        assertEquals("Test Outpost", tech_outpost, outpostOrbitalvo.getOrbital().getHullTech());
        assertEquals("Test Outpost", tech_photon150, outpostOrbitalvo.getOrbital().getScannerTech());
        assertEquals("Test Outpost", null, outpostOrbitalvo.getOrbital().getModuleTechs());

        // Test Mining Station
        assertEquals("Test planet Space Station", planet1mine, planet1vo.getMiningColony());
        PlanetVO planet1minevo = getPlanet(cr, "SS1-MINE");
        Orbital minevo = planet1minevo.getOrbital();
        assertEquals("Test planet Space Station", tech_habitatI, tech_oreExtractor, tech_researchModule, minevo.getModuleTechs());
        assertEquals("Test planet Space Station", tech_photon100, minevo.getScannerTech());
        assertEquals("Test planet Space Station", tech_spaceStation, minevo.getHullTech());        
        
        assertEquals("Test planet project", "TestFighter", planet1.getProject().getName());
        assertEquals("Test planet project", 50, planet1.getProduction());
        assertEquals("Test planet project", 5, planet1.getRepeatProject());

        assertEquals("Test planet project", TestTechs.MASS_DRIVER1, planet2.getProject().getName());
        //assertEquals("Test planet project", "Upgrade "+TestTechs.MASS_DRIVER1+" to "+TestTechs.FUSION_BEAM4, planet3.getProject().getName());
        assertEquals("Test planet project", TestTechs.ENERGY10, planet4.getProject().getName());
        //assertEquals("Test planet project", "Upgrade "+TestTechs.ENERGY10+" to "+TestTechs.ENERGY20, planet6.getProject().getName());
        assertEquals("Test planet project", TestTechs.BATTLE_STATIONI, planet7a.getProject().getName());
        //assertEquals("Test planet project", "Upgrade "+TestTechs.BATTLE_STATIONI+" to "+TestTechs.BATTLE_STATIONII, planet7b.getProject().getName());
        
        assertEquals("Test planet project", tech_massDriver1, ((WeaponDesign)getPlanet(cr, "SS2-A").getProject().getDesign()).getWeapon());
        //assertEquals("Test planet project", tech_massDriver1, ((WeaponUpgradeDesign)getPlanet(cr, "SS3-A").getProject().getDesign()).getOldWeapon());
        //assertEquals("Test planet project", tech_fusionBeam4, ((WeaponUpgradeDesign)getPlanet(cr, "SS3-A").getProject().getDesign()).getNewWeapon());
        assertEquals("Test planet project", tech_energy10, ((ShieldDesign)getPlanet(cr, "SS4-A").getProject().getDesign()).getShield());
        //assertEquals("Test planet project", tech_energy10, ((ShieldUpgradeDesign)getPlanet(cr, "SS6-A").getProject().getDesign()).getOldShield());
        //assertEquals("Test planet project", tech_energy20, ((ShieldUpgradeDesign)getPlanet(cr, "SS6-A").getProject().getDesign()).getNewShield());
        assertEquals("Test planet project", tech_battleStationI, ((BattleStationDesign)getPlanet(cr, "SS7-A").getProject().getDesign()).getBattleStation());
        //assertEquals("Test planet project", tech_battleStationI, ((BattleStationUpgradeDesign)getPlanet(cr, "SS7-B").getProject().getDesign()).getOldBattleStation());
        //assertEquals("Test planet project", tech_battleStationII, ((BattleStationUpgradeDesign)getPlanet(cr, "SS7-B").getProject().getDesign()).getNewBattleStation());
        assertEquals("Test planet project", tech_photon100, ((ScannerDesign)getPlanet(cr, "SS7-C").getProject().getDesign()).getScanner());
        //assertEquals("Test planet project", tech_photon100, ((ScannerUpgradeDesign)getPlanet(cr, "SS7-D").getProject().getDesign()).getOldScanner());
        //assertEquals("Test planet project", tech_photon150, ((ScannerUpgradeDesign)getPlanet(cr, "SS7-D").getProject().getDesign()).getNewScanner());
        assertEquals("Test planet project", tech_outpost, ((OutpostDesign)getPlanet(cr, "SS7-E").getProject().getDesign()).getOutpost());
        assertEquals("Test planet project", tech_spaceStation, ((SpaceStationDesign)getPlanet(cr, "SS7-F").getProject().getDesign()).getSpaceStation());
        assertEquals("Test planet project", tech_asteroidFieldConstruction, ((AsteroidDesign)getPlanet(cr, "SS7-G").getProject().getDesign()).getAsteroids());
        assertEquals("Test planet project", tech_planetConstruction, ((ConstructPlanetDesign)getPlanet(cr, "SS7-H").getProject().getDesign()).getPlanetConstructionTech());
        
        PlanetVO planet2vo = getPlanet(cr, "SS2-A");
        PlanetVO planet3vo = getPlanet(cr, "SS3-A");
        PlanetVO planet4vo = getPlanet(cr, "SS4-A");
        PlanetVO planet7avo = getPlanet(cr, "SS7-A");
        PlanetVO planet7bvo = getPlanet(cr, "SS7-B");
        assertEquals("Test Resources", new ResourceAntiMatter().getName(), planet1minevo.getResource());
        assertEquals("Test Resources", new ResourceWarpCrystal().getName(), planet1vo.getResource());
		assertEquals("Test Resources", new ResourceCloakPalm().getName(), planet2vo.getResource());
        assertEquals("Test Resources", new ResourceTritanOre().getName(), planet3vo.getResource());
        assertEquals("Test Resources", new ResourcePsiFungus().getName(), planet4vo.getResource());
        assertEquals("Test Resources", new ResourceBoralium().getName(), planet7avo.getResource());
        assertEquals("Test Resources", new ResourceEnergySpores().getName(), planet7bvo.getResource());
        
        BlackHoleVO blackholevo = (BlackHoleVO) getStellarObject(cr, blackHole.getName());
        assertEquals("Test Black Hole", tech_spaceStation,   ((SpaceStationVO)blackholevo.getOrbital()).getOrbital().getHullTech());
        assertEquals("Test Black Hole", 1,                   ((SpaceStationVO)blackholevo.getOrbital()).getOrbital().getModuleTechs().getModules().length);
        assertEquals("Test Black Hole", tech_researchModule, ((SpaceStationVO)blackholevo.getOrbital()).getOrbital().getModuleTechs().getModules()[0]);
        assertEquals("Test Black Hole", player1.getName(), 	 ((SpaceStationVO)blackholevo.getOrbital()).getOwner());
        assertEquals("Test Black Hole", tech_photon100,      ((SpaceStationVO)blackholevo.getOrbital()).getOrbital().getScannerTech());
       
        TradeRouteListVO tradeRoutes = (TradeRouteListVO) cr.getType(TradeRouteListVO.class);
        assertEquals(ss3, ss4, 3000, tradeRoutes.getTradeRoutes()[0]);
    }
    
    public void testFetchGraph() throws Exception {
        Logger.logDebug("*******************************  GeometryTest.testFetchGraph() *************************");
        init();
        
        Graph graph = new Graph();
        player1.setGraph(graph);
        graph.add("TESTLINE1", 3000, 10);
        graph.add("TESTLINE1", 3010, 20);
        graph.add("TESTLINE2", 2, 1);
        
	    GraphState graphCr = (GraphState) new FetchGraphCmdHandler().process(null, player1.getName(), null);
	    graphCr = (GraphState) serialiseDeserialise(graphCr);
	    graph = graphCr.getGraphPlayerState()[0].getGraph();
	    assertEquals("Has correct Graph", 2, graph.getGraphLines().length);
	    assertEquals("Has correct Graph", "TESTLINE1", graph.getGraphLines()[0].getName());
	    assertEquals("Has correct Graph", 2, graph.getGraphLines()[0].getStatsData().length);
	    assertEquals("Has correct Graph", 3000, graph.getGraphLines()[0].getStatsData()[0].getDate());
	    assertEquals("Has correct Graph", 10, graph.getGraphLines()[0].getStatsData()[0].getValue());
	    assertEquals("Has correct Graph", 3010, graph.getGraphLines()[0].getStatsData()[1].getDate());
	    assertEquals("Has correct Graph", 20, graph.getGraphLines()[0].getStatsData()[1].getValue());
	    assertEquals("Has correct Graph", "TESTLINE2", graph.getGraphLines()[1].getName());
	    assertEquals("Has correct Graph", 1, graph.getGraphLines()[1].getStatsData().length);
	    assertEquals("Has correct Graph", 2, graph.getGraphLines()[1].getStatsData()[0].getDate());
	    assertEquals("Has correct Graph", 1, graph.getGraphLines()[1].getStatsData()[0].getValue());
    }
    
    public void testBattleEvents() throws Exception {
        Logger.logDebug("*******************************  GeometryTest.testBattleEvents() *************************");
        init();
        
        Battle battle = MotEngine.getInstance().getBattlesNotNull().getBattleAt(planet1.getOrbit(), true);
        battle.join(craft1, true);
        battle.join(craft2, false);
        battle.setup();
        
        BattleCraft[] bca = battle.getCrafts();
        
        bca[0].setLocation(new Location(200,200));
        bca[0].setDirection(90);
        
        BattleCraftLeaveEvent e1 = new BattleCraftLeaveEvent("Battle", "Craft");
        e1 = (BattleCraftLeaveEvent) serialiseDeserialise(e1);
	    assertEquals("Battle", e1.getBattle());
	    assertEquals("Craft", e1.getCraft());
        
	    ObjectMovement[] ma = new ObjectMovement[2];
	    ma[0] = new ObjectTurn(90, 0.1, bca[0].getCraftState(player1));
	    ma[1] = new ObjectShift(new Location(300,300), 0.1, bca[0].getCraftState(player1));
		BattleCraftMoveEvent e2 = new BattleCraftMoveEvent("Battle", "Craft", bca[0].getCraftState(player1), ma);
        e2 = (BattleCraftMoveEvent) serialiseDeserialise(e2);
	    assertEquals("Battle", e2.getBattle());
	    assertEquals("Craft", e2.getName());
	    assertEquals(90, ((ObjectTurn)e2.getMovements()[0]).getTo());
	    assertEquals(300,300, ((ObjectShift)e2.getMovements()[1]).getDestination());
	    assertEquals(bca[0], e2.getCraftState());
	    
	    BattleCraftNewEvent e3 = new BattleCraftNewEvent("Battle", new BattleCraftVOAdapter(bca[0], player1), true);
        e3 = (BattleCraftNewEvent) serialiseDeserialise(e3);
	    assertEquals("Battle", e3.getBattle());
	    assertEquals(bca[0], e3.getBattleCraft().getSpeed());
	    assertEquals(bca[0], e3.getBattleCraft().getState());
	    assertEquals(bca[0], e3.getBattleCraft().getWeaponState());
	    
	    BattleCraftSurrenderEvent e4 = new BattleCraftSurrenderEvent("Battle", "Craft", bca[0].getCraftState(player1), bca[0].getCraftState(player1));
        e4 = (BattleCraftSurrenderEvent) serialiseDeserialise(e4);
	    assertEquals("Battle", e4.getBattle());
	    assertEquals("Craft", e4.getCraft());
	    assertEquals(bca[0], e4.getOldState());
	    assertEquals(bca[0], e4.getNewState());
	    
	    BattleCraftTeleportEvent e5 = new BattleCraftTeleportEvent("Battle", "Craft", bca[0].getCraftState(player1), bca[0].getCraftState(player1), 0.1);
        e5 = (BattleCraftTeleportEvent) serialiseDeserialise(e5);
	    assertEquals("Battle", e5.getBattle());
	    assertEquals("Craft", e5.getCraft());
	    assertEquals(bca[0], e5.getOldState());
	    assertEquals(bca[0], e5.getNewState());
	    assertEquals(0.1, e5.getPercentMove(), 0.001);
	    
	    BattleCraftUpdateEvent e6 = new BattleCraftUpdateEvent("Battle", "Craft", bca[0].getCraftState(player1));
        e6 = (BattleCraftUpdateEvent) serialiseDeserialise(e6);
	    assertEquals("Battle", e6.getBattle());
	    assertEquals("Craft", e6.getCraft());
	    assertEquals(bca[0], e6.getNewState());
	    
	    BattleDamageEvent e7 = new BattleDamageEvent("Battle", "Craft", new Damage("TS", 1.0, 2.0, true, bca[0].getCraftState(player1), bca[0].getCraftState(player1)));
        e7 = (BattleDamageEvent) serialiseDeserialise(e7);

	    assertEquals("Battle", e7.getBattle());
	    assertEquals("Craft", e7.getTarget());
	    assertEquals("TS", e7.getDamage().getTargetDescription());
	    assertEquals(bca[0], e7.getDamage().getOldTargetState());
	    assertEquals(bca[0], e7.getDamage().getNewTargetState());
	    
	    BattleDamageRingEvent e8 = new BattleDamageRingEvent("Battle", "Craft", bca[0].getCraftState(player1), bca[0].getCraftState(player1), new Location(300,300), 2, "Weapon");
        e8 = (BattleDamageRingEvent) serialiseDeserialise(e8);
	    assertEquals("Battle", e8.getBattle());
	    assertEquals("Craft", e8.getSource());
	    assertEquals(bca[0], e8.getOldState());
	    assertEquals(bca[0], e8.getNewState());
	    assertEquals(300,300, e8.getLocation());
	    assertEquals("Weapon", e8.getWeapon());
	    
	    BattleDestroyedEvent e9 = new BattleDestroyedEvent("Battle", "Craft", bca[0].getCraftState(player1), true);
        e9 = (BattleDestroyedEvent) serialiseDeserialise(e9);
	    assertEquals("Battle", e9.getBattle());
	    assertEquals("Craft", e9.getTarget());
	    assertEquals(bca[0], e9.getOldState());
	    assertEquals(true, e9.isHologram());
	    
	    BattleDroidMineLaunchEvent e10 = new BattleDroidMineLaunchEvent("Battle", new DroidMineVO("Craft", "Battle", bca[0].getCraftState(player1), "Origin", "Target"));
        e10 = (BattleDroidMineLaunchEvent) serialiseDeserialise(e10);
	    assertEquals("Battle", e10.getBattle());
	    assertEquals(bca[0], e10.getDroidMine().getState());
	    assertEquals("Battle", e10.getDroidMine().getBattle());
	    assertEquals("Target", e10.getDroidMine().getTarget());
	    assertEquals("Origin", e10.getDroidMine().getOrigin());
	    
	    BattleDroidMineMoveEvent e11 = new BattleDroidMineMoveEvent("Battle", "DM", new Location(300,300), new Location(400,400), bca[0].getCraftState(player1), bca[0].getCraftState(player1));
        e11 = (BattleDroidMineMoveEvent) serialiseDeserialise(e11);
	    assertEquals("Battle", e11.getBattle());
	    assertEquals("DM", e11.getDroidMine());
	    assertEquals(bca[0], e11.getState());
	    assertEquals(bca[0], e11.getTargetState());
	    assertEquals(300,300, e11.getFrom());
	    assertEquals(400,400, e11.getTo());

	    String[] dca = new String[2];
	    dca[0] = "C1";
	    dca[1] = "C2";
		BattleEndEvent e12 = new BattleEndEvent("Battle", dca );
        e12 = (BattleEndEvent) serialiseDeserialise(e12);
	    assertEquals("Battle", e12.getBattle());
	    assertEquals(dca, e12.getCraftDestroyd());
	    
	    BattleFearEvent e13 = new BattleFearEvent("Battle", "Craft", new Location(300,300), "Target");
        e13 = (BattleFearEvent) serialiseDeserialise(e13);
	    assertEquals("Battle", e13.getBattle());
	    assertEquals("Craft", e13.getSource());
	    assertEquals("Target", e13.getTarget());
	    assertEquals(300,300, e13.getLocation());
	    
	    BattleMissileLaunchEvent e14 = new BattleMissileLaunchEvent("Battle", new MissilesVO("Craft", "Battle", bca[0].getCraftState(player1), "Origin", "Target"));
        e14 = (BattleMissileLaunchEvent) serialiseDeserialise(e14);
	    assertEquals("Battle", e14.getBattle());
	    assertEquals(bca[0], e14.getMissile().getState());
	    assertEquals("Battle", e14.getMissile().getBattle());
	    assertEquals("Origin", e14.getMissile().getOrigin());
	    assertEquals("Target", e14.getMissile().getTarget());
	    
	    BattleMissileMoveEvent e15 = new BattleMissileMoveEvent("Battle", "MM", new Location(300,300), new Location(400,400), bca[0].getCraftState(player1), bca[0].getCraftState(player1));
        e15 = (BattleMissileMoveEvent) serialiseDeserialise(e15);
	    assertEquals("Battle", e15.getBattle());
	    assertEquals("MM", e15.getMissile());
	    assertEquals(bca[0], e15.getState());
	    assertEquals(bca[0], e15.getTargetState());
	    assertEquals(300,300, e15.getFrom());
	    assertEquals(400,400, e15.getTo());

	    BattleNewTurnEvent e16 = new BattleNewTurnEvent("Battle");
        e16 = (BattleNewTurnEvent) serialiseDeserialise(e16);
	    assertEquals("Battle", e16.getBattle());

	    BattleObjectNotificationEvent e17 = new BattleObjectNotificationEvent("Battle", "Target", "Message", BattleObjectNotificationType.plague, bca[0].getCraftState(player1), bca[0].getCraftState(player1));
        e17 = (BattleObjectNotificationEvent) serialiseDeserialise(e17);
	    assertEquals("Battle", e17.getBattle());
	    assertEquals("Target", e17.getTarget());
	    assertEquals("Message", e17.getMessage());
	    assertEquals(BattleObjectNotificationType.plague, e17.getType());
	    assertEquals(bca[0], e17.getOldTargetState());
	    assertEquals(bca[0], e17.getNewTargetState());

	    BattleObjectTriggerEvent e19 = new BattleObjectTriggerEvent("Battle", "Target", "Type", bca[0].getCraftState(player1), bca[0].getCraftState(player1), "Message");
        e19 = (BattleObjectTriggerEvent) serialiseDeserialise(e19);
	    assertEquals("Battle", e19.getBattle());
	    assertEquals("Target", e19.getBattleObject());
	    assertEquals("Message", e19.getDescription());
	    assertEquals("Type", e19.getType());
	    assertEquals(bca[0], e19.getOriginalState());
	    assertEquals(bca[0], e19.getNewState());

	    BattleStateUpdateContainerEvent e20 = new BattleStateUpdateContainerEvent("Battle");
	    e20.addStateUpdate(new BattleVOAdapter(battle));
        e20 = (BattleStateUpdateContainerEvent) serialiseDeserialise(e20);
	    assertEquals("Battle", e20.getBattle());
	    assertEquals("Battle1", ((BattleVO)e20.getStateUpdates()[0]).getName());
	    assertEquals(battle.getOrbit(), ((BattleVO)e20.getStateUpdates()[0]).getOrbit());

	    WreckageDetails wreckage = new WreckageDetails(new Rectangle(400, 400, 10, 20), "Wreckage");
	    BattleWeaponFireEvent e21 = new BattleWeaponFireEvent("Battle", "Source", "Target", "Weapon", 2.0, 3.0, true, new Location(300,300), true, bca[0].getCraftState(player1), bca[0].getCraftState(player1), bca[0].getCraftState(player1), bca[0].getCraftState(player1), "SourceDescription", "TargetDescription", "AnimationConfig", wreckage);
        e21 = (BattleWeaponFireEvent) serialiseDeserialise(e21);
	    assertEquals("Battle", e21.getBattle());
	    assertEquals("Source", e21.getSource());
	    assertEquals("Target", e21.getTarget());
	    assertEquals("Weapon", e21.getWeapon());
	    assertEquals(2.0, e21.getDamage().getDamage());
	    assertEquals(3.0, e21.getDamage().getShieldBlockedDamage());
	    assertEquals(true, e21.getDamage().getDestroyed());
	    assertEquals(300,300, e21.getDamage().getTargetLocation());
	    assertEquals("SourceDescription", e21.getSourceDescription());
	    assertEquals("TargetDescription", e21.getTargetDescription());
	    assertEquals("AnimationConfig", e21.getAnimationConfigNameSuffix());
	    assertEquals(bca[0], e21.getOldSourceState());
	    assertEquals(bca[0], e21.getNewSourceState());
	    assertEquals(bca[0], e21.getOldTargetState());
	    assertEquals(bca[0], e21.getNewTargetState());
	    assertEquals(410,410, ((WreckageDetails)e21.getData()).getCenterLocation());

	    SpaceDistortionDetails sdd = new SpaceDistortionDetails(10,20,30,40);
	    BattleWeaponFireEvent e22 = new BattleWeaponFireEvent("Battle", "Source", "Target", "Weapon", 2.0, 3.0, true, new Location(300,300), true, bca[0].getCraftState(player1), bca[0].getCraftState(player1), bca[0].getCraftState(player1), bca[0].getCraftState(player1), "SourceDescription", "TargetDescription", "AnimationConfig", sdd);
	    e22 = (BattleWeaponFireEvent) serialiseDeserialise(e22);
	    assertEquals("Battle", e22.getBattle());
	    assertEquals("Source", e22.getSource());
	    assertEquals("Target", e22.getTarget());
	    assertEquals("Weapon", e22.getWeapon());
	    assertEquals(2.0, e22.getDamage().getDamage());
	    assertEquals(3.0, e22.getDamage().getShieldBlockedDamage());
	    assertEquals(true, e22.getDamage().getDestroyed());
	    assertEquals(300,300, e22.getDamage().getTargetLocation());
	    assertEquals("SourceDescription", e22.getSourceDescription());
	    assertEquals("TargetDescription", e22.getTargetDescription());
	    assertEquals("AnimationConfig", e22.getAnimationConfigNameSuffix());
	    assertEquals(bca[0], e22.getOldSourceState());
	    assertEquals(bca[0], e22.getNewSourceState());
	    assertEquals(bca[0], e22.getOldTargetState());
	    assertEquals(bca[0], e22.getNewTargetState());
	    assertEquals(25,40, ((SpaceDistortionDetails)e22.getData()).getCenterLocation());

	    TroopBattleResult tbr = new TroopBattleResult(1,2,3,4);
	    BattleWeaponFireEvent e23 = new BattleWeaponFireEvent("Battle", "Source", "Target", "Weapon", 2.0, 3.0, true, new Location(300,300), true, bca[0].getCraftState(player1), bca[0].getCraftState(player1), bca[0].getCraftState(player1), bca[0].getCraftState(player1), "SourceDescription", "TargetDescription", "AnimationConfig", tbr);
	    e23 = (BattleWeaponFireEvent) serialiseDeserialise(e23);
	    assertEquals("Battle", e23.getBattle());
	    assertEquals("Source", e23.getSource());
	    assertEquals("Target", e23.getTarget());
	    assertEquals("Weapon", e23.getWeapon());
	    assertEquals(2.0, e23.getDamage().getDamage());
	    assertEquals(3.0, e23.getDamage().getShieldBlockedDamage());
	    assertEquals(true, e23.getDamage().getDestroyed());
	    assertEquals(300,300, e23.getDamage().getTargetLocation());
	    assertEquals("SourceDescription", e23.getSourceDescription());
	    assertEquals("TargetDescription", e23.getTargetDescription());
	    assertEquals("AnimationConfig", e23.getAnimationConfigNameSuffix());
	    assertEquals(bca[0], e23.getOldSourceState());
	    assertEquals(bca[0], e23.getNewSourceState());
	    assertEquals(bca[0], e23.getOldTargetState());
	    assertEquals(bca[0], e23.getNewTargetState());
	    assertEquals(1, ((TroopBattleResult)e23.getData()).getQtyAttackers());
	    assertEquals(2, ((TroopBattleResult)e23.getData()).getQtyDefenders());

	    BattleWeaponMissEvent e24 = new BattleWeaponMissEvent("Battle", "Source", "Target", "Weapon", new Location(300,300), 90, new Location(400,400));
	    e24 = (BattleWeaponMissEvent) serialiseDeserialise(e24);
	    assertEquals("Battle", e24.getBattle());
	    assertEquals("Source", e24.getSource());
	    assertEquals("Target", e24.getTarget());
	    assertEquals("Weapon", e24.getWeaponName());
	    assertEquals(300,300, e24.getSourceDirection());
	    assertEquals(400,400, e24.getTargetLocation());

	    BattleWeaponStateUpdateEvent e25 = new BattleWeaponStateUpdateEvent("Battle", "Source", new BattleObjectWeaponStateVOAdapter(bca[0]));
	    e25 = (BattleWeaponStateUpdateEvent) serialiseDeserialise(e25);
	    assertEquals("Battle", e25.getBattle());
	    assertEquals("Source", e25.getSource());
	    assertEquals(bca[0], e25.getState());

        String [] winners = new String[2];
        winners[0] = "P1";
        winners[1] = "P2";
	    NewBattleEvent e26 = new NewBattleEvent(new BattleVOAdapter(battle), new BattleStateVO("Battle", 2, true, winners));
	    e26 = (NewBattleEvent) serialiseDeserialise(e26);
	    assertEquals("Battle1", e26.getBattle().getName());
	    assertEquals("Humans", e26.getBattle().getStartingPlayers()[0]);
	    assertEquals("SS1-A", e26.getBattle().getOrbit().getPlanet());
	    assertEquals("Battle", e26.getBattleState().getBattle());
	    assertEquals(2, e26.getBattleState().getTurn());
	    assertEquals(true, e26.getBattleState().isHasEnded());
	    assertEquals(winners, e26.getBattleState().getWinners());

    }

    public void testGalaxyEvents() throws Exception {
        Logger.logDebug("*******************************  GeometryTest.testGalaxyEvents() *************************");
        init();
        
        ColonisePlanetEvent e1 = new ColonisePlanetEvent("Craft");
        e1 = (ColonisePlanetEvent) serialiseDeserialise(e1);
	    assertEquals("Craft", e1.getCraft());
        
	    DestroyColonyEvent e2 = new DestroyColonyEvent("Planet");
        e2 = (DestroyColonyEvent) serialiseDeserialise(e2);
	    assertEquals("Planet", e2.getPlanet());
        
	    DiplomaticRequestEvent e3 = new DiplomaticRequestEvent("Player", DiplomaticProposal.getWar(), "Msg");
        e3 = (DiplomaticRequestEvent) serialiseDeserialise(e3);
	    assertEquals("Player", e3.getPlayer());
	    assertEquals("Msg", e3.getMessage());
        
	    DiplomaticResponseEvent e4 = new DiplomaticResponseEvent("Player", DiplomaticProposal.getWar(), true, "Msg");
        e4 = (DiplomaticResponseEvent) serialiseDeserialise(e4);
	    assertEquals("Player", e4.getPlayer());
	    assertEquals(true, e4.isAccept());
	    assertEquals("Msg", e4.getMessage());
        
//	    DiplomaticEventCancelTreaty e5 = new DiplomaticEventCancelTreaty("Player", "Treaty", "Msg");
//        e5 = (DiplomaticEventCancelTreaty) serialiseDeserialise(e5);
//	    assertEquals("Player", e5.getPlayer());
//	    assertEquals("Treaty", e5.getTreaty());
//	    assertEquals("Msg", e5.getMessage());
//        
//	    DiplomaticEventDeclareWar e6 = new DiplomaticEventDeclareWar("Player", "Msg");
//        e6 = (DiplomaticEventDeclareWar) serialiseDeserialise(e6);
//	    assertEquals("Player", e6.getPlayer());
//	    assertEquals("Msg", e6.getMessage());
//        
//	    PlayerAssets assets = new PlayerAssets(tech_ancientWeapon, 100, "Planet");
//		DiplomaticEventDemandAssetsEvent e7 = new DiplomaticEventDemandAssetsEvent("Player", assets );
//        e7 = (DiplomaticEventDemandAssetsEvent) serialiseDeserialise(e7);
//	    assertEquals("Player", e7.getPlayer());
//	    assertEquals(assets, e7.getWantedAssets());
//        
//	    DiplomaticEventDemandAssetsResponseEvent e8 = new DiplomaticEventDemandAssetsResponseEvent("Player", assets, true, "Msg");
//        e8 = (DiplomaticEventDemandAssetsResponseEvent) serialiseDeserialise(e8);
//	    assertEquals("Player", e8.getPlayer());
//	    assertEquals(true, e8.isAccept());
//	    assertEquals(assets, e8.getWantedAssets());
//	    assertEquals("Msg", e8.getMessage());
//        
//        
//	    DiplomaticEventGift e9 = new DiplomaticEventGift("Player", assets );
//        e9 = (DiplomaticEventGift) serialiseDeserialise(e9);
//	    assertEquals("Player", e9.getPlayer());
//	    assertEquals(assets, e9.getGift());
//        
//	    DiplomaticEventGiftResponse e10 = new DiplomaticEventGiftResponse("Player", assets, "Response" );
//	    e10 = (DiplomaticEventGiftResponse) serialiseDeserialise(e10);
//	    assertEquals("Player", e10.getPlayer());
//	    assertEquals(assets, e10.getGift());
//	    assertEquals("Response", e10.getMessage());
//        
//	    DiplomaticEventNonAggressionRequestEvent e11 = new DiplomaticEventNonAggressionRequestEvent("Player", "Msg");
//        e11 = (DiplomaticEventNonAggressionRequestEvent) serialiseDeserialise(e11);
//	    assertEquals("Player", e11.getPlayer());
//	    assertEquals("Msg", e11.getMessage());
//        
//	    DiplomaticEventNonAggressionResponseEvent e12 = new DiplomaticEventNonAggressionResponseEvent("Player", true, "Msg");
//        e12 = (DiplomaticEventNonAggressionResponseEvent) serialiseDeserialise(e12);
//	    assertEquals("Player", e12.getPlayer());
//	    assertEquals(true, e12.isAccept());
//	    assertEquals("Msg", e12.getMessage());
//        
//	    DiplomaticEventPeaceRequestEvent e13 = new DiplomaticEventPeaceRequestEvent("Player", "Msg");
//        e13 = (DiplomaticEventPeaceRequestEvent) serialiseDeserialise(e13);
//	    assertEquals("Player", e13.getPlayer());
//	    assertEquals("Msg", e13.getMessage());
//        
//	    DiplomaticEventPeaceResponseEvent e14 = new DiplomaticEventPeaceResponseEvent("Player", true, "Msg");
//        e14 = (DiplomaticEventPeaceResponseEvent) serialiseDeserialise(e14);
//	    assertEquals("Player", e14.getPlayer());
//	    assertEquals(true, e14.isAccept());
//	    assertEquals("Msg", e14.getMessage());        
//        
//	    DiplomaticEventResearchTreatyRequestEvent e15 = new DiplomaticEventResearchTreatyRequestEvent("Player", "Msg");
//        e15 = (DiplomaticEventResearchTreatyRequestEvent) serialiseDeserialise(e15);
//	    assertEquals("Player", e15.getPlayer());
//	    assertEquals("Msg", e15.getMessage());
//        
//	    DiplomaticEventResearchTreatyResponseEvent e16 = new DiplomaticEventResearchTreatyResponseEvent("Player", true, "Msg");
//        e16 = (DiplomaticEventResearchTreatyResponseEvent) serialiseDeserialise(e16);
//	    assertEquals("Player", e16.getPlayer());
//	    assertEquals(true, e16.isAccept());
//	    assertEquals("Msg", e16.getMessage());        
//        
//	    DiplomaticEventSwapAssetsRequestEvent e17 = new DiplomaticEventSwapAssetsRequestEvent("Player", assets, assets, "Msg");
//        e17 = (DiplomaticEventSwapAssetsRequestEvent) serialiseDeserialise(e17);
//	    assertEquals("Player", e17.getPlayer());
//	    assertEquals(assets, e17.getOfferedAssets());
//	    assertEquals(assets, e17.getWantedAssets());
//	    assertEquals("Msg", e17.getMessage());
//        
//	    DiplomaticEventSwapAssetsResponseEvent e18 = new DiplomaticEventSwapAssetsResponseEvent("Player", assets, assets, true, "Msg");
//        e18 = (DiplomaticEventSwapAssetsResponseEvent) serialiseDeserialise(e18);
//	    assertEquals("Player", e18.getPlayer());
//	    assertEquals(assets, e18.getOfferedAssets());
//	    assertEquals(assets, e18.getWantedAssets());
//	    assertEquals(true, e18.isAccept());
//	    assertEquals("Msg", e18.getMessage());        
//
//	    DiplomaticEventTradeRouteRequestEvent e19 = new DiplomaticEventTradeRouteRequestEvent("Player", "Msg" );
//        e19 = (DiplomaticEventTradeRouteRequestEvent) serialiseDeserialise(e19);
//	    assertEquals("Player", e19.getPlayer());
//	    assertEquals("Msg", e19.getMessage());
//        
//	    DiplomaticEventTradeRouteResponseEvent e20 = new DiplomaticEventTradeRouteResponseEvent("Player", true, "Response" );
//	    e20 = (DiplomaticEventTradeRouteResponseEvent) serialiseDeserialise(e20);
//	    assertEquals("Player", e20.getPlayer());
//	    assertEquals(true, e20.isAccept());
//	    assertEquals("Response", e20.getMessage());

	    FundsGoneEvent e21 = new FundsGoneEvent("XX", "Planet", 5 );
        e21 = (FundsGoneEvent) serialiseDeserialise(e21);
	    assertEquals("XX", e21.getObject());
	    assertEquals("Planet", e21.getPlanet());
	    assertEquals(5, e21.getMoney());

	    FundsLowEvent e22 = new FundsLowEvent();
        e22 = (FundsLowEvent) serialiseDeserialise(e22);

        String [] winners = new String[2];
        winners[0] = "P1";
        winners[1] = "P2";
        GameEndEvent e23 = new GameEndEvent(winners, new GameScore(new GameScoreData(tech_fighterI, 1, tech_flyer100, 2, tech_flyer200, 3), 1.0, 2.0, 3.0, 4.0, 5, 6.0, 7, 8.0) );
        e23 = (GameEndEvent) serialiseDeserialise(e23);
	    assertEquals(winners, e23.getWinners());
	    assertEquals(1, e23.getScore().getScoreData().getTotalQtyCraftsBuilt());
	    assertEquals(tech_fighterI, e23.getScore().getScoreData().getCraftBuilt()[0].getHullTech());
	    assertEquals(1, e23.getScore().getScoreData().getCraftBuilt()[0].getQty());
	    assertEquals(2, e23.getScore().getScoreData().getTotalQtyCraftsDestroyed());
	    assertEquals(tech_flyer100, e23.getScore().getScoreData().getCraftDestroyed()[0].getHullTech());
	    assertEquals(2, e23.getScore().getScoreData().getCraftDestroyed()[0].getQty());
	    assertEquals(3, e23.getScore().getScoreData().getTotalQtyCraftsInvaded());
	    assertEquals(tech_flyer200, e23.getScore().getScoreData().getCraftInvaded()[0].getHullTech());
	    assertEquals(3, e23.getScore().getScoreData().getCraftInvaded()[0].getQty());
	    assertEquals(1.0, e23.getScore().getCraftsBuiltScore());
	    assertEquals(2.0, e23.getScore().getCraftsDestroyedScore());
	    assertEquals(3.0, e23.getScore().getCraftsInvadedScore());
	    assertEquals(4.0, e23.getScore().getAncientsDefeatScore());
	    assertEquals(5, e23.getScore().getQtyPopulation());
	    assertEquals(6.0, e23.getScore().getPopulationScore());
	    assertEquals(7, e23.getScore().getQtyTechnology());
	    assertEquals(8.0, e23.getScore().getTechnologyScore());

	    LeaderGainLevelEvent e24 = new LeaderGainLevelEvent("Leader", 2);
        e24 = (LeaderGainLevelEvent) serialiseDeserialise(e24);
	    assertEquals("Leader", e24.getLeader());
	    assertEquals(2, e24.getExperience());

	    MessageEvent e25 = new MessageEvent("Msg",MessageType.plain ,"Sound");
        e25 = (MessageEvent) serialiseDeserialise(e25);
	    assertEquals("Msg", e25.getMessage());
	    assertEquals(MessageType.plain, e25.getMessageType());
	    assertEquals("Sound", e25.getSound());

	    NewSpyEvent e26 = new NewSpyEvent(4);
        e26 = (NewSpyEvent) serialiseDeserialise(e26);
	    assertEquals(4, e26.getQtySpies());

	    NoProjectEvent e27 = new NoProjectEvent("Planet", "Reason");
        e27 = (NoProjectEvent) serialiseDeserialise(e27);
	    assertEquals("Planet", e27.getPlanet());
	    assertEquals("Reason", e27.getReason());

	    NoResearchProjectEvent e28 = new NoResearchProjectEvent();
        e28 = (NoResearchProjectEvent) serialiseDeserialise(e28);

        OfferLeaderEvent e29 = new OfferLeaderEvent("Leader");
        e29 = (OfferLeaderEvent) serialiseDeserialise(e29);
	    assertEquals("Leader", e29.getLeader());

	    OfferMoralChoiceEvent e30 = new OfferMoralChoiceEvent("Name");
	    e30 = (OfferMoralChoiceEvent) serialiseDeserialise(e30);
	    assertEquals("Name", e30.getName());

	    PlanetBombardedEvent e31 = new PlanetBombardedEvent("Planet", 1.0, 2.0);
	    e31 = (PlanetBombardedEvent) serialiseDeserialise(e31);
	    assertEquals("Planet", e31.getTarget());
	    assertEquals(1,0, e31.getPopulationDestroyed());
	    assertEquals(2.0, e31.getFactoriesDestroyed());

	    PlanetColonisedEvent e32 = new PlanetColonisedEvent("Planet");
	    e32 = (PlanetColonisedEvent) serialiseDeserialise(e32);
	    assertEquals("Planet", e32.getPlanet());

	    PlanetConqueredEvent e33 = new PlanetConqueredEvent("Craft", "Planet", "OldOwner");
	    e33 = (PlanetConqueredEvent) serialiseDeserialise(e33);
	    assertEquals("Craft", e33.getSource());
	    assertEquals("Planet", e33.getTarget());
	    assertEquals("OldOwner", e33.getOldOwner());

	    PlanetInvadeEvent e34 = new PlanetInvadeEvent("Attacker", "Victim", "Target", 1, 2, 3.0, 4, 5);
	    e34 = (PlanetInvadeEvent) serialiseDeserialise(e34);
	    assertEquals("Attacker", e34.getAttackerRace());
	    assertEquals("Victim", e34.getDefenderRace());
	    assertEquals("Target", e34.getTarget());
	    assertEquals(1, e34.getQtyAttackers());
	    assertEquals(2, e34.getQtyDefenders());
	    assertEquals(3.0, e34.getAttackerAdvantage());
	    assertEquals(4, e34.getRemainingAttackers());
	    assertEquals(5, e34.getRemainingDefenders());

	    PlayerLoseEvent e35 = new PlayerLoseEvent("Player");
	    e35 = (PlayerLoseEvent) serialiseDeserialise(e35);
	    assertEquals("Player", e35.getPlayer());

	    PlayerSurrenderEvent e36 = new PlayerSurrenderEvent("Player", "Target");
	    e36 = (PlayerSurrenderEvent) serialiseDeserialise(e36);
	    assertEquals("Player", e36.getPlayer());
	    assertEquals("Target", e36.getTarget());

	    PrizeGiftEvent e37 = new PrizeGiftEvent(true, "Config", "Tech", "Description");
	    e37 = (PrizeGiftEvent) serialiseDeserialise(e37);
	    assertEquals(true, e37.isPrize());
	    assertEquals("Config", e37.getImageConfigName());
	    assertEquals("Tech", e37.getTechFullName());
	    assertEquals("Description", e37.getDescription());

        String [] craftDestroyed = new String[2];
        winners[0] = "C1";
        winners[1] = "C2";
	    RoutedEvent e38 = new RoutedEvent("Player", "SO", craftDestroyed);
	    e38 = (RoutedEvent) serialiseDeserialise(e38);
	    assertEquals("Player", e38.getPlayer());
	    assertEquals("SO", e38.getOrbit());
	    assertEquals(craftDestroyed, e38.getCraftDestroyed());

	    SabotageEvent e39 = new SabotageEvent("Planet", "Player", 1,2,3);
	    e39 = (SabotageEvent) serialiseDeserialise(e39);
	    assertEquals("Planet", e39.getPlanet());
	    assertEquals("Player", e39.getPlayer());
	    assertEquals(1, e39.getQtyFactoriesSabotaged());
	    assertEquals(2, e39.getQtyPopulationSabotaged());
	    assertEquals(3, e39.getQtyProductionSabotaged());

	    EndTurnEvent e40 = new EndTurnEvent();
	    e40 = (EndTurnEvent) serialiseDeserialise(e40);

	    TechnologyDiscoveredEvent e41 = new TechnologyDiscoveredEvent("Tech", true);
	    e41 = (TechnologyDiscoveredEvent) serialiseDeserialise(e41);
	    assertEquals("Tech", e41.getTech());
	    assertEquals(true, e41.isFromSalvage());

	    TechnologyStolenEvent e42 = new TechnologyStolenEvent("Tech", "Reciever", "Giver");
	    e42 = (TechnologyStolenEvent) serialiseDeserialise(e42);
	    assertEquals("Tech", e42.getTech());
	    assertEquals("Reciever", e42.getReceiver());
	    assertEquals("Giver", e42.getGiver());

	    TooManySpiesEvent e43 = new TooManySpiesEvent();
	    e43 = (TooManySpiesEvent) serialiseDeserialise(e43);

	    PlanetCrisisEvent e44 = new PlanetCrisisEvent("Planet");
	    e44 = (PlanetCrisisEvent) serialiseDeserialise(e44);
	    assertEquals("Planet", e44.getTarget());

    }


    public void testBeans() throws Exception {
        Logger.logDebug("*******************************  GeometryTest.testBeans() *************************");
        init();
        
        DecoratorList dl = new DecoratorList();
        dl.add(DecoratorBerserker.getInstance());
        dl.add(DecoratorCowardice.getInstance());
        dl.add(DecoratorHologram.getInstance());
        dl.add(DecoratorSleep.getInstance());
        dl.add(DecoratorMindControl.getInstance());
        dl.add(DecoratorCommandCenter.getInstance());
        dl.add(DecoratorDisabled.getInstance());
        dl.add(DecoratorDamageBot.getInstance(2));
        dl.add(DecoratorPlague.getInstance(3));
        
        DecoratorList d1 = (DecoratorList) serialiseDeserialise(dl);
	    assertEquals(DecoratorBerserker.class, d1.getDecorators()[0].getClass());
	    assertEquals(DecoratorCowardice.class, d1.getDecorators()[1].getClass());
	    assertEquals(DecoratorHologram.class, d1.getDecorators()[2].getClass());
	    assertEquals(DecoratorSleep.class, d1.getDecorators()[3].getClass());
	    assertEquals(DecoratorMindControl.class, d1.getDecorators()[4].getClass());
	    assertEquals(DecoratorCommandCenter.class, d1.getDecorators()[5].getClass());
	    assertEquals(DecoratorDisabled.class, d1.getDecorators()[6].getClass());
	    assertEquals(2, ((DecoratorDamageBot)d1.getDecorators()[7]).getQty());
	    assertEquals(3, ((DecoratorPlague)d1.getDecorators()[8]).getQty());
	    
        ImmunityBio i1 = (ImmunityBio) serialiseDeserialise(new ImmunityBio());
        ImmunityGravity i2 = (ImmunityGravity) serialiseDeserialise(new ImmunityGravity());
        ImmunityMindControl i3 = (ImmunityMindControl) serialiseDeserialise(new ImmunityMindControl());
        ImmunityMoveCraft i4 = (ImmunityMoveCraft) serialiseDeserialise(new ImmunityMoveCraft());
        ImmunityPsi i5 = (ImmunityPsi) serialiseDeserialise(new ImmunityPsi());
        ImmunityReplicaBeam i6 = (ImmunityReplicaBeam) serialiseDeserialise(new ImmunityReplicaBeam());
        ImmunityTroopTransport i7 = (ImmunityTroopTransport) serialiseDeserialise(new ImmunityTroopTransport());

        PlayerCharacterBasic pc = new PlayerCharacterBasic();
    	pc.setProductionBonus(1.0);
    	pc.setProductionLevelBonus(1.1);
    	pc.setResearchBonus(2.0);
    	pc.setResearchLevelBonus(2.1);
    	pc.setDevelopmentBonus(3.0);
    	pc.setDevelopmentLevelBonus(3.1);
    	pc.setReproductionBonus(4.0);
    	pc.setFactoryPerPopulationBonus(5.0);
    	pc.setEcologyBonus(6.0);
        pc.setMaxPopulationBonus(7.0);
    	pc.setPlayerEcologyPercent(8.0);
    	pc.setPlayerDevelopmentPercent(9.0);
    	pc.setPlayerResearchPercent(10.0);
    	pc.setPlayerProductionPercent(11.0);
    	pc.setPlayerMoneyPercent(12.0);
    	pc.setPsiRating(13);
    	pc.addMissedTechnology(tech_battleStationI);
    	pc.addMissedTechnology(tech_antiMissileBeam);
    	pc.setBattleTurningBonus(14.0);
    	pc.setBattleSpeedBonus(15.0);
    	pc.setInitiativeBonus(16.0);
    	pc.setSpeedBonus(17.0);
    	pc.setMaxDamageBonus(18.0);
    	pc.setCloakLevel(19);
        pc.setTradingBonus(20.0);
        pc.setAssaultBonus(21.0);
        pc.setSpyBonus(22.0);
        pc.setResourceful(true);
        pc.setImmunity(new ImmunityBio());
        pc.setImmunity(new ImmunityPsi());

        pc = (PlayerCharacterBasic) serialiseDeserialise(pc);

        assertEquals(1.0, pc.getProductionBonus());
        assertEquals(1.1, pc.getProductionLevelBonus());
        assertEquals(2.0, pc.getResearchBonus());
        assertEquals(2.1, pc.getResearchLevelBonus());
        assertEquals(3.0, pc.getDevelopmentBonus());
        assertEquals(3.1, pc.getDevelopmentLevelBonus());
        assertEquals(4.0, pc.getReproductionBonus());
        assertEquals(5.0, pc.getFactoryPerPopulationBonus());
        assertEquals(6.0, pc.getEcologyBonus());
        assertEquals(7.0, pc.getMaxPopulationBonus());
        assertEquals(8.0, pc.getPlayerEcologyPercent());
        assertEquals(9.0, pc.getPlayerDevelopmentPercent());
        assertEquals(10.0, pc.getPlayerResearchPercent());
        assertEquals(11.0, pc.getPlayerProductionPercent());
        assertEquals(12.0, pc.getPlayerMoneyPercent());
        assertEquals(13, pc.getPsiRating());
        assertEquals(tech_battleStationI, tech_antiMissileBeam, pc.getMissedTechnologiesAsList());
        assertEquals(14.0, pc.getBattleTurningBonus());
        assertEquals(15.0, pc.getBattleSpeedBonus());
        assertEquals(16.0, pc.getInitiativeBonus());
        assertEquals(17.0, pc.getSpeedBonus());
        assertEquals(18.0, pc.getMaxDamageBonus());
        assertEquals(19, pc.getCloakLevel());
        assertEquals(20.0, pc.getTradingBonus());
        assertEquals(21.0, pc.getAssaultBonus());
        assertEquals(22.0, pc.getSpyBonus());
        assertEquals(true, pc.getIsResourceful());
        assertEquals(ImmunityBio.NAME, pc.getImmunities()[0].getName());
        assertEquals(ImmunityPsi.NAME, pc.getImmunities()[1].getName());
        
        WreckageDetails wd = new WreckageDetails(new Rectangle(100, 200, 50, 50), "CraftName");
	    wd = (WreckageDetails) serialiseDeserialise(wd);
	    assertEquals(110, 210, wd.getCenterLocation());
	    assertEquals("CraftName", wd.getCraftName());

	    AsteroidFieldDetails afd = new AsteroidFieldDetails(new Rectangle(100, 200, 50, 50));
	    afd = (AsteroidFieldDetails) serialiseDeserialise(afd);
	    assertEquals(125, 225, afd.getCenterLocation());

	    SpaceDistortionDetails sdd = new SpaceDistortionDetails(new Rectangle(100, 200, 50, 50));
	    sdd = (SpaceDistortionDetails) serialiseDeserialise(sdd);
	    assertEquals(125, 225, sdd.getCenterLocation());

	    TroopBattleResult tbr = new TroopBattleResult(1,2,3,4);
	    tbr = (TroopBattleResult) serialiseDeserialise(tbr);
	    assertEquals(1, tbr.getQtyAttackers());
	    assertEquals(2, tbr.getQtyDefenders());
	    assertEquals(3, tbr.getRemainingAttackers());
	    assertEquals(4, tbr.getRemainingDefenders());

    }
    
	private Object serialiseDeserialise(Serializable in) throws IOException, ClassNotFoundException {
        ByteArrayOutputStream bo = new ByteArrayOutputStream();
        ObjectOutputStream oo = new ObjectOutputStream(bo);
        oo.writeObject(in);
        byte[] ba = bo.toByteArray();
        ByteArrayInputStream bi = new ByteArrayInputStream(ba);
        ObjectInputStream oi = new ObjectInputStream(bi);
        return oi.readObject();
	}

    public static void main(String args[]) {
        Logger.clearContents();
        junit.textui.TestRunner.run(suite());
    }

}