/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.test;

import junit.framework.Test;
import junit.framework.TestSuite;
import mot.client.sounds.SoundConfigFactory;
import mot.client.sounds.SoundEffect;
import mot.client.sounds.Sounds;
import mot.common.util.Comp;
import mot.common.util.Logger;

/**
 * Tests Prizes Work - When a craft arrives at a planet for the first time
 * it activates a prize for its owner. Future visitors do not get the prize.
 */
public class SoundTest extends TestBase {
    public static Test suite() {
        TestSuite suite = new TestSuite(SoundTest.class);
        return suite;
    }

    public SoundTest(String name) {
        super(name);
    }

    protected void setUp() throws Exception {
        Logger.clearContents();
        Logger.setInMemory(false);
        Logger.setLogLevelLoaded();
        Logger.setDebug();
    }
    

    public void testLiveSounds() throws Exception {
        setUp();
        Logger.logDebug("*******************************  SoundTest.testLiveSounds() *************************");
        String javaVersion = System.getProperty("java.version");
        Logger.logDebug("*******************************  Java Version "+javaVersion+"*************************");
         
        String[] sounds = SoundConfigFactory.getInstance().getAllSoundNames();
        Comp.sortByName(sounds);
        for (int i = 0; i < sounds.length; i++) {
        	Logger.logDebug("Play Sound "+sounds[i]);
			SoundEffect sound = Sounds.getSound(sounds[i]);
			sound.play();
			while(sound.isPlaying()) {
				Thread.sleep(100);
			}
			//sound.stop();
		}
    }

    protected void tearDown() {
    	Logger.flushLog();
    }

    public static void main(String args[]) {
        Logger.clearContents();
        junit.textui.TestRunner.run(suite());
    }

}