/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.test;

import java.util.ArrayList;

import mot.client.deligates.BattleObjectDelegate;
import mot.client.deligates.MoveableOwnedObjectDelegate;
import mot.client.deligates.NamedObjectDelegate;
import mot.client.deligates.PlanetDelegate;
import mot.client.deligates.TradeRouteDelegate;
import mot.client.swing.config.AnimationConfigFactory;
import mot.client.swing.config.ImageAnimationConfig;
import mot.client.swing.config.ImageConfig;
import mot.client.swing.config.ImageConfigFactory;
import mot.client.swing.config.ImageConfigList;
import mot.client.swing.config.ImageDuelStrokeAnimationConfig;
import mot.client.swing.config.ImageStrokeAnimationConfig;
import mot.client.swing.config.MenuConfig;
import mot.client.swing.config.MenuImageConfig;
import mot.client.swing.config.StrokeSize;
import mot.client.swing.config.WeaponFireAnimationConfig;
import mot.common.bean.Area;
import mot.common.bean.CraftGraphics;
import mot.common.bean.CraftState;
import mot.common.bean.Decorator;
import mot.common.bean.DiplomaticHistoryEvent;
import mot.common.bean.GalaxyGraphicsList;
import mot.common.bean.Location;
import mot.common.bean.LocationAndDirection;
import mot.common.bean.MotColor;
import mot.common.bean.NameIntPair;
import mot.common.bean.NameList;
import mot.common.bean.NamedObject;
import mot.common.bean.ObjectMovement;
import mot.common.bean.ObjectTurn;
import mot.common.bean.PlayerAssets;
import mot.common.bean.PlayerColor;
import mot.common.bean.RaceGraphics;
import mot.common.bean.RaceGraphicsForColony;
import mot.common.bean.RaceGraphicsList;
import mot.common.bean.Size;
import mot.common.bean.StellarObjectGraphics;
import mot.common.bean.TreatyType;
import mot.common.command_results.NameListCR;
import mot.common.designs.BattleStationDesign;
import mot.common.designs.CraftDesign;
import mot.common.designs.CraftDesigns;
import mot.common.designs.Orbital;
import mot.common.designs.OutpostDesign;
import mot.common.designs.WeaponBaysDesign;
import mot.common.event.MotEvent;
import mot.common.event.StateContainer;
import mot.common.factory.GraphicsFactory;
import mot.common.gifts.AncientGift;
import mot.common.gifts.AncientGifts;
import mot.common.lang.L;
import mot.common.leaders.GeneralDetails;
import mot.common.leaders.GeneralDetailsList;
import mot.common.leaders.GovenorDetails;
import mot.common.leaders.GovenorDetailsList;
import mot.common.morals.MoralChoice;
import mot.common.morals.MoralChoiceList;
import mot.common.resources.Resource;
import mot.common.resources.Resources;
import mot.common.setup.OptionsFactory;
import mot.common.setup.RaceOptions;
import mot.common.setup.SetupOption;
import mot.common.setup.SetupOptions;
import mot.common.technology.Biotechnology;
import mot.common.technology.Computer;
import mot.common.technology.Computers;
import mot.common.technology.Engine;
import mot.common.technology.Factory;
import mot.common.technology.Hull;
import mot.common.technology.Laboratory;
import mot.common.technology.MiscTechnology;
import mot.common.technology.Module;
import mot.common.technology.Modules;
import mot.common.technology.Scanner;
import mot.common.technology.Scanners;
import mot.common.technology.Shield;
import mot.common.technology.Shields;
import mot.common.technology.Special;
import mot.common.technology.Specials;
import mot.common.technology.Technology;
import mot.common.technology.TechnologyList;
import mot.common.technology.TechnologyTree;
import mot.common.technology.TechnologyTreeNode;
import mot.common.technology.TestTechnologyList;
import mot.common.technology.Theory;
import mot.common.technology.Weapon;
import mot.common.technology.WeaponFirePoint;
import mot.common.technology.Weapons;
import mot.common.util.ApplicationError;
import mot.common.util.BasicNameValueList;
import mot.common.util.Comp;
import mot.common.util.Logger;
import mot.common.util.NameValuePair;
import mot.common.util.NameValuePairList;
import mot.common.util.ValidationError;
import mot.common.vo.BattleCraftSpeedVO;
import mot.common.vo.BattleObjectWeaponStateVO;
import mot.common.vo.CraftDesignVO;
import mot.common.vo.CraftVO;
import mot.common.vo.FleetVO;
import mot.common.vo.OrbitVO;
import mot.common.vo.PlanetVO;
import mot.common.vo.PlayerConstantsVO;
import mot.common.vo.PlayerDetailsVO;
import mot.common.vo.PlayerTechnologiesVO;
import mot.common.vo.PlayerVO;
import mot.common.vo.RelationVO;
import mot.common.vo.StellarObjectVO;
import mot.common.vo.TechnologyListVO;
import mot.common.vo.TradeRouteVO;
import mot.common.vo.ValueObject;
import mot.common.vo.WeaponInstanceVO;
import mot.engine.MotEngine;
import mot.engine.battles.Battle;
import mot.engine.battles.BattleCraft;
import mot.engine.battles.BattleObject;
import mot.engine.battles.ExclusionZone;
import mot.engine.common.MoveableOwnedObject;
import mot.engine.common.Orbit;
import mot.engine.common.StellarObject;
import mot.engine.common.StellarObjectReference;
import mot.engine.crafts.Craft;
import mot.engine.crafts.Crafts;
import mot.engine.crafts.Fleet;
import mot.engine.crafts.FleetFactory;
import mot.engine.crafts.WeaponBays;
import mot.engine.planets.BlackHole;
import mot.engine.planets.Planet;
import mot.engine.planets.PlanetFactory;
import mot.engine.planets.PlanetReference;
import mot.engine.planets.Planets;
import mot.engine.planets.ProjectBattleStation;
import mot.engine.planets.ProjectOutpost;
import mot.engine.planets.SolarSystem;
import mot.engine.planets.StellarObjects;
import mot.engine.planets.TradeRoute;
import mot.engine.planets.TradeRoutes;
import mot.engine.players.ComputerPlayer;
import mot.engine.players.Player;
import mot.engine.players.UserPlayer;
import mot.engine.relations.Relations;
import mot.engine.setup.UserPlayerFactory;
import mot.engine.technology.ShieldInstance;
import mot.engine.technology.WeaponInstance;
import mot.engine.transports.Transport;
import mot.engine.transports.TransportTaskDeployStation;
import mot.engine.transports.TransportTaskInvade;

public class TestBase extends TestTechnologyBase {

	protected  static final String ANCIENT_WATER_MAN = "WaterMan";
    protected  static final String ANCIENT_AIR_MAN = "AirMan";
    
    protected TestErrorHandler testErrorHandler = new TestErrorHandler();

    public static boolean __TEST_RUNNING = false;

    public TestBase(String name) {
        super(name);
        __TEST_RUNNING = true;
    }

    public static ComputerPlayer newPlayer(String name, PlayerColor colour, SetupOptions options, String [] playerNames) throws ValidationError, ApplicationError {
        RaceOptions ro = new RaceOptions(name, options);
        return newPlayer(name, colour, ro, playerNames);
    }
    
    public static ComputerPlayer newPlayer(String name, PlayerColor colour, RaceOptions options, String [] playerNames) throws ValidationError, ApplicationError {
    	return newPlayer(name, colour, null, null, options, playerNames);
    }
    
    public static ComputerPlayer newPlayer(String name, PlayerColor colour, Double level, String alignment, RaceOptions options, String [] playerNames) throws ValidationError, ApplicationError {
        MotEngine engine = MotEngine.getInstance();
		Relations relations = engine.getRelations();
		if (relations == null) {
			relations = new Relations();
			engine.setRelations(relations);
		}
        
        TestComputerPlayerFactory cpf = new TestComputerPlayerFactory();
		Player player = cpf.createNewPlayer(options, name, level, colour, alignment, null, playerNames);
        return (ComputerPlayer) player;
    }

    public static UserPlayer newUserPlayer(String name, PlayerColor colour, SetupOptions options) throws ValidationError, ApplicationError {
    	return newUserPlayer(name, colour, null, new RaceOptions(name, options));
    }

    public static UserPlayer newUserPlayer(String name, PlayerColor colour, String alignment, RaceOptions options) throws ValidationError, ApplicationError {
        UserPlayerFactory upf = new UserPlayerFactory();
        Player player = upf.createNewPlayer(options, name, null, colour, alignment, null, null);
        return (UserPlayer) player;
    }
    
    public static PlayerColor playerColourBlue;
    public static PlayerColor playerColourRed;
    public static PlayerColor playerColourGreen;
    public static PlayerColor playerColourYellow;
    
    static {
    	try {
			playerColourBlue = PlayerColor.getColorForName(L.COLOUR_BLUE);
			playerColourRed = PlayerColor.getColorForName(L.COLOUR_RED);
			playerColourGreen = PlayerColor.getColorForName(L.COLOUR_GREEN);
			playerColourYellow = PlayerColor.getColorForName(L.COLOUR_YELLOW);
		} catch (ApplicationError e) {
			Logger.logError("", e);
		}
    }
    
    public static SolarSystem newSolarSystem(String name, int x, int y) {
        MotEngine engine = MotEngine.getInstance();

        StellarObjects sos = engine.getStellarObjects();
        if (sos == null) {
            Size galaxySize = new Size(500, 500);
            sos = new StellarObjects();
            sos.setSize(galaxySize);
    		engine.setStellarObjects(sos);
        }

        SolarSystem ss = new SolarSystem(name, x, y);
        ss.setStarType( StellarObjectGraphics.getRandomStarType() );

        sos.add( ss );
        return ss;
    }
    
    public static BlackHole newBlackHole(String name, int x, int y, float researchBonus, boolean hasSpaceJumpAbility) {
        MotEngine engine = MotEngine.getInstance();

        StellarObjects sos = engine.getStellarObjects();
        if (sos == null) {
            Size galaxySize = new Size(500, 500);
            sos = new StellarObjects();
            sos.setSize(galaxySize);
    		engine.setStellarObjects(sos);
        }

        BlackHole bh = new BlackHole(name, x, y, researchBonus, hasSpaceJumpAbility);

        sos.add( bh );
        return bh;
    }
    
    public static Planet newPlanetAndSS(String name, int x, int y, int size, double terraform) throws ApplicationError, ValidationError {
        SolarSystem ss = newSolarSystem(name, x, y);
        Planet planet2 = newPlanet(name+"-A", ss, null, size, terraform);
        return planet2;
    }
    
    public static Planet newPlanetAndSS(String name, int x, int y, Player player) throws ApplicationError, ValidationError {
        SolarSystem ss = newSolarSystem(name, x, y);
        Planet planet2 = newPlanet(name+"-A", ss, player);
        return planet2;
    }
    
    public static Planet newPlanet(String name, SolarSystem ss, Player owner, int size, double terraform) throws ApplicationError, ValidationError {
        MotEngine engine = MotEngine.getInstance();

        Planets planets = engine.getPlanets();
        if (planets == null) {
    		planets = new Planets();
            engine.setPlanets(planets);
        }
        
        Planet planet = new Planet(name, owner, ss);
        planet.setSize( size );
        planet.setPopulation( 0 );
        planet.setTeraforming( terraform );
        planet.setQtyFactories( 0 );
        planet.setProductionBonus( 0 );
        planet.setResearchBonus( 0 );
        planet.setReproductionBonus( 0 );
        planets.add(planet);
        
        return planet;
    }

    public static Planet newPlanet(String name, SolarSystem ss, Player owner, int size, double terraform, int population, int qtyFactories) throws ApplicationError, ValidationError {
        MotEngine engine = MotEngine.getInstance();

        Planets planets = engine.getPlanets();
        if (planets == null) {
    		planets = new Planets();
            engine.setPlanets(planets);
        }
        
        Planet planet = new Planet(name, owner, ss);
        planet.setSize( size );
        planet.setPopulation( population );
        planet.setTeraforming( terraform );
        planet.setQtyFactories( qtyFactories );
        planet.setProductionBonus( 0 );
        planet.setResearchBonus( 0 );
        planet.setReproductionBonus( 0 );
        planets.add(planet);
        
        return planet;
    }

    public static Planet newPlanet(String name, SolarSystem ss, int size, double terraform, double productionBonus) throws ApplicationError, ValidationError {
        MotEngine engine = MotEngine.getInstance();

        Planets planets = engine.getPlanets();
        if (planets == null) {
    		planets = new Planets();
            engine.setPlanets(planets);
        }
        
        Planet planet = new Planet(name, null, ss);
        planet.setSize( size );
        planet.setPopulation( 0 );
        planet.setTeraforming( terraform );
        planet.setQtyFactories( 0 );
        planet.setProductionBonus( productionBonus );
        planet.setResearchBonus( 0 );
        planet.setReproductionBonus( 0 );
        planets.add(planet);
        
        return planet;
    }

    public static Planet newPlanet(String name, SolarSystem ss, Player owner) throws ApplicationError, ValidationError {
        MotEngine engine = MotEngine.getInstance();

        Planets planets = engine.getPlanets();
        if (planets == null) {
    		planets = new Planets();
            engine.setPlanets(planets);
        }
        
        Planet planet = (owner == null) ? PlanetFactory.createRandomPlanet(ss) : PlanetFactory.createHomePlanet(name, owner, ss, null);
        planet.setPercentDevelopment(0.25);
        planet.setPercentEcology(0.25);
        planet.setPercentProduction(0.25);
        planet.setPercentResearch(0.25);
        
        return planet;
    }
    

    
    protected Orbital createBattleStation(Hull battleStation, Planet p) throws ApplicationError {
        new ProjectBattleStation(new BattleStationDesign(battleStation)).build(p);
        return p.getOrbital();
    }
    
    protected void createOutpost(Hull outpost, StellarObject target, Planet builder) throws ApplicationError {
        new ProjectOutpost(new OutpostDesign(outpost), target).build(builder);
    }
    
    protected void createSpaceStation(Hull spaceStation, StellarObject target, Player builder) throws ApplicationError {
    	target.deploy(new Orbital(spaceStation, null, null), builder);
    }
    
    protected void createSpaceStation(Hull spaceStation, Planet target, Planet builder) throws ApplicationError {
    	target.deploy(builder, new Orbital(spaceStation, null, null));
    }
    
	public static CraftDesign fighterDesign;
	public static CraftDesign fighterDesignNoShield;
	public static CraftDesign defenderDesign;
	public static CraftDesign coloniserDesign;
	public static CraftDesign bomberDesign;
	public static CraftDesign powerfulDesign;
	public static CraftDesign fastFighterDesign;
	public static CraftDesign bigFighterDesign;
	
	static {
		try {
			fighterDesignNoShield = new CraftDesign("TestFighterNoShield", 
					tech_flyer30,
					tech_fusion25,
					tech_massDriver1);

			fighterDesign = new CraftDesign("TestFighter", 
					tech_flyer30,
					tech_fusion25,
					tech_electronic25,
					tech_energy10,
					tech_massDriver1);

			defenderDesign = new CraftDesign("TestDefender", 
					tech_flyer60,
					tech_fusion25,
					tech_electronic25,
					tech_energy10,
					tech_massDriver1, tech_massDriver1, tech_massDriver1);

			coloniserDesign = new CraftDesign("Coloniser", 
					tech_flyer60,
					tech_fusion25,
					tech_colonyModule8);

			powerfulDesign = new CraftDesign("TestPowerful", 
					tech_flyer100,
					tech_fusion40,
					tech_electronic40,
					tech_photon200,
					tech_energy20,
					tech_fusionBeam4, tech_fusionBeam4, tech_fusionBeam4, tech_fusionBeam4,
					tech_missile6, tech_missile6,
					tech_shieldDrain,
					tech_shieldModulatorII, tech_augumentedEnginesI, tech_eneryAmplifierI, tech_armour25);
			//powerfulDesign.getWeaponBays().getBaysAsArray()[0].setWeaponBayDetails(tech_flyer100.getBayWithBestWeaponFireAngle());
			
			bomberDesign = new CraftDesign("TestBomber", 
					tech_flyer200,
					tech_fusion400,
					tech_electronic40,
					tech_photon400,
					tech_energy20,
					tech_ancientWeapon,tech_ancientWeapon,tech_ancientWeapon,tech_ancientWeapon,tech_ancientWeapon,tech_ancientWeapon,tech_ancientWeapon,tech_ancientWeapon,tech_ancientWeapon,
					tech_shieldModulatorII, tech_augumentedEnginesI, tech_eneryAmplifierI, tech_armour200);
			
			
			fastFighterDesign = new CraftDesign("TestFastFighter", 
					tech_flyer30,
					tech_fusion400,
					tech_electronic25,
					tech_energy10,
					tech_massDriver1);

			bigFighterDesign = new CraftDesign("TestBigFighter", 
					tech_flyer200,
					tech_fusion25,
					tech_electronic25,
					tech_energy10,
					tech_massDriver1);

			
		} catch (ApplicationError e) {
			e.printStackTrace();
		}
	}

    static {
		try {
			CraftDesigns cds = new CraftDesigns();
			CraftDesigns.setInstance(cds);
			if (cds.get("Coloniser") == null) {
				cds.add(coloniserDesign);
			}
			if (cds.get("Scout") == null) {
				cds.add(new CraftDesign("Scout", tech_flyer30, tech_fusion25));
			}
	        CraftDesign monster_small = new CraftDesign("monster_small", tech_flyer30, tech_fusion25, tech_fusionBeam4, tech_electronic40, tech_energy20);
	        cds.add(monster_small);
	        CraftDesign monster = new CraftDesign("monster", tech_flyer60, tech_fusion40, tech_fusionBeam4, tech_fusionBeam4, tech_fusionBeam4, tech_fusionBeam4, tech_electronic40, tech_energy20);
	        cds.add(monster);
	        CraftDesign waterMan1 = new CraftDesign("large_WaterMan", tech_flyer60, tech_fusion40, tech_fusionBeam4, tech_fusionBeam4, tech_fusionBeam4, tech_fusionBeam4, tech_electronic40, tech_energy20);
	        cds.add(waterMan1);
	        CraftDesign waterMan2 = new CraftDesign("medium_WaterMan", tech_flyer60, tech_fusion40, tech_fusionBeam4, tech_fusionBeam4, tech_fusionBeam4, tech_fusionBeam4, tech_electronic40, tech_energy20);
	        cds.add(waterMan2);
	        CraftDesign waterMan3 = new CraftDesign("small_WaterMan", tech_flyer60, tech_fusion40, tech_fusionBeam4, tech_fusionBeam4, tech_fusionBeam4, tech_fusionBeam4, tech_electronic40, tech_energy20);
	        cds.add(waterMan3);
	        CraftDesign airMan1 = new CraftDesign("large_AirMan", tech_flyer60, tech_fusion40, tech_fusionBeam4, tech_fusionBeam4, tech_fusionBeam4, tech_fusionBeam4, tech_electronic40, tech_energy20);
	        cds.add(airMan1);
	        CraftDesign airMan2 = new CraftDesign("medium_AirMan", tech_flyer60, tech_fusion40, tech_fusionBeam4, tech_fusionBeam4, tech_fusionBeam4, tech_fusionBeam4, tech_electronic40, tech_energy20);
	        cds.add(airMan2);
	        CraftDesign airMan3 = new CraftDesign("small_AirMan", tech_flyer60, tech_fusion40, tech_fusionBeam4, tech_fusionBeam4, tech_fusionBeam4, tech_fusionBeam4, tech_electronic40, tech_energy20);
	        cds.add(airMan3);
	        CraftDesign kaan = new CraftDesign("kaan", tech_flyer60, tech_fusion40, tech_fusionBeam4, tech_fusionBeam4, tech_fusionBeam4, tech_fusionBeam4, tech_electronic40);
	        cds.add(kaan);
		} catch (ApplicationError e) {
			Logger.logError("", e);
		}
    }
	
//	public static CraftDesign getAltFighterDesign(String name, Technology [] weapons) throws ApplicationError {
//		return new CraftDesign(name, 
//				tech_flyer30,
//				tech_fusion25,
//				tech_electronic25,
//				tech_energy10,
//				weapons);
//	}
	
    public static Craft newFighterCraft(Player owner, SolarSystem ss) throws ApplicationError {
	    return newCraft(fighterDesign, owner, ss);
    }
    
    public static Craft newCraft(CraftDesign craftDesign, Player owner, StellarObject ss) throws ApplicationError {
        MotEngine engine = MotEngine.getInstance();

        Crafts crafts = engine.getCrafts();
        if (crafts == null) {
    		crafts = new Crafts();
            engine.setCrafts(crafts);
        }
        
        Craft craft = new Craft(owner, craftDesign, ss.getOrbit());
        crafts.add(craft);
        
        return craft;
    }
    
//    public static Craft newCraft(String design, Player owner, Planet planet) throws ApplicationError {
//        return newCraft(TestFactory.getCraftDesign(design), owner, planet);
//    }
    
    public static Craft newCraft(CraftDesign craftDesign, Player owner, Planet planet) throws ApplicationError {
        MotEngine engine = MotEngine.getInstance();

        Crafts crafts = engine.getCrafts();
        if (crafts == null) {
    		crafts = new Crafts();
            engine.setCrafts(crafts);
        }
        
        Craft craft = new Craft(owner, craftDesign, planet.getOrbit());
        crafts.add(craft);
        
        return craft;
    }
    
    public static Fleet newFleet(Player owner, Planet planet, CraftDesign cd, int qty) throws ApplicationError {
    	Craft [] r = new Craft[qty];
    	for (int i = 0; i < r.length; i++) {
    		r[i] = newCraft(cd, owner, planet);
		}
    	return FleetFactory.create(r);
    }
    
    public static Fleet newFleet(Player owner, Planet planet, CraftDesign cd1, int qty1, CraftDesign cd2, int qty2) throws ApplicationError {
    	Craft [] r = new Craft[qty1+qty2];
    	for (int i = 0; i < qty1; i++) {
    		r[i] = newCraft(cd1, owner, planet);
		}
    	for (int i = qty1; i < qty1+qty2; i++) {
    		r[i] = newCraft(cd2, owner, planet);
		}
    	return FleetFactory.create(r);
    }

    public static Transport newTransport(Player owner) throws ApplicationError {
    	Transport transport = owner.getTransportManagerNotNull().getFreeTransportOrCreateTransport(owner);
    	return transport;
    }
    
    public static Transport newTransportWithStationLoaded(Planet stationOwner, Hull spaceStationHull) throws ApplicationError {
    	Player owner = stationOwner.getOwner();
		Transport transport = owner.getTransportManagerNotNull().getFreeTransportOrCreateTransport(owner);
    	Orbital orbital = new Orbital(spaceStationHull, null, null);
    	new TransportTaskDeployStation(transport, stationOwner, null, orbital, false);
    	return transport;
    }
    
    public static Transport newTransportWithTroopsLoaded(Planet source, Planet destination, int qty) throws ApplicationError {
    	if (source.getQtyGroundDefense() < qty) {
    		source.setQtyGroundDefense(qty*3);
    	}
    	Player owner = source.getOwner();
		Transport transport = owner.getTransportManagerNotNull().getFreeTransportOrCreateTransport(owner);
     	new TransportTaskInvade(transport, source, destination, qty);
    	return transport;
    }
    
    public static Orbital newSpaceStation(Planet buildPlanet, Planet destinationPlanet) throws ApplicationError {
        Player owner = buildPlanet.getOwner();
    	Orbital orbital = new Orbital(tech_spaceStation, null, null);
    	destinationPlanet.deploy(buildPlanet, orbital);
    	return orbital;
//        new ProjectSpaceStation(spaceStationHull, destinationPlanet).build(buildPlanet, false);
//        Transport transport = owner.getTransportManager().getTransportsAsArray()[0];
//        TransportTaskDeployStation task = (TransportTaskDeployStation) transport.getTask();
//        transport.setOrbit(destinationPlanet.getStellarObject(), destinationPlanet);
//        task.arrivedAt(destinationPlanet.getStellarObject(), transport);
    }

    public static Orbital newSpaceStation(Planet buildPlanet, Planet destinationPlanet, Module module) throws ApplicationError {
        Player owner = buildPlanet.getOwner();
    	Orbital orbital = new Orbital(tech_spaceStation, null, new Modules(module));
    	destinationPlanet.deploy(buildPlanet, orbital);
    	return orbital;
    }

    public static Orbital newSpaceStation(Planet buildPlanet, Planet destinationPlanet, Module module1, Module module2) throws ApplicationError {
        Player owner = buildPlanet.getOwner();
    	Orbital orbital = new Orbital(tech_spaceStation, null, new Modules(module1, module2));
    	destinationPlanet.deploy(buildPlanet, orbital);
    	return orbital;
    }

    public static void newOutpost(Planet buildPlanet, StellarObject destinationSolarSystem) throws ApplicationError {
    	Player owner = buildPlanet.getOwner();
    	Orbital orbital = new Orbital(tech_outpost, tech_photon100, null);
    	destinationSolarSystem.deploy(orbital, owner);
//        new ProjectOutpost(outpostHull, destinationSolarSystem).build(buildPlanet, false);
//        Transport transport = owner.getTransportManager().getTransportsAsArray()[0];
//        TransportTaskDeployStation task = (TransportTaskDeployStation) transport.getTask();
//        task.arrivedAt(destinationSolarSystem, transport);
    }

    public static void newSpaceStation(Player owner, StellarObject destinationSolarSystem) throws ApplicationError {
    	Orbital orbital = new Orbital(tech_spaceStation, null, null);
    	destinationSolarSystem.deploy(orbital, owner);
    }

	protected Battle startBattle(Craft fighter1, Craft fighter2, Planet enemyPlanet) throws ApplicationError {
		Battle battle = MotEngine.instance.getBattlesNotNull().getBattleAt(enemyPlanet.getOrbit(), true);
        battle.join(enemyPlanet);
        battle.join(fighter1, true);
        battle.join(fighter2, true);
		return battle;
	}

	protected void endTurnUntilArrive(MoveableOwnedObject c, Planet dest) throws ApplicationError, ValidationError {
		while (c.getOrbit() == null || c.getOrbit().getStellarObject() != dest.getSolarSystem()) c.endTurn();
	}

	protected void endTurnUntilArrive(MoveableOwnedObject c, StellarObject dest) throws ApplicationError, ValidationError {
		while (c.getOrbit().getStellarObject() != dest) c.endTurn();
	}

    public void setupConfigs() throws ApplicationError {
        setupTestLeaders();
        setupOptions();
        setupGraphics();
        setupRelics();
    }
    
    private void setupGraphics() throws ApplicationError {
    	RaceGraphicsList gl = GraphicsFactory.getRaceGraphicsList();
    	RaceGraphics rg = gl.getGraphicsFor("Humans");
    	CraftGraphics hg = rg.getHullGraphics(tech_flyer200.getName());
    	if (hg == null) {
    		CraftGraphics cg = new CraftGraphics(tech_flyer200.getName(), "hull_flyer", "hull_flyer_cloaked", "hull_flyer", new Size(40,40), ".png");
			rg.setCraftGraphics(cg);
    	}
	}

    public void setupFlyer200Graphics() throws ApplicationError {
    	RaceGraphicsList gl = GraphicsFactory.getRaceGraphicsList();
    	ArrayList<RaceGraphics> rgl = gl.getGraphics();
    	for (RaceGraphics rg : rgl) {    		
    		CraftGraphics hg = rg.getHullGraphics(tech_flyer200.getName());
    		if (hg == null) {
    			CraftGraphics cg = new CraftGraphics(tech_flyer200.getName(), "hull_flyer", "hull_flyer_cloaked", "hull_flyer", new Size(40,40), ".png");
    			rg.setCraftGraphics(cg);
    		}
    	}
	}

	private void setupOptions() throws ApplicationError {
        if (!OptionsFactory.generalOptionsLoaded()) {
            SetupOptions options = TestFactory.getGeneralOptions();
            OptionsFactory.setGeneralOptions(options);
            OptionsFactory.setSetupOptions("Humans", TestFactory.getHumansOptions());
            OptionsFactory.setSetupOptions("Birds", TestFactory.getBirdsOptions());
            OptionsFactory.setSetupOptions("Bears", TestFactory.getBearsOptions());
            OptionsFactory.setSetupOptions("Ghosts", TestFactory.getGhostsOptions());
            OptionsFactory.setSetupOptions("Machines", TestFactory.getMachinesOptions());
            OptionsFactory.setSetupOptions("monster", TestFactory.getMonsterOptions());
        }
    }

	private void setupRelics() throws ApplicationError {
//		SetupOptions relics = new SetupOptions();
//		relics.addOption(name, value, cost);
//		RelicsFactory.setRelics(relics);
	}
	
    private void setupTestLeaders() {
        TestFactory.flush();
        
        //
        // HAVE NO TECHNOLOGY TREE SO CANNOT DO RESEARCH!
        // RESEARCH SHOULD USE REAL TECHS SO THEY ARE TESTED!
        //
        TechnologyTree.setInstance(new TechnologyTree());
        
        //
        // MUST ALSO SETUP TEST LEADERS
        //
        GeneralDetails general = new GeneralDetails();
        general.setName("TestGeneral");
        general.setAssaultBonus(0.1);
        general.setBattleSpeedBonus(0.2);
        general.setCloakLevel(150);
        general.setDamageBonus(0.3);
        general.setInitiativeBonus(0.4);
        general.setMaxDamageBonus(0.5);
        general.setSpeedBonus(0.6);
        GeneralDetailsList.setInstance(general);

        GovenorDetails govenor = new GovenorDetails();
        govenor.setName("TestGovenor");
        govenor.setMaxPopulationBonus(0.1);
        govenor.setProductionBonus(0.2);
        govenor.setMaxTradeRoutes(2);
        govenor.setPsiRating(10);
        govenor.setResearchBonus(0.3);
        govenor.setReproductionBonus(0.4);
        govenor.setDevelopmentBonus(0.5);
        govenor.setSpyBonus(0.5);
        govenor.setTradingBonus(0.6);
        govenor.setEcologyBonus(0.8);
        govenor.setFactoryPerPopulationBonus(0.9);
        GovenorDetailsList.setInstance(govenor);
    }
    
    protected Weapon createTestWeapon(int num) {
        Weapon w = new Weapon();
        w.setName("TestWeapon"+num);
        w.setDamage(1);        
        w.setRange(100+num);        
        w.setDegredation(0);        
        w.setVariance(0);
        return w;
    }
    
    protected void setLocationAndDirection(BattleCraft bc, Location l, int d, Craft craft1) {
    	assertEquals(craft1.getName(), bc.getName());
		bc.setLocation(l);
		bc.setDirection(d);
	}

    protected Player getPlayer(String name) throws ApplicationError {
        return MotEngine.instance.getPlayersNotNull().getPlayer(name);
    }
    
    protected String [] order(String [] da, String... names) {
    	assertEquals(Comp.toString(da), names.length, da.length);
    	String [] r = new String[da.length];
    	for (int i = 0; i < r.length; i++) {
    		String nd = Comp.find(names[i], da);
    		assertNotNull("Did not find "+names[i]+" in "+Comp.toString(da), nd);
            assertEquals(names[i], nd);
            r[i] = nd;
		}
    	return r;
    }

    protected NamedObjectDelegate [] order(NamedObjectDelegate [] da, NamedObjectDelegate [] r, String... names) {
    	assertEquals(Comp.toString(da), names.length, da.length);
    	for (int i = 0; i < r.length; i++) {
    		NamedObjectDelegate nd = Comp.find(names[i], da);
    		assertNotNull("Did not find "+names[i]+" in "+Comp.toString(da), nd);
            assertEquals(names[i], nd.getName());
            r[i] = nd;
		}
    	return r;
    }

    protected NamedObject [] order(NamedObject [] da, NamedObject [] r, String... names) {
    	assertEquals(Comp.toString(da), da.length, names.length);
    	for (int i = 0; i < r.length; i++) {
    		NamedObject nd = (NamedObject) Comp.find(names[i], da);
    		assertNotNull("Did not find "+names[i]+" in "+Comp.toString(da), nd);
            assertEquals(names[i], nd.getName());
            r[i] = nd;
		}
    	return r;
    }
    

    protected void assertEquals(BattleCraft craft, BattleCraft[] crafts) {
    	if (craft == null) {
    		assertNull(crafts);
    	} else {
	        assertEquals(1, crafts.length);
	        assertEquals(craft, crafts[0]);
    	}
    }

    protected void assertEquals(BattleCraft craft1, BattleCraft craft2, BattleCraft[] crafts) {
        assertEquals(2, crafts.length);
        assertEquals(craft1, crafts[0]);
        assertEquals(craft2, crafts[1]);
    }

    protected void assertEquals(Craft craft1, BattleCraft[] crafts) {
        assertEquals(1, crafts.length);
        assertEquals(craft1, crafts[0].getCraft());
    }

    protected void assertEquals(Craft craft1, Craft craft2, BattleCraft[] crafts) {
        assertEquals(2, crafts.length);
        assertEquals(craft1, crafts[0].getCraft());
        assertEquals(craft2, crafts[1].getCraft());
    }

    protected void assertEquals(Craft craft1, Craft craft2, Craft craft3, BattleCraft[] crafts) {
        assertEquals(3, crafts.length);
        assertEquals(craft1, crafts[0].getCraft());
        assertEquals(craft2, crafts[1].getCraft());
        assertEquals(craft3, crafts[2].getCraft());
    }

    protected void assertEquals(Craft craft1, Craft craft2, Craft craft3, Craft craft4, BattleCraft[] crafts) {
        assertEquals(4, crafts.length);
        assertEquals(craft1, crafts[0].getCraft());
        assertEquals(craft2, crafts[1].getCraft());
        assertEquals(craft3, crafts[2].getCraft());
        assertEquals(craft4, crafts[3].getCraft());
    }

    protected void assertEquals(String craft1, String craft2, BattleCraft[] crafts) {
        assertEquals(2, crafts.length);
        assertEquals(craft1, crafts[0].getName());
        assertEquals(craft2, crafts[1].getName());
    }

    protected void assertEquals(String craft1, String craft2, String craft3, BattleCraft[] crafts) {
        assertEquals(3, crafts.length);
        assertEquals(craft1, crafts[0].getName());
        assertEquals(craft2, crafts[1].getName());
        assertEquals(craft3, crafts[2].getName());
    }

    protected void assertEquals(String craft1, String craft2, String craft3, String craft4, BattleCraft[] crafts) {
        assertEquals(4, crafts.length);
        assertEquals(craft1, crafts[0].getName());
        assertEquals(craft2, crafts[1].getName());
        assertEquals(craft3, crafts[2].getName());
        assertEquals(craft4, crafts[3].getName());
    }

    protected void assertEquals(MoveableOwnedObjectDelegate craft, MoveableOwnedObjectDelegate[] crafts) {
    	if (craft == null) {
    		assertNull(crafts);
    	} else {
	        assertEquals(1, crafts.length);
	        assertEquals(craft, crafts[0]);
    	}
    }

    protected void assertEquals(MoveableOwnedObjectDelegate craft1, MoveableOwnedObjectDelegate craft2, MoveableOwnedObjectDelegate[] crafts) {
        assertEquals(2, crafts.length);
        int index1 = findIndexOf(craft1, crafts);
        assertTrue(index1 >= 0);
        int index2 = findIndexOf(craft2, crafts);
        assertTrue(index2 >= 0);
        bubbleSort(crafts, 0, craft1);
        bubbleSort(crafts, 1, craft2);
     }

    protected void assertEquals(MoveableOwnedObjectDelegate craft1, MoveableOwnedObjectDelegate craft2, MoveableOwnedObjectDelegate craft3, MoveableOwnedObjectDelegate[] crafts) {
        assertEquals(3, crafts.length);
        int index1 = findIndexOf(craft1, crafts);
        assertTrue(index1 >= 0);
        int index2 = findIndexOf(craft2, crafts);
        assertTrue(index2 >= 0);
        int index3 = findIndexOf(craft3, crafts);
        assertTrue(index3 >= 0);
        bubbleSort(crafts, 0, craft1);
        bubbleSort(crafts, 1, craft2);
        bubbleSort(crafts, 2, craft3);
    }

    protected void assertEquals(String craft, MoveableOwnedObject[] crafts) {
    	if (craft == null) {
    		assertNull(crafts);
    	} else {
	        assertEquals(1, crafts.length);
	        assertEquals(craft, crafts[0].getName());
    	}
    }

    protected void assertEquals(String craft1, String craft2, MoveableOwnedObject[] crafts) {
        assertEquals(2, crafts.length);
        int index1 = findIndexOf(craft1, crafts);
        assertTrue(index1 >= 0);
        int index2 = findIndexOf(craft2, crafts);
        assertTrue(index2 >= 0);
        bubbleSort(crafts, 0, craft1);
        bubbleSort(crafts, 1, craft2);
    }

    protected void assertEquals(String craft1, String craft2, String craft3, MoveableOwnedObject[] crafts) {
        assertEquals(3, crafts.length);
        int index1 = findIndexOf(craft1, crafts);
        assertTrue(index1 >= 0);
        int index2 = findIndexOf(craft2, crafts);
        assertTrue(index2 >= 0);
        int index3 = findIndexOf(craft3, crafts);
        assertTrue(index3 >= 0);
        bubbleSort(crafts, 0, craft1);
        bubbleSort(crafts, 1, craft2);
        bubbleSort(crafts, 2, craft3);
    }

    protected void assertEquals(String craft1, String craft2, String craft3, String craft4, MoveableOwnedObject[] crafts) {
        assertEquals(4, crafts.length);
        int index1 = findIndexOf(craft1, crafts);
        assertTrue(index1 >= 0);
        int index2 = findIndexOf(craft2, crafts);
        assertTrue(index2 >= 0);
        int index3 = findIndexOf(craft3, crafts);
        assertTrue(index3 >= 0);
        int index4 = findIndexOf(craft4, crafts);
        assertTrue(index4 >= 0);
        bubbleSort(crafts, 0, craft1);
        bubbleSort(crafts, 1, craft2);
        bubbleSort(crafts, 2, craft3);
        bubbleSort(crafts, 3, craft4);
    }


    protected void assertEquals(String craft, MoveableOwnedObjectDelegate[] crafts) {
    	if (craft == null) {
    		assertNull(crafts);
    	} else {
	        assertEquals(1, crafts.length);
	        assertEquals(craft, crafts[0].getName());
    	}
    }

    protected void assertEquals(String craft1, String craft2, MoveableOwnedObjectDelegate[] crafts) {
        assertEquals(2, crafts.length);
        int index1 = findIndexOf(craft1, crafts);
        assertTrue(index1 >= 0);
        int index2 = findIndexOf(craft2, crafts);
        assertTrue(index2 >= 0);
        bubbleSort(crafts, 0, craft1);
        bubbleSort(crafts, 1, craft2);
    }

    protected void assertEquals(String craft1, String craft2, String craft3, MoveableOwnedObjectDelegate[] crafts) {
        assertEquals(3, crafts.length);
        int index1 = findIndexOf(craft1, crafts);
        assertTrue(index1 >= 0);
        int index2 = findIndexOf(craft2, crafts);
        assertTrue(index2 >= 0);
        int index3 = findIndexOf(craft3, crafts);
        assertTrue(index3 >= 0);
        bubbleSort(crafts, 0, craft1);
        bubbleSort(crafts, 1, craft2);
        bubbleSort(crafts, 2, craft3);
    }

    protected void assertEquals(Planet planet, Planet[] planets) {
    	if (planet == null) {
    		assertNull(planets);
    	} else {
	        assertEquals(1, planets.length);
	        assertEquals(planet, planets[0]);
    	}
    }

    protected void assertEquals(Planet planet1, Planet planet2, Planet[] planets) {
        assertEquals(2, planets.length);
        assertEquals(planet1, planets[0]);
        assertEquals(planet2, planets[1]);
    }


    protected void assertEquals(Craft fighter1, Craft[] crafts) {
        assertEquals(1, crafts.length);
        assertEquals(fighter1, crafts[0]);
    }

    protected void assertEquals(Craft fighter1, Craft fighter2, Craft[] crafts) {
        assertEquals(2, crafts.length);
        assertEquals(fighter1, crafts[0]);
        assertEquals(fighter2, crafts[1]);
    }

    protected void assertEquals(Craft fighter1, Craft fighter2, Craft fighter3, Craft[] crafts) {
        assertEquals(3, crafts.length);
        assertEquals(fighter1, crafts[0]);
        assertEquals(fighter2, crafts[1]);
        assertEquals(fighter3, crafts[2]);
    }

    protected void assertEquals(MoveableOwnedObject fighter1, MoveableOwnedObjectDelegate craft) {
        assertEquals(fighter1.getName(), craft.getName());
    }

    protected void assertEquals(MoveableOwnedObject fighter1, MoveableOwnedObjectDelegate[] crafts) {
        assertEquals(1, crafts.length);
        assertEquals(fighter1, crafts[0]);
    }

    protected void assertEquals(MoveableOwnedObject fighter1, MoveableOwnedObject fighter2, MoveableOwnedObjectDelegate[] crafts) {
        assertEquals(2, crafts.length);
        int index1 = findIndexOf(fighter1, crafts);
        assertTrue(index1 >= 0);
        int index2 = findIndexOf(fighter2, crafts);
        assertTrue(index2 >= 0);
        bubbleSort(crafts, 0, fighter1);
        bubbleSort(crafts, 1, fighter2);
    }

    protected void assertEquals(MoveableOwnedObject fighter1, MoveableOwnedObject fighter2, MoveableOwnedObject fighter3, MoveableOwnedObjectDelegate[] crafts) {
        assertEquals(3, crafts.length);
        int index1 = findIndexOf(fighter1, crafts);
        assertTrue(index1 >= 0);
        int index2 = findIndexOf(fighter2, crafts);
        assertTrue(index2 >= 0);
        int index3 = findIndexOf(fighter3, crafts);
        assertTrue(index3 >= 0);
        bubbleSort(crafts, 0, fighter1);
        bubbleSort(crafts, 1, fighter2);
        bubbleSort(crafts, 2, fighter3);
    }

    protected void assertEquals(MoveableOwnedObject fighter1, MoveableOwnedObject fighter2, MoveableOwnedObject fighter3, MoveableOwnedObject fighter4, MoveableOwnedObjectDelegate[] crafts) {
        assertEquals(4, crafts.length);
        int index1 = findIndexOf(fighter1, crafts);
        assertTrue(index1 >= 0);
        int index2 = findIndexOf(fighter2, crafts);
        assertTrue(index2 >= 0);
        int index3 = findIndexOf(fighter3, crafts);
        assertTrue(index3 >= 0);
        int index4 = findIndexOf(fighter4, crafts);
        assertTrue(index4 >= 0);
        bubbleSort(crafts, 0, fighter1);
        bubbleSort(crafts, 1, fighter2);
        bubbleSort(crafts, 2, fighter3);
        bubbleSort(crafts, 3, fighter4);
    }

    protected void assertEquals(String name, NameListCR names) {
    	if (name == null) {
    		assertNull(names);
    	} else {
	        String[] na = names.getNames();
	        assertEquals(1, na.length);
	        assertEquals(name, na[0]);
    	}
    }

    protected void assertEquals(String v1, String v2, NameListCR names) {
        assertEquals(2, names.getQuantity());
        int index1 = names.findIndexOf(v1);
        assertTrue(index1 >= 0);
        int index2 = names.findIndexOf(v2);
        assertTrue(index2 >= 0);
        bubbleSort(names, 0, v1);
        bubbleSort(names, 1, v2);
    }

    protected void assertEquals(String v1, String v2, String v3, NameListCR names) {
        assertEquals(3, names.getQuantity());
        int index1 = names.findIndexOf(v1);
        assertTrue(index1 >= 0);
        int index2 = names.findIndexOf(v2);
        assertTrue(index2 >= 0);
        int index3 = names.findIndexOf(v3);
        assertTrue(index3 >= 0);
        bubbleSort(names, 0, v1);
        bubbleSort(names, 1, v2);
        bubbleSort(names, 2, v3);
    }

    private void bubbleSort(NameListCR l, int index, String item) {
		int qty = l.getQuantity();
		for (int i = 0; i < qty; i++) {
			if (item.equals(l.getNameAtIndex(i))) {
				l.swap(i, index);
			}
		}
	}

    private void bubbleSort(NamedObject[] l, int index, String item) {
		for (int i = 0; i < l.length; i++) {
			if (item.equals(l[i].getName())) {
				swap(l, i, index);
			}
		}
	}

    private void bubbleSort(NamedObjectDelegate[] l, int index, String item) {
		for (int i = 0; i < l.length; i++) {
			if (item.equals(l[i].getName())) {
				swap(l, i, index);
			}
		}
	}

    private void bubbleSort(NamedObjectDelegate[] l, int index, NamedObject item) {
		for (int i = 0; i < l.length; i++) {
			if (item.equals(l[i])) {
				swap(l, i, index);
			}
		}
	}

    private void bubbleSort(NamedObjectDelegate[] l, int index, NamedObjectDelegate item) {
		for (int i = 0; i < l.length; i++) {
			if (item.equals(l[i])) {
				swap(l, i, index);
			}
		}
	}

	private void swap(NamedObject[] l, int i1, int i2) {
    	NamedObject t = l[i1];
    	l[i1] =  l[i2];
    	l[i2] = t;
	}

	private void swap(NamedObjectDelegate[] l, int i1, int i2) {
    	NamedObjectDelegate t = l[i1];
    	l[i1] =  l[i2];
    	l[i2] = t;
	}

	protected int findIndexOf(String name, MoveableOwnedObject[] crafts) {
    	for (int i = 0; i < crafts.length; i++) {
    		if (crafts[i].getName().equals(name)) return i;
		}
    	return -1;
	}

	protected int findIndexOf(String name, MoveableOwnedObjectDelegate[] crafts) {
    	for (int i = 0; i < crafts.length; i++) {
    		if (crafts[i].getName().equals(name)) return i;
		}
    	return -1;
	}

	protected int findIndexOf(MoveableOwnedObject moo, MoveableOwnedObjectDelegate[] crafts) {
    	for (int i = 0; i < crafts.length; i++) {
    		if (moo.equals(crafts[i])) return i;
		}
    	return -1;
	}

	protected int findIndexOf(MoveableOwnedObjectDelegate moo, MoveableOwnedObjectDelegate[] crafts) {
    	for (int i = 0; i < crafts.length; i++) {
    		if (moo.equals(crafts[i])) return i;
		}
    	return -1;
	}

	protected void assertEquals(String reason, Location v1, Location v2) {
    	assertEquals(v1, v2);
    }

    protected void assertEquals(String reason, int x, int y, Location v2) {
        if (v2 == null) fail("Expected "+x+","+y+" but found null");
        if (x != v2.getX() || y != v2.getY()) {
        	fail("Expected "+x+","+y+" but found "+v2);
        }
    }

    protected void assertEquals(int x, int y, int dir, LocationAndDirection v2) {
        if (v2 == null) fail("Expected "+x+","+y+" but found null");
        if (x != v2.getX() || y != v2.getY()) {
        	fail("Expected "+x+","+y+" but found "+v2);
        }
        if (dir != v2.getDirection()) {
        	fail("Expected "+dir+" but found "+v2.getDirection());
        }
    }

    protected void assertEquals(int x, int y, Location v2) {
        if (v2 == null) fail("Expected "+x+","+y+" but found null");
        if (x != v2.getX() || y != v2.getY()) {
        	fail("Expected "+x+","+y+" but found "+v2);
        }
    }

    protected void assertEquals(int x, int y, int r, ExclusionZone v) {
        if (v == null) fail("Expected "+x+","+y+" but found null");
        assertEquals(x, v.getLocation().getX());
        assertEquals(y, v.getLocation().getY());
        assertEquals(r, v.getRadius());
    }
    

    protected void assertEquals(int x, int y, Size v2) {
        if (v2 == null) fail("Expected "+x+","+y+" but found null");
        if (x != v2.getX() || y != v2.getY()) {
        	fail("Expected "+x+","+y+" but found "+v2);
        }
    }
    
    protected void assertEquals(Location v1, Location v2) {
        if (v1 == v2) return;
        if (v1 == null && v2 != null) fail("Expected null but found "+v2);
        if (v2 == null && v1 != null) fail("Expected "+v1+" but found null");
        if (v1.getX() != v2.getX() || v1.getY() != v2.getY()) {
        	fail("Expected "+v1+" but found "+v2);
        }
    }
    
    protected void assertEquals(Size v1, Size v2) {
        if (v1 == v2) return;
        if (v1 == null && v2 != null) fail("Expected null but found "+v2);
        if (v2 == null && v1 != null) fail("Expected "+v1+" but found null");
        assertEquals("X coordinate", v1.getX(), v2.getX());
        assertEquals("Y coordinate", v1.getY(), v2.getY());
    }
    
    protected void assertEquals(Area v1, Area v2) {
        if (v1 == v2) return;
        if (v1 == null && v2 != null) fail("Expected null but found "+v2);
        if (v2 == null && v1 != null) fail("Expected "+v1+" but found null");
        assertEquals("Top", v1.getTop(), v2.getTop());
        assertEquals("Left", v1.getLeft(), v2.getLeft());
        assertEquals("Bottom", v1.getBottom(), v2.getBottom());
        assertEquals("Right", v1.getRight(), v2.getRight());
    }
    
    protected void assertEquals(TechnologyList v1, TechnologyList v2) {
        if (v1 == v2) return;
        if (v1 == null && v2 == null) return;
        if (v1 == null && v2.getQuantity() == 0) return;
        if (v2 == null && v1.getQuantity() == 0) return;
        assertNotNull(v1);
        assertNotNull(v2);
        Technology [] tl1 = v1.getAllAsArray();
        Technology [] tl2 = v2.getAllAsArray();
        assertEquals(tl1.length, tl2.length);
        for (int i=0; i<tl1.length; i++) {
            assertEquals(tl1[i], tl2[i]);
        }
    }

    protected void assertEquals(Technology [] v1, TechnologyList v2) {
        assertEquals(v1.length, v2.getQuantity());
        assertTrue(v2.contains(v1));
    }

    protected void assertEquals(Technology tech, String techName) {
        assertEquals(tech.getName(), techName);
    }

    protected void assertEquals(String r, Technology tech, String techName) {
        assertEquals(r, tech.getName(), techName);
    }

    protected void assertEquals(Object [] v1, Object [] v2) {
        if (v1 == null && v2 == null) return;
        if (v1 == null || v2 == null) fail("One value is null");
        assertEquals(v1.length, v2.length);
        for (int i = 0; i < v1.length; i++) {
			assertEquals(v1[i], v2[i]);
		}
    }

    protected void assertEquals(String text, Planet v1, Orbit v2) {
        if (v1 == null && v2 == null) return;
        if (v1 == null || v2 == null) fail(text + ": One value is null");
        if (v2.getPlanet() == null) fail(text + ": Orbit "+v2+" does not have a planet");
        assertEquals(text, v1, v2.getPlanet());
        assertEquals(text, v1.getStellarObject(), v2.getStellarObject());
    }
    
    protected void assertEquals(Planet v1, Orbit v2) {
        if (v1 == null && v2 == null) return;
        if (v1 == null || v2 == null) fail("One value is null");
        if (v2.getPlanet() == null) fail("Orbit "+v2+" does not have a planet ");
        assertEquals(v1, v2.getPlanet());
        assertEquals(v1.getStellarObject(), v2.getStellarObject());
    }

    protected void assertEquals(Orbit v1, Orbit v2) {
        if (v1 == null && v2 == null) return;
        if (v1 == null || v2 == null) fail("One value is null");
        if (v1.getPlanet() == null) {
        	assertNull(v2.getPlanet());
        } else {
        	assertEquals(v1.getPlanet(), v2.getPlanet());
        }
        assertEquals(v1.getStellarObject(), v2.getStellarObject());
    }

    protected void assertEquals(Orbit v1, OrbitVO v2) {
        if (v1 == null && v2 == null) return;
        if (v1 == null || v2 == null) fail("One value is null");
        if (v1.getPlanet() == null) {
        	assertNull(v2.getPlanet());
        } else {
        	assertEquals(v1.getPlanet().getName(), v2.getPlanet());
        }
        assertEquals(v1.getStellarObject().getName(), v2.getStellarObject());
    }

    protected void assertEquals(String text, StellarObject v1, Orbit v2) {
        if (v1 == null && v2 == null) return;
        if (v1 == null || v2 == null) fail(text + ": One value is null");
        if (v2.getPlanet() != null) fail(text + ": Orbit "+v2+" has a planet");
        assertEquals(text, v1, v2.getStellarObject());
    }
    
    protected void assertEquals(StellarObject v1, Orbit v2) {
        if (v1 == null && v2 == null) return;
        if (v1 == null || v2 == null) fail("One value is null");
        if (v2.getPlanet() != null) fail("Orbit "+v2+" has a planet ");
        assertEquals(v1, v2.getStellarObject());
    }

    protected void assertEquals(Planet v1, PlanetReference v2) {
        assertEquals(v1, v2.getPlanet());
    }

    protected void assertEquals(StellarObject v1, StellarObjectReference v2) {
        assertEquals(v1, v2.getStellarObject());
    }

    protected void assertEquals(WeaponBays v1, WeaponBays v2) {
        if (v1 == null && v2 == null) return;
        if (v1 == v2) return;
        assertNotNull(v1);
        assertNotNull(v2);
        Weapons v1List = v1.getAllWeaponsAsList();
		Weapons v2List = v2.getAllWeaponsAsList();
		assertEquals(v1List, v2List);
    }

    protected void assertEquals(WeaponBaysDesign v1, WeaponBaysDesign v2) throws ApplicationError {
        if (v1 == null && v2 == null) return;
        if (v1 == v2) return;
        assertNotNull(v1);
        assertNotNull(v2);
        Weapons v1List = v1.getAllWeaponsAsList();
		Weapons v2List = v2.getAllWeaponsAsList();
		assertEquals(v1List, v2List);
    }

    protected void assertEquals(CraftDesign v1, CraftDesign v2) throws ApplicationError {
        if (v1 == null && v2 == null) return;
        if (v1 == v2) return;
        assertNotNull(v1);
        assertNotNull(v2);
        assertEquals(v1.getName(), v2.getName());
        assertEquals(v1.getComputers(), v2.getComputers());
        assertEquals(v1.getEngine(), v2.getEngine());
        assertEquals(v1.getHull(), v2.getHull());
        assertEquals(v1.getScanners(), v2.getScanners());
        assertEquals(v1.getShields(), v2.getShields());
        assertEquals(v1.getSpecials(), v2.getSpecials());
        assertEquals(v1.getWeaponBays(), v2.getWeaponBays());
    }

    protected void assertEquals(CraftDesigns v1, CraftDesigns v2) throws ApplicationError {
        if (v1 == null && v2 == null) return;
        assertEquals(v1.getCraftDesigns(), v2.getCraftDesigns());
    }
    
    protected void assertEquals(CraftDesign [] v1, CraftDesign [] v2) throws ApplicationError {
        if (v1 == null && v2 == null) return;
        if (v1 == null && v2.length == 0) return;
        if (v2 == null && v1.length == 0) return;
        assertEquals(v1.length, v2.length);
        for (int i=0; i<v1.length; i++) {
        	assertEquals(v1[i], v2[i]);
        }
    }
    
    protected void assertEquals(String reason, Craft v1, CraftDesign v2) throws ApplicationError {
    	assertEquals(v1, v2);
    }
    
    protected void assertEquals(Craft v1, CraftDesign v2) throws ApplicationError {
        if (v1 == null && v2 == null) return;
        assertNotNull(v2);
        assertTrue(v1.getName().startsWith(v2.getName()));
        assertEquals(v1.getComputers(), new Computers(v2.getComputers()));
        assertEquals(v1.getEngine(), v2.getEngine());
        assertEquals(v1.getHull(), v2.getHull());
        assertEquals(v1.getScanners(), new Scanners(v2.getScanners()));
        assertEquals(v1.getShields(), new Shields(v2.getShields()));
        assertEquals(v1.getSpecials(), new Specials(v2.getSpecials()));
        assertEquals(v1.getWeaponBays(), new WeaponBays(v2.getWeaponBays()));
    }

    protected void assertEquals(PlayerAssets v1, PlayerAssets v2) throws ApplicationError {
        if (v1 == null && v2 == null) return;
        if (v1 == v2) return;
        assertNotNull(v1);
        assertNotNull(v2);
        assertEquals(v1.getMoney(), v2.getMoney());
        assertEquals(v1.getPlanet(), v2.getPlanet());
        assertEquals(v1.getTechnologList(), v2.getTechnologList());
        assertEquals(v1.getCraftNames(), v2.getCraftNames());
    }
    
    protected void assertEquals(BattleCraft v1, CraftState v2) throws ApplicationError {
    	assertEquals(v1.getOwner(), v1, v2);
    }

    protected void assertEquals(Player viewer, BattleCraft v1, CraftState v2) throws ApplicationError {
        if (v1 == null && v2 == null) return;
        assertNotNull(v1);
        assertNotNull(v2);
        assertEquals(v1.getOwnerName(), v2.getOwner());
	    assertEquals(v1.getLocation(), v2.getLocation());
	    assertEquals(v1.getDirection(), v2.getDirection());
	    assertEquals(v1.getMoveRemaining(), v2.getMoveRemainingAsPercent());
	    assertEquals(v1.getController().getName(), v2.getController());
	    assertEquals(v1.getCrewAsPercent(), v2.getCrewPercent());
	    assertEquals(v1.getDamageAsPercent(), v2.getDamagePercent());
	    assertEquals(v1.getDamageAsPercent(), v2.getDamagePercent());
	    assertEquals(v1.getMovementDamageAsPercent(), v2.getMovementDamagePercent());
	    assertEquals(v1.getPsiDamageAsPercent(), v2.getPsiDamagePercent());
	    assertEquals(v1.getShieldAsPercent(), v2.getShieldPercent());
	    assertEquals(v1.getOwner().getColor().getName(), v2.getColor());
	    assertEquals(v1.getIsCloakedToList(), v2.getCloakedToPlayerNames());
	    assertEquals(v1.getVisibleDecorators(viewer), v2.getDecorators());
    }

    protected void assertEquals(String name, PlanetDelegate v) throws ApplicationError {
		assertEquals(name, v.getName());
    }
    
    protected void assertEquals(Planet p, PlanetDelegate v) throws ApplicationError {
		assertEquals(p.getName(), v.getName());
    }
    
    protected void assertEquals(SolarSystem ss1, SolarSystem ss2, int date, TradeRouteDelegate [] v) throws ApplicationError {
        assertEquals(1, v.length);
        assertEquals(ss1, ss2, date, v[0]);
    }
    
    protected void assertEquals(SolarSystem ss1, SolarSystem ss2, int date1, SolarSystem ss3, SolarSystem ss4, int date2, TradeRouteDelegate [] v) throws ApplicationError {
        assertEquals(2, v.length);
        assertEquals(ss1, ss2, date1, v[0]);
        assertEquals(ss3, ss4, date2, v[1]);
    }
    
    protected void assertEquals(SolarSystem ss1, SolarSystem ss2, int date, TradeRouteDelegate v) throws ApplicationError {
		assertEquals(ss1.getName(), v.getSolarSystem1().getName());
		assertEquals(ss2.getName(), v.getSolarSystem2().getName());
		assertEquals(date, v.getStartDate());
    }

    protected void assertEquals(SolarSystem ss1, SolarSystem ss2, int date, TradeRouteVO v) throws ApplicationError {
		assertEquals(ss1, v.getSolarSystem1());
		assertEquals(ss2, v.getSolarSystem2());
		assertEquals(date, v.getStartDate());
    }

    protected void assertEquals(String ss1, String ss2, int date, TradeRouteVO v) throws ApplicationError {
		assertEquals(ss1, v.getSolarSystem1());
		assertEquals(ss2, v.getSolarSystem2());
		assertEquals(date, v.getStartDate());
    }
    
    protected void assertEquals(SolarSystem ss1, SolarSystem ss2, int date, TradeRoute v) throws ApplicationError {
		assertEquals(ss1, v.getSolarSystem1Name());
		assertEquals(ss2, v.getSolarSystem2Name());
		assertEquals(date, v.getStartDate());
    }

    protected void assertEquals(SolarSystem ss1, SolarSystem ss2, int date, TradeRoutes v) throws ApplicationError {
    	TradeRoute[] tra = v.getTradeRoutes();
		assertEquals(1, tra.length);
		assertEquals(ss1, ss2, date, tra[0]);
    }

    protected void assertEquals(SolarSystem tr1_ss1, SolarSystem tr1_ss2, int tr1_date, SolarSystem tr2_ss1, SolarSystem tr2_ss2, int tr2_date, TradeRoutes v) throws ApplicationError {
    	TradeRoute[] tra = v.getTradeRoutes();
		assertEquals(2, tra.length);
		assertEquals(tr1_ss1, tr1_ss2, tr1_date, tra[0]);
		assertEquals(tr2_ss1, tr2_ss2, tr2_date, tra[1]);
    }

    protected void assertEquals(SolarSystem tr1_ss1, SolarSystem tr1_ss2, int tr1_date, SolarSystem tr2_ss1, SolarSystem tr2_ss2, int tr2_date, SolarSystem tr3_ss1, SolarSystem tr3_ss2, int tr3_date, TradeRoutes v) throws ApplicationError {
    	TradeRoute[] tra = v.getTradeRoutes();
		assertEquals(3, tra.length);
		assertEquals(tr1_ss1, tr1_ss2, tr1_date, tra[0]);
		assertEquals(tr2_ss1, tr2_ss2, tr2_date, tra[1]);
		assertEquals(tr3_ss1, tr3_ss2, tr2_date, tra[2]);
    }

    protected void assertEquals(SolarSystem tr1_ss1, SolarSystem tr1_ss2, int tr1_date, SolarSystem tr2_ss1, SolarSystem tr2_ss2, int tr2_date, SolarSystem tr3_ss1, SolarSystem tr3_ss2, int tr3_date, SolarSystem tr4_ss1, SolarSystem tr4_ss2, int tr4_date, TradeRoutes v) throws ApplicationError {
    	TradeRoute[] tra = v.getTradeRoutes();
		assertEquals(4, tra.length);
		assertEquals(tr1_ss1, tr1_ss2, tr1_date, tra[0]);
		assertEquals(tr2_ss1, tr2_ss2, tr2_date, tra[1]);
		assertEquals(tr3_ss1, tr3_ss2, tr3_date, tra[2]);
		assertEquals(tr4_ss1, tr4_ss2, tr4_date, tra[3]);
    }

    protected void assertEquals(String planet1, String planet2, int date, TradeRoute v) throws ApplicationError {
		assertEquals(planet1, v.getSolarSystem1());
		assertEquals(planet2, v.getSolarSystem2());
		assertEquals(date, v.getStartDate());
    }
    

    protected void assertEquals(ObjectTurn v1, ObjectMovement [] v2) {
    	assertEquals(1, v2.length);
    	assertEquals(v1, v2[0]);
    }

//    protected void assertEquals(ObjectTurn v1, ObjectMovement v2) {
//    	assertEquals(v1.getMovePercent(), v2);
//    }

    protected void assertEquals(BattleCraft v1, BattleCraftSpeedVO v2) throws ApplicationError {
	    assertEquals(v1.getSpeed(), v2.getSpeed());
	    assertEquals(v1.getTurningSpeed(), v2.getTurningSpeed());
    }
    
    protected void assertEquals(BattleCraft v1, BattleObjectWeaponStateVO v2) throws ApplicationError {
	    WeaponInstanceVO[] wa = v2.getWeapons();
	    for (int i = 0; i < wa.length; i++) {
	    	WeaponInstance wi = v1.getWeapon(wa[i].getWeapon());
	    	assertEquals(wi.getQty(), wa[i].getQty());
	    	assertEquals(wi.getQtyFired(), wa[i].getQtyFired());
	    	assertEquals(wi.getRange(), wa[i].getRange());
		}
	    assertEquals(v1.hasFightersToLaunch(), v2.isHasFightersToLaunch());
    }
    
    protected void assertEquals(BattleObject bo, BattleObjectDelegate bod) {
        if (bo == null && bod == null) return;
        assertNotNull(bo);
        assertNotNull(bod);
        assertEquals(bo.getName(), bod.getName());
    }
    
    protected void assertEquals(BattleObject bo, String name) {
        assertEquals(bo.getName(), name);
    }
    
    protected void assertEmptyArray(Object [] a) {
    	if (a != null) {
    		assertEquals(0, a.length);
    	}
    }
    
    public Craft[] toArray(Craft craft) {
        Craft [] ca = new Craft[1];
        ca[0] = craft;
		return ca;
	}

    protected void assertInRange(String reason, int min, int max, int value) {
        assertTrue(reason, value >= min);
        assertTrue(reason, value <= max);
    }

    protected void assertEquals(NameList v1, NameList v2) {
        if (v1 == null && v2 == null) return;
        if (v1 == null && v2.getQuantity() == 0) return;
        if (v2 == null && v1.getQuantity() == 0) return;
        String [] tl1 = v1.getNamesAsArray();
        String [] tl2 = v2.getNamesAsArray();
        assertEquals(tl1.length, tl2.length);
        for (int i=0; i<tl1.length; i++) {
        	assertEquals(tl1[i], tl2[i]);
        }
	}

    protected void assertEquals(String reason, String v1, String[] l) {
    	assertEquals(v1, l);
    }
    
    protected void assertEquals(String v1, String[] l) {
    	if (v1 == null) {
    		if (l != null) assertEquals(0, l.length);
    	} else {
    		assertEquals(1, l.length);
    		assertEquals(v1, l[0]);
    	}
    }

    protected void assertEquals(String reason, StellarObject so, String name) {
       	assertEquals(so, name);
	}
    
    protected void assertEquals(StellarObject so, String name) {
       	assertEquals(so.getName(), name);
	}

    protected void assertEquals(String reason, Planet p, String name) {
       	assertEquals(p, name);
	}
    
    protected void assertEquals(Planet p, String name) {
       	assertEquals(p.getName(), name);
	}

    protected void assertEquals(String reason, Player p, String name) {
       	assertEquals(p, name);
	}
    
    protected void assertEquals(Player p, String name) {
       	assertEquals(p.getName(), name);
	}

    
    protected void assertEquals(Resource v1, String name) {
       	assertEquals(v1, Resources.getResource(name));
	}

    protected void assertEquals(String name, Resource v1) {
       	assertEquals(name, v1.getName());
	}


    protected void assertDifferentyInstances(TechnologyList v1, TechnologyList v2) {
        if (v1 == null || v1.getQuantity() == 0) return;
        if (v2 == null) return;
        Technology [] tl1 = v1.getAllAsArray();
        for (int i=0; i<tl1.length; i++) {
        	Technology tech = v2.get(tl1[i].getName());
        	assertNotNull(tech);
        	assertTrue(tl1[i] != tech);
        }
	}

    protected void assertSameContent(TechnologyList v1, TechnologyList v2) {
        if (v1 == null && v2 == null) return;
        if (v1 == null && v2.getQuantity() == 0) return;
        if (v2 == null && v1.getQuantity() == 0) return;
        Technology [] tl1 = v1.getAllAsArray();
        Technology [] tl2 = v2.getAllAsArray();
        assertEquals(tl1.length, tl2.length);
        for (int i=0; i<tl1.length; i++) {
        	assertSameContent(tl1[i], tl2[i]);
        }
	}

    protected void assertEquals(TechnologyList v1, TechnologyListVO v2) throws ApplicationError {
        if (v1 == null && v2 == null) return;
        if (v1 == null && v2.getQuantity() == 0) return;
        if (v2 == null && v1.getQuantity() == 0) return;
        Technology [] tl1 = v1.getAllAsArray();
        Technology [] tl2 = v2.getAllAsArray();
        assertEquals(tl1.length, tl2.length);
        for (int i=0; i<tl1.length; i++) {
        	assertSameContent(tl1[i], tl2[i]);
        }
	}

    protected void assertEquals(Technology v1, String[] tl) {
        if (v1 == null && tl == null) return;
        assertEquals(1, tl.length);
       	assertEquals(v1.getName(), tl[0]);
	}

    protected void assertEquals(String reason, Technology v1, String[]  tl) {
       	assertEquals(v1, tl);
	}

    protected void assertEquals(Technology v1, Technology v2, String[]  tl) {
        if (v1 == null || v2 == null) return;
        assertEquals(2, tl.length);
        if (v1.sameName(tl[0])) {
	       	assertEquals(v1, tl[0]);
	       	assertEquals(v2, tl[1]);
        } else {
	       	assertEquals(v2, tl[0]);
	       	assertEquals(v1, tl[1]);
        	
        }
	}

    protected void assertEquals(String reason, Technology v1, Technology v2, Technology v3, String[]  tl) {
       	assertEquals(v1, v2, tl);
	}

    protected void assertEquals(Technology v1, Technology v2, Technology v3, String[]  tl) {
        if (v1 == null || v2 == null || v3 == null) return;
        if (tl == null) return;
        assertEquals(3, tl.length);
       	assertEquals(v1, tl[0]);
       	assertEquals(v2, tl[1]);
       	assertEquals(v3, tl[2]);
	}

    protected void assertEquals(String reason, Technology v1, Technology v2, String[]  v3) {
       	assertEquals(v1, v2, v3);
	}
    
    
    protected void assertEquals(Technology v1, TechnologyList tl) {
        if (v1 == null && tl == null) return;
        Technology [] tl2 = tl.getAllAsArray();
        assertEquals(1, tl2.length);
       	assertEquals(v1, tl2[0]);
	}

    protected void assertEquals(String reason, Technology v1, TechnologyList tl) {
       	assertEquals(v1, tl);
	}

    protected void assertEquals(Technology v1, Technology v2, TechnologyList tl) {
        if (v1 == null || v2 == null) return;
        Technology [] tl2 = tl.getAllAsArray();
        assertEquals(2, tl2.length);
        if (v1 == tl2[0]) {
	       	assertEquals(v1, tl2[0]);
	       	assertEquals(v2, tl2[1]);
        } else {
	       	assertEquals(v2, tl2[0]);
	       	assertEquals(v1, tl2[1]);
        	
        }
	}

    protected void assertEquals(String reason, Technology v1, Technology v2, Technology v3, Technology v4, TechnologyList tl) {
       	assertEquals(v1, v2, v3, v4, tl);
	}

    protected void assertEquals(String reason, Technology v1, Technology v2, Technology v3, TechnologyList tl) {
       	assertEquals(v1, v2, v3, tl);
	}

    protected void assertEquals(Technology v1, Technology v2, Technology v3, TechnologyList tl) {
        if (v1 == null || v2 == null || v3 == null) return;
        if (tl == null) return;
        Technology [] tl2 = tl.getAllAsArray();
        assertEquals(3, tl2.length);
       	assertEquals(v1, tl2[0]);
       	assertEquals(v2, tl2[1]);
       	assertEquals(v3, tl2[2]);
	}

    protected void assertEquals(Technology v1, Technology v2, Technology v3, Technology v4, TechnologyList tl) {
        if (v1 == null || v2 == null || v3 == null) return;
        if (tl == null) return;
        Technology [] tl2 = tl.getAllAsArray();
        assertEquals(4, tl2.length);
       	assertEquals(v1, tl2[0]);
       	assertEquals(v2, tl2[1]);
       	assertEquals(v3, tl2[2]);
       	assertEquals(v4, tl2[3]);
	}

    protected void assertEquals(Technology v1, Technology v2, Technology v3, Technology v4, Technology v5, TechnologyList tl) {
        if (v1 == null || v2 == null || v3 == null) return;
        if (tl == null) return;
        Technology [] tl2 = tl.getAllAsArray();
        assertEquals(5, tl2.length);
       	assertEquals(v1, tl2[0]);
       	assertEquals(v2, tl2[1]);
       	assertEquals(v3, tl2[2]);
       	assertEquals(v4, tl2[3]);
       	assertEquals(v5, tl2[4]);
	}

    protected void assertEquals(String reason, Technology v1, Technology v2, TechnologyList v3) {
       	assertEquals(v1, v2, v3);
	}

    protected void assertEquals(Technology v1, TechnologyListVO v2) throws ApplicationError {
        if (v1 == null && v2 == null) return;
        if (v2 == null) return;
        Technology [] tl2 = v2.getAllAsArray();
        assertEquals(1, tl2.length);
       	assertEquals(v1, tl2[0]);
	}

    protected void assertEquals(Technology v1, Technology []tl) {
        if (v1 == null) return;
        if (tl == null) fail();
        assertEquals(1, tl.length);
       	assertEquals(v1, tl[0]);
	}

    protected void assertEquals(Technology v1, Technology v2, Technology []tl) {
        if (v1 == null || v2 == null) return;
        if (tl == null) return;
        assertEquals(2, tl.length);
       	assertEquals(v1, tl[0]);
       	assertEquals(v2, tl[1]);
	}

    protected void assertEquals(Technology v1, Technology v2, Technology v3, Technology []tl) {
        if (v1 == null || v2 == null || v3 == null) return;
        if (tl == null) return;
        assertEquals(3, tl.length);
       	assertEquals(v1, tl[0]);
       	assertEquals(v2, tl[1]);
       	assertEquals(v3, tl[2]);
	}

    protected void assertEquals(Technology v1, Technology v2, Technology v3, Technology v4, Technology [] tl) {
        if (v1 == null || v2 == null || v3 == null) return;
        if (tl == null) return;
        assertEquals(4, tl.length);
       	assertEquals(v1, tl[0]);
       	assertEquals(v2, tl[1]);
       	assertEquals(v3, tl[2]);
       	assertEquals(v4, tl[3]);
	}

    protected void assertEquals(Technology v1, Technology v2, Technology v3, Technology v4, Technology v5, Technology [] tl) {
        if (v1 == null || v2 == null || v3 == null) return;
        if (tl == null) return;
        assertEquals(5, tl.length);
       	assertEquals(v1, tl[0]);
       	assertEquals(v2, tl[1]);
       	assertEquals(v3, tl[2]);
       	assertEquals(v4, tl[3]);
       	assertEquals(v5, tl[4]);
	}

    protected void assertEquals(Technology v1, Technology v2, Technology v3, Technology v4, Technology v5, Technology v6, Technology [] tl) {
        if (v1 == null || v2 == null || v3 == null) return;
        if (tl == null) return;
        assertEquals(6, tl.length);
       	assertEquals(v1, tl[0]);
       	assertEquals(v2, tl[1]);
       	assertEquals(v3, tl[2]);
       	assertEquals(v4, tl[3]);
       	assertEquals(v5, tl[4]);
       	assertEquals(v6, tl[5]);
	}

    protected void assertEquals(Technology v1, Technology v2, Technology v3, Technology v4, Technology v5, Technology v6, Technology v7, Technology [] tl) {
        if (v1 == null || v2 == null || v3 == null) return;
        if (tl == null) return;
        assertEquals(7, tl.length);
       	assertEquals(v1, tl[0]);
       	assertEquals(v2, tl[1]);
       	assertEquals(v3, tl[2]);
       	assertEquals(v4, tl[3]);
       	assertEquals(v5, tl[4]);
       	assertEquals(v6, tl[5]);
       	assertEquals(v7, tl[6]);
	}

    protected void assertEquals(Weapon v, int qty, Weapon [] tl) {
        assertEquals(1, tl.length);
        for (int i = 0; i < tl.length; i++) {			
        	assertEquals(v, tl[i]);
		}
    }

    protected void assertEquals(Weapon v, int qty, WeaponInstance [] tl) {
        assertEquals(1, tl.length);
    	assertEquals(v, qty, tl[0]);
    }
    
    protected void assertEquals(Weapon v1, int qty1, Weapon v2, int qty2, WeaponInstance [] tl) {
        assertEquals(2, tl.length);
    	assertEquals(v1, qty1, tl[0]);
    	assertEquals(v2, qty2, tl[1]);
    }
    
    protected void assertEquals(Weapon v1, int qty, WeaponInstance tl) {
        if (v1 == null) return;
        if (tl == null) return;
        assertEquals(qty, tl.getQty());
       	assertEquals(v1, tl.getWeapon());
	}

    protected void assertEquals(Shield v, ShieldInstance [] tl) {
        assertEquals(1, tl.length);
        assertEquals(v, tl[0].getShield());
    }
    
//    protected void assertIn(Technology v, Technology v1, Technology v2) {
//        if (v == v1 || v == v2) return;
//        fail(""+v+" not in "+v1+" "+v2);
//	}
//
//    protected void assertIn(Technology v, Technology v1, Technology v2, Technology v3) {
//        if (v == v1 || v == v2 || v == v3) return;
//        fail(""+v+" not in "+v1+" "+v2+" "+v3);
//	}
//
//    protected void assertIn(Technology v, Technology v1, Technology v2, Technology v3, Technology v4) {
//        if (v == v1 || v == v2 || v == v3 || v == v4) return;
//        fail(""+v+" not in "+v1+" "+v2+" "+v3+" "+v4);
//	}
//
//    protected void assertIn(Technology v, Technology v1, Technology v2, Technology v3, Technology v4, Technology v5) {
//        if (v == v1 || v == v2 || v == v3 || v == v4 || v == v5) return;
//        fail(""+v+" not in "+v1+" "+v2+" "+v3+" "+v4+" "+v5);
//	}

    protected void assertIn(TechnologyList techs, Technology ... tl) throws ApplicationError {
        if (tl == null) return;
        if (techs == null) return;
        Technology[] ta = techs.getAllAsArray();
        for (int i = 0; i < ta.length; i++) {
			assertIn(ta[i], tl);
		}
	}

    protected void assertIn(Technology tech, Technology ... tl) throws ApplicationError {
        if (tl == null) return;
        if (tech == null) return;
        for (int i = 0; i < tl.length; i++) {
			if (tech == tl[i]) return;
		}
        fail(""+tech+" not in "+new TestTechnologyList(tl));
	}

    protected void assertIn(Technology tech, TechnologyList tl) {
        if (tl == null) return;
        if (tech == null) return;
        Technology[] ta = tl.getAllAsArray();
        for (int i = 0; i < ta.length; i++) {
			if (tech == ta[i]) return;
		}
        fail(""+tech+" not in "+tl);
	}

    protected void assertSameContent(Technology t1, Technology t2) {
		if (t1 instanceof Weapon) {
			Weapon w1 = (Weapon) t1;
			Weapon w2 = (Weapon) t2;
			assertFalse(t1 == t2);
			assertEquals(w1.getName(), 				w2.getName());
			assertEquals(w1.getCostToBuild(), 		w2.getCostToBuild());
			assertEquals(w1.getCostToResearch(), 	w2.getCostToResearch());
			assertEquals(w1.getDescription(), 		w2.getDescription());
			assertEquals(w1.getGroup(), 			w2.getGroup());
			assertEquals(w1.getImage(), 			w2.getImage());
			assertEquals(w1.getMaxQtyOnCraft(), 	w2.getMaxQtyOnCraft());
			assertEquals(w1.getMaxQtyOnPlanet(), 	w2.getMaxQtyOnPlanet());
			assertEquals(w1.getAnimationType(), 	w2.getAnimationType());
			assertEquals(w1.getSpace(), 			w2.getSpace());
			assertEquals(w1.getCostToBuild(), 		w2.getCostToBuild());
			assertEquals(w1.getDegredation(), 		w2.getDegredation());
			assertEquals(w1.getRange(), 			w2.getRange());
			assertEquals(w1.getDamage(), 			w2.getDamage());
			assertEquals(w1.getVariance(), 			w2.getVariance());
			assertEquals(w1.getQtyShots(), 			w2.getQtyShots());
		} else if (t1 instanceof Biotechnology) {
			Biotechnology w1 = (Biotechnology) t1;
			Biotechnology w2 = (Biotechnology) t2;
			assertFalse(t1 == t2);
			assertEquals(w1.getName(), 				w2.getName());
			assertEquals(w1.getCostToBuild(), 		w2.getCostToBuild());
			assertEquals(w1.getCostToResearch(), 	w2.getCostToResearch());
			assertEquals(w1.getDescription(), 		w2.getDescription());
			assertEquals(w1.getGroup(), 			w2.getGroup());
			assertEquals(w1.getImage(), 			w2.getImage());
			assertEquals(w1.getPsiRating(), 		w2.getPsiRating());
			assertEquals(w1.getReproductionBonus(), w2.getReproductionBonus());
			assertEquals(w1.getSpyRating(), 		w2.getSpyRating());
			assertEquals(w1.getTerraformRating(), 	w2.getTerraformRating());
		} else if (t1 instanceof Computer) {
			Computer w1 = (Computer) t1;
			Computer w2 = (Computer) t2;
			assertFalse(t1 == t2);
			assertEquals(w1.getName(), 				w2.getName());
			assertEquals(w1.getCostToBuild(), 		w2.getCostToBuild());
			assertEquals(w1.getCostToResearch(), 	w2.getCostToResearch());
			assertEquals(w1.getDescription(), 		w2.getDescription());
			assertEquals(w1.getGroup(), 			w2.getGroup());
			assertEquals(w1.getImage(), 			w2.getImage());
			assertEquals(w1.getCommerce(), 			w2.getCommerce());
			assertEquals(w1.getInfluence(), 		w2.getInfluence());
			assertEquals(w1.getPower(), 			w2.getPower());
			assertEquals(w1.getSpace(), 			w2.getSpace());
			assertEquals(w1.getCostToBuild(), 		w2.getCostToBuild());
		} else if (t1 instanceof Engine) {
			Engine w1 = (Engine) t1;
			Engine w2 = (Engine) t2;
			assertFalse(t1 == t2);
			assertEquals(w1.getName(), 				w2.getName());
			assertEquals(w1.getCostToBuild(), 		w2.getCostToBuild());
			assertEquals(w1.getCostToResearch(), 	w2.getCostToResearch());
			assertEquals(w1.getDescription(), 		w2.getDescription());
			assertEquals(w1.getGroup(), 			w2.getGroup());
			assertEquals(w1.getImage(), 			w2.getImage());
			assertEquals(w1.getMaxTravelDistance(),	w2.getMaxTravelDistance());
			assertEquals(w1.getTurningSpeed(), 		w2.getTurningSpeed());
			assertEquals(w1.getImpulseSpeed(), 		w2.getImpulseSpeed());
			assertEquals(w1.getWarpSpeed(), 		w2.getWarpSpeed());
			assertEquals(w1.getSpace(), 			w2.getSpace());
			assertEquals(w1.getCostToBuild(), 		w2.getCostToBuild());
		} else if (t1 instanceof Factory) {
			Factory w1 = (Factory) t1;
			Factory w2 = (Factory) t2;
			assertFalse(t1 == t2);
			assertEquals(w1.getName(), 				w2.getName());
			assertEquals(w1.getCostToBuild(), 		w2.getCostToBuild());
			assertEquals(w1.getCostToResearch(), 	w2.getCostToResearch());
			assertEquals(w1.getDescription(), 		w2.getDescription());
			assertEquals(w1.getGroup(), 			w2.getGroup());
			assertEquals(w1.getImage(), 			w2.getImage());
			assertEquals(w1.getBuildQuality(),		w2.getBuildQuality());
			assertEquals(w1.getMinEcologyWork(), 	w2.getMinEcologyWork());
			assertEquals(w1.getProduction(), 		w2.getProduction());
			assertEquals(w1.getPropaganda(), 		w2.getPropaganda());
			assertEquals(w1.getQtyPerPopulation(), 	w2.getQtyPerPopulation());
			assertEquals(w1.getSpace(), 			w2.getSpace());
			assertEquals(w1.getCostToBuild(), 		w2.getCostToBuild());
		} else if (t1 instanceof Hull) {
			Hull w1 = (Hull) t1;
			Hull w2 = (Hull) t2;
			assertFalse(t1 == t2);
			assertEquals(w1.getName(), 				w2.getName());
			assertEquals(w1.getCostToBuild(), 		w2.getCostToBuild());
			assertEquals(w1.getCostToResearch(), 	w2.getCostToResearch());
			assertEquals(w1.getDescription(), 		w2.getDescription());
			assertEquals(w1.getGroup(), 			w2.getGroup());
			assertEquals(w1.getImage(), 			w2.getImage());
			assertEquals(w1.getBattleMovementCost(),w2.getBattleMovementCost());
			assertEquals(w1.getBattleTurningCost(), w2.getBattleTurningCost());
			assertEquals(w1.getCostToBuildFactor(), w2.getCostToBuildFactor());
			assertEquals(w1.getCrew(), 				w2.getCrew());
			assertEquals(w1.getMaxDamage(), 		w2.getMaxDamage());
			assertEquals(w1.getMeta(), 				w2.getMeta());
			assertEquals(w1.getSpace(), 			w2.getSpace());
			assertEquals(w1.getCostToBuild(), 		w2.getCostToBuild());
		} else if (t1 instanceof Laboratory) {
			Laboratory w1 = (Laboratory) t1;
			Laboratory w2 = (Laboratory) t2;
			assertFalse(t1 == t2);
			assertEquals(w1.getName(), 				w2.getName());
			assertEquals(w1.getCostToBuild(), 		w2.getCostToBuild());
			assertEquals(w1.getCostToResearch(), 	w2.getCostToResearch());
			assertEquals(w1.getDescription(), 		w2.getDescription());
			assertEquals(w1.getGroup(), 			w2.getGroup());
			assertEquals(w1.getImage(), 			w2.getImage());
			assertEquals(w1.getProduction(),		w2.getProduction());
			assertEquals(w1.getChanceToDiscoverSalvagedTechBonus(), w2.getChanceToDiscoverSalvagedTechBonus());
			assertEquals(w1.getSpace(), 			w2.getSpace());
			assertEquals(w1.getCostToBuild(), 		w2.getCostToBuild());
		} else if (t1 instanceof MiscTechnology) {
			MiscTechnology w1 = (MiscTechnology) t1;
			MiscTechnology w2 = (MiscTechnology) t2;
			assertFalse(t1 == t2);
			assertEquals(w1.getName(), 				w2.getName());
			assertEquals(w1.getCostToBuild(), 		w2.getCostToBuild());
			assertEquals(w1.getCostToResearch(), 	w2.getCostToResearch());
			assertEquals(w1.getDescription(), 		w2.getDescription());
			assertEquals(w1.getGroup(), 			w2.getGroup());
			assertEquals(w1.getImage(), 			w2.getImage());
			assertEquals(w1.getSpace(), 			w2.getSpace());
			assertEquals(w1.getCostToBuild(), 		w2.getCostToBuild());
		} else if (t1 instanceof Module) {
			Module w1 = (Module) t1;
			Module w2 = (Module) t2;
			assertFalse(t1 == t2);
			assertEquals(w1.getName(), 				w2.getName());
			assertEquals(w1.getCostToBuild(), 		w2.getCostToBuild());
			assertEquals(w1.getCostToResearch(), 	w2.getCostToResearch());
			assertEquals(w1.getDescription(), 		w2.getDescription());
			assertEquals(w1.getGroup(), 			w2.getGroup());
			assertEquals(w1.getImage(), 			w2.getImage());
			assertEquals(w1.getPopulation(),		w2.getPopulation());
			assertEquals(w1.getProduction(), 		w2.getProduction());
			assertEquals(w1.getResearch(), 			w2.getResearch());
			assertEquals(w1.getSpace(), 			w2.getSpace());
			assertEquals(w1.getCostToBuild(), 		w2.getCostToBuild());
		} else if (t1 instanceof Scanner) {
			Scanner w1 = (Scanner) t1;
			Scanner w2 = (Scanner) t2;
			assertFalse(t1 == t2);
			assertEquals(w1.getName(), 				w2.getName());
			assertEquals(w1.getCostToBuild(), 		w2.getCostToBuild());
			assertEquals(w1.getCostToResearch(), 	w2.getCostToResearch());
			assertEquals(w1.getDescription(), 		w2.getDescription());
			assertEquals(w1.getGroup(), 			w2.getGroup());
			assertEquals(w1.getImage(), 			w2.getImage());
			assertEquals(w1.getStrength(),			w2.getStrength());
			assertEquals(w1.getSpace(), 			w2.getSpace());
			assertEquals(w1.getCostToBuild(), 		w2.getCostToBuild());
		} else if (t1 instanceof Shield) {
			Shield w1 = (Shield) t1;
			Shield w2 = (Shield) t2;
			assertFalse(t1 == t2);
			assertEquals(w1.getName(), 				w2.getName());
			assertEquals(w1.getCostToBuild(), 		w2.getCostToBuild());
			assertEquals(w1.getCostToResearch(), 	w2.getCostToResearch());
			assertEquals(w1.getDescription(), 		w2.getDescription());
			assertEquals(w1.getGroup(), 			w2.getGroup());
			assertEquals(w1.getImage(), 			w2.getImage());
			assertEquals(w1.getCloakLevel(),		w2.getCloakLevel());
			assertEquals(w1.getDamageBlocked(), 	w2.getDamageBlocked());
			assertEquals(w1.getDischargeRate(), 	w2.getDischargeRate());
			assertEquals(w1.getRechargeRate(), 		w2.getRechargeRate());
			assertEquals(w1.getPower(), 			w2.getPower());
			assertEquals(w1.getSpace(), 			w2.getSpace());
			assertEquals(w1.getCostToBuild(), 		w2.getCostToBuild());
		} else if (t1 instanceof Special) {
			Special w1 = (Special) t1;
			Special w2 = (Special) t2;
			assertFalse(t1 == t2);
			assertEquals(w1.getName(), 				w2.getName());
			assertEquals(w1.getCostToBuild(), 		w2.getCostToBuild());
			assertEquals(w1.getCostToResearch(), 	w2.getCostToResearch());
			assertEquals(w1.getDescription(), 		w2.getDescription());
			assertEquals(w1.getGroup(), 			w2.getGroup());
			assertEquals(w1.getImage(), 			w2.getImage());
			assertEquals(w1.getAttackerModification(),	w2.getAttackerModification());
			assertEquals(w1.getBattleSpeedBonus(), 		w2.getBattleSpeedBonus());
			assertEquals(w1.getBattleTurningBonus(), 	w2.getBattleTurningBonus());
			assertEquals(w1.getCanColoniseRating(),  	w2.getCanColoniseRating());
			assertEquals(w1.getDefenderModification(),		w2.getDefenderModification());
			assertEquals(w1.getFleetAttackerModification(), w2.getFleetAttackerModification());
			assertEquals(w1.getFleetBattleSpeedBonus(), 	w2.getFleetBattleSpeedBonus());
			assertEquals(w1.getFleetBattleTurningBonus(), 	w2.getFleetBattleTurningBonus());
			assertEquals(w1.getFleetDefenderModification(), w2.getFleetDefenderModification());
			assertEquals(w1.getFleetInitiativeBonus(), 		w2.getFleetInitiativeBonus());
			assertEquals(w1.getFleetRangeModification(), 	w2.getFleetRangeModification());
			assertEquals(w1.getInfluence(), 		w2.getInfluence());
			assertEquals(w1.getInitiativeBonus(), 	w2.getInitiativeBonus());
			assertEquals(w1.getMaxDamageBonus(), 	w2.getMaxDamageBonus());
			assertEquals(w1.getMissileRetarget(), 	w2.getMissileRetarget());
			assertEquals(w1.getQtyBerths(), 		w2.getQtyBerths());
			assertEquals(w1.getQtyFighters(), 		w2.getQtyFighters());
			assertEquals(w1.getQtyHoloCraft(), 		w2.getQtyHoloCraft());
			assertEquals(w1.getRepairEffect(), 		w2.getRepairEffect());
			assertEquals(w1.getSalvageEffect(), 	w2.getSalvageEffect());
			assertEquals(w1.getSpeedBonus(), 		w2.getSpeedBonus());
			assertEquals(w1.getSpace(), 			w2.getSpace());
			assertEquals(w1.getCostToBuild(), 		w2.getCostToBuild());
		} else if (t1 instanceof Theory) {
			Theory w1 = (Theory) t1;
			Theory w2 = (Theory) t2;
			assertFalse(t1 == t2);
			assertEquals(w1.getName(), 				w2.getName());
			assertEquals(w1.getCostToBuild(), 		w2.getCostToBuild());
			assertEquals(w1.getCostToResearch(), 	w2.getCostToResearch());
			assertEquals(w1.getDescription(), 		w2.getDescription());
			assertEquals(w1.getGroup(), 			w2.getGroup());
			assertEquals(w1.getImage(), 			w2.getImage());
			assertEquals(w1.getSpace(), 			w2.getSpace());
			assertEquals(w1.getCostToBuild(), 		w2.getCostToBuild());
		}
	}

    protected void assertSameContent(TechnologyTree v1, TechnologyTree v2) {
        if (v1 == null && v2 == null) return;
        if (v1 == null && v2.getQuantity() == 0) return;
        if (v2 == null && v1.getQuantity() == 0) return;
        TechnologyTreeNode[] tl1 = v1.getNodesAsArray();
        TechnologyTreeNode [] tl2 = v2.getNodesAsArray();
        assertEquals(tl1.length, tl2.length);
        for (int i=0; i<tl1.length; i++) {
        	assertSameContent(tl1[i], tl2[i]);
        }
	}

    protected void assertSameContent(TechnologyTreeNode t1, TechnologyTreeNode t2) {
		assertFalse(t1 == t2);
		assertEquals(t1.getNode().getName(), t2.getNode().getName());
	}


    protected void assertEquals(SetupOptions v1, SetupOptions v2) {
        if (v1 == null && v2 == null) return;
        if (v1 == null && v2.getQuantity() == 0) return;
        if (v2 == null && v1.getQuantity() == 0) return;
        SetupOption[] tl1 = v1.getOptionsAsArray();
        SetupOption[] tl2 = v2.getOptionsAsArray();
        assertEquals(tl1.length, tl2.length);
        for (int i=0; i<tl1.length; i++) {
        	assertEquals(tl1[i], tl2[i]);
        }
    }
    
    protected void assertEquals(AnimationConfigFactory v1, AnimationConfigFactory v2) {
    	assertEquals(v1.getIntervals(), v2.getIntervals());
    	assertEquals(v1.getWeaponFireAnimationConfigs(), v2.getWeaponFireAnimationConfigs());
    	assertEquals(v1.getImageAnimationConfigs(), v2.getImageAnimationConfigs());
    	assertEquals(v1.getImageConfigs(), v2.getImageConfigs());
    	assertEquals(v1.getImageStrokeAnimations(), v2.getImageStrokeAnimations());
    	assertEquals(v1.getImageDuelStrokeAnimations(), v2.getImageDuelStrokeAnimations());
    	assertEquals(v1.getNoWeaponFireAnimation(), v2.getNoWeaponFireAnimation());
    	assertEquals(v1.getNoDamageAnimation(), v2.getNoDamageAnimation());
    }

    protected void assertEquals(ImageDuelStrokeAnimationConfig [] v1, ImageDuelStrokeAnimationConfig [] v2) {
        if (v1 == null && v2 == null) return;
        if (v1 == null && v2.length == 0) return;
        if (v2 == null && v1.length == 0) return;
        assertEquals(v1.length, v2.length);
        for (int i=0; i<v1.length; i++) {
        	assertEquals(v1[i], v2[i]);
        }
    }

    protected void assertEquals(ImageDuelStrokeAnimationConfig v1, ImageDuelStrokeAnimationConfig v2) {
    	assertEquals(v1.getName(), v2.getName());
    	assertEquals(v1.getInterval(), v2.getInterval());
    	assertEquals(v1.getLife(), v2.getLife());
    	assertEquals(v1.getStrokeGap(), v2.getStrokeGap());
    	assertEquals(v1.getStrokeImage1(), v2.getStrokeImage1());
    	assertEquals(v1.getStrokeImage2(), v2.getStrokeImage2());
    	assertEquals(v1.getStrokeSize(), v2.getStrokeSize());
    	assertEquals(v1.getStrokeStep(), v2.getStrokeStep());
    }

    protected void assertEquals(ImageStrokeAnimationConfig [] v1, ImageStrokeAnimationConfig [] v2) {
        if (v1 == null && v2 == null) return;
        if (v1 == null && v2.length == 0) return;
        if (v2 == null && v1.length == 0) return;
        assertEquals(v1.length, v2.length);
        for (int i=0; i<v1.length; i++) {
        	assertEquals(v1[i], v2[i]);
        }
    }

    protected void assertEquals(ImageStrokeAnimationConfig v1, ImageStrokeAnimationConfig v2) {
    	assertEquals(v1.getName(), v2.getName());
    	assertEquals(v1.getInterval(), v2.getInterval());
    	assertEquals(v1.getLife(), v2.getLife());
    	assertEquals(v1.getStrokeGap(), v2.getStrokeGap());
    	assertEquals(v1.getStrokeImage(), v2.getStrokeImage());
    	assertEquals(v1.getStrokeSize(), v2.getStrokeSize());
    	assertEquals(v1.getStrokeStep(), v2.getStrokeStep());
    }

    protected void assertEquals(ImageAnimationConfig [] v1, ImageAnimationConfig [] v2) {
        if (v1 == null && v2 == null) return;
        if (v1 == null && v2.length == 0) return;
        if (v2 == null && v1.length == 0) return;
        assertEquals(v1.length, v2.length);
        for (int i=0; i<v1.length; i++) {
        	assertEquals(v1[i], v2[i]);
        }
    }

    protected void assertEquals(ImageAnimationConfig v1, ImageAnimationConfig v2) {
    	assertEquals(v1.getName(), v2.getName());
    	assertEquals(v1.getActualImage(), v2.getActualImage());
    	assertEquals(v1.getImageSize(), v2.getImageSize());
    	assertEquals(v1.getImage(), v2.getImage());
    	assertEquals(v1.getImageType(), v2.getImageType());
    	assertEquals(v1.getQtyImages(), v2.getQtyImages());
    	assertEquals(v1.getStages(), v2.getStages());
    }

    protected void assertEquals(WeaponFireAnimationConfig [] v1, WeaponFireAnimationConfig [] v2) {
        if (v1 == null && v2 == null) return;
        if (v1 == null && v2.length == 0) return;
        if (v2 == null && v1.length == 0) return;
        assertEquals(v1.length, v2.length);
        for (int i=0; i<v1.length; i++) {
        	assertEquals(v1[i], v2[i]);
        }
    }

    protected void assertEquals(WeaponFireAnimationConfig v1, WeaponFireAnimationConfig v2) {
    	assertEquals(v1.getName(), v2.getName());
    	assertEquals(v1.getGroup(), v2.getGroup());
    	assertEquals(v1.getInterval(), v2.getInterval());
    	assertEquals(v1.getLife(), v2.getLife());
    	assertEquals(v1.getStrokeGap(), v2.getStrokeGap());
    	assertEquals(v1.getStrokeImage(), v2.getStrokeImage());
    	assertEquals(v1.getStrokeStep(), v2.getStrokeStep());
    	assertEquals(v1.getStrokeColorColor(), v2.getStrokeColorColor());
    	assertEquals(v1.getStrokeSize(), v2.getStrokeSize());
    }
    
    protected void assertEquals(StrokeSize v1, StrokeSize v2) {
    	if (v1 == v2) return;
    	assertEquals(v1.getX(), v2.getX());
    	assertEquals(v1.getY(), v2.getY());
    	assertEquals(v1.getDistance(), v2.getDistance());
    }

    protected void assertEquals(String v1, Decorator[]  tl) {
        if (v1 == null) return;
        if (tl == null) return;
        assertEquals(1, tl.length);
       	assertEquals(v1, tl[0].getName());
	}

    protected void assertEquals(String v1, String v2, Decorator[]  tl) {
        if (v1 == null || v2 == null) return;
        if (tl == null) return;
        assertEquals(2, tl.length);
       	assertEquals(v1, tl[0].getName());
       	assertEquals(v2, tl[1].getName());
	}


    protected void assertEquals(NameIntPair [] v1, NameIntPair [] v2) {
        if (v1 == null && v2 == null) return;
        if (v1 == null && v2.length == 0) return;
        if (v2 == null && v1.length == 0) return;
        assertEquals(v1.length, v2.length);
        for (int i=0; i<v1.length; i++) {
        	assertEquals(v1[i], v2[i]);
        }
    }
    
    protected void assertEquals(NameIntPair v1, NameIntPair v2) {
    	assertEquals(v1.getName(), v2.getName());
    	assertEquals(v1.getValue(), v2.getValue());
    }
    
    protected void assertEquals(RaceGraphicsList v1, RaceGraphicsList v2) {
    	assertEquals(v1.getRaceGraphicsAsArray(), v2.getRaceGraphicsAsArray());
    }
    
    protected void assertEquals(RaceGraphics[] v1, RaceGraphics[] v2) {
        if (v1 == null && v2 == null) return;
        if (v1 == null && v2.length == 0) return;
        if (v2 == null && v1.length == 0) return;
        assertEquals(v1.length, v2.length);
        for (int i=0; i<v1.length; i++) {
        	assertEquals(v1[i], v2[i]);
        }
    }

    protected void assertEquals(RaceGraphics v1, RaceGraphics v2) {
		assertEquals(v1.getName(), v2.getName());
		assertEquals(v1.getDescription(), v2.getDescription());
		assertEquals(v1.getPicture(), v2.getPicture());
		assertEquals(v1.getType(), v2.getType());
		assertEquals(v1.getColonyGraphics(), v2.getColonyGraphics());
		assertEquals(v1.getCraftGraphicsAsArray(), v2.getCraftGraphicsAsArray());
    }

    protected void assertEquals(RaceGraphicsForColony v1, RaceGraphicsForColony v2) {
    	if (v1 == v2) return;
		assertEquals(v1.getImageName(), v2.getImageName());
		assertEquals(v1.getImageType(), v2.getImageType());
		assertEquals(v1.getImagesSuffixes(), v2.getImagesSuffixes());
    }
    
    protected void assertEquals(CraftGraphics [] v1, CraftGraphics [] v2) {
        if (v1 == null && v2 == null) return;
        if (v1 == null && v2.length == 0) return;
        if (v2 == null && v1.length == 0) return;
        assertEquals(v1.length, v2.length);
        for (int i=0; i<v1.length; i++) {
        	assertEquals(v1[i], v2[i]);
        }
    }

    protected void assertEquals(CraftGraphics v1, CraftGraphics v2) {
		assertEquals(v1.getName(), v2.getName());
		assertEquals(v1.getPictureNormal(), v2.getPictureNormal());
		assertEquals(v1.getPictureCloaked(), v2.getPictureCloaked());
		assertEquals(v1.getPictureSmall(), v2.getPictureSmall());
		assertEquals(v1.getSize(), v2.getSize());
		assertEquals(v1.getDishOffset(), v2.getDishOffset());
		assertEquals(v1.getWeaponFireOffset(), v2.getWeaponFireOffset());
    }

    protected void assertEquals(WeaponFirePoint [] v1, WeaponFirePoint [] v2) {
        if (v1 == null && v2 == null) return;
        if (v1 == null && v2.length == 0) return;
        if (v2 == null && v1.length == 0) return;
        assertEquals(v1.length, v2.length);
        for (int i=0; i<v1.length; i++) {
        	assertEquals(v1[i], v2[i]);
        }
    }

    protected void assertEquals(WeaponFirePoint v1, WeaponFirePoint v2) {
    	if (v1 == v2) return;
    	assertEquals(v1.getX(), v2.getX());
    	assertEquals(v1.getY(), v2.getY());
    }
    
    protected void assertEquals(SetupOption v1, SetupOption v2) {
    	if (v1 == null) {
    		assertNull(v2);
    	} else {    		
    		assertEquals(v1.getName(), v2.getName());
    		assertEquals(v1.getCost(), v2.getCost());
    		assertEquals(v1.getDescription(), v2.getDescription());
    		assertEquals(v1.getLabel(), v2.getLabel());
    		assertEquals(v1.getValue(), v2.getValue());
    		assertEquals(v1.getLevel(), v2.getLevel());
    		assertEquals(v1.getParameters(), v2.getParameters());
    	}
    }

    protected void assertEquals(String name, int value, BasicNameValueList v) {
    	assertEquals(1, v.getAsArray().length);
    	assertEquals(name, v.getAsArray()[0].getName());
    	assertEquals(value, v.getAsArray()[0].getValue());
    }


    protected void assertEquals(String name1, int value1, String name2, int value2, BasicNameValueList v) {
    	assertEquals(2, v.getAsArray().length);
    	assertEquals(name1, v.getAsArray()[0].getName());
    	assertEquals(value1, v.getAsArray()[0].getValue());
    	assertEquals(name2, v.getAsArray()[1].getName());
    	assertEquals(value2, v.getAsArray()[1].getValue());
    }

    protected void assertEquals(NameValuePair v1, NameValuePair v2) {
    	assertEquals(v1.getName(), v2.getName());
    	assertEquals(v1.getValue(), v2.getValue());
    }

    protected void assertEquals(String name1, String value1, NameValuePairList v) {
        assertEquals(1, v.getSize());
        NameValuePair[] list = v.getAsArray();
		assertEquals(name1, list[0].getName());
        assertEquals(value1, list[0].getValue());
    }

    protected void assertEquals(String name1, String value1, String name2, String value2, NameValuePairList v) {
        assertEquals(2, v.getSize());
        NameValuePair[] list = v.getAsArray();
		assertEquals(name1, list[0].getName());
        assertEquals(value1, list[0].getValue());
		assertEquals(name2, list[1].getName());
        assertEquals(value2, list[1].getValue());
    }

    protected void assertEquals(String name1, String value1, String name2, String value2, String name3, String value3, NameValuePairList v) {
        assertEquals(3, v.getSize());
        NameValuePair[] list = v.getAsArray();
		assertEquals(name1, list[0].getName());
        assertEquals(value1, list[0].getValue());
		assertEquals(name2, list[1].getName());
        assertEquals(value2, list[1].getValue());
		assertEquals(name3, list[2].getName());
        assertEquals(value3, list[2].getValue());
    }

    protected void assertEquals(AncientGifts v1, AncientGifts v2) {
        if (v1 == null && v2 == null) return;
        if (v1 == null && v2.getQtyGifts() == 0) return;
        if (v2 == null && v1.getQtyGifts() == 0) return;
        AncientGift[] tl1 = v1.getGifts();
        AncientGift[] tl2 = v2.getGifts();
        assertEquals(tl1.length, tl2.length);
        for (int i=0; i<tl1.length; i++) {
        	assertEquals(tl1[i], tl2[i]);
        }
    }
    
    protected void assertEquals(AncientGift v1, AncientGift v2) {
    	assertEquals(v1.getName(), v2.getName());
    	assertEquals(v1.getAncientName(), v2.getAncientName());
    	assertEquals(v1.getGiftName(), v2.getGiftName());
    	assertEquals(v1.getRound(), v2.getRound());
    	if (v1.getTechnology() == null) {
    		assertNull(v2.getTechnology());
    	} else {
    		assertEquals(v1.getTechnology().getName(), v2.getTechnology().getName());
    	}
    	assertEquals(v1.getOption(), v2.getOption());
    }

    protected void assertEquals(GalaxyGraphicsList v1, GalaxyGraphicsList v2) {
    	assertEquals(v1.getBlackHoleGraphics(), v2.getBlackHoleGraphics());
    	assertEquals(v1.getNebulaGraphics(), v2.getNebulaGraphics());
    	assertEquals(v1.getStarGraphicsAsArray(), v2.getStarGraphicsAsArray());
    	assertEquals(v1.getSunGraphicsAsArray(), v2.getSunGraphicsAsArray());
    }

    protected void assertEquals(StellarObjectGraphics [] v1, StellarObjectGraphics [] v2) {
        if (v1 == null && v2 == null) return;
        if (v1 == null && v2.length == 0) return;
        if (v2 == null && v1.length == 0) return;
        assertEquals(v1.length, v2.length);
        for (int i=0; i<v1.length; i++) {
        	assertEquals(v1[i], v2[i]);
        }
    }
    
    protected void assertEquals(StellarObjectGraphics v1, StellarObjectGraphics v2) {
    	assertEquals(v1.getName(), v2.getName());
    	assertEquals(v1.getPicture(), v2.getPicture());
    	assertEquals(v1.getPictureType(), v2.getPictureType());
    	assertEquals(v1.getQtyAnimations(), v2.getQtyAnimations());
    	assertEquals(v1.getRotateAbout(), v2.getRotateAbout());
    	assertEquals(v1.getSize(), v2.getSize());
    	assertEquals(v1.getStages(), v2.getStages());
    	assertEquals(v1.getStarType(), v2.getStarType());
    }
    
    protected void assertEquals(ImageConfigFactory v1, ImageConfigFactory v2) {
    	assertEquals(v1.getFlagConfig(), v2.getFlagConfig());
    	assertEquals(v1.getGalaxySizeIconConfig(), v2.getGalaxySizeIconConfig());
    	assertEquals(v1.getMenuConfig(), v2.getMenuConfig());
    	assertEquals(v1.getLevelIconConfig(), v2.getLevelIconConfig());
    	assertEquals(v1.getQtyPlayersIconConfig(), v2.getQtyPlayersIconConfig());
    	assertEquals(v1.getRaceImageConfig(), v2.getRaceImageConfig());
    	assertEquals(v1.getRaceIconConfig(), v2.getRaceIconConfig());
    	assertEquals(v1.getImageConfigs(), v2.getImageConfigs());
    }
    
    protected void assertEquals(MenuConfig v1, MenuConfig v2) {
    	assertEquals(v1.getImageSize(), v2.getImageSize());
    	assertEquals(v1.getBackground(), v2.getBackground());
    	assertEquals(v1.getTipBackground(), v2.getTipBackground());
    	assertEquals(v1.getMenuImageConfigs(), v2.getMenuImageConfigs());
    }

    protected void assertEquals(MotColor v1, MotColor v2) {
    	assertEquals(v1.getBlue(), v2.getBlue());
    	assertEquals(v1.getGreen(), v2.getGreen());
    	assertEquals(v1.getRed(), v2.getRed());
    }
    
    protected void assertEquals(MenuImageConfig [] v1, MenuImageConfig [] v2) {
        if (v1 == null && v2 == null) return;
        if (v1 == null && v2.length == 0) return;
        if (v2 == null && v1.length == 0) return;
        assertEquals(v1.length, v2.length);
        for (int i=0; i<v1.length; i++) {
        	assertEquals(v1[i], v2[i]);
        }
    }

    protected void assertEquals(MenuImageConfig v1, MenuImageConfig v2) {
    	assertEquals(v1.getName(), v2.getName());
    	assertEquals(v1.getImage(), v2.getImage());
    	assertEquals(v1.getImageSize(), v2.getImageSize());
    }
    
    protected void assertEquals(ImageConfigList v1, ImageConfigList v2) {
    	assertEquals(v1.getImageConfigArray(), v2.getImageConfigArray());
    }
    
    protected void assertEquals(ImageConfig [] v1, ImageConfig [] v2) {
        if (v1 == null && v2 == null) return;
        if (v1 == null && v2.length == 0) return;
        if (v2 == null && v1.length == 0) return;
        assertEquals(v1.length, v2.length);
        for (int i=0; i<v1.length; i++) {
        	assertEquals(v1[i], v2[i]);
        }
    }

    protected void assertEquals(ImageConfig v1, ImageConfig v2) {
    	assertEquals(v1.getName(), v2.getName());
    	assertEquals(v1.getImage(), v2.getImage());
    	assertEquals(v1.getImageSize(), v2.getImageSize());
    	assertEquals(v1.getLife(), v2.getLife());
    	assertEquals(v1.getDescription(), v2.getDescription());
    }
    
    protected void assertEquals(int date, String text, DiplomaticHistoryEvent v, Player p1, Player p2) throws ApplicationError {
    	assertEquals(date, v.getDate(), 0.5);
    	assertEquals(text, v.getDiplomaticHistorySummary(p1.getName(), p2.getName()));
    }
    
    protected void assertEquals(int date, String treaty, String playerName, DiplomaticHistoryEvent v) {
    	assertEquals(date, v.getDate());
    	if (treaty == TreatyType.PEACE) assertTrue(v.getProposal().isPeace());
    	if (treaty == TreatyType.NON_AGGRESSION) assertTrue(v.getProposal().isNonAggression());
    	if (treaty == TreatyType.ALLIANCE) assertTrue(v.getProposal().isAlliance());
    	if (treaty == TreatyType.TRADE) assertTrue(v.getProposal().isTrade());
    	if (treaty == TreatyType.RESEARCH) assertTrue(v.getProposal().isResearch());
    	if (treaty == TreatyType.WAR) assertTrue(v.getProposal().isWar());
    	assertEquals(playerName, v.getPlayerOfferMaker());
    }
    
    
    protected void assertEquals(GeneralDetailsList v1, GeneralDetailsList v2) {
    	assertEquals(v1.getGenerals(), v2.getGenerals());
    }
    
    protected void assertEquals(GeneralDetails [] v1, GeneralDetails [] v2) {
        if (v1 == null && v2 == null) return;
        if (v1 == null && v2.length == 0) return;
        if (v2 == null && v1.length == 0) return;
        assertEquals(v1.length, v2.length);
        for (int i=0; i<v1.length; i++) {
        	assertEquals(v1[i], v2[i]);
        }
    }
    
    protected void assertEquals(GeneralDetails v1, GeneralDetails v2) {
    	assertEquals(v1.getName(), v2.getName());
    	assertEquals(v1.getDescription(), v2.getDescription());
    	assertEquals(v1.getPicture(), v2.getPicture());
    	assertEquals(v1.getAssaultBonus(), v2.getAssaultBonus());
    	assertEquals(v1.getBattleSpeedBonus(), v2.getBattleSpeedBonus());
    	assertEquals(v1.getBattleTurningBonus(), v2.getBattleTurningBonus());
    	assertEquals(v1.getCloakLevel(), v2.getCloakLevel());
    	assertEquals(v1.getDamageBonus(), v2.getDamageBonus());
    	assertEquals(v1.getInitiativeBonus(), v2.getInitiativeBonus());
    	assertEquals(v1.getMaxDamageBonus(), v2.getMaxDamageBonus());
    	assertEquals(v1.getSpeedBonus(), v2.getSpeedBonus());
    }
    
    protected void assertEquals(GovenorDetailsList v1, GovenorDetailsList v2) {
    	assertEquals(v1.getGovenors(), v2.getGovenors());
    }
    
    protected void assertEquals(GovenorDetails [] v1, GovenorDetails [] v2) {
        if (v1 == null && v2 == null) return;
        if (v1 == null && v2.length == 0) return;
        if (v2 == null && v1.length == 0) return;
        assertEquals(v1.length, v2.length);
        for (int i=0; i<v1.length; i++) {
        	assertEquals(v1[i], v2[i]);
        }
    }
    
    protected void assertEquals(GovenorDetails v1, GovenorDetails v2) {
    	assertEquals(v1.getName(), v2.getName());
    	assertEquals(v1.getDescription(), v2.getDescription());
    	assertEquals(v1.getPicture(), v2.getPicture());
    	assertEquals(v1.getDevelopmentBonus(), v2.getDevelopmentBonus());
    	assertEquals(v1.getEcologyBonus(), v2.getEcologyBonus());
    	assertEquals(v1.getFactoryPerPopulationBonus(), v2.getFactoryPerPopulationBonus());
    	assertEquals(v1.getMaxPopulationBonus(), v2.getMaxPopulationBonus());
    	assertEquals(v1.getMaxTradeRoutes(), v2.getMaxTradeRoutes());
    	assertEquals(v1.getProductionBonus(), v2.getProductionBonus());
    	assertEquals(v1.getPsiRating(), v2.getPsiRating());
    	assertEquals(v1.getReproductionBonus(), v2.getReproductionBonus());
    	assertEquals(v1.getResearchBonus(), v2.getResearchBonus());
    	assertEquals(v1.getSpyBonus(), v2.getSpyBonus());
    	assertEquals(v1.getTradingBonus(), v2.getTradingBonus());
    }
    
    protected void assertEquals(MoralChoiceList v1, MoralChoiceList v2) {
    	if (v1 == v2) return;
    	assertTrue(v1 != null);
    	assertTrue(v2 != null);
    	assertEquals(v1.getAllAsArray(), v2.getAllAsArray());
    }
    
    protected void assertEquals(MoralChoice [] v1, MoralChoice [] v2) {
        if (v1 == null && v2 == null) return;
        if (v1 == null && v2.length == 0) return;
        if (v2 == null && v1.length == 0) return;
        assertEquals(v1.length, v2.length);
        for (int i=0; i<v1.length; i++) {
        	assertEquals(v1[i], v2[i]);
        }
    }
    
    protected void assertEquals(MoralChoice v1, MoralChoice v2) {
    	assertEquals(v1.getName(), v2.getName());
    	assertEquals(v1.getDescription(), v2.getDescription());
    	assertEquals(v1.getDamageBonus(), v2.getDamageBonus());
    	assertEquals(v1.getInfluenceBonus(), v2.getInfluenceBonus());
    	assertEquals(v1.getProductionBonus(), v2.getProductionBonus());
    	assertEquals(v1.getRelationsBonus(), v2.getRelationsBonus());
    }
    
    protected void assertEquals(CraftDesign v1, CraftDesignVO v2) throws ApplicationError {
    	assertEquals(v1, v2.getCraftDesign());
	}


    protected void assertEquals(String so, String planet, OrbitVO v) throws ApplicationError {
        assertEquals(so, v.getStellarObject());
       	assertEquals(planet, v.getPlanet());
	}

    protected void assertEquals(String reason, MoralChoice moralChoice, String[] moralChoices) {
    	assertEquals(moralChoice, moralChoices);
	}

    protected void assertEquals(MoralChoice moralChoice, String[] moralChoices) {
    	assertEquals(1, moralChoices.length);
    	assertEquals(moralChoice.getName(), moralChoices[0]);
	}

    protected void assertEquals(String reason, MoralChoice moralChoice, MoralChoice [] moralChoices) {
    	assertEquals(moralChoice, moralChoices);
	}

    protected void assertEquals(MoralChoice moralChoice, MoralChoice [] moralChoices) {
    	assertEquals(1, moralChoices.length);
    	assertEquals(moralChoice, moralChoices[0]);
	}

    protected PlayerConstantsVO getPlayerConstants(StateContainer state, String name) {
    	ValueObject[] sua = state.getStateUpdates();
    	if (sua == null) return null;
    	for (int i = 0; i < sua.length; i++) {
			if (sua[i] instanceof PlayerConstantsVO) {
				PlayerConstantsVO v = (PlayerConstantsVO) sua[i];
				if (Comp.same(name, v.getName())) {
					return v;
				}
			}
		}
    	return null;
    }
    
    protected RelationVO getRelation(StateContainer state, String name1, String name2) {
    	ValueObject[] sua = state.getStateUpdates();
    	if (sua == null) return null;
    	for (int i = 0; i < sua.length; i++) {
			if (sua[i] instanceof RelationVO) {
				RelationVO v = (RelationVO) sua[i];
				if (v.equals(name1, name2)) {
					return v;
				}
			}
		}
    	return null;
    }
    
    protected PlayerVO getPlayer(StateContainer state, String name) {
    	ValueObject[] sua = state.getStateUpdates();
    	if (sua == null) return null;
    	for (int i = 0; i < sua.length; i++) {
			if (sua[i] instanceof PlayerVO) {
				PlayerVO v = (PlayerVO) sua[i];
				if (Comp.same(name, v.getName())) {
					return v;
				}
			}
		}
    	return null;
    }
    
    protected PlayerDetailsVO getPlayerDetails(StateContainer state, String name) {
    	ValueObject[] sua = state.getStateUpdates();
    	if (sua == null) return null;
    	for (int i = 0; i < sua.length; i++) {
			if (sua[i] instanceof PlayerDetailsVO) {
				PlayerDetailsVO v = (PlayerDetailsVO) sua[i];
				if (Comp.same(name, v.getName())) {
					return v;
				}
			}
		}
    	return null;
    }
    
    protected PlayerTechnologiesVO getPlayerTechnologies(StateContainer state, String name) {
    	ValueObject[] sua = state.getStateUpdates();
    	if (sua == null) return null;
    	for (int i = 0; i < sua.length; i++) {
			if (sua[i] instanceof PlayerTechnologiesVO) {
				PlayerTechnologiesVO v = (PlayerTechnologiesVO) sua[i];
				if (Comp.same(name, v.getPlayer())) {
					return v;
				}
			}
		}
    	return null;
    }
    
    protected StellarObjectVO getStellarObject(StateContainer state, String name) {
    	ValueObject[] sua = state.getStateUpdates();
    	if (sua == null) return null;
    	for (int i = 0; i < sua.length; i++) {
			if (sua[i] instanceof StellarObjectVO) {
				StellarObjectVO v = (StellarObjectVO) sua[i];
				if (Comp.same(name, v.getName())) {
					return v;
				}
			}
		}
    	return null;
    }
    
    protected PlanetVO getPlanet(StateContainer state, String name) {
    	ValueObject[] sua = state.getStateUpdates();
    	if (sua == null) return null;
    	for (int i = 0; i < sua.length; i++) {
			if (sua[i] instanceof PlanetVO) {
				PlanetVO v = (PlanetVO) sua[i];
				if (Comp.same(name, v.getName())) {
					return v;
				}
			}
		}
    	return null;
    }
    
    protected CraftVO getCraft(StateContainer state, String name) {
    	ValueObject[] sua = state.getStateUpdates();
    	if (sua == null) return null;
    	for (int i = 0; i < sua.length; i++) {
			if (sua[i] instanceof CraftVO) {
				CraftVO v = (CraftVO) sua[i];
				if (Comp.same(name, v.getName())) {
					return v;
				}
			}
		}
    	return null;
    }
    
    protected FleetVO getFleet(StateContainer state, String name) {
    	ValueObject[] sua = state.getStateUpdates();
    	if (sua == null) return null;
    	for (int i = 0; i < sua.length; i++) {
			if (sua[i] instanceof FleetVO) {
				FleetVO v = (FleetVO) sua[i];
				if (Comp.same(name, v.getName())) {
					return v;
				}
			}
		}
    	return null;
    }
    
    protected ArrayList<MotEvent> eventList = new ArrayList<MotEvent>();
    
    protected MotEvent getEvent(Class c) {
        for (int i=eventList.size()-1; i>=0; i--) {
            MotEvent e = (MotEvent) eventList.get(i);
            if (e.getClass() == c) {
                return e;
            }
        }
        return null;
    }

    protected MotEvent getEventFromBack(Class c, int index) {
        for (int i=eventList.size()-1; i>=0; i--) {
            MotEvent e = (MotEvent) eventList.get(i);
            if (e.getClass() == c) {
            	if (index == 0) {
            		return e;
            	} else {
            		index--;
            	}
            }
        }
        return null;
    }

    protected MotEvent getEventFromFront(Class c, int index) {
        for (int i=0; i<eventList.size(); i++) {
            MotEvent e = (MotEvent) eventList.get(i);
            if (e.getClass() == c) {
            	if (index == 0) {
            		return e;
            	} else {
            		index--;
            	}
            }
        }
        return null;
    }

    protected int getQtyEvent(Class c) {
    	int qty = 0;
        for (int i=eventList.size()-1; i>=0; i--) {
            MotEvent e = (MotEvent) eventList.get(i);
            if (e.getClass() == c) {
            	qty++;
            }
        }
        return qty;
    }

    protected void clearEvents() {
        Logger.logDebug("TestBase.clearEvents() Clear Events ");
        eventList.clear();
    }



}