/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.test;

import java.util.ArrayList;

import mot.common.event.MotEvent;
import mot.common.proxy.ClientProxy;
import mot.common.util.ApplicationError;
import mot.engine.MotEngine;
import mot.engine.event.MotEventFactory;
import mot.engine.players.Player;

public class TestClientProxy implements ClientProxy {

	private Player owner;
	
	private ArrayList<MotEvent> events = new ArrayList();
	private MotEvent lastEvent = null;
	
	public TestClientProxy(Player owner) {
		this.owner = owner;
		MotEngine.getInstance().getProxyManager().add(this);
	}
	
	public Player getOwner() {
		return owner;
	}

	public void notify(MotEvent e) throws ApplicationError {
		lastEvent = e;
		events.add(e);
	}

	public void notify(MotEventFactory e) throws ApplicationError {
        notify(e.createEvent(getOwner()));
	}
	
	public void clear() {
		events.clear();
	}

	public MotEvent getLastEvent() {
		return lastEvent;
	}

	public MotEvent getEvent(int index) {
		return events.get(index);
	}

	public int getQtyEvent() {
		return events.size();
	}

	public MotEvent getEvent(Class c) {
        for (int i=events.size()-1; i>=0; i--) {
            MotEvent e = (MotEvent) events.get(i);
            if (e.getClass() == c) {
                return e;
            }
        }
        return null;
    }
	
}
