/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.test;

import mot.common.bean.PlayerColor;
import mot.common.technology.Technology;
import mot.common.util.ApplicationError;
import mot.engine.MotEngine;
import mot.engine.event.SabotageEF;
import mot.engine.event.TechnologyStolenEF;
import mot.engine.planets.Planet;
import mot.engine.players.ComputerPlayer;
import mot.engine.players.Player;
import mot.engine.players.PlayerCharacter;

public class TestComputerPlayer extends ComputerPlayer {
    public TestComputerPlayer() throws ApplicationError {
    }

    public TestComputerPlayer(String name, PlayerCharacter character, PlayerColor color, String alignment) throws ApplicationError {
        super(name, character, color, alignment);
    }

	public void notifySpying(Player player, Technology tech) throws ApplicationError {
        super.notifySpying(player, tech);
        TechnologyStolenEF event = new TechnologyStolenEF(tech, player, this);
		MotEngine.instance.broadcast( event, this );
    }

	public void notifySabotage(Planet planet, Player player, int productionSabotaged, int factoriesSabotaged, int populationSabotaged)  throws ApplicationError {
        super.notifySabotage(planet, player, productionSabotaged, factoriesSabotaged, populationSabotaged);
        SabotageEF event = new SabotageEF(planet, player);
         if (productionSabotaged > 0) {
            event.setQtyProductionSabotaged(productionSabotaged);
         }
         if (populationSabotaged > 0) {
            event.setQtyPopulationSabotaged(populationSabotaged);
         }
         if (factoriesSabotaged > 0) {
            event.setQtyFactoriesSabotaged(factoriesSabotaged);
         }
		MotEngine.instance.broadcast( event, this );
    }
    
  /**
    * @return The full name of this class (including package names) if the class attribute 
    * provided by this implementation.
    */
  protected String getClassAttribute() {
      return ComputerPlayer.class.getName();
  }
    
}