/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.test;

import mot.common.setup.SetupOption;
import mot.common.setup.SetupOptions;
import mot.common.util.ApplicationError;
import mot.common.util.NameValuePair;

/**
 * Creates and stores Standard Craft and technologies used by the test harness.
 * The test harnesses use separate technologies where possibly so that changes 
 * to a craft design or weapon details do not cause tests to fail.
 */
public class TestFactory  {
    
    private TestFactory() throws ApplicationError {
    }

    public static SetupOptions getGeneralOptions() throws ApplicationError {
        SetupOptions options = new SetupOptions();
        options.setOption("production-bonus", "0.0",0);
        options.setOption("research-bonus", "0.0",0);
        options.setOption("development-bonus", "0.0",0);
        options.setOption("ecology-bonus", "0.0",0);
        options.setOption("reproduction-bonus", "0.0",0);
        options.setOption("trading-bonus", "0.0",0);
        options.setOption("max-player-trade-agreements", "1",0);
        options.addOption("charisma", "-10",-1);
        options.addOption("charisma", "0",0);
        options.addOption("charisma", "10",1);
        options.setOption("factory-per-population-bonus", "0.0",0);
        options.setOption("max-population-bonus", "0.0",0);
        options.setOption("psi-rating", "0",0);
        options.setOption("assault-bonus", "0.0",0);
        options.setOption("battle-turning-bonus", "0.0",0);
        options.setOption("battle-speed-bonus", "0.0",0);
        options.setOption("initiative-bonus", "0.0",0);
        options.setOption("speed-bonus", "0.0",0);
        options.setOption("max-damage-bonus", "0.0",0);
        options.setOption("cloak-level", "0",0);
        options.setOption("spy-bonus", "0.0",0);
        options.setOption("qty-missed-techs", "0.15",0);
        options.setOption("home-planet-size", "100",0);
        options.setOption("home-planet-teraforming", "1.0",0);
        options.setOption("home-planet-population", "40",0);
        options.setOption("home-planet-qty-factories", "10",0);
        options.setOption("home-planet-production-bonus", "0",0);
        options.setOption("home-planet-research-bonus", "0",0);
        options.setOption("home-planet-reproduction-bonus", "0",0);
        options.setOption("is-resourceful", "false",0);
        options.setOption("chance-to-discover-salvaged-tech", "0.5",0);
        options.setOption("eloquence", "0.0",0);
        options.setOption("immunity", "",0);
        options.setOption("max-solar-system-trade-routes", "2",0);

        
        options.setOption("max-time-between-fleets", "40",0);
        options.setOption("qty-craft-per-planet-to-declare-war", "3",0);
        options.setOption("qty-craft-to-declare-war", "3",0);
        options.setOption("introversion-rating", "1",0);
        options.setOption("demand-probability", "0",0);
        options.setOption("blockade-or-attack-probability", "0",0);
        options.setOption("accept-peace-propability", "0.25",0);
        options.setOption("accept-alliance-propability-when-like", "0.5",0);
        options.setOption("accept-alliance-propability-when-fond", "0.25",0);
        options.setOption("accept-swap-propability-when-like", "1.0",0);
        options.setOption("accept-swap-propability-when-neutral", "0.5",0);
        options.setOption("accept-swap-propability-when-dislike", "0.1",0);
        options.setOption("percent-ecology", "0.1",0);
        options.setOption("percent-development", "0.1",0);
        options.setOption("percent-research", "0.5",0);
        options.setOption("isolationist-percent-research", "0.8",0);
        options.setOption("percent-production", "0.5",0);
        options.setOption("isolationist-percent-production", "0.2",0);
        options.setOption("percent-money", "0.05",0);
        options.setOption("spy-defend-percent", "0.5",0);
        options.setOption("spy-attack-most-hated-percent", "0.25",0);
        options.setOption("spy-attack-largest-percent", "0.25",0);
        options.setOption("crafts-special-weapons", "Girator,Transport,ShieldDrain,Immobiliser,Psi",0);
        options.setOption("crafts-want-psi-shields", "true",0);
        options.setOption("acceptable-moral-choices", "TestMoralChoice",0);
        
        SetupOption so = new SetupOption();
        so.setName("starting-techs");
        so.setValue("0");
        so.setCost("0");
        so.setParameter(new NameValuePair("engine , Fusion25", " "));
        so.setParameter(new NameValuePair("hull , Flyer30", " "));
        so.setParameter(new NameValuePair("hull , Flyer60", " "));
        so.setParameter(new NameValuePair("hull , FighterI", " "));
        so.setParameter(new NameValuePair("weapon , MassDriver1", " "));
        so.setParameter(new NameValuePair("weapon , Missile6", " "));
        so.setParameter(new NameValuePair("scanner , Photon100", " "));
        so.setParameter(new NameValuePair("factory , Basic Computerised Factory", " "));
        so.setParameter(new NameValuePair("special , ColonyModule8", " "));
        options.setOption(so);
        
        return options;
    }

    public static SetupOptions getHumansOptions() throws ApplicationError {
        SetupOptions options = new SetupOptions();
        options.setOption("trading-bonus", "1.25",0);
        options.setOption("max-solar-system-trade-routes", "3",0);
        options.setOption("charisma", "20",0);
        options.setOption("is-resourceful", "true",0);
        options.setOption("chance-to-discover-salvaged-tech", "1.0",0);
        return options;
    }

    public static SetupOptions getBirdsOptions() throws ApplicationError {
        SetupOptions options = new SetupOptions();
        options.setOption("battle-turning-bonus", "0.25",0);
        options.setOption("battle-speed-bonus", "0.25",0);
        options.setOption("speed-bonus", "0.5",0);
        options.setOption("immunity", "Psi",0);
        options.setOption("eloquence", "0.1",0);
        return options;
    }

    public static SetupOptions getBearsOptions() throws ApplicationError {
        SetupOptions options = new SetupOptions();
        options.setOption("assault-bonus", "1.0",0);
        options.setOption("factory-per-population-bonus", "0.25",0);
        options.setOption("max-damage-bonus", "0.25",0);
        options.setOption("immunity", "Gravity",0);
        return options;
    }

    public static SetupOptions getGhostsOptions() throws ApplicationError {
        SetupOptions options = new SetupOptions();
        options.setOption("charisma", "-10",0);
        options.setOption("psi-rating", "20",0);
        options.setOption("max-population-bonus", "0.1",0);
        options.setOption("cloak-level", "100",0);
        options.setOption("spy-bonus", "0.1",0);
        options.setOption("immunity", "Bio",0);
        return options;
    }

    public static SetupOptions getMachinesOptions() throws ApplicationError {
        SetupOptions options = new SetupOptions();
        options.setOption("factory-per-population-bonus", "0.1",0);
        options.setOption("development-bonus", "0.25",0);
        options.setOption("reproduction-bonus", "0.25",0);
        options.setOption("initiative-bonus", "0.5",0);
        options.setOption("immunity", "Psi",0);
        return options;
    }

    public static SetupOptions getMonsterOptions() throws ApplicationError {
        SetupOptions options = new SetupOptions();
        options.setOption("immunity", "ReplicaBeam",0);
        options.setOption("immunity", "MindControl",0);
        options.setOption("immunity", "Bio",0);
        options.setOption("immunity", "TroopTransport",0);
        return options;
    }


    /**
     * The instance holding all the designs.
     */
    private static TestFactory instance = null;
     
    public static void flush() {
        instance = null;
    }
}