/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.test;

import junit.framework.TestCase;
import mot.common.bean.CraftGraphics;
import mot.common.bean.PlayerColor;
import mot.common.bean.RaceGraphics;
import mot.common.bean.RaceGraphicsForColony;
import mot.common.bean.RaceGraphicsList;
import mot.common.factory.GraphicsFactory;
import mot.common.morals.MoralChoice;
import mot.common.morals.MoralChoiceList;
import mot.common.morals.MoralChoices;
import mot.common.technology.AsteroidFieldConstruction;
import mot.common.technology.Biotechnologies;
import mot.common.technology.Biotechnology;
import mot.common.technology.Computer;
import mot.common.technology.Computers;
import mot.common.technology.Engine;
import mot.common.technology.Engines;
import mot.common.technology.ExtendedSpaceJump;
import mot.common.technology.Factories;
import mot.common.technology.Factory;
import mot.common.technology.GalacticLore;
import mot.common.technology.GeneralTechnologyList;
import mot.common.technology.Hull;
import mot.common.technology.Hulls;
import mot.common.technology.Humanities;
import mot.common.technology.Humanity;
import mot.common.technology.Kamikaze;
import mot.common.technology.Laboratories;
import mot.common.technology.Laboratory;
import mot.common.technology.MinCostRestriction;
import mot.common.technology.MineField;
import mot.common.technology.MiscTechnologies;
import mot.common.technology.Module;
import mot.common.technology.Modules;
import mot.common.technology.NewsSystem;
import mot.common.technology.PlanetConstruction;
import mot.common.technology.Scanner;
import mot.common.technology.Scanners;
import mot.common.technology.Shield;
import mot.common.technology.ShieldSpan;
import mot.common.technology.Shields;
import mot.common.technology.Special;
import mot.common.technology.Specials;
import mot.common.technology.StationMissileBase;
import mot.common.technology.Technologies;
import mot.common.technology.TechnologyList;
import mot.common.technology.TechnologyTree;
import mot.common.technology.TechnologyTreeConditionPercentage;
import mot.common.technology.TechnologyTreeNode;
import mot.common.technology.Theories;
import mot.common.technology.Theory;
import mot.common.technology.Weapon;
import mot.common.technology.WeaponBayDetails;
import mot.common.technology.Weapons;
import mot.common.util.ApplicationError;
import mot.common.util.Logger;

public class TestTechnologyBase extends TestCase {

    public TestTechnologyBase(String name) {
        super(name);
    }

    public static PlayerColor blue; 
    public static PlayerColor green; 
    public static PlayerColor red; 
    public static PlayerColor yellow; 
    		
    static {
    	try {
			blue = PlayerColor.getColorForName("blue");
		} catch (ApplicationError e) {
			Logger.logError("TestTechnologyBase No Color blue", e);
		}
    	try {
			green = PlayerColor.getColorForName("green");
			red = PlayerColor.getColorForName("red");
			yellow = PlayerColor.getColorForName("yellow");
		} catch (ApplicationError e) {
			Logger.logError("TestTechnologyBase No Color green", e);
		}
    }

    public static Weapons weapons = new Weapons();
    public static Hulls hulls = new Hulls(); 
    public static Engines engines = new Engines(); 
    public static Shields shields = new Shields(); 
    public static Computers computers = new Computers(); 
    public static Scanners scanners = new Scanners(); 
    public static Specials specials = new Specials(); 
    public static Factories factories = new Factories();
    public static Laboratories labs = new Laboratories();
    public static Biotechnologies bios = new Biotechnologies();
    public static Modules modules = new Modules();
    public static Humanities humanities = new Humanities();
    public static MiscTechnologies miscTechs = new MiscTechnologies();
    public static Theories theories = new Theories(); 
    public static MoralChoiceList moralChoices = new MoralChoiceList();

    
    static {
    	if (Technologies.notInitialised()) {
    		Technologies.setWeapons(weapons);
    		Technologies.setHulls(hulls); 
    		Technologies.setEngines(engines);
    		Technologies.setShields(shields);
    		Technologies.setComputers(computers);
    		Technologies.setScanners(scanners);
    		Technologies.setSpecials(specials);
    	    Technologies.setFactories(factories);
    		Technologies.setLaboratories(labs);
    		Technologies.setBiotechnologies(bios);
    		Technologies.setModules(modules);
    		Technologies.setHumanities(humanities);
    		Technologies.setMiscTechnologies(miscTechs);
    		Technologies.setTheories(theories);
   			MoralChoices.setList(moralChoices);
    	}
    }
    public static Weapon tech_weaponWithDefaultDamage = new Weapon();
    static {
    	tech_weaponWithDefaultDamage.setName("BeamWithDefaultDamage");
    	tech_weaponWithDefaultDamage.setDamage(-1);
    	tech_weaponWithDefaultDamage.setDegredation(0.1);
    	tech_weaponWithDefaultDamage.setQtyShots(null);
    	tech_weaponWithDefaultDamage.setRange(200);
    	tech_weaponWithDefaultDamage.setVariance(0);
    	tech_weaponWithDefaultDamage.setSpace(4);
    	tech_weaponWithDefaultDamage.setCostToBuild(20);
    	tech_weaponWithDefaultDamage.setCostToResearch(10);
    	tech_weaponWithDefaultDamage.setMaintenanceCost(new Integer(4));
    	tech_weaponWithDefaultDamage.setGroup("Projectile");
	    weapons.add(tech_weaponWithDefaultDamage);
    }
    public static Weapon tech_massDriver1 = new Weapon();
    static {
	    tech_massDriver1.setName("MassDriver1");
	    tech_massDriver1.setDamage(2);
	    tech_massDriver1.setDegredation(0);
	    tech_massDriver1.setQtyShots(null);
	    tech_massDriver1.setRange(200);
	    tech_massDriver1.setVariance(0);
	    tech_massDriver1.setSpace(4);
	    tech_massDriver1.setMaxQtyOnCraft(-1);
	    tech_massDriver1.setMaxQtyOnPlanet(0);
	    tech_massDriver1.setCostToBuild(20);
	    tech_massDriver1.setCostToResearch(10);
	    tech_massDriver1.setMaintenanceCost(new Integer(4));
	    tech_massDriver1.setGroup("Projectile");
	    weapons.add(tech_massDriver1);
    }
    public static Weapon tech_massDriver2 = new Weapon();
    static {
        tech_massDriver2.setName("MassDriver2");
        tech_massDriver2.setDamage(2);
        tech_massDriver2.setDegredation(0);
        tech_massDriver2.setQtyShots(null);
        tech_massDriver2.setRange(300);
        tech_massDriver2.setVariance(0);
        tech_massDriver2.setSpace(4);
	    tech_massDriver2.setMaxQtyOnCraft(-1);
	    tech_massDriver2.setMaxQtyOnPlanet(0);
        tech_massDriver2.setCostToBuild(25);
        tech_massDriver2.setCostToResearch(250);
        tech_massDriver2.setMaintenanceCost(new Integer(4));
        tech_massDriver2.setGroup("Projectile");
        weapons.add(tech_massDriver2);
    }
    public static Weapon tech_missile6 = new Weapon();
    static {
        tech_missile6.setName("Missile6");
        tech_missile6.setDamage(6);
        tech_missile6.setDegredation(0);
        tech_missile6.setQtyShots(new Integer(5));
        tech_missile6.setRange(350);
        tech_missile6.setVariance(0);
        tech_missile6.setSpace(6);
        tech_missile6.setMaxQtyOnCraft(-1);
        tech_missile6.setMaxQtyOnPlanet(6);
        tech_missile6.setCostToBuild(30);
        tech_missile6.setCostToResearch(50);
        tech_missile6.setMaintenanceCost(new Integer(6));
        tech_missile6.setGroup("Missile");
        weapons.add(tech_missile6);
    }
    public static Weapon tech_missile15 = new Weapon();
    static {
    	tech_missile15.setName("Missile15");
    	tech_missile15.setDamage(15);
    	tech_missile15.setDegredation(0);
    	tech_missile15.setQtyShots(new Integer(2));
    	tech_missile15.setRange(350);
    	tech_missile15.setVariance(0);
    	tech_missile15.setSpace(7);
    	tech_missile15.setMaxQtyOnCraft(-1);
    	tech_missile15.setMaxQtyOnPlanet(6);
    	tech_missile15.setCostToBuild(30);
    	tech_missile15.setCostToResearch(60);
    	tech_missile15.setMaintenanceCost(new Integer(6));
    	tech_missile15.setGroup("Missile");
        weapons.add(tech_missile15);
    }
    public static Weapon tech_fusionBeam4 = new Weapon();
    static {
        tech_fusionBeam4.setName("FusionBeam4");
        tech_fusionBeam4.setDamage(4);
        tech_fusionBeam4.setDegredation(0.25);
        tech_fusionBeam4.setQtyShots(null);
        tech_fusionBeam4.setRange(200);
        tech_fusionBeam4.setVariance(0);
        tech_fusionBeam4.setSpace(5);
        tech_fusionBeam4.setCostToBuild(30);
        tech_fusionBeam4.setCostToResearch(1100);
        tech_fusionBeam4.setMaintenanceCost(new Integer(4));
        tech_fusionBeam4.setGroup("Beam");
        weapons.add(tech_fusionBeam4);
    }
    public static Weapon tech_immobiliser = new Weapon();
    static {
        tech_immobiliser.setName("Immobiliser");
        tech_immobiliser.setDamage(25);
        tech_immobiliser.setDegredation(0.0);
        tech_immobiliser.setQtyShots(null);
        tech_immobiliser.setRange(150);
        tech_immobiliser.setVariance(0);
        tech_immobiliser.setSpace(10);
        tech_immobiliser.setCostToBuild(30);
        tech_immobiliser.setCostToResearch(1100);
        tech_immobiliser.setMaintenanceCost(new Integer(4));
        tech_immobiliser.setGroup("Immobiliser");
        tech_immobiliser.setUsesDish(true);
        weapons.add(tech_immobiliser);
    }
    public static Weapon tech_shieldDrain = new Weapon();
    static {
        tech_shieldDrain.setName("ShieldDrain");
        tech_shieldDrain.setDamage(5);
        tech_shieldDrain.setDegredation(0.0);
        tech_shieldDrain.setQtyShots(null);
        tech_shieldDrain.setRange(150);
        tech_shieldDrain.setVariance(0);
        tech_shieldDrain.setSpace(5);
        tech_shieldDrain.setCostToBuild(30);
        tech_shieldDrain.setCostToResearch(2100);
        tech_shieldDrain.setMaintenanceCost(new Integer(4));
        tech_shieldDrain.setGroup("ShieldDrain");
        weapons.add(tech_shieldDrain);
    }
    public static Weapon tech_girator = new Weapon();
    static {
        tech_girator.setName("Girator");
        tech_girator.setDamage(25);
        tech_girator.setDegredation(0.0);
        tech_girator.setQtyShots(null);
        tech_girator.setRange(150);
        tech_girator.setVariance(0);
        tech_girator.setSpace(25);
        tech_girator.setUsesDish(true);
        tech_girator.setCostToBuild(30);
        tech_girator.setCostToResearch(2500);
        tech_girator.setMaintenanceCost(new Integer(4));
        tech_girator.setGroup("Girator");
        weapons.add(tech_girator);
    }
    public static Weapon tech_psiBlast = new Weapon();
    static {
        tech_psiBlast.setName("PsiBlast");
        tech_psiBlast.setDamage(1);
        tech_psiBlast.setDegredation(0.0);
        tech_psiBlast.setQtyShots(null);
        tech_psiBlast.setRange(150);
        tech_psiBlast.setVariance(0);
        tech_psiBlast.setSpace(25);
        tech_psiBlast.setCostToBuild(30);
        tech_psiBlast.setCostToResearch(7000);
        tech_psiBlast.setMaintenanceCost(new Integer(4));
        tech_psiBlast.setGroup("Psi");
        weapons.add(tech_psiBlast);
    }
    public static Weapon tech_equipmentTransport = new Weapon();
    static {
        tech_equipmentTransport.setName("EquipmentTransport");
        tech_equipmentTransport.setDamage(5);
        tech_equipmentTransport.setDegredation(0.0);
        tech_equipmentTransport.setQtyShots(null);
        tech_equipmentTransport.setRange(150);
        tech_equipmentTransport.setVariance(0);
        tech_equipmentTransport.setSpace(25);
        tech_equipmentTransport.setCostToBuild(60);
        tech_equipmentTransport.setCostToResearch(15000);
        tech_equipmentTransport.setMaintenanceCost(new Integer(7));
        tech_equipmentTransport.setGroup("Transport");
        weapons.add(tech_equipmentTransport);
    }
    public static Weapon tech_detonator = new Weapon();
    static {
        tech_detonator.setName("Detonator");
        tech_detonator.setDamage(0);
        tech_detonator.setDegredation(0.0);
        tech_detonator.setQtyShots(null);
        tech_detonator.setRange(350);
        tech_detonator.setVariance(0);
        tech_detonator.setSalvageEffect(new Double(0.25));
        tech_detonator.setSpace(10);
        tech_detonator.setCostToBuild(40);
        tech_detonator.setCostToResearch(700);
        tech_detonator.setMaintenanceCost(new Integer(5));
        tech_detonator.setGroup("Detonator");
        weapons.add(tech_detonator);
    }
    public static Weapon tech_prioVirus = new Weapon();
    static {
        tech_prioVirus.setName("PrioVirus");
        tech_prioVirus.setDamage(5);
        tech_prioVirus.setDegredation(0.0);
        tech_prioVirus.setQtyShots(null);
        tech_prioVirus.setRange(150);
        tech_prioVirus.setVariance(0);
        tech_prioVirus.setSpace(6);
        tech_prioVirus.setCostToBuild(30);
        tech_prioVirus.setCostToResearch(700);
        tech_prioVirus.setMaintenanceCost(new Integer(8));
        tech_prioVirus.setUsesDish(true);
        tech_prioVirus.setGroup("Bio");
        weapons.add(tech_prioVirus);
    }
    public static Weapon tech_troopTransport = new Weapon();
    static {
        tech_troopTransport.setName("TroopTransport");
        tech_troopTransport.setDamage(10);
        tech_troopTransport.setDegredation(0.0);
        tech_troopTransport.setQtyShots(null);
        tech_troopTransport.setRange(150);
        tech_troopTransport.setVariance(0);
        tech_troopTransport.setSpace(50);
        tech_troopTransport.setCostToBuild(50);
        tech_troopTransport.setCostToResearch(700);
        tech_troopTransport.setMaintenanceCost(new Integer(4));
        tech_troopTransport.setGroup("TroopTransport");
        weapons.add(tech_troopTransport);
    }
   public static Weapon tech_ancientWeapon = new Weapon();
   static {
        tech_ancientWeapon.setName("ancient");
        tech_ancientWeapon.setDamage(50);
        tech_ancientWeapon.setDegredation(0.1);
        tech_ancientWeapon.setQtyShots(null);
        tech_ancientWeapon.setRange(500);
        tech_ancientWeapon.setVariance(0.0);
        tech_ancientWeapon.setSpace(25);
        tech_ancientWeapon.setCostToBuild(100);
        tech_ancientWeapon.setCostToResearch(55000);
        tech_ancientWeapon.setMaintenanceCost(new Integer(10));
        tech_ancientWeapon.setGroup("Beam");
        weapons.add(tech_ancientWeapon);
    }
   public static Weapon tech_pulse = new Weapon();
   static {
	   tech_pulse.setName("IonPulse");
	   tech_pulse.setDamage(10);
	   tech_pulse.setDegredation(0.0);
	   tech_pulse.setQtyShots(null);
	   tech_pulse.setRange(100);
	   tech_pulse.setVariance(0);
	   tech_pulse.setSpace(10);
	   tech_pulse.setParam1("60");
	   tech_pulse.setCostToBuild(30);
	   tech_pulse.setCostToResearch(1500);
	   tech_pulse.setGroup("Pulse");
       weapons.add(tech_pulse);
   }
    public static Weapon tech_fakeWeapon = new Weapon();
    static {
        tech_fakeWeapon.setName("FakeWeapon");
        tech_fakeWeapon.setDamage(1);
        tech_fakeWeapon.setDegredation(0.0);
        tech_fakeWeapon.setQtyShots(0);
        tech_fakeWeapon.setRange(1);
        tech_fakeWeapon.setVariance(0.0);
        tech_fakeWeapon.setSpace(1);
        tech_fakeWeapon.setCostToBuild(1);
        tech_fakeWeapon.setCostToResearch(1);
        tech_fakeWeapon.setMaintenanceCost(null);
        tech_fakeWeapon.setGroup("Beam");
        weapons.add(tech_fakeWeapon);
    }
    public static Weapon tech_spacialDistortion = new Weapon();
    static {
        tech_spacialDistortion.setName("SpacialDistortion");
        tech_spacialDistortion.setDamage(100);
        tech_spacialDistortion.setDegredation(0.0);
        tech_spacialDistortion.setQtyShots(10);
        tech_spacialDistortion.setRange(500);
        tech_spacialDistortion.setVariance(0.0);
        tech_spacialDistortion.setSpace(100);
        tech_spacialDistortion.setMaxQtyOnCraft(0);
        tech_spacialDistortion.setMaxQtyOnPlanet(1);
        tech_spacialDistortion.setCostToBuild(100);
        tech_spacialDistortion.setCostToResearch(650);
        tech_spacialDistortion.setMaintenanceCost(new Integer(5));
        tech_spacialDistortion.setGroup("SpacialDistortion");
        weapons.add(tech_spacialDistortion);
    }
    public static Weapon tech_plague = new Weapon();
    static {
        tech_plague.setName("Plague");
        tech_plague.setDamage(5);
        tech_plague.setDegredation(0.0);
        tech_plague.setQtyShots(null);
        tech_plague.setRange(150);
        tech_plague.setVariance(0);
        tech_plague.setSpace(20);
        tech_plague.setCostToBuild(30);
        tech_plague.setCostToResearch(5200);
        tech_plague.setMaintenanceCost(new Integer(8));
        tech_plague.setUsesDish(true);
        tech_plague.setGroup("Plague");
        weapons.add(tech_plague);
    }
    public static Weapon tech_timeWarpGenerator = new Weapon();
    static {
        tech_timeWarpGenerator.setName("Time Warp Generator");
        tech_timeWarpGenerator.setDamage(0);
        tech_timeWarpGenerator.setDegredation(0.0);
        tech_timeWarpGenerator.setQtyShots(null);
        tech_timeWarpGenerator.setRange(100);
        tech_timeWarpGenerator.setVariance(0);
        tech_timeWarpGenerator.setSpace(50);
        tech_timeWarpGenerator.setCostToBuild(250);
        tech_timeWarpGenerator.setCostToResearch(32000);
        tech_timeWarpGenerator.setMaintenanceCost(new Integer(7));
        tech_timeWarpGenerator.setGroup("TimeWarp");
        weapons.add(tech_timeWarpGenerator);
    }
    public static Weapon tech_damageBots = new Weapon();
    static {
        tech_damageBots.setName("Damage Bots");
        tech_damageBots.setDamage(5);
        tech_damageBots.setDegredation(0.0);
        tech_damageBots.setQtyShots(null);
        tech_damageBots.setRange(150);
        tech_damageBots.setVariance(0.0);
        tech_damageBots.setSpace(25);
        tech_damageBots.setCostToBuild(80);
        tech_damageBots.setCostToResearch(14000);
        tech_damageBots.setMaintenanceCost(new Integer(4));
        tech_damageBots.setGroup("DamageBot");
        weapons.add(tech_damageBots);
    }
    public static Weapon tech_mindControl = new Weapon();
    static {
        tech_mindControl.setName("Mind Control");
        tech_mindControl.setDamage(0.5);
        tech_mindControl.setDegredation(0.0);
        tech_mindControl.setQtyShots(new Integer(3));
        tech_mindControl.setRange(500);
        tech_mindControl.setVariance(0.0);
        tech_mindControl.setSpace(25);
        tech_mindControl.setCostToBuild(80);
        tech_mindControl.setCostToResearch(14000);
        tech_mindControl.setMaintenanceCost(null);
        tech_mindControl.setGroup("MindControl");
        weapons.add(tech_mindControl);
    }
    public static Weapon tech_berserker = new Weapon();
    static {
        tech_berserker.setName("Berserker");
        tech_berserker.setDamage(0.5);
        tech_berserker.setDegredation(0.0);
        tech_berserker.setQtyShots(new Integer(3));
        tech_berserker.setRange(700);
        tech_berserker.setVariance(0.0);
        tech_berserker.setSpace(25);
        tech_berserker.setCostToBuild(80);
        tech_berserker.setCostToResearch(14000);
        tech_berserker.setMaintenanceCost(null);
        tech_berserker.setGroup("Berserker");
        weapons.add(tech_berserker);
    }
    public static Weapon tech_cowardice = new Weapon();
    static {
        tech_cowardice.setName("Cowardice");
        tech_cowardice.setDamage(0.5);
        tech_cowardice.setDegredation(0.0);
        tech_cowardice.setQtyShots(new Integer(3));
        tech_cowardice.setRange(500);
        tech_cowardice.setVariance(0.0);
        tech_cowardice.setSpace(25);
        tech_cowardice.setCostToBuild(80);
        tech_cowardice.setCostToResearch(14000);
        tech_cowardice.setMaintenanceCost(null);
        tech_cowardice.setGroup("Cowardice");
        weapons.add(tech_cowardice);
    }
    public static Weapon tech_droidMine = new Weapon();
    static {
        tech_droidMine.setName("Droid Mine");
        tech_droidMine.setDamage(0);
        tech_droidMine.setDegredation(0.0);
        tech_droidMine.setQtyShots(new Integer(5));
        tech_droidMine.setRange(500);
        tech_droidMine.setVariance(0.0);
        tech_droidMine.setSpace(20);
        tech_droidMine.setCostToBuild(80);
        tech_droidMine.setCostToResearch(5100);
        tech_droidMine.setMaintenanceCost(null);
        tech_droidMine.setGroup("DroidMine");
        weapons.add(tech_droidMine);
    }
    public static Weapon tech_retargetBeam = new Weapon();
    static {
        tech_retargetBeam.setName("Retarget Beam");
        tech_retargetBeam.setDamage(0.95);
        tech_retargetBeam.setDegredation(0.0);
        tech_retargetBeam.setQtyShots(null);
        tech_retargetBeam.setParam1("1");
        tech_retargetBeam.setRange(250);
        tech_retargetBeam.setVariance(0.0);
        tech_retargetBeam.setSpace(10);
        tech_retargetBeam.setCostToBuild(20);
        tech_retargetBeam.setCostToResearch(5500);
        tech_retargetBeam.setMaintenanceCost(null);
        tech_retargetBeam.setGroup("Retarget");
        weapons.add(tech_retargetBeam);
    }
    public static Weapon tech_antiMissileBeam = new Weapon();
    static {
    	tech_antiMissileBeam.setName("Anti Missile Beam");
    	tech_antiMissileBeam.setDamage(25);
    	tech_antiMissileBeam.setDegredation(0.0);
    	tech_antiMissileBeam.setQtyShots(null);
        tech_antiMissileBeam.setParam1("0");
        tech_antiMissileBeam.setRange(250);
        tech_antiMissileBeam.setVariance(0.0);
        tech_antiMissileBeam.setSpace(10);
        tech_antiMissileBeam.setCostToBuild(20);
        tech_antiMissileBeam.setCostToResearch(5500);
        tech_antiMissileBeam.setMaintenanceCost(null);
        tech_antiMissileBeam.setGroup("Retarget");
        weapons.add(tech_antiMissileBeam);
    }
    public static Weapon tech_timeWarpBeam = new Weapon();
    static {
        tech_timeWarpBeam.setName("Time Warp Beam");
        tech_timeWarpBeam.setDamage(3);
        tech_timeWarpBeam.setDegredation(0.0);
        tech_timeWarpBeam.setQtyShots(null);
        tech_timeWarpBeam.setRange(250);
        tech_timeWarpBeam.setParam1("100");
        tech_timeWarpBeam.setGroup("TimeWarpBeam");
        tech_timeWarpBeam.setMaxQtyOnCraft(1);
        weapons.add(tech_timeWarpBeam);
    }
    public static Weapon tech_salvageBeam = new Weapon();
    static {
        tech_salvageBeam.setName("Salvage Beam");
        tech_salvageBeam.setRange(300);
        tech_salvageBeam.setQtyShots(3);
        tech_salvageBeam.setGroup("SalvageBeam");
        weapons.add(tech_salvageBeam);
    }
    public static Weapon tech_replicaBeam = new Weapon();
    static {
    	tech_replicaBeam.setName("Replica Beam");
    	tech_replicaBeam.setRange(300);
    	tech_replicaBeam.setGroup(Weapon.GROUP_REPLICA_BEAM);
        weapons.add(tech_replicaBeam);
    }
    public static Weapon tech_shieldBurst = new Weapon();
    static {
    	tech_shieldBurst.setName("ShieldBurst");
    	tech_shieldBurst.setDamage(10);
    	tech_shieldBurst.setRange(80);
    	tech_shieldBurst.setGroup(Weapon.GROUP_SHIELD_BURST);
        weapons.add(tech_shieldBurst);
    }
    public static Weapon tech_teleporter = new Weapon();
    static {
    	tech_teleporter.setName("TeleportWeapon");
    	tech_teleporter.setDamage(0.5);
    	tech_teleporter.setDegredation(0.0);
    	tech_teleporter.setQtyShots(null);
    	tech_teleporter.setRange(200);
    	tech_teleporter.setSpace(20);
    	tech_teleporter.setCostToBuild(30);
    	tech_teleporter.setCostToResearch(5200);
    	tech_teleporter.setMaintenanceCost(new Integer(8));
    	tech_teleporter.setUsesDish(true);
    	tech_teleporter.setGroup(Weapon.GROUP_TELEPORT);
        weapons.add(tech_teleporter);
    }
    public static Weapon tech_sleep = new Weapon();
    static {
    	tech_sleep.setName("SleepWeapon");
    	tech_sleep.setDamage(11);
    	tech_sleep.setVariance(0.5);
    	tech_sleep.setDegredation(0.0);
    	tech_sleep.setQtyShots(null);
    	tech_sleep.setRange(200);
    	tech_sleep.setSpace(20);
    	tech_sleep.setCostToBuild(30);
    	tech_sleep.setCostToResearch(5200);
    	tech_sleep.setMaintenanceCost(new Integer(8));
    	tech_sleep.setUsesDish(true);
    	tech_sleep.setGroup(Weapon.GROUP_SLEEP);
        weapons.add(tech_sleep);
    }
    
    
    
    
    
    
    
    
	
    public static Hull tech_flyer30 = new Hull();
    static {
        tech_flyer30.setName("Flyer30");
        tech_flyer30.setBattleTurningCost(1);
        tech_flyer30.setBattleMovementCost(1);
        tech_flyer30.setMaxDamage(20);
        tech_flyer30.setSpace(30);
        tech_flyer30.setCrew(10);
        tech_flyer30.setCostToBuild(300);
        tech_flyer30.setCostToResearch(5);
        tech_flyer30.setMaintenanceCost(new Integer(4));
        tech_flyer30.setCostToBuildFactor(1);
        tech_flyer30.setWeaponBayDetails(new WeaponBayDetails("TestWeaponBayDetails", 45));
        tech_flyer30.setGroup("craft");
        tech_flyer30.setDestructonCanCauseWreckage(true);
        hulls.add(tech_flyer30);
    }
    public static Hull tech_flyer60 = new Hull();
    static {
        tech_flyer60.setName("Flyer60");
        tech_flyer60.setBattleTurningCost(1.25);
        tech_flyer60.setBattleMovementCost(1.25);
        tech_flyer60.setMaxDamage(40);
        tech_flyer60.setSpace(60);
        tech_flyer60.setCrew(10);
        tech_flyer60.setCostToBuild(700);
        tech_flyer60.setCostToResearch(6);
        tech_flyer60.setMaintenanceCost(new Integer(6));
        tech_flyer60.setCostToBuildFactor(2.0);
        tech_flyer60.setGroup("craft");
        tech_flyer60.setDestructonCanCauseWreckage(true);
        hulls.add(tech_flyer60);
    }
    public static Hull tech_flyer100 = new Hull();
    static {
        tech_flyer100.setName("Flyer100");
        tech_flyer100.setBattleTurningCost(1.5);
        tech_flyer100.setBattleMovementCost(1.5);
        tech_flyer100.setMaxDamage(80);
        tech_flyer100.setSpace(100);
        tech_flyer100.setCrew(10);
        tech_flyer100.setCostToBuild(1400);
        tech_flyer100.setCostToResearch(250);
        tech_flyer100.setMaintenanceCost(new Integer(8));
        tech_flyer100.setCostToBuildFactor(3);
        tech_flyer100.setGroup("craft");
		tech_flyer100.setWeaponBayDetails(new WeaponBayDetails("TestWeaponBayDetails", 45));
        tech_flyer100.setDestructonCanCauseWreckage(true);
        hulls.add(tech_flyer100);
    }
    public static Hull tech_flyer200 = new Hull();
    static {
    	tech_flyer200.setName("Flyer200");
    	tech_flyer200.setBattleTurningCost(1.5);
    	tech_flyer200.setBattleMovementCost(1.5);
        tech_flyer200.setMaxDamage(500);
        tech_flyer200.setSpace(200);
        tech_flyer200.setCrew(25);
        tech_flyer200.setCostToBuild(1800);
        tech_flyer200.setCostToResearch(5000);
        tech_flyer200.setMaintenanceCost(new Integer(10));
        tech_flyer200.setCostToBuildFactor(3);
        tech_flyer200.setGroup("craft");
		tech_flyer200.setWeaponBayDetails(new WeaponBayDetails("TestWeaponBayDetails", 45));
        tech_flyer200.setDestructonCanCauseWreckage(true);
        hulls.add(tech_flyer200);
    }
    public static Hull tech_fighterI = new Hull();
    static {
        tech_fighterI.setName("FighterI");
        tech_fighterI.setBattleTurningCost(0.75);
        tech_fighterI.setBattleMovementCost(0.75);
        tech_fighterI.setMaxDamage(20);
        tech_fighterI.setSpace(20);
        tech_fighterI.setCrew(10);
        tech_fighterI.setCostToBuild(100);
        tech_fighterI.setCostToResearch(10);
        tech_fighterI.setMaintenanceCost(new Integer(0));
        tech_fighterI.setCostToBuildFactor(0.75);
        tech_fighterI.setGroup("fighter");
        tech_fighterI.setDestructonCanCauseWreckage(false);
        hulls.add(tech_fighterI);
    }
    public static Hull tech_outpost = new Hull();
    static {
        tech_outpost.setName("Outpost");
        tech_outpost.setBattleTurningCost(1.0);
        tech_outpost.setBattleMovementCost(1.0);
        tech_outpost.setMaxDamage(50);
        tech_outpost.setSpace(15);
        tech_outpost.setCrew(10);
        tech_outpost.setCostToBuild(500);
        tech_outpost.setCostToResearch(300);
        tech_outpost.setMaintenanceCost(new Integer(1));
        tech_outpost.setCostToBuildFactor(3);
        tech_outpost.setGroup("outpost");
        tech_outpost.setMeta("Photon100");
        tech_outpost.setDestructonCanCauseWreckage(false);
        hulls.add(tech_outpost);
    }
    public static Hull tech_battleStationI = new Hull();
    static {
        tech_battleStationI.setName("BattleStationI");
        tech_battleStationI.setBattleTurningCost(1.0);
        tech_battleStationI.setBattleMovementCost(1.0);
        tech_battleStationI.setMaxDamage(200);
        tech_battleStationI.setSpace(44);
        tech_battleStationI.setCrew(100);
        tech_battleStationI.setCostToBuild(2000);
        tech_battleStationI.setCostToResearch(900);
        tech_battleStationI.setMaintenanceCost(new Integer(4));
        tech_battleStationI.setCostToBuildFactor(3);
        tech_battleStationI.setGroup("battle_station");
        tech_battleStationI.setDestructonCanCauseWreckage(false);
        hulls.add(tech_battleStationI);
    }
    public static Hull tech_battleStationII = new Hull();
    static {
        tech_battleStationII.setName("BattleStationII");
        tech_battleStationII.setBattleTurningCost(1.0);
        tech_battleStationII.setBattleMovementCost(1.0);
        tech_battleStationII.setMaxDamage(400);
        tech_battleStationII.setSpace(104);
        tech_battleStationII.setCrew(200);
        tech_battleStationII.setCostToBuild(4000);
        tech_battleStationII.setCostToResearch(5200);
        tech_battleStationII.setMaintenanceCost(new Integer(5));
        tech_battleStationII.setCostToBuildFactor(3);
        tech_battleStationII.setGroup("battle_station");
        tech_battleStationII.setDestructonCanCauseWreckage(false);
        hulls.add(tech_battleStationII);
    }
    public static Hull tech_spaceStation = new Hull();
    static {
        tech_spaceStation.setName("SpaceStation");
        tech_spaceStation.setBattleTurningCost(1.0);
        tech_spaceStation.setBattleMovementCost(1.0);
        tech_spaceStation.setMaxDamage(400);
        tech_spaceStation.setSpace(100);
        tech_spaceStation.setCrew(1000);
        tech_spaceStation.setCostToBuild(5000);
        tech_spaceStation.setCostToResearch(2600);
        tech_spaceStation.setMaintenanceCost(new Integer(6));
        tech_spaceStation.setCostToBuildFactor(3);
        tech_spaceStation.setGroup("space_station");
        tech_spaceStation.setDestructonCanCauseWreckage(false);
        hulls.add(tech_spaceStation);
    }
    public static Hull tech_sentinelHull = new Hull();
    static {
    	tech_sentinelHull.setName("Sentinel");
    	tech_sentinelHull.setBattleTurningCost(1.0);
    	tech_sentinelHull.setBattleMovementCost(1.0);
    	tech_sentinelHull.setMaxDamage(50);
    	tech_sentinelHull.setSpace(15);
    	tech_sentinelHull.setCrew(1);
    	tech_sentinelHull.setCostToBuild(500);
    	tech_sentinelHull.setCostToResearch(300);
    	tech_sentinelHull.setMaintenanceCost(new Integer(1));
    	tech_sentinelHull.setCostToBuildFactor(3);
    	tech_sentinelHull.setGroup("sentinel");
    	tech_sentinelHull.setDestructonCanCauseWreckage(false);
        hulls.add(tech_sentinelHull);
    }
    public static Hull tech_SmallWaterMan = new Hull();
    static {
        tech_SmallWaterMan.setName("small_WaterMan");
        tech_SmallWaterMan.setBattleTurningCost(1.0);
        tech_SmallWaterMan.setBattleMovementCost(1.0);
        tech_SmallWaterMan.setMaxDamage(200);
        tech_SmallWaterMan.setSpace(150);
        tech_SmallWaterMan.setCrew(10);
        tech_SmallWaterMan.setCostToBuild(900);
        tech_SmallWaterMan.setCostToResearch(100000);
        tech_SmallWaterMan.setMaintenanceCost(new Integer(6));
        tech_SmallWaterMan.setCostToBuildFactor(1);
        tech_SmallWaterMan.setGroup("craft");
        hulls.add(tech_SmallWaterMan);
    }
    public static Hull tech_mediumWaterMan = new Hull();
    static {
        tech_mediumWaterMan.setName("medium_WaterMan");
        tech_mediumWaterMan.setBattleTurningCost(1.0);
        tech_mediumWaterMan.setBattleMovementCost(1.0);
        tech_mediumWaterMan.setMaxDamage(2000);
        tech_mediumWaterMan.setSpace(400);
        tech_mediumWaterMan.setCrew(20);
        tech_mediumWaterMan.setCostToBuild(2000);
        tech_mediumWaterMan.setCostToResearch(100000);
        tech_mediumWaterMan.setMaintenanceCost(new Integer(8));
        tech_mediumWaterMan.setCostToBuildFactor(2);
        tech_mediumWaterMan.setGroup("craft");
        hulls.add(tech_mediumWaterMan);
    }
    public static Hull tech_largeWaterMan = new Hull();
    static {
        tech_largeWaterMan.setName("large_WaterMan");
        tech_largeWaterMan.setBattleTurningCost(1.0);
        tech_largeWaterMan.setBattleMovementCost(1.0);
        tech_largeWaterMan.setMaxDamage(5000);
        tech_largeWaterMan.setSpace(600);
        tech_largeWaterMan.setCrew(50);
        tech_largeWaterMan.setCostToBuild(9000);
        tech_largeWaterMan.setCostToResearch(100000);
        tech_largeWaterMan.setMaintenanceCost(new Integer(10));
        tech_largeWaterMan.setCostToBuildFactor(3);
        tech_largeWaterMan.setGroup("craft");
        hulls.add(tech_largeWaterMan);
    }
    public static Hull tech_smallAirMan = new Hull();
    static {
        tech_smallAirMan.setName("small_AirMan");
        tech_smallAirMan.setBattleTurningCost(1.0);
        tech_smallAirMan.setBattleMovementCost(1.0);
        tech_smallAirMan.setMaxDamage(200);
        tech_smallAirMan.setSpace(150);
        tech_smallAirMan.setCrew(10);
        tech_smallAirMan.setCostToBuild(900);
        tech_smallAirMan.setCostToResearch(100000);
        tech_smallAirMan.setMaintenanceCost(new Integer(6));
        tech_smallAirMan.setCostToBuildFactor(1);
        tech_smallAirMan.setGroup("craft");
        hulls.add(tech_smallAirMan);
    }
    public static Hull tech_mediumAirMan = new Hull();
    static {
        tech_mediumAirMan.setName("medium_AirMan");
        tech_mediumAirMan.setBattleTurningCost(1.0);
        tech_mediumAirMan.setBattleMovementCost(1.0);
        tech_mediumAirMan.setMaxDamage(2000);
        tech_mediumAirMan.setSpace(400);
        tech_mediumAirMan.setCrew(20);
        tech_mediumAirMan.setCostToBuild(2000);
        tech_mediumAirMan.setCostToResearch(100000);
        tech_mediumAirMan.setMaintenanceCost(new Integer(8));
        tech_mediumAirMan.setCostToBuildFactor(2);
        tech_mediumAirMan.setGroup("craft");
        hulls.add(tech_mediumAirMan);
    }
    public static Hull tech_largeAirMan = new Hull();
    static {
        tech_largeAirMan.setName("large_AirMan");
        tech_largeAirMan.setBattleTurningCost(1.0);
        tech_largeAirMan.setBattleMovementCost(1.0);
        tech_largeAirMan.setMaxDamage(5000);
        tech_largeAirMan.setSpace(600);
        tech_largeAirMan.setCrew(50);
        tech_largeAirMan.setCostToBuild(9000);
        tech_largeAirMan.setCostToResearch(100000);
        tech_largeAirMan.setMaintenanceCost(new Integer(10));
        tech_largeAirMan.setCostToBuildFactor(3);
        tech_largeAirMan.setGroup("craft");
        hulls.add(tech_largeAirMan);
    }
    
    
    static {
		try {
			RaceGraphicsList graphicsList = GraphicsFactory._createEmptyRaceGraphics();
			RaceGraphics humans = new RaceGraphics();
			humans.setName("Humans");
			humans.setType("player");
			humans.setCraftGraphics(new CraftGraphics("Transport", "hull_transport", "hull_transport", null, "3d/3d_hull_transport.png", 35, ".png", 0,0, 0,0, 0,0));
			humans.setCraftGraphics(new CraftGraphics("Flyer30", "hull_flyer", "hull_flyer_cloaked", null, "3d/3d_hull_flyer.png", 18, ".png", -8,-8, -8,8, -7,0));
			humans.setCraftGraphics(new CraftGraphics("Flyer60", "hull_flyer", "hull_flyer_cloaked", null, "3d/3d_hull_flyer.png", 25, ".png", -12,-11, -12,11, -10,0));
			humans.setCraftGraphics(new CraftGraphics("Flyer100", "hull_flyer", "hull_flyer_cloaked", null, "3d/3d_hull_flyer.png", 35, ".png", -14,-16, -14,16, -14,0));
			humans.setCraftGraphics(new CraftGraphics("Flyer200", "hull_flyer", "hull_flyer_cloaked", null, "3d/3d_hull_flyer.png", 35, ".png", -14,-16, -14,16, -14,0));
			humans.setCraftGraphics(new CraftGraphics("Outpost", "outpost_station", "space_station_cloaked", "small_outpost_station", null, 30, ".png", 0,0, 0,0, 0,0));
			humans.setCraftGraphics(new CraftGraphics("FighterI", "hull_fighterI", "hull_fighterI_cloaked", null, null, 15, ".png", -7,0, 0,0, 0,0));
			humans.setCraftGraphics(new CraftGraphics("FighterII", "hull_fighterII", "hull_fighterII_cloaked", null, null, 15, ".png", -7,0, 0,0, 0,0));
			humans.setCraftGraphics(new CraftGraphics("Defender30", "hull_defender", "hull_defender_cloaked", null, "3d/3d_hull_defender.png", 18, ".png", -8,-2, -8,2, -7,0));
			humans.setCraftGraphics(new CraftGraphics("Defender75", "hull_defender", "hull_defender_cloaked", null, "3d/3d_hull_defender.png", 25, ".png", -11,-3, -11,3, -10,0));
			humans.setCraftGraphics(new CraftGraphics("Defender130", "hull_defender", "hull_defender_cloaked", null, "3d/3d_hull_defender.png", 35, ".png", -13,-5, -13,5, -14,0));
			humans.setCraftGraphics(new CraftGraphics("BattleStationI", "space_station", "space_station_cloaked", null, null, 40, ".png", 0,0, 0,0, 0,0));
			humans.setCraftGraphics(new CraftGraphics("BattleStationII", "space_station", "space_station_cloaked", null, null, 40, ".png", 0,0, 0,0, 0,0));
			humans.setCraftGraphics(new CraftGraphics("SpaceStation", "space_station", "space_station_cloaked", "small_outpost_station", null, 50, ".png", -12,0, 0,0, 0,0));
			humans.setCraftGraphics(new CraftGraphics("Sentinel", "hull_sentinel", "hull_sentinel", null, null, 20, ".png", -15,0, 0,0, -15,0));
			humans.setCraftGraphics(new CraftGraphics("small_WaterMan", "hull_WaterMan", "hull_WaterMan_cloaked", null, "3d/3d_hull_ancient_waterman.png", 25, ".png", 0,0, 0,0, 0,0));
			humans.setCraftGraphics(new CraftGraphics("medium_WaterMan", "hull_WaterMan", "hull_WaterMan_cloaked", null, "3d/3d_hull_ancient_waterman.png", 35, ".png", 0,0, 0,0, 0,0));
			humans.setCraftGraphics(new CraftGraphics("large_WaterMan", "hull_WaterMan", "hull_WaterMan_cloaked", null, "3d/3d_hull_ancient_waterman.png", 45, ".png", 0,0, 0,0, 0,0));
			humans.setCraftGraphics(new CraftGraphics("small_AirMan", "hull_AirMan", "hull_AirMan_cloaked", null, "3d/3d_hull_ancient_airman.png", 25, ".png", 0,0, 0,0, 0,0));
			humans.setCraftGraphics(new CraftGraphics("medium_AirMan", "hull_AirMan", "hull_AirMan_cloaked", null, "3d/3d_hull_ancient_airman.png", 35, ".png", 0,0, 0,0, 0,0));
			humans.setCraftGraphics(new CraftGraphics("large_AirMan", "hull_AirMan", "hull_AirMan_cloaked", null, "3d/3d_hull_ancient_airman.png", 45, ".png", 0,0, 0,0, 0,0));
			humans.setColonyGraphics(new RaceGraphicsForColony("images/planets/colony_", ".jpg", "1,2"));
			graphicsList.setRaceGraphics(humans);

			RaceGraphics bears = new RaceGraphics();
			bears.setName("Bears");
			bears.setType("player");
			bears.setCopyAllCraftGraphics("Humans");
			graphicsList.setRaceGraphics(bears);

			RaceGraphics machines = new RaceGraphics();
			machines.setName("Machines");
			machines.setType("player");
			machines.setCopyAllCraftGraphics("Humans");
			graphicsList.setRaceGraphics(machines);

			RaceGraphics birds = new RaceGraphics();
			birds.setName("Birds");
			birds.setType("player");
			birds.setCopyAllCraftGraphics("Humans");
			graphicsList.setRaceGraphics(birds);

			RaceGraphics testPlayer1 = new RaceGraphics();
			testPlayer1.setName("TestPlayer1");
			testPlayer1.setType("test");
			testPlayer1.setCopyAllCraftGraphics("Humans");
			graphicsList.setRaceGraphics(testPlayer1);

			RaceGraphics testPlayer2 = new RaceGraphics();
			testPlayer2.setName("TestPlayer2");
			testPlayer2.setType("test");
			testPlayer2.setCopyAllCraftGraphics("Humans");
			graphicsList.setRaceGraphics(testPlayer2);

			RaceGraphics monster = new RaceGraphics();
			monster.setName("Monster");
			monster.setType("monster");
			monster.setCopyAllCraftGraphics("Humans");
			graphicsList.setRaceGraphics(monster);

			RaceGraphics waterMan = new RaceGraphics();
			waterMan.setName("WaterMan");
			waterMan.setType("ancient");
			waterMan.setCopyAllCraftGraphics("Humans");
			graphicsList.setRaceGraphics(waterMan);

			RaceGraphics airMan = new RaceGraphics();
			airMan.setName("AirMan");
			airMan.setType("ancient");
			airMan.setCopyAllCraftGraphics("Humans");
			graphicsList.setRaceGraphics(airMan);

		} catch (Exception e) {
			Logger.logError("", e);
		}

    }
    
    
    public static Engine tech_fusion25 = new Engine();
    static {
        tech_fusion25.setName("Fusion25");
        tech_fusion25.setMaxTravelDistance(150);
        tech_fusion25.setWarpSpeed(25);
        tech_fusion25.setImpulseSpeed(100);
        tech_fusion25.setTurningSpeed(200);
        tech_fusion25.setSpace(8);
        tech_fusion25.setCostToBuild(100);
        tech_fusion25.setCostToResearch(6);
        tech_fusion25.setUseBuildCostHullFactor(true);
        tech_fusion25.setGroup("AntiMatter");
        engines.add(tech_fusion25);
    }
    public static Engine tech_fusion25x = new Engine();
    static {
        tech_fusion25x.setName("Fusion25x");
        tech_fusion25x.setMaxTravelDistance(200);
        tech_fusion25x.setWarpSpeed(25);
        tech_fusion25x.setImpulseSpeed(100);
        tech_fusion25x.setTurningSpeed(200);
        tech_fusion25x.setSpace(8);
        tech_fusion25x.setCostToBuild(100);
        tech_fusion25x.setCostToResearch(25);
        tech_fusion25x.setUseBuildCostHullFactor(true);
        tech_fusion25x.setGroup("AntiMatter");
        engines.add(tech_fusion25x);
    }
    public static Engine tech_fusion40 = new Engine();
    static {
        tech_fusion40.setName("Fusion40");
        tech_fusion40.setMaxTravelDistance(250);
        tech_fusion40.setWarpSpeed(40);
        tech_fusion40.setImpulseSpeed(120);
        tech_fusion40.setTurningSpeed(250);
        tech_fusion40.setSpace(10);
        tech_fusion40.setCostToBuild(140);
        tech_fusion40.setCostToResearch(250);
        tech_fusion40.setUseBuildCostHullFactor(true);
        tech_fusion40.setGroup("AntiMatter");
        engines.add(tech_fusion40);
    }
    public static Engine tech_fusion400 = new Engine();
    static {
    	tech_fusion400.setName("Fusion400");
    	tech_fusion400.setMaxTravelDistance(500);
        tech_fusion400.setWarpSpeed(400);
        tech_fusion400.setImpulseSpeed(500);
        tech_fusion400.setTurningSpeed(900);
        tech_fusion400.setSpace(10);
        tech_fusion400.setCostToBuild(140);
        tech_fusion400.setCostToResearch(1150);
        tech_fusion400.setUseBuildCostHullFactor(true);
        tech_fusion400.setGroup("AntiMatter");
        engines.add(tech_fusion400);
    }
    public static Engine tech_teleport = new Engine();
    static {
        tech_teleport.setName("Teleport");
        tech_teleport.setMaxTravelDistance(600);
        tech_teleport.setWarpSpeed(300);
        tech_teleport.setImpulseSpeed(500);
        tech_teleport.setTurningSpeed(1000);
        tech_teleport.setSpace(30);
        tech_teleport.setCostToBuild(600);
        tech_teleport.setCostToResearch(18100);
        tech_teleport.setUseBuildCostHullFactor(true);
        tech_teleport.setGroup("Teleport");
        engines.add(tech_teleport);
    }
    public static Engine tech_ancientEngine = new Engine();
    static {
        tech_ancientEngine.setName("ancient");
        tech_ancientEngine.setMaxTravelDistance(10000);
        tech_ancientEngine.setWarpSpeed(25);
        tech_ancientEngine.setImpulseSpeed(600);
        tech_ancientEngine.setTurningSpeed(800);
        tech_ancientEngine.setSpace(40);
        tech_ancientEngine.setCostToBuild(500);
        tech_ancientEngine.setCostToResearch(55000);
        tech_ancientEngine.setUseBuildCostHullFactor(true);
        tech_ancientEngine.setGroup("AntiMatter");
        engines.add(tech_ancientEngine);
    }
    
    
    
    
    
    
    
    
	
    public static Shield tech_energy10 = new Shield();
    static {
        tech_energy10.setName("Energy10");
        tech_energy10.setDamageBlocked(1.0);
        tech_energy10.setPower(10);
        tech_energy10.setRechargeRate(1);
        tech_energy10.setDischargeRate(1);
        tech_energy10.setPsiRating(0);
        tech_energy10.setCloakLevel(0);
        tech_energy10.setSpace(10);
        tech_energy10.setCostToBuild(150);
        tech_energy10.setCostToResearch(50);
        tech_energy10.setMaintenanceCost(new Integer(3));
        tech_energy10.setGroup("Shield");
        shields.add(tech_energy10);
    }
    public static Shield tech_energy20 = new Shield();
    static {
        tech_energy20.setName("Energy20");
        tech_energy20.setDamageBlocked(2.0);
        tech_energy20.setPower(20);
        tech_energy20.setRechargeRate(1);
        tech_energy20.setDischargeRate(1);
        tech_energy20.setPsiRating(0);
        tech_energy20.setCloakLevel(0);
        tech_energy20.setSpace(15);
        tech_energy20.setCostToBuild(200);
        tech_energy20.setCostToResearch(600);
        tech_energy20.setMaintenanceCost(new Integer(3));
        tech_energy20.setGroup("Shield");
        shields.add(tech_energy20);
    }
    public static Shield tech_psiI = new Shield();
    static {
        tech_psiI.setName("PsiI");
        tech_psiI.setDamageBlocked(0.0);
        tech_psiI.setPower(0);
        tech_psiI.setRechargeRate(0);
        tech_psiI.setDischargeRate(0);
        tech_psiI.setPsiRating(0.25);
        tech_psiI.setCloakLevel(0);
        tech_psiI.setSpace(10);
        tech_psiI.setCostToBuild(100);
        tech_psiI.setCostToResearch(2300);
        tech_psiI.setGroup("Psi");
        shields.add(tech_psiI);
    }
    public static Shield tech_cloak150 = new Shield();
    static {
        tech_cloak150.setName("Cloak150");
        tech_cloak150.setDamageBlocked(0.0);
        tech_cloak150.setPower(0);
        tech_cloak150.setRechargeRate(0);
        tech_cloak150.setDischargeRate(0);
        tech_cloak150.setPsiRating(0);
        tech_cloak150.setCloakLevel(75);
        tech_cloak150.setSpace(10);
        tech_cloak150.setCostToBuild(100);
        tech_cloak150.setCostToResearch(2300);
        tech_cloak150.setGroup("Cloak");
        shields.add(tech_cloak150);
    }
    public static Shield tech_ancientShieldSmall = new Shield();
    static {
        tech_ancientShieldSmall.setName("ancient_small");
        tech_ancientShieldSmall.setDamageBlocked(10.0);
        tech_ancientShieldSmall.setPower(100);
        tech_ancientShieldSmall.setRechargeRate(5);
        tech_ancientShieldSmall.setDischargeRate(1.0);
        tech_ancientShieldSmall.setPsiRating(0);
        tech_ancientShieldSmall.setCloakLevel(0);
        tech_ancientShieldSmall.setSpace(10);
        tech_ancientShieldSmall.setCostToBuild(500);
        tech_ancientShieldSmall.setCostToResearch(55000);
        tech_ancientShieldSmall.setMaintenanceCost(new Integer(10));
        tech_ancientShieldSmall.setGroup("Shield");
        shields.add(tech_ancientShieldSmall);
    }
    public static Shield tech_fakeShield = new Shield();
    static {
        tech_fakeShield.setName("FakeShield");
        tech_fakeShield.setDamageBlocked(1.0);
        tech_fakeShield.setPower(1);
        tech_fakeShield.setRechargeRate(1);
        tech_fakeShield.setDischargeRate(1.0);
        tech_fakeShield.setPsiRating(0);
        tech_fakeShield.setCloakLevel(0);
        tech_fakeShield.setSpace(1);
        tech_fakeShield.setCostToBuild(1);
        tech_fakeShield.setCostToResearch(1);
        tech_fakeShield.setMaintenanceCost(new Integer(1));
        tech_fakeShield.setGroup("Shield");
        shields.add(tech_fakeShield);
    }
    public static Shield tech_ancientShieldMedium = new Shield();
    static {
        tech_ancientShieldMedium.setName("ancient_medium");
        tech_ancientShieldMedium.setDamageBlocked(25);
        tech_ancientShieldMedium.setPower(300);
        tech_ancientShieldMedium.setRechargeRate(20);
        tech_ancientShieldMedium.setDischargeRate(1);
        tech_ancientShieldMedium.setPsiRating(0.5);
        tech_ancientShieldMedium.setCloakLevel(0);
        tech_ancientShieldMedium.setSpace(20);
        tech_ancientShieldMedium.setCostToBuild(1000);
        tech_ancientShieldMedium.setCostToResearch(55000);
        tech_ancientShieldMedium.setMaintenanceCost(new Integer(10));
        tech_ancientShieldMedium.setGroup("Shield");
        shields.add(tech_ancientShieldMedium);
    }
    public static Shield tech_ancientShieldLarge = new Shield();
    static {
        tech_ancientShieldLarge.setName("ancient_large");
        tech_ancientShieldLarge.setDamageBlocked(50);
        tech_ancientShieldLarge.setPower(1000);
        tech_ancientShieldLarge.setRechargeRate(25);
        tech_ancientShieldLarge.setDischargeRate(1);
        tech_ancientShieldLarge.setPsiRating(1.0);
        tech_ancientShieldLarge.setCloakLevel(250);
        tech_ancientShieldLarge.setSpace(40);
        tech_ancientShieldLarge.setCostToBuild(2000);
        tech_ancientShieldLarge.setCostToResearch(55000);
        tech_ancientShieldLarge.setMaintenanceCost(new Integer(10));
        tech_ancientShieldLarge.setGroup("Shield");
        shields.add(tech_ancientShieldLarge);
    }
    
    



	
    public static Computer tech_electronic25 = new Computer();
    static {
        tech_electronic25.setName("Electronic25");
        tech_electronic25.setPower(new Integer(25));
        tech_electronic25.setSpace(5);
        tech_electronic25.setCostToBuild(50);
        tech_electronic25.setCostToResearch(9);
        tech_electronic25.setGroup("Computer");
        computers.add(tech_electronic25);
    }
    public static Computer tech_electronic40 = new Computer();
    static {
        tech_electronic40.setName("Electronic40");
        tech_electronic40.setPower(new Integer(40));
        tech_electronic40.setSpace(8);
        tech_electronic40.setCostToBuild(100);
        tech_electronic40.setCostToResearch(600);
        tech_electronic40.setGroup("Computer");
        computers.add(tech_electronic40);
    }
    public static Computer tech_galacticExchangeI = new Computer();
    static {
        tech_galacticExchangeI.setName("GalacticExchangeI");
        tech_galacticExchangeI.setCommerce(new Integer(5));
        tech_galacticExchangeI.setSpace(0);
        tech_galacticExchangeI.setCostToBuild(50);
        tech_galacticExchangeI.setCostToResearch(250);
        computers.add(tech_galacticExchangeI);
    }
    public static Computer tech_galaxyNetI = new Computer();
    static {
        tech_galaxyNetI.setName("GalaxyNetI");
        tech_galaxyNetI.setInfluence(new Integer(2));
        tech_galaxyNetI.setSpace(0);
        tech_galaxyNetI.setCostToBuild(50);
        tech_galaxyNetI.setCostToResearch(1100);
        computers.add(tech_galaxyNetI);
    }
    public static Computer tech_ancientComputer = new Computer();
    static {
        tech_ancientComputer.setName("ancient");
        tech_ancientComputer.setPower(new Integer(500));
        tech_ancientComputer.setSpace(30);
        tech_ancientComputer.setCostToBuild(400);
        tech_ancientComputer.setCostToResearch(55000);
        tech_ancientComputer.setGroup("Computer");
        computers.add(tech_ancientComputer);
    }
    
    
    
    
     
	
    public static Scanner tech_photon100 = new Scanner();
    static {
        tech_photon100.setName("Photon100");
        tech_photon100.setStrength(100);
        tech_photon100.setSpace(4);
        tech_photon100.setCostToBuild(100);
        tech_photon100.setCostToResearch(10);
        tech_photon100.setMaintenanceCost(new Integer(1));
        tech_photon100.setGroup("Scanner");
        scanners.add(tech_photon100);
    }
    public static Scanner tech_photon150 = new Scanner();
    static {
        tech_photon150.setName("Photon150");
        tech_photon150.setStrength(150);
        tech_photon150.setSpace(6);
        tech_photon150.setCostToBuild(125);
        tech_photon150.setCostToResearch(100);
        tech_photon150.setMaintenanceCost(new Integer(1));
        tech_photon150.setGroup("Scanner");
        scanners.add(tech_photon150);
    }
    public static Scanner tech_photon200 = new Scanner();
    static {
        tech_photon200.setName("Photon200");
        tech_photon200.setStrength(200);
        tech_photon200.setSpace(6);
        tech_photon200.setCostToBuild(200);
        tech_photon200.setCostToResearch(1000);
        tech_photon200.setMaintenanceCost(new Integer(2));
        tech_photon200.setGroup("Scanner");
        scanners.add(tech_photon200);
    }
    public static Scanner tech_photon400 = new Scanner();
    static {
        tech_photon400.setName("Photon400");
        tech_photon400.setStrength(400);
        tech_photon400.setSpace(6);
        tech_photon400.setCostToBuild(200);
        tech_photon400.setCostToResearch(1000);
        tech_photon400.setMaintenanceCost(new Integer(2));
        tech_photon400.setGroup("Scanner");
        scanners.add(tech_photon400);
    }
    
    


	
    public static Special tech_augumentedEnginesI = new Special();
    static {
        tech_augumentedEnginesI.setName("AugumentedEnginesI");
        tech_augumentedEnginesI.setSpeedBonus(new Double(0.1));
        tech_augumentedEnginesI.setBattleSpeedBonus(new Double(0.1));
        tech_augumentedEnginesI.setBattleTurningBonus(new Double(0.1));
        tech_augumentedEnginesI.setSpace(10);
        tech_augumentedEnginesI.setCostToBuild(80);
        tech_augumentedEnginesI.setCostToResearch(1000);
        tech_augumentedEnginesI.setGroup("AugumentedEngines");
        specials.add(tech_augumentedEnginesI);
    }
    public static Special tech_shieldModulatorI = new Special();
    static {
        tech_shieldModulatorI.setName("ShieldModulatorI");
        tech_shieldModulatorI.setDefenderModification(new Double(0.1));
        tech_shieldModulatorI.setSpace(5);
        tech_shieldModulatorI.setCostToBuild(80);
        tech_shieldModulatorI.setCostToResearch(500);
        tech_shieldModulatorI.setGroup("ShieldModulator");
        specials.add(tech_shieldModulatorI);
    }
    public static Special tech_shieldModulatorII = new Special();
    static {
        tech_shieldModulatorII.setName("ShieldModulatorII");
        tech_shieldModulatorII.setDefenderModification(new Double(0.2));
        tech_shieldModulatorII.setSpace(10);
        tech_shieldModulatorII.setCostToBuild(150);
        tech_shieldModulatorII.setCostToResearch(2700);
        tech_shieldModulatorII.setGroup("ShieldModulator");
        specials.add(tech_shieldModulatorII);
    }
    public static Special tech_colonyModule8 = new Special();
    static {
        tech_colonyModule8.setName("ColonyModule8");
        tech_colonyModule8.setCanColoniseRating(new Double(0.8));
        tech_colonyModule8.setSpace(40);
        tech_colonyModule8.setCostToBuild(150);
        tech_colonyModule8.setCostToResearch(8);
        tech_colonyModule8.setGroup("ColonyModule");
        specials.add(tech_colonyModule8);
    }
    public static Special tech_colonyModule7 = new Special();
    static {
        tech_colonyModule7.setName("ColonyModule7");
        tech_colonyModule7.setCanColoniseRating(new Double(0.7));
        tech_colonyModule7.setSpace(40);
        tech_colonyModule7.setCostToBuild(200);
        tech_colonyModule7.setCostToResearch(50);
        tech_colonyModule7.setGroup("ColonyModule");
        specials.add(tech_colonyModule7);
    }
    public static Special tech_spacePods10 = new Special();
    static {
        tech_spacePods10.setName("SpacePods10");
        tech_spacePods10.setSpace(-10);
        tech_spacePods10.setCostToBuild(50);
        tech_spacePods10.setCostToResearch(250);
        tech_spacePods10.setGroup("SpacePods");
        specials.add(tech_spacePods10);
    }
    public static Special tech_holoEmiter = new Special();
    static {
        tech_holoEmiter.setName("HoloEmiter");
        tech_holoEmiter.setSpace(2);
        tech_holoEmiter.setCostToBuild(100);
        tech_holoEmiter.setCostToResearch(2600);
        tech_holoEmiter.setQtyHoloCraft(new Integer(1));
        tech_holoEmiter.setGroup("HoloEmiter");
        specials.add(tech_holoEmiter);
    }
    public static Special tech_fighterBays = new Special();
    static {
        tech_fighterBays.setName("FighterBays");
        tech_fighterBays.setQtyFighters(new Integer(2));
        tech_fighterBays.setSpace(60);
        tech_fighterBays.setCostToBuild(50);
        tech_fighterBays.setCostToResearch(1000);
        tech_fighterBays.setGroup(Special.GROUP_FIGHTER_BAYS);
        specials.add(tech_fighterBays);
    }
    public static Special tech_commandModule = new Special();
    static {
    	tech_commandModule.setName("CommandModule");
    	tech_commandModule.setFleetBattleSpeedBonus(0.1);
    	tech_commandModule.setFleetBattleTurningBonus(0.2);
    	tech_commandModule.setFleetInitiativeBonus(0.3);
    	tech_commandModule.setFleetAttackerModification(0.5);
    	tech_commandModule.setFleetDefenderModification(0.75);
    	tech_commandModule.setSpace(50);
    	tech_commandModule.setCostToBuild(500);
    	tech_commandModule.setCostToResearch(1200);
    	tech_commandModule.setGroup(Special.GROUP_COMMAND_CENTER);
        specials.add(tech_commandModule);
    }
    public static Special tech_armour25 = new Special();
    static {
        tech_armour25.setName("Armour25");
        tech_armour25.setMaxDamageBonus(new Double(0.25));
        tech_armour25.setSpace(15);
        tech_armour25.setCostToBuild(50);
        tech_armour25.setCostToResearch(600);
        tech_armour25.setGroup("Armour");
        specials.add(tech_armour25);
    }
    public static Special tech_armour200 = new Special();
    static {
    	tech_armour200.setName("Armour200");
    	tech_armour200.setMaxDamageBonus(new Double(8.0));
    	tech_armour200.setSpace(20);
    	tech_armour200.setCostToBuild(50);
    	tech_armour200.setCostToResearch(600);
    	tech_armour200.setGroup("Armour");
        specials.add(tech_armour200);
    }
    public static Special tech_shieldSpan = new Special();
    static {
    	tech_shieldSpan.setName("ShieldSpan");
    	tech_shieldSpan.setShieldSpan(new ShieldSpan(0.5, 150));
    	tech_shieldSpan.setSpace(8);
    	tech_shieldSpan.setCostToBuild(40);
    	tech_shieldSpan.setCostToResearch(1500);
    	tech_shieldSpan.setGroup("ShieldSpan");
        specials.add(tech_shieldSpan);
    }
    public static Special tech_eneryAmplifierI = new Special();
    static {
        tech_eneryAmplifierI.setName("EnergyAmplifierI");
        tech_eneryAmplifierI.setAttackerModification(new Double(0.1));
        tech_eneryAmplifierI.setRangeModification(new Double(0.1));
        tech_eneryAmplifierI.setSpace(6);
        tech_eneryAmplifierI.setCostToBuild(80);
        tech_eneryAmplifierI.setCostToResearch(900); // was 700!
        tech_eneryAmplifierI.setGroup("EnergyAmplifier");
        specials.add(tech_eneryAmplifierI);
    }
    public static Special tech_tacticalStationI = new Special();
    static {
        tech_tacticalStationI.setName("TacticalStationI");
        tech_tacticalStationI.setInitiativeBonus(new Double(0.25));
        tech_tacticalStationI.setSpace(5);
        tech_tacticalStationI.setCostToBuild(80);
        tech_tacticalStationI.setCostToResearch(1100);
        tech_tacticalStationI.setGroup("TacticalStation");
        specials.add(tech_tacticalStationI);
    }
    public static Special tech_troopModule20 = new Special();
    static {
        tech_troopModule20.setName("TroopModule20");
        tech_troopModule20.setQtyBerths(new Integer(20));
        tech_troopModule20.setSpace(25);
        tech_troopModule20.setCostToBuild(150);
        tech_troopModule20.setCostToResearch(100);
        tech_troopModule20.setGroup("TroopModule");
        specials.add(tech_troopModule20);
    }
    public static Special tech_FleetNewsService = new Special();
    static {
        tech_FleetNewsService.setName("Fleet News Service");
        tech_FleetNewsService.setInfluence(new Double(1.0));
        tech_FleetNewsService.setSpace(80);
        tech_FleetNewsService.setCostToBuild(150);
        tech_FleetNewsService.setCostToResearch(4800);
        tech_FleetNewsService.setGroup("News Service");
        specials.add(tech_FleetNewsService);
    }
    public static Special tech_incinerator = new Special();
    static {
    	tech_incinerator.setName("Incinerator");
    	tech_incinerator.setSpace(5);
    	tech_incinerator.setSalvageEffect(0.0);
    	tech_incinerator.setCostToBuild(10);
    	tech_incinerator.setCostToResearch(200);
    	tech_incinerator.setGroup("Incinerator");
        specials.add(tech_incinerator);
    }
    public static Special tech_imunity = new Special();
    static {
    	tech_imunity.setName("Imunity");
    	tech_imunity.setImunity(Weapon.GROUP_REPLICA_BEAM);
    	tech_imunity.setSpace(20);
    	tech_imunity.setCostToBuild(200);
    	tech_imunity.setCostToResearch(200);
    	tech_imunity.setGroup(Special.GROUP_IMMUNITY);
        specials.add(tech_imunity);
    }
    public static Special tech_missile_guidance_unit = new Special();
    static {
    	tech_missile_guidance_unit.setName("MissileGuidanceUnit");
    	tech_missile_guidance_unit.setMissileRetarget(true);
    	tech_missile_guidance_unit.setSpace(10);
    	tech_missile_guidance_unit.setCostToBuild(50);
    	tech_missile_guidance_unit.setCostToResearch(1000);
    	tech_missile_guidance_unit.setGroup("MissileGuidance");
        specials.add(tech_missile_guidance_unit);
    }
    public static Special tech_auto_repair_unit = new Special();
    static {
    	tech_auto_repair_unit.setName("AutomaticRepairUnit");
    	tech_auto_repair_unit.setRepairEffect(0.1);
    	tech_auto_repair_unit.setSpace(10);
    	tech_auto_repair_unit.setCostToBuild(50);
    	tech_auto_repair_unit.setCostToResearch(1000);
        specials.add(tech_auto_repair_unit);
    }
    public static Special tech_dimensionChamber = new Special();
    static {
    	tech_dimensionChamber.setName("Dimension Chamber");
    	tech_dimensionChamber.setSpace(-30);
    	tech_dimensionChamber.setCostToBuild(50);
    	tech_dimensionChamber.setCostToResearch(250);
    	tech_dimensionChamber.setGroup("SpacePods");
        specials.add(tech_dimensionChamber);
    }
    public static Special tech_stationFighterBays = new Special();
    static {
    	tech_stationFighterBays.setName("Station Fighters Bays");
    	tech_stationFighterBays.setSpace(1);
    	tech_stationFighterBays.setQtyFighters(2);
    	tech_stationFighterBays.setCostToBuild(1);
    	tech_stationFighterBays.setCostToResearch(1);
    	tech_stationFighterBays.setGroup("FighterBays");
        specials.add(tech_stationFighterBays);
    }

    
    
    
     
	
    public static Factory tech_basicComputerisedFactory = new Factory();
    static {
        tech_basicComputerisedFactory.setName("Basic Computerised Factory");
        tech_basicComputerisedFactory.setQtyPerPopulation(0.5);
        tech_basicComputerisedFactory.setMinEcologyWork(0.5);
        tech_basicComputerisedFactory.setProduction(1);
        tech_basicComputerisedFactory.setCostToBuild(40);
        tech_basicComputerisedFactory.setCostToResearch(10);
        tech_basicComputerisedFactory.setGroup(Factory.GROUP_PRODUCTION);
        factories.add(tech_basicComputerisedFactory);
    }
    public static Factory tech_computerisedFactoryII = new Factory();
    static {
        tech_computerisedFactoryII.setName("ComputerisedII");
        tech_computerisedFactoryII.setQtyPerPopulation(0.25);
        tech_computerisedFactoryII.setMinEcologyWork(0.25);
        tech_computerisedFactoryII.setProduction(1);
        tech_computerisedFactoryII.setCostToBuild(80);
        tech_computerisedFactoryII.setCostToResearch(500);
        tech_computerisedFactoryII.setGroup(Factory.GROUP_PRODUCTION);
        factories.add(tech_computerisedFactoryII);
    }
    public static Factory tech_qualityControl = new Factory();
    static {
    	tech_qualityControl.setName("QualityControl");
    	tech_qualityControl.setBuildQuality(0.05);
    	tech_qualityControl.setCostToBuild(80);
    	tech_qualityControl.setCostToResearch(500);
    	tech_qualityControl.setGroup(Factory.GROUP_OTHER);
        factories.add(tech_qualityControl);
    }
    public static Factory tech_galacticNewsService = new Factory();
    static {
        tech_galacticNewsService.setName("Galactic News Service");
        tech_galacticNewsService.setPropaganda(0.1);
        tech_galacticNewsService.setCostToBuild(0);
        tech_galacticNewsService.setCostToResearch(800);
        tech_galacticNewsService.setGroup(Factory.GROUP_OTHER);
        factories.add(tech_galacticNewsService);
    }
    
    
     
	
    public static Laboratory tech_ComputerisedLabI = new Laboratory();
    static {
        tech_ComputerisedLabI.setName("ComputerisedI");
        tech_ComputerisedLabI.setProduction(1);
        tech_ComputerisedLabI.setCostToBuild(2);
        tech_ComputerisedLabI.setCostToResearch(50);
        labs.add(tech_ComputerisedLabI);
    }
    public static Laboratory tech_ComputerisedLabII = new Laboratory();
    static {
        tech_ComputerisedLabII.setName("ComputerisedII");
        tech_ComputerisedLabII.setProduction(1);
        tech_ComputerisedLabII.setCostToBuild(80);
        tech_ComputerisedLabII.setCostToResearch(500);
        labs.add(tech_ComputerisedLabII);
    }
    public static Laboratory tech_SalvageAnalyser = new Laboratory();
    static {
    	tech_SalvageAnalyser.setName("SalvageAnalyser");
    	tech_SalvageAnalyser.setChanceToDiscoverSalvagedTechBonus(0.5);
    	tech_SalvageAnalyser.setGroup("Salvage Analyser");
    	tech_SalvageAnalyser.setCostToBuild(80);
    	tech_SalvageAnalyser.setCostToResearch(500);
        labs.add(tech_SalvageAnalyser);
    }
    
    
    
	
    public static Biotechnology tech_terraforming10 = new Biotechnology();
    static {
        tech_terraforming10.setName("Terraforming10");
        tech_terraforming10.setPsiRating(null);
        tech_terraforming10.setReproductionBonus(null);
        tech_terraforming10.setSpyRating(null);
        tech_terraforming10.setTerraformRating(new Double(0.1));
        tech_terraforming10.setCostToBuild(0);
        tech_terraforming10.setCostToResearch(700);
        tech_terraforming10.setGroup("TerraLevel");
        bios.add(tech_terraforming10);
    }
    public static Biotechnology tech_spice25 = new Biotechnology();
    static {
        tech_spice25.setName(TestTechs.SPICE25);
        tech_spice25.setPsiRating(null);
        tech_spice25.setReproductionBonus(new Double(0.25));
        tech_spice25.setSpyRating(null);
        tech_spice25.setTerraformRating(null);
        tech_spice25.setCostToBuild(0);
        tech_spice25.setCostToResearch(800);
        bios.add(tech_spice25);
    }
    public static Biotechnology tech_bioCloak1 = new Biotechnology();
    static {
        tech_bioCloak1.setName("BioCloak1");
        tech_bioCloak1.setPsiRating(null);
        tech_bioCloak1.setReproductionBonus(null);
        tech_bioCloak1.setSpyRating(new Integer(1));
        tech_bioCloak1.setTerraformRating(null);
        tech_bioCloak1.setCostToBuild(0);
        tech_bioCloak1.setCostToResearch(100);
        bios.add(tech_bioCloak1);
    }
    public static Biotechnology tech_psi10 = new Biotechnology();
    static {
        tech_psi10.setName("Psi10");
        tech_psi10.setPsiRating(new Integer(10));
        tech_psi10.setReproductionBonus(null);
        tech_psi10.setSpyRating(null);
        tech_psi10.setTerraformRating(null);
        tech_psi10.setCostToBuild(0);
        tech_psi10.setCostToResearch(600);
        tech_psi10.setGroup("psi");
        bios.add(tech_psi10);
    }
    public static Biotechnology tech_psi20 = new Biotechnology();
    static {
        tech_psi20.setName("Psi20");
        tech_psi20.setPsiRating(new Integer(10));
        tech_psi20.setReproductionBonus(null);
        tech_psi20.setSpyRating(null);
        tech_psi20.setTerraformRating(null);
        tech_psi20.setCostToBuild(0);
        tech_psi20.setCostToResearch(1200);
        tech_psi20.setGroup("psi");
        bios.add(tech_psi20);
    }
    
    
	
    public static Module tech_core_habitat = new Module();
    static {
    	tech_core_habitat.setName("Core Habitat");
    	tech_core_habitat.setPopulation(new Integer(10));
    	tech_core_habitat.setProduction(null);
    	tech_core_habitat.setResearch(null);
    	tech_core_habitat.setCostToBuild(100);
    	tech_core_habitat.setCostToResearch(100);
    	tech_core_habitat.setGroup("habitat_module");
    	tech_core_habitat.setOnBattleStation(true);
    	tech_core_habitat.setOnSpaceStation(true);
    	tech_core_habitat.setOnOutpost(false);
        modules.add(tech_core_habitat);
    }
    public static Module tech_habitatI = new Module();
    static {
        tech_habitatI.setName("HabitatI");
        tech_habitatI.setPopulation(new Integer(10));
        tech_habitatI.setProduction(null);
        tech_habitatI.setResearch(null);
        tech_habitatI.setCostToBuild(100);
        tech_habitatI.setCostToResearch(3200);
        tech_habitatI.setGroup("habitat_module");
        tech_habitatI.setOnBattleStation(true);
        tech_habitatI.setOnSpaceStation(true);
        tech_habitatI.setOnOutpost(false);
        modules.add(tech_habitatI);
    }
    public static Module tech_habitatII = new Module();
    static {
        tech_habitatII.setName("HabitatII");
        tech_habitatII.setPopulation(new Integer(20));
        tech_habitatII.setProduction(null);
        tech_habitatII.setResearch(null);
        tech_habitatII.setCostToBuild(200);
        tech_habitatII.setCostToResearch(6200);
        tech_habitatII.setGroup("habitat_module");
        tech_habitatII.setOnBattleStation(true);
        tech_habitatII.setOnSpaceStation(true);
        tech_habitatII.setOnOutpost(false);
        modules.add(tech_habitatII);
    }
    public static Module tech_oreExtractor = new Module();
    static {
        tech_oreExtractor.setName("Ore Extractor");
        tech_oreExtractor.setPopulation(null);
        tech_oreExtractor.setProduction(new Integer(20));
        tech_oreExtractor.setResearch(null);
        tech_oreExtractor.setCostToBuild(100);
        tech_oreExtractor.setCostToResearch(3200);
        tech_oreExtractor.setGroup("ore_module");
        tech_oreExtractor.setOnBattleStation(false);
        tech_oreExtractor.setOnSpaceStation(true);
        tech_oreExtractor.setOnOutpost(false);
        modules.add(tech_oreExtractor);
    }
    public static Module tech_researchModule = new Module();
    static {
        tech_researchModule.setName("Research Module");
        tech_researchModule.setPopulation(null);
        tech_researchModule.setProduction(null);
        tech_researchModule.setResearch(new Integer(30));
        tech_researchModule.setCostToBuild(100);
        tech_researchModule.setCostToResearch(3200);
        tech_researchModule.setGroup("research_module");
        tech_researchModule.setOnBattleStation(false);
        tech_researchModule.setOnSpaceStation(true);
        tech_researchModule.setOnOutpost(false);
        modules.add(tech_researchModule);
    }
    public static Module tech_fightersModule = new Module();
    static {
    	tech_fightersModule.setName("Fighters Module");
    	tech_fightersModule.setPopulation(null);
    	tech_fightersModule.setProduction(null);
    	tech_fightersModule.setQtyFighterBays(2);
    	tech_fightersModule.setCostToBuild(100);
    	tech_fightersModule.setCostToResearch(3200);
    	tech_fightersModule.setGroup("fighters_module");
    	tech_fightersModule.setOnBattleStation(false);
    	tech_fightersModule.setOnSpaceStation(true);
    	tech_fightersModule.setOnOutpost(false);
        modules.add(tech_fightersModule);
    }
    public static Module tech_sentinelsModule = new Module();
    static {
    	tech_sentinelsModule.setName("Sentinels Module");
    	tech_sentinelsModule.setPopulation(null);
    	tech_sentinelsModule.setProduction(null);
    	tech_sentinelsModule.setQtySentinels(2);
    	tech_sentinelsModule.setCostToBuild(100);
    	tech_sentinelsModule.setCostToResearch(3200);
    	tech_sentinelsModule.setGroup("sentinels_module");
    	tech_sentinelsModule.setOnBattleStation(true);
    	tech_sentinelsModule.setOnSpaceStation(true);
    	tech_sentinelsModule.setOnOutpost(true);
        modules.add(tech_sentinelsModule);
    }
    
    public static Humanity tech_trade_route = new Humanity();
    static {
    	tech_trade_route.setName("Trade Route");
    	tech_trade_route.setMaxTradeRouteDistance(new Integer(100));
        tech_trade_route.setCostToBuild(100);
        tech_trade_route.setCostToResearch(3250);
        tech_trade_route.setGroup("TradeRoute");
        humanities.add(tech_trade_route);
    }

    public static Humanity tech_trade_routeII = new Humanity();
    static {
    	tech_trade_routeII.setName("Trade RouteII");
    	tech_trade_routeII.setMaxTradeRouteDistance(new Integer(200));
    	tech_trade_routeII.setCostToBuild(200);
    	tech_trade_routeII.setCostToResearch(3250);
    	tech_trade_routeII.setGroup("TradeRoute");
        humanities.add(tech_trade_routeII);
    }

    public static Humanity tech_trade_route_bonus = new Humanity();
    static {
    	tech_trade_route_bonus.setName("Trade Route Bonus");
    	tech_trade_route_bonus.setTradeRouteBonus(0.25);
    	tech_trade_route_bonus.setCostToBuild(200);
    	tech_trade_route_bonus.setCostToResearch(3250);
    	tech_trade_route_bonus.setGroup("TradeRouteBonus");
        humanities.add(tech_trade_route_bonus);
    }

    public static MineField tech_mineField = new MineField();
    static {
        tech_mineField.setName("Mine Field");
        tech_mineField.setRange(25);
        tech_mineField.setQty(3);
        tech_mineField.setCostToBuild(40);
        tech_mineField.setCostToResearch(7);
        miscTechs.add(tech_mineField);
    }
    public static NewsSystem tech_planetaryNewsService = new NewsSystem();
    static {
        tech_planetaryNewsService.setName("Planetary News Service");
        tech_planetaryNewsService.setInfluence(1.0);
        tech_planetaryNewsService.setCostToBuild(0);
        tech_planetaryNewsService.setCostToResearch(1100);
        miscTechs.add(tech_planetaryNewsService);
    }
    public static Kamikaze tech_kamikaze = new Kamikaze();
    static {
    	tech_kamikaze.setName("Kamikaze");
    	tech_kamikaze.setSuicidePercent(0.5);
    	tech_kamikaze.setCostToBuild(0);
    	tech_kamikaze.setCostToResearch(2700);
        miscTechs.add(tech_kamikaze);
    }
    public static ExtendedSpaceJump tech_extendedSpaceJump = new ExtendedSpaceJump();
    static {
    	tech_extendedSpaceJump.setName("Extended Space Jump");
    	tech_extendedSpaceJump.setCostToBuild(0);
    	tech_extendedSpaceJump.setCostToResearch(2700);
        miscTechs.add(tech_extendedSpaceJump);
    }
    public static AsteroidFieldConstruction tech_asteroidFieldConstruction = new AsteroidFieldConstruction();
    static {
        tech_asteroidFieldConstruction.setName("Asteroid Field Construction");
        tech_asteroidFieldConstruction.setCostToBuild(1500);
        tech_asteroidFieldConstruction.setCostToResearch(2800);
        miscTechs.add(tech_asteroidFieldConstruction);
    }
    public static PlanetConstruction tech_planetConstruction = new PlanetConstruction();
    static {
    	tech_planetConstruction.setName(TestTechs.MISC_PLANET_CONSTRUCTION);
    	tech_planetConstruction.setCostToBuild(9000);
    	tech_planetConstruction.setCostToResearch(4000);
    	tech_planetConstruction.setPlanetSize(110);
    	tech_planetConstruction.setPlanetTerraform(0.7);
    	tech_planetConstruction.setPlanetProductionBonus(0.5);
    	tech_planetConstruction.setPlanetReproductionBonus(0.5);
    	tech_planetConstruction.setPlanetResearchBonus(0.5);
        miscTechs.add(tech_planetConstruction);
    }
    public static StationMissileBase tech_stationMissileBase = new StationMissileBase();
    static {
    	tech_stationMissileBase.setName("Station Missile Base");
    	tech_stationMissileBase.setQtyMissiles(2);
    	tech_stationMissileBase.setCostToBuild(1);
    	tech_stationMissileBase.setCostToResearch(100);
        miscTechs.add(tech_stationMissileBase);
    }
    public static GalacticLore tech_galacticLore = new GalacticLore();
    static {
    	tech_galacticLore.setName("Galactic Lore");
    	tech_galacticLore.setQtyGalacticLore(1);
    	tech_galacticLore.setCostToBuild(1);
    	tech_galacticLore.setCostToResearch(100);
        miscTechs.add(tech_galacticLore);
    }
    
    public static final String TEST_MORAL_CHOICE = "TestMoralChoice";
    public static MoralChoice mc_testMoralChoice = new MoralChoice();
    static {
    	mc_testMoralChoice.setName(TEST_MORAL_CHOICE);
    	mc_testMoralChoice.setProductionBonus(new Double(0.1));
    	mc_testMoralChoice.setInfluenceBonus(new Double(0.2));
    	mc_testMoralChoice.setRelationsBonus(new Integer(-20));
    	mc_testMoralChoice.setDamageBonus(new Double(0.3));
    	moralChoices.add(mc_testMoralChoice);
    }
    
	
    public static Theory tech_researchLabI = new Theory();
    static {
        tech_researchLabI.setName(TestTechs.RESEARCH_LABI);
        tech_researchLabI.setCostToResearch(100);
        tech_researchLabI.setRestriction(new MinCostRestriction(99));
        tech_researchLabI.setForbidEspionage(true);
        theories.add(tech_researchLabI);
    }
    public static Theory tech_researchLabII = new Theory();
    static {
        tech_researchLabII.setName(TestTechs.RESEARCH_LABII);
        tech_researchLabII.setCostToResearch(500);
        tech_researchLabII.setForbidEspionage(true);
        theories.add(tech_researchLabII);
    }
    public static Theory tech_researchLabIII = new Theory();
    static {
        tech_researchLabIII.setName(TestTechs.RESEARCH_LABIII);
        tech_researchLabIII.setCostToResearch(2000);
        tech_researchLabIII.setForbidEspionage(true);
        theories.add(tech_researchLabIII);
    }
    
    
    protected void setupOneTierTechTree() throws ApplicationError {
        TechnologyTree tree = new TechnologyTree();
    	setupTreeNodeWithTechsToResearch(tree, null);
        TechnologyTree.setInstance(tree);
    }
    
    protected void setupTwoTierTechTree() throws ApplicationError {
        TechnologyTree tree = new TechnologyTree();
        tree.setNode(new TechnologyTreeNode(tech_massDriver1));
        tree.setNode(new TechnologyTreeNode(tech_flyer30));
        tree.setNode(new TechnologyTreeNode(tech_flyer60));
        tree.setNode(new TechnologyTreeNode(tech_researchLabI));
    	setupTreeNodeWithTechsToResearch(tree, new GeneralTechnologyList(tech_researchLabI));
        TechnologyTree.setInstance(tree);
    }
    
    protected void setupTreeNodeWithTechsToResearch(TechnologyTree tree, TechnologyList parents) throws ApplicationError {
        tree.setNode(new TechnologyTreeNode(tech_massDriver2, parents) );
        tree.setNode(new TechnologyTreeNode(tech_fusionBeam4, parents));
        tree.setNode(new TechnologyTreeNode(tech_fusion25, parents));
        tree.setNode(new TechnologyTreeNode(tech_fusion25x, parents));
        tree.setNode(new TechnologyTreeNode(tech_armour25, parents));
        tree.setNode(new TechnologyTreeNode(tech_troopModule20, parents));
        tree.setNode(new TechnologyTreeNode(tech_photon100, parents));
        tree.setNode(new TechnologyTreeNode(tech_electronic25, parents));
        tree.setNode(new TechnologyTreeNode(tech_flyer100, parents));
        tree.setNode(new TechnologyTreeNode(tech_energy10, parents));
        tree.setNode(new TechnologyTreeNode(tech_computerisedFactoryII, parents));
        tree.setNode(new TechnologyTreeNode(tech_ComputerisedLabI, parents));
        tree.setNode(new TechnologyTreeNode(tech_mineField, parents));
        tree.setNode(new TechnologyTreeNode(tech_trade_route, parents));
    }

    protected void addTierToTechTree() throws ApplicationError {
    	TechnologyTree tree = TechnologyTree.getInstance();
    	tree.setNode(new TechnologyTreeNode(tech_girator, new GeneralTechnologyList(tech_fusionBeam4)));
    	tree.setNode(new TechnologyTreeNode(tech_mindControl, new GeneralTechnologyList(tech_fusionBeam4)));
    }
    
    protected void setupThreeTierTechTree() throws ApplicationError {
        TechnologyTree tree = new TechnologyTree();
        tree.setNode(new TechnologyTreeNode(tech_massDriver1));
        tree.setNode(new TechnologyTreeNode(tech_flyer30));
        tree.setNode(new TechnologyTreeNode(tech_flyer60));
        tree.setNode(new TechnologyTreeNode(tech_researchLabI));
    	GeneralTechnologyList parent1 = new GeneralTechnologyList(tech_researchLabI);
        tree.setNode(new TechnologyTreeNode(tech_massDriver2, parent1) );
        tree.setNode(new TechnologyTreeNode(tech_fusionBeam4, parent1));
        tree.setNode(new TechnologyTreeNode(tech_fusion25, parent1));
        tree.setNode(new TechnologyTreeNode(tech_fusion25x, parent1));
        tree.setNode(new TechnologyTreeNode(tech_researchLabII));
    	GeneralTechnologyList parent2 = new GeneralTechnologyList(tech_researchLabII);
        tree.setNode(new TechnologyTreeNode(tech_armour25, parent2));
        tree.setNode(new TechnologyTreeNode(tech_troopModule20, parent2));
        TechnologyTree.setInstance(tree);
    }

    
    protected void setupFourTierTechTree_As_Per_Tech_Tree() throws ApplicationError {
        TechnologyTree tree = new TechnologyTree();
        tree.setNode(new TechnologyTreeNode(tech_massDriver1));
        tree.setNode(new TechnologyTreeNode(tech_flyer30));
        tree.setNode(new TechnologyTreeNode(tech_flyer60));
        tree.setNode(new TechnologyTreeNode(tech_researchLabI));
        GeneralTechnologyList parent1 = new GeneralTechnologyList(tech_researchLabI);
        tree.setNode(new TechnologyTreeNode(tech_missile6, parent1) );
        tree.setNode(new TechnologyTreeNode(tech_massDriver2, parent1) );
        tree.setNode(new TechnologyTreeNode(tech_fusionBeam4, parent1));
        tree.setNode(new TechnologyTreeNode(tech_fusion25, parent1));
        tree.setNode(new TechnologyTreeNode(tech_photon100, parent1));
        tree.setNode(new TechnologyTreeNode(tech_electronic25, parent1));
        tree.setNode(new TechnologyTreeNode(tech_researchLabII, parent1, new TechnologyTreeConditionPercentage(tech_researchLabI, 0.7)));
    	GeneralTechnologyList parent2 = new GeneralTechnologyList(tech_researchLabII);
        tree.setNode(new TechnologyTreeNode(tech_missile15, parent2) );
    	tree.setNode(new TechnologyTreeNode(tech_fusion25x, parent2));
        tree.setNode(new TechnologyTreeNode(tech_armour25, parent2));
        tree.setNode(new TechnologyTreeNode(tech_photon150, parent2));
        tree.setNode(new TechnologyTreeNode(tech_electronic40, parent2));
        tree.setNode(new TechnologyTreeNode(tech_troopModule20, parent2));
        tree.setNode(new TechnologyTreeNode(tech_researchLabIII, parent2, new TechnologyTreeConditionPercentage(tech_researchLabII, 0.7)));
    	GeneralTechnologyList parent3 = new GeneralTechnologyList(tech_researchLabIII);
    	tree.setNode(new TechnologyTreeNode(tech_fusion40, parent3));
        tree.setNode(new TechnologyTreeNode(tech_armour200, parent3));
        tree.setNode(new TechnologyTreeNode(tech_photon400, parent3));
        TechnologyTree.setInstance(tree);
    }

}
