/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.test.demo;

import java.io.File;

import javax.sound.midi.MetaEventListener;
import javax.sound.midi.MetaMessage;
import javax.sound.midi.MidiChannel;
import javax.sound.midi.MidiSystem;
import javax.sound.midi.Sequencer;
import javax.sound.midi.Synthesizer;
import javax.sound.sampled.AudioFormat;
import javax.sound.sampled.AudioInputStream;
import javax.sound.sampled.AudioSystem;
import javax.sound.sampled.Clip;
import javax.sound.sampled.DataLine;
import javax.sound.sampled.FloatControl;
import javax.sound.sampled.LineEvent;
import javax.sound.sampled.LineListener;

public class SoundDemo {
	
	private Clip clip;
	
	public static void main(String[] args) throws Exception {
		new SoundDemo().playWav();
		//new SoundDemo().playMidi();
		//new MidiDemo().play();
//		JukeBox.getInstance().start();
//		Thread.sleep(4000);
//		JukeBox.getInstance().setVolume(0.1);
//		Thread.sleep(8000);
	}
	
	public void playWav() throws Exception {
        //URL url = new URL("file:/E:/dev/emot/sounds/craft_move.mp3");
        //AudioClip ac = Applet.newAudioClip(url);
        //ac.play();
		File file = new File("sounds/WeaponFire_Girator.wav");
		AudioInputStream stream = AudioSystem.getAudioInputStream(file);
		AudioFormat format = stream.getFormat();
		DataLine.Info info = new DataLine.Info(Clip.class, format);
		clip = (Clip) AudioSystem.getLine(info);
		clip.open(stream);
		System.out.println("START");
		clip.start();
		LineListener listener = new LineListener() {
			public void update(LineEvent event) {
				if (event.getType() == LineEvent.Type.STOP) {
					clip.setMicrosecondPosition(0);
					System.out.println("RESTART");
					clip.start();
				}
			}
		};
        Thread.sleep(1000);
        FloatControl control = (FloatControl) clip.getControl(FloatControl.Type.VOLUME);
        control.setValue(1.0f);
		clip.addLineListener(listener);
        Thread.sleep(80000);
    }
	
	public static final int VOLUME_CONTROL = 7;
	Sequencer sequencer;
	
	public void playMidi() throws Exception {
		File file = new File("sounds/xfiles.mid");
	    sequencer = MidiSystem.getSequencer();
	    sequencer.setSequence(MidiSystem.getSequence(file));
	    MetaEventListener listener = new MetaEventListener() {
			public void meta(MetaMessage meta) {
				int type = meta.getType();
				System.out.println("MSG TYPE "+type);
				if (type == 47) {
					sequencer.setMicrosecondPosition(0);
					System.out.println("RESTART");
					sequencer.start();
				}
			}
		};
	    sequencer.open();
	    sequencer.start();
		sequencer.addMetaEventListener(listener);
        Thread.sleep(90000);
    }

}

class MidiDemo {
	/** The midi sequencer */
    private Sequencer sequencer = null;
    
    /** The synthesizer (for volume control) */
    private Synthesizer synthesizer = null;
 
    /** 
     * Default constructor.
     * @throws Exception 
     * @since 1.0
     */
    public MidiDemo() throws Exception {
		System.out.println("START");
    	// JDK 1.4 needs true, JDK 5 needs false!
        sequencer = MidiSystem.getSequencer(false);
        // get the system synthesizer
        synthesizer = MidiSystem.getSynthesizer();
        // open the sequencer
        sequencer.open();
        // open the synthesizer
        synthesizer.open();
        // link the sequencer to the synthesizer
        sequencer.getTransmitter().setReceiver(synthesizer.getReceiver());

        // set this class to list for meta events
        // (end of track event in particular)
        MetaEventListener listener = new MetaEventListener() {
			public void meta(MetaMessage meta) {
				int type = meta.getType();
				//System.out.println("MSG TYPE "+type);
				if (type == 47) {
					sequencer.setMicrosecondPosition(0);
					System.out.println("RESTART");
					sequencer.start();
				}
			}
		};
        sequencer.addMetaEventListener(listener);
    }
 
	public void play() throws Exception {
		File file = new File("sounds/xfiles.mid");
    	//setGain(1);
	    sequencer.setSequence(MidiSystem.getSequence(file));
    	setGain(1);
    	sequencer.start();
    	setGain(1);
	}

	public void setGain(int volume) throws Exception {
//		MidiChannel[] channels = synthesizer.getChannels();
//		for (int i = 0; i < channels.length; i++) {
//			channels[i].controlChange(7, (int) (127 * (this.gain / 100.0)));
//		}
		
//		Synthesizer synthesizer = (Synthesizer)sequencer;
        MidiChannel[] channels = synthesizer.getChannels();
    
        for (int i=0; i<channels.length; i++) {
            channels[i].controlChange(7, 10);
            //channels[i].setChannelPressure(1);
        }
	}
}
