/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.test.demo;

import java.awt.DisplayMode;
import java.awt.FlowLayout;
import java.awt.Frame;
import java.awt.GraphicsDevice;
import java.awt.GraphicsEnvironment;
import java.awt.event.WindowEvent;
import java.awt.event.WindowListener;

import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JPanel;

import mot.client.swing.window.galaxy.GalaxyMapPanel;
import mot.common.util.ApplicationError;

public class ToolTipBugDemo extends JFrame implements WindowListener {

    private ToolTipBugDemo(boolean fullScreen) throws ApplicationError {
        super("Tool Tip Bug Demo");
		getContentPane().add( new GalaxyMapPanel(null, false, false));
		if (fullScreen) {
	        GraphicsDevice device = GraphicsEnvironment.getLocalGraphicsEnvironment().getDefaultScreenDevice();
            setExtendedState(Frame.MAXIMIZED_BOTH);
	       	setSize(640, 480);
            device.setFullScreenWindow(this);
            if (device.isDisplayChangeSupported()) {
            	DisplayMode mode = new DisplayMode(640, 480, 16, DisplayMode.REFRESH_RATE_UNKNOWN);
                device.setDisplayMode(mode);
            }
            //createBufferStrategy(2);
		}
		
		JPanel buttonPanel = new JPanel();
		buttonPanel.setLayout(new FlowLayout(1, 200, 100));
        JButton button1 = new JButton("Button1");
        button1.setToolTipText("Small Tip");
        buttonPanel.add(button1);
        JButton button2 = new JButton("Button2");
        button2.setToolTipText("Large tip with lots of text and descriptions of this button that does nothing but display a tool tip");
        buttonPanel.add(button2);
        add(buttonPanel);
		
        setVisible(true);
        repaint();
    }
    
	public static void main(String[] args) throws Exception {
        new ToolTipBugDemo(args == null || args.length == 0);
	}

	public void windowActivated(WindowEvent e) {}
	public void windowClosed(WindowEvent e) { System.exit(0); }
	public void windowClosing(WindowEvent e) { }
	public void windowDeactivated(WindowEvent e) { }
	public void windowDeiconified(WindowEvent e) { }
	public void windowIconified(WindowEvent e) { }
	public void windowOpened(WindowEvent e) { }

}