/*
 * Copyright (c) 2013-2019 Paul Davis
 *  
 * This file is part of Master of Tactics.
 *
 * Master of Tactics is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Master of Tactics is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Master of Tactics.  If not, see <https://www.gnu.org/licenses/>.
 * 
 * @author Paul Davis
 */
package mot.common.morals;

import mot.common.bean.NamedObject;
import mot.common.xml.DomNode;

/**
 * Through the game the player gets to make moral choices about the
 * way he / she / it runs the empire. For example exploitation of your
 * people will increase production but decrease influence. The moral
 * choices leaders make also effect the way other players relate to them.
 * 
 * This is a base class for all types of moral choices.
 */
public class MoralChoice extends NamedObject implements Cloneable {

    /**
     * The description of this piece of technology.
     * This is optional for all tech types but can be useful to display to user about this
     * technology.
     */
    private String description;
    
    private Double productionBonus;
    private Double influenceBonus;
    private Double damageBonus;
    private Integer relationsBonus;
    
    public MoralChoice() {
	}

    public MoralChoice(DomNode n) {
    	super(n.getNodeValueByName_String("name"));
    	description = n.getNodeValueByName_String("description");
        productionBonus = n.getNodeValueByName_Double("production-bonus");
        influenceBonus = n.getNodeValueByName_Double("influence-bonus");
        damageBonus = n.getNodeValueByName_Double("damage-bonus");
        relationsBonus = n.getNodeValueByName_Integer("relations-bonus");
	}

	public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

	protected String getElementName() {
		return "moral-choice";
	}

	
	public Double getProductionBonus() {
		return productionBonus;
	}

	public Double getInfluenceBonus() {
		return influenceBonus;
	}

	public void setInfluenceBonus(Double influenceBonus) {
		this.influenceBonus = influenceBonus;
	}

	public Integer getRelationsBonus() {
		return relationsBonus;
	}

	public void setRelationsBonus(Integer relationsBonus) {
		this.relationsBonus = relationsBonus;
	}

	public void setProductionBonus(Double productionBonus) {
		this.productionBonus = productionBonus;
	}

	public Double getDamageBonus() {
		return damageBonus;
	}

	public void setDamageBonus(Double damageBonus) {
		this.damageBonus = damageBonus;
	}
}
